<?php

/**
 * @file
 * Chemical taxonomy.
 */

/**
 * Get chemical  data.
 */
function chemical_taxonomy_get_chemical_data() {
  $chemical_list = array(
    array(
      'tid' => 0,
      'name' => "Organic compounds",
      'description' => "Compounds that contain at least carbon atom, excluding isocyanide/cyanide and their non-hydrocarbyl derivatives, thiophosgene, carbon diselenide, carbon monosulfide, carbon disulfide, carbon subsulfide, carbon monoxide, carbon trioxide, Carbon suboxide, and dicarbon monoxide.",
      'parent' => -1,
    ),
    array(
      'tid' => 1,
      'name' => "Inorganic compounds",
      'description' => "Compounds that do not contain a C atom.",
      'parent' => -1,
    ),
    array(
      'tid' => 2,
      'name' => "Organoheterocyclic compounds",
      'description' => "Compounds containing a ring with least one carbon atom and one non-carbon atom.",
      'parent' => 0,
    ),
    array(
      'tid' => 3,
      'name' => "Thiepanes",
      'description' => "Organic compounds containing a heptane ring in which one carbon atom is replaced by a sulfur atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 4,
      'name' => "Organosulfur compounds",
      'description' => "Organic compounds containing a carbon-sulfur bond.",
      'parent' => 0,
    ),
    array(
      'tid' => 5,
      'name' => "Pyrroloquinoline quinones",
      'description' => "Compounds with a structure based on the 2,7,-tricarboxy-1H-pyrrolo[2,3-f ]quinoline-4,5-dione. Pyrroloquinoline Quinones usually bear a carboxylic acid group at the C-2, C-7 and C-9 positions.",
      'parent' => 1734,
    ),
    array(
      'tid' => 6,
      'name' => "Benzoxazolines",
      'description' => "Organic compounds containing a benzene ring fused to an oxazoline ring. Oxazoline is five-membered unsaturated ring with a nitrogen atom and an oxygen atom at the 1- and 3-position, respectively. Additionally, it contains two double bonds.",
      'parent' => 2,
    ),
    array(
      'tid' => 7,
      'name' => "Amidines",
      'description' => "Derivatives of oxoacids RnE(=O)OH in which the hydroxy group is replaced by an amino group and the oxo group is replaced by =NR. Amidines include carboxamidines, sulfinamidines and phosphinamidines.",
      'parent' => 278,
    ),
    array(
      'tid' => 8,
      'name' => "Cembrane diterpenoids",
      'description' => "Diterpenoids with a structure based a cembrane skeleton, which is characterized by the presence of an isopropyl group at C-1 and by three symmetrically disposed methyl groups a the t C-4, -8 and -12 positions.",
      'parent' => 1551,
    ),
    array(
      'tid' => 9,
      'name' => "Sulfines",
      'description' => "S-Oxides of thioaldehydes and thioketones.",
      'parent' => 4,
    ),
    array(
      'tid' => 10,
      'name' => "Sulfenes",
      'description' => "S,S-Dioxides of thioaldehydes and thioketones, R2C=SO2.",
      'parent' => 4,
    ),
    array(
      'tid' => 11,
      'name' => "Carbohydrates and carbohydrate conjugates",
      'description' => "Monosaccharides, disaccharides, oligosaccharides, polysaccharides, and their derivatives.",
      'parent' => 323,
    ),
    array(
      'tid' => 12,
      'name' => "Lipids and lipid-like molecules",
      'description' => "Fatty acids and their derivatives, and substances related biosynthetically or functionally to these compounds.",
      'parent' => 0,
    ),
    array(
      'tid' => 13,
      'name' => "Amino acids, peptides, and analogues",
      'description' => "Organic compounds containing an amino acid or a peptide backbone, or derivatives thereof.",
      'parent' => 265,
    ),
    array(
      'tid' => 14,
      'name' => "Phenylbutylamines",
      'description' => "Compounds containing a phenylbutylamine moiety, which consists of a phenyl group substituted at the fourth carbon by an butan-1-amine.",
      'parent' => 2279,
    ),
    array(
      'tid' => 15,
      'name' => "Dibenzofurans",
      'description' => "Compounds containing a dibenzofuran moiety, which consists of two benzene rings fused to a central furan ring.",
      'parent' => 301,
    ),
    array(
      'tid' => 16,
      'name' => "Allenes",
      'description' => "Compounds in which one carbon atom has double bonds with each of its two adjacent carbon centers. The definition includes both the hydrocarbon molecules and their derivatives obtained by substitution.",
      'parent' => 0,
    ),
    array(
      'tid' => 17,
      'name' => "Cycloalkenes",
      'description' => "Unsaturated monocyclic hydrocarbons having one endocyclic double bond.",
      'parent' => 2840,
    ),
    array(
      'tid' => 18,
      'name' => "Anthracenes",
      'description' => "Organic compounds containing a system of three linearly fused benzene rings.",
      'parent' => 2448,
    ),
    array(
      'tid' => 19,
      'name' => "Dibenzocycloheptenes",
      'description' => "Compounds containing a dibenzocycloheptene moiety, which consists of two benzene rings connected by a cycloheptene ring.",
      'parent' => 2448,
    ),
    array(
      'tid' => 20,
      'name' => "Fluorenes",
      'description' => "Compounds containing a fluorene moiety, which consists of two benzene rings connected through either a cyclopentane, cyclopentene, or cyclopenta-1,3-diene.",
      'parent' => 2448,
    ),
    array(
      'tid' => 21,
      'name' => "Indenes and isoindenes",
      'description' => "Compounds containing an indene moiety(which consists of a cyclopentadiene fused to a benzene ring), or a isoindene moiety (which consists of a cyclopentadiene fused to cyclohexadiene ring).",
      'parent' => 2448,
    ),
    array(
      'tid' => 22,
      'name' => "Naphthacenes",
      'description' => "Compounds containing a naphthacene moiety, which is a polyaromatic hydrocarbon made of four linearly fused benzene rings.",
      'parent' => 2448,
    ),
    array(
      'tid' => 23,
      'name' => "Naphthalenes",
      'description' => "Compounds containing a naphthalene moiety, which consists of two fused benzene rings.",
      'parent' => 2448,
    ),
    array(
      'tid' => 24,
      'name' => "Pentacenes",
      'description' => "Compounds containing a pentacene moiety, which is consists of five linearly fused benzene rings.",
      'parent' => 2448,
    ),
    array(
      'tid' => 25,
      'name' => "Phenanthrenes and derivatives",
      'description' => "Polycyclic compounds containing a phenanthrene moiety, which is a tricyclic aromatic compound with three non-linearly fused benzene.",
      'parent' => 2448,
    ),
    array(
      'tid' => 26,
      'name' => "Purine ribonucleoside bisphosphates",
      'description' => "Purine Ribonucleotides in which the ribose sugar esterified with one phosphate group attached to each of two different hydroxy groups on the sugar, usually at positions 2', 3', or 5'.",
      'parent' => 1544,
    ),
    array(
      'tid' => 27,
      'name' => "Indanes",
      'description' => "Compounds containing an indane moiety, which consists of a cyclopentane fused to a benzene ring.",
      'parent' => 2448,
    ),
    array(
      'tid' => 28,
      'name' => "Pyridoxals and derivatives",
      'description' => "Compounds containing a pyridoxal moiety, which consists of a pyridine ring substituted at positions 2,3,4, and 5 by a methyl group, a hydroxyl group, a carbaldehyde group, and a hydroxymethyl group, respectively.",
      'parent' => 2212,
    ),
    array(
      'tid' => 29,
      'name' => "Cinnamaldehydes",
      'description' => "Organic aromatic compounds containing a cinnamlaldehyde moiety, consisting of a benzene and an aldehyde group to form 3-phenylprop-2-enal.",
      'parent' => 261,
    ),
    array(
      'tid' => 30,
      'name' => "Hydroxyeicosatrienoic acids",
      'description' => "Eicosanoic acids with an attached hydroxyl group and three CC double bonds.",
      'parent' => 513,
    ),
    array(
      'tid' => 31,
      'name' => "Benzenesulfonamides",
      'description' => "Organic compounds containing a sulfonamide group that is S-linked to a benzene ring.",
      'parent' => 2279,
    ),
    array(
      'tid' => 32,
      'name' => "Benzenesulfonic acids and derivatives",
      'description' => "Organic compounds containing a sulfonic acid or a derivative thereof that is linked to a benzene ring.",
      'parent' => 2279,
    ),
    array(
      'tid' => 33,
      'name' => "Benzyl alcohols",
      'description' => "Organic compounds containing the phenylmethanol substructure.",
      'parent' => 2279,
    ),
    array(
      'tid' => 34,
      'name' => "Sulfobenzoic acids",
      'description' => "Benzoic acids carrying a sulfonyl group on the benzene ring.",
      'parent' => 32,
    ),
    array(
      'tid' => 35,
      'name' => "Halobenzenes",
      'description' => "Aromatic compounds containing a halogen atom linked to a benzene ring.",
      'parent' => 2279,
    ),
    array(
      'tid' => 36,
      'name' => "Nitrobenzenes",
      'description' => "Compounds containing a nitrobenzene moiety, which consists of a benzene ring with a carbon bearing a nitro group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 37,
      'name' => "Styrenes",
      'description' => "Organic compounds containing an ethenylbenzene moiety.",
      'parent' => 2279,
    ),
    array(
      'tid' => 38,
      'name' => "Sulfanilides",
      'description' => "Organic aromatic compounds containing a sulfanilide moiety, with the general structure RS(=O)(=O)NC1=CC=CC=C1.",
      'parent' => 2279,
    ),
    array(
      'tid' => 39,
      'name' => "Sulfamic acid derivatives",
      'description' => "Organic compounds containing a sulfamic acid moiety or a derivative, with the general structure R1N(R2)S(=O)2OR3  (R1,R2,R3=H, alkyl, aryl).",
      'parent' => 264,
    ),
    array(
      'tid' => 40,
      'name' => "Indanediones",
      'description' => "Compounds containing an indane ring bearing two ketone groups.",
      'parent' => 1151,
    ),
    array(
      'tid' => 41,
      'name' => "Biphenyls and derivatives",
      'description' => "Organic compounds containing to benzene rings linked together by a C-C bond.",
      'parent' => 2279,
    ),
    array(
      'tid' => 42,
      'name' => "Diphenhydramines",
      'description' => "Cyclic aromatic compounds containing a diphenhydramine moiety, which consists of a diphenylmethoxyl group like to an ethyldimethylamine to form [2-(diphenylmethoxy)ethyl]dimethylamine.",
      'parent' => 2279,
    ),
    array(
      'tid' => 43,
      'name' => "Biphenylbenzimidazoles",
      'description' => "Organic compounds containing a biphenyl attached to a benzimidazole. A carbon atom of the biphenyl moiety is boned to a carbon or the nitrogen atom of the benzimidazole moiety.",
      'parent' => 330,
    ),
    array(
      'tid' => 44,
      'name' => "Biphenyltetrazoles and derivatives",
      'description' => "Organic compounds containing a biphenyl attached to a tetrazole. A carbon atom of the biphenyl moiety is boned to a carbon or the nitrogen atom of the tetrazole moiety.",
      'parent' => 306,
    ),
    array(
      'tid' => 45,
      'name' => "Phenylpropenes",
      'description' => "Compounds containing a phenylpropene moiety, which consists of a propene substituent bound to a phenyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 46,
      'name' => "Hydroxyeicosatetraenoic acids",
      'description' => "Eicosanoic acids with an attached hydroxyl group and four CC double bonds.",
      'parent' => 513,
    ),
    array(
      'tid' => 47,
      'name' => "Podophyllotoxins",
      'description' => "Tetralin lignans in which the benzene moiety of the tetralin skeleton is fused to a 1,3-dioxolane and the cyclohexane is fused to a butyrolactone (pyrrolidin-2-one).",
      'parent' => 1510,
    ),
    array(
      'tid' => 48,
      'name' => "Tetralins",
      'description' => "Polycyclic aromatic compounds containing a tetralin moiety, which consists of a benzene fused to a cyclohexane.",
      'parent' => 2448,
    ),
    array(
      'tid' => 49,
      'name' => "Tametralines",
      'description' => "Compounds containing a tametraline moiety, which consists of a tetrahydronaphthalene linked to a phenyl group to form N-methyl-4-phenyl-1,2,3,4-tetrahydronaphthalen-1-amine skeleton.",
      'parent' => 48,
    ),
    array(
      'tid' => 50,
      'name' => "Lactones",
      'description' => "Cyclic esters of hydroxy carboxylic acids, containing a 1-oxacycloalkan-2-one structure, or analogues having unsaturation or heteroatoms replacing one or more carbon atoms of the ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 51,
      'name' => "Aromatic monoterpenoids",
      'description' => "Monoterpenoids containing at least one aromatic ring.",
      'parent' => 1549,
    ),
    array(
      'tid' => 52,
      'name' => "Brominated biphenyls",
      'description' => "Organic compounds containing a biphenyl moiety substituted at one or more positions by a bromine atom.",
      'parent' => 41,
    ),
    array(
      'tid' => 53,
      'name' => "Aminoquinolines and derivatives",
      'description' => "Organic compounds containing an amino group attached to a quinoline ring system.",
      'parent' => 1253,
    ),
    array(
      'tid' => 54,
      'name' => "Benzylisoquinolines",
      'description' => "Organic compounds containing an isoquinoline to which a benzyl group is attached.",
      'parent' => 2566,
    ),
    array(
      'tid' => 55,
      'name' => "Dibenzothiazepines",
      'description' => "Compounds containing a dibenzothiazepine moiety, which consists of two benzene connected by a thiazepine ring.",
      'parent' => 317,
    ),
    array(
      'tid' => 56,
      'name' => "Quinolones and derivatives",
      'description' => "Compounds containing a quinoline moiety which bears a ketone group.",
      'parent' => 1253,
    ),
    array(
      'tid' => 57,
      'name' => "Hydroxyquinolines",
      'description' => "Compounds containing a quinoline moiety bearing a hydroxyl group.",
      'parent' => 1253,
    ),
    array(
      'tid' => 58,
      'name' => "Morphinans",
      'description' => "Polycyclic compounds with a four-ring skeleton with three condensed six-member rings forming a partially hydrogenated phenanthrene moiety, one of which is aromatic while the two others are alicyclic.",
      'parent' => 279,
    ),
    array(
      'tid' => 59,
      'name' => "Coumaric acids and derivatives",
      'description' => "Aromatic compounds containing Aromatic compounds containing a cinnamic acid moiety (or a derivative thereof) hydroxylated at the C2 (ortho-), C3 (meta-), or C4 (para-) carbon atom of the benzene ring.",
      'parent' => 1391,
    ),
    array(
      'tid' => 60,
      'name' => "Alpha amino acids and derivatives",
      'description' => "Amino acids in which the amino group is attached to the carbon atom immediately adjacent to the carboxylate group (alpha carbon), or a derivative thereof.",
      'parent' => 347,
    ),
    array(
      'tid' => 61,
      'name' => "Indoloquinolines",
      'description' => "Polycyclic aromatic compounds containing an indole fused to a quinoline.",
      'parent' => 1253,
    ),
    array(
      'tid' => 62,
      'name' => "2-sulfobenzoic acids",
      'description' => "Sulfobenzoic acid carrying the sulfonyl group at the 2-position of the benzene group.",
      'parent' => 34,
    ),
    array(
      'tid' => 63,
      'name' => "Nitrate esters",
      'description' => "Compounds containing a nitrate ester functional group, with the general structure RON+(=O)O, (R cannot be a hydrogen).",
      'parent' => 488,
    ),
    array(
      'tid' => 64,
      'name' => "Macrolactams",
      'description' => "Cyclic amides of amino carboxylic acids, having a 1-azacycloalkan-2-one structure, or analogues having unsaturation or heteroatoms replacing one or more carbon atoms of the ring.  They are nitrogen analogues (the a nitrogen atom replacing the o atom of the cyclic carboxylic acid group ) of the naturally occurring macrolides.",
      'parent' => 261,
    ),
    array(
      'tid' => 65,
      'name' => "Arsoles",
      'description' => "Organic compounds containing an arsacyclopentadiene ring (a five member ring with one arsenic atom, four carbon atoms, and two double bonds).",
      'parent' => 2052,
    ),
    array(
      'tid' => 66,
      'name' => "Oxazepines",
      'description' => "Compounds containing an oxazepine moiety, which consists of an unsaturated aliphatic seven-member ring with one oxygen atom, a nitrogen atom, and five carbon atoms. Isomers  of oxazepine include 1,2-oxazepine, 1,3-oxazepine,and 1,4-oxazepine.",
      'parent' => 2,
    ),
    array(
      'tid' => 67,
      'name' => "Pyrazines",
      'description' => "Compounds containing a pyrazine ring, which is a six-member aromatic heterocycle, that consists of two nitrogen atoms (at positions 1 and 4) and four carbon atoms.",
      'parent' => 1346,
    ),
    array(
      'tid' => 68,
      'name' => "Thiazepines",
      'description' => "Heterocyclic compounds containing a seven-member aromatic ring with five carbon atoms, one sulfur atom, and one nitrogen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 69,
      'name' => "Azepines",
      'description' => "Organic compounds containing an unsaturated seven-member heterocycle with one nitrogen atom replacing a carbon atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 70,
      'name' => "Oxetanes",
      'description' => "Compounds containing an oxetane ring, which is a four-member saturated aliphatic ring with an oxygen, and three carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 71,
      'name' => "Diazepines",
      'description' => "Organic compounds containing a seven-member heterocyclic moiety with five nitrogen atoms, and two nitrogen atoms at positions 1 and 2 (1,2-Diazepines), 1 and 3 (1,3-Diazepines), or 1 and 4 (1,4-Diazepines).",
      'parent' => 2,
    ),
    array(
      'tid' => 72,
      'name' => "Dibenzodiazepines",
      'description' => "Compounds containing a dibenzodiazepine moiety, which consists of two benzene connected by diazepine ring.",
      'parent' => 295,
    ),
    array(
      'tid' => 73,
      'name' => "Oxetenes",
      'description' => "Compounds containing an oxetene ring, which is a four-member unsaturated aliphatic ring with an oxygen, three carbon atoms, and one CC double bond.",
      'parent' => 2,
    ),
    array(
      'tid' => 74,
      'name' => "Pyridazines and derivatives",
      'description' => "Compounds containing a pyridazine ring, which is a six-member aromatic ring containing two nitrogen atoms at positions 1 and 2, and four carbon atoms.",
      'parent' => 1346,
    ),
    array(
      'tid' => 75,
      'name' => "Pyrimidines and pyrimidine derivatives",
      'description' => "Compounds containing a pyrimidne ring, which is a six-member aromatic heterocycle which consists of two nitrogen atoms (at positions 1 and 3) and four carbon atoms.",
      'parent' => 1346,
    ),
    array(
      'tid' => 76,
      'name' => "Furans",
      'description' => "Compounds containing a furan ring, which is a five-member aromatic ring with one oxygen atom, four carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 77,
      'name' => "Thiosalicylic acids and derivatives",
      'description' => "Compounds containing a benzene ring which bears a carboxyl group (or a derivative thereof) and a sulfhydryl functional group at positions 1 and 2, respectively.",
      'parent' => 2086,
    ),
    array(
      'tid' => 78,
      'name' => "Imidazoles",
      'description' => "Compounds containing an imidazole ring, which is an aromatic five-member ring with two nitrogen atoms at positions 1 and 3, and three carbon atoms.",
      'parent' => 436,
    ),
    array(
      'tid' => 79,
      'name' => "Imidazolines",
      'description' => "Organic compounds containing an imidazoline ring, which is an unsaturated ring (derived from imidazole) with two nitrogen atoms at positions 1 and 3 respectively, and containing only one CN double bond.",
      'parent' => 2490,
    ),
    array(
      'tid' => 80,
      'name' => "Indazoles",
      'description' => "Compounds containing an indazole, which is structurally characterized by a pyrazole fused to a benzene.",
      'parent' => 1629,
    ),
    array(
      'tid' => 81,
      'name' => "Isoxazoles",
      'description' => "Heterocyclic organic compounds containing an isoxazole moiety, with a structure characterized by a five-member aromatic ring with one oxygen atom and one nitrogen atom at ring positions 1 and 2, respectively.",
      'parent' => 436,
    ),
    array(
      'tid' => 82,
      'name' => "Oxazines",
      'description' => "Compounds containing an oxazine moiety, which consists of an unsaturated aliphatic six-member ring with one oxygen atom, a nitrogen atom, four carbon atoms, and two double bonds. Isomers  of oxaphospholane include 1,2-oxazine, 1,3-oxazine, and 1,4-oxazine.",
      'parent' => 2,
    ),
    array(
      'tid' => 83,
      'name' => "Oxazoles",
      'description' => "Compounds containing an oxazole ring, which is a five-membered aromatic heterocycle with one  oxygen, one nitrogen, and three carbon atoms. Isomers include 1,2-oxazole and 1,3-oxazole.",
      'parent' => 436,
    ),
    array(
      'tid' => 84,
      'name' => "Oxazolines",
      'description' => "Organic compounds containing 1,3-oxazoline, a five-membered ring with a nitrogen and an oxygen atoms at the 1- and 3-position, respectively. Additionally, it contains two double bonds.",
      'parent' => 2490,
    ),
    array(
      'tid' => 85,
      'name' => "Phosphinines",
      'description' => "Compounds containing a phosphinine ring, which is a benzene derivative where a carbon ring is replaced by a phosphorus atom.",
      'parent' => 2052,
    ),
    array(
      'tid' => 86,
      'name' => "Pyrans",
      'description' => "Compounds containing a pyran ring, which is a six-member heterocyclic, non-aromatic ring with five carbon atoms, one oxygen atom and  two ring double bonds.",
      'parent' => 2,
    ),
    array(
      'tid' => 87,
      'name' => "Pyrazoles",
      'description' => "Compounds containing a pyrazole ring, which is a five-member aromatic ring with two nitrogen atoms (at positions 1 and 2) and three carbon atoms.",
      'parent' => 436,
    ),
    array(
      'tid' => 88,
      'name' => "Pyrazolines",
      'description' => "Compounds containing a pyrazoline ring, which is a five-member saturated aliphatic ring with two nitrogen atoms (at positions 1 and 2) and three carbon atoms.",
      'parent' => 2490,
    ),
    array(
      'tid' => 89,
      'name' => "Pyridines and derivatives",
      'description' => "Compounds containing a pyridine ring, which is a six-member aromatic heterocycle which consists of one nitrogen atom and five carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 90,
      'name' => "Pyrroles",
      'description' => "Compounds containing a pyrrole ring, which is a five-member aromatic heterocycle with one nitrogen atom and four carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 91,
      'name' => "Pyrrolines",
      'description' => "Compounds containing a pyrroline ring, which is a five-member unsaturated aliphatic ring with one nitrogen atom and four carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 92,
      'name' => "Tetrazines",
      'description' => "Organic compounds containing a tetrazine ring, which is a six-membered aromatic heterocycle made up of four nitrogen atoms and a two carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 93,
      'name' => "Thiadiazoles",
      'description' => "Cyclic organic compounds containing a thiadiazole ring, which is a five-membered aromatic heterocycle made up of one sulfur atom and two nitrogen atoms.",
      'parent' => 436,
    ),
    array(
      'tid' => 94,
      'name' => "Thiazines",
      'description' => "Heterocyclic compounds containing an aliphatic unsaturated six-member ring with four carbon atoms, one sulfur atom, and one nitrogen. Isomers include 1,2-thiazines, 1,3-thiazines, and 1,4-thiazines.",
      'parent' => 2,
    ),
    array(
      'tid' => 95,
      'name' => "Thiazoles",
      'description' => "Heterocyclic compounds containing a five-member aromatic ring made up of one sulfur atom, one nitrogen, and three carbon atoms.",
      'parent' => 436,
    ),
    array(
      'tid' => 96,
      'name' => "Thiepins",
      'description' => "Heterocyclic compounds containing an unsaturated seven-member heterocycle, with six carbon atoms and one sulfur atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 97,
      'name' => "Thiophenes",
      'description' => "Compounds containing a five-membered aromatic moiety made up of one sulfur atom and four carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 98,
      'name' => "Triazines",
      'description' => "Compounds containing a triazine ring, which is a heterocyclic ring, similar to the six-member benzene ring but with three carbons replaced by nitrogen atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 99,
      'name' => "Triazoles",
      'description' => "Compounds containing  a five-member aromatic ring of two carbon atoms and three nitrogen atoms.",
      'parent' => 436,
    ),
    array(
      'tid' => 100,
      'name' => "Phenanthridines and derivatives",
      'description' => "Polycyclic compounds containing a phenanthridine moiety, which is a tricyclic system with two benzene rings joined by a pyridine forming a non-linear skeleton. Hydrogenated derivatives are also included.",
      'parent' => 1908,
    ),
    array(
      'tid' => 101,
      'name' => "Eudesmane, isoeudesmane or cycloeudesmane sesquiterpenoids",
      'description' => "Sesquiterpenoids with a structure based on the eudesmane skeleton.",
      'parent' => 1550,
    ),
    array(
      'tid' => 102,
      'name' => "Azetidines",
      'description' => "Organic compounds containing a saturated four-member heterocycle where one nitrogen atom replaces a carbon atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 103,
      'name' => "Aziridines",
      'description' => "Organic compounds containing a saturated three-member heterocycle with one amino group and two methylene groups.",
      'parent' => 2,
    ),
    array(
      'tid' => 104,
      'name' => "Azirines",
      'description' => "Organic compounds containing an unsaturated three-member heterocycle with one amino group and a double bond.",
      'parent' => 2,
    ),
    array(
      'tid' => 105,
      'name' => "Dioxolanes",
      'description' => "Compounds containing a dioxolane ring, which is a five-membered saturated ring of two oxygen atoms and three carbon atoms. The dioxolanes are divided in 1,2-dioxolanes, and 1,3-dioxolanes.",
      'parent' => 2,
    ),
    array(
      'tid' => 106,
      'name' => "Oxathiolanes",
      'description' => "Compounds containing an oxathiolane moiety, which consists of a saturated aliphatic five-member ring with one oxygen atom, a sulfur atom, and three carbon atoms. Isomers  of oxaphospholane include meta-oxathiolane, and ortho-oxathiolane.",
      'parent' => 2,
    ),
    array(
      'tid' => 107,
      'name' => "Oxazinanes",
      'description' => "Compounds containing an oxazinane moiety, which consists of a saturated aliphatic six-member ring with one oxygen atom, a nitrogen atom, and four carbon atoms. Isomers  of oxaphospholane include 1,2-oxazinane, 1,3-oxazinane, and 1,4-oxazinane.",
      'parent' => 2,
    ),
    array(
      'tid' => 108,
      'name' => "Oxazolidines",
      'description' => "Compounds containing an oxazolidine moiety, which consists of a saturated aliphatic five-member ring with one oxygen atom, one nitrogen, three carbon atoms, and two double bonds.",
      'parent' => 2491,
    ),
    array(
      'tid' => 109,
      'name' => "Pteridines and derivatives",
      'description' => "Polycyclic aromatic compounds containing a pteridine moiety, which consists of a pyrimidine fused to a pyrazine ring to form  pyrimido(4,5-b)pyrazine.",
      'parent' => 2,
    ),
    array(
      'tid' => 110,
      'name' => "Pterins and derivatives",
      'description' => "Polycyclic aromatic compounds containing a pterin moiety, which consist of a pteridine ring bearing a ketone and an amine group to form 2-aminopteridin-4(3H)-one.",
      'parent' => 109,
    ),
    array(
      'tid' => 111,
      'name' => "Tetrazoles",
      'description' => "Organic compounds containing a tetrazole ring, which is a five-member aromatic heterocycle made up of four nitrogen atoms and a one carbon atom.",
      'parent' => 436,
    ),
    array(
      'tid' => 112,
      'name' => "Hydrazines and derivatives",
      'description' => "Compounds comprising the hydrazine functional group, with the general formula R1R2NNR3R4.",
      'parent' => 278,
    ),
    array(
      'tid' => 113,
      'name' => "Phenylhydrazines",
      'description' => "Compounds containing a phenylhydrazide moiety, which consists of a hydrazide substituent attached to a phenyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 114,
      'name' => "Semicarbazides",
      'description' => "Organic compounds containing the semicarbazide functional group with the general structure R1(N)R2NR3C(=O)N(R4)R5 (R1-R5=H, alkyl, aryl), a derivative of urea, where the amine group on one side has been replace by a hydrazine group.",
      'parent' => 112,
    ),
    array(
      'tid' => 115,
      'name' => "Semicarbazones",
      'description' => "Organic compounds containing the semicarbazone functional group, with the general structure R2C=NNHC(=O)NH2.",
      'parent' => 114,
    ),
    array(
      'tid' => 116,
      'name' => "Hydrazones",
      'description' => "Compounds containing an N-Alkylidene derivative of hydrazine. They have the generic structure RNN=C(R')R\" (R,R',R\"= H or organyl group).",
      'parent' => 112,
    ),
    array(
      'tid' => 117,
      'name' => "Imines",
      'description' => "Compounds containing an imine functional group, with the general structure RN=CR2 (R = H, hydrocarbyl).",
      'parent' => 278,
    ),
    array(
      'tid' => 118,
      'name' => "Ketones",
      'description' => "Organic compounds  in which a carbonyl group is bonded to two carbon atoms R2C=O (neither R may be a hydrogen atom). Ketones that have one or more alpha-hydrogen atoms undergo keto-enol tautomerization, the tautomer being an enol.",
      'parent' => 1831,
    ),
    array(
      'tid' => 119,
      'name' => "Acetophenones",
      'description' => "Organic compounds containing the acetophenone structure.",
      'parent' => 2279,
    ),
    array(
      'tid' => 120,
      'name' => "Benzophenones",
      'description' => "Organic compounds containing a ketone attached to two phenyl groups.",
      'parent' => 2279,
    ),
    array(
      'tid' => 121,
      'name' => "Thioketones",
      'description' => "Compounds in which the oxygen of a ketone has been replaced by divalent sulfur R2C=S ( R not H ). Thioketones that have an alpha-hydrogen interconvert with Thioenols. Moreover, they interconvert with thioaldehydes.",
      'parent' => 1198,
    ),
    array(
      'tid' => 122,
      'name' => "Alpha-amino ketones",
      'description' => "Ketones containing a carboxylic acid, and an amine group attached to the alpha carbon atom relative to C=O group.",
      'parent' => 118,
    ),
    array(
      'tid' => 123,
      'name' => "Benzopyrans",
      'description' => "Organic compounds containing a benzene ring fused to a pyran ring. Pyran a six-membered heterocyclic, non-aromatic ring, made up of five carbon atoms and one oxygen atom and containing two double bonds.",
      'parent' => 2,
    ),
    array(
      'tid' => 124,
      'name' => "Aldehydes",
      'description' => "Organic compounds containing the aldehyde functional group.",
      'parent' => 1831,
    ),
    array(
      'tid' => 125,
      'name' => "Quinomethanes",
      'description' => "Organic compounds containing a cyclohexene or cyclohexadiene ring that bears a methylidene group and a ketone group. Isomers include m-quinomethane (6-methylidenecyclohex-2-en-1-one), o-quinomethane (5-methylidenecyclohex-2-en-1-one), and p-quinomethane (4-methylidenecyclohexa-2,5-dien-1-one).",
      'parent' => 3487,
    ),
    array(
      'tid' => 126,
      'name' => "Organic azides",
      'description' => "Compounds bearing the group N3, viz. -N=N+=N-; usually attached to carbon, e.g. PhN3 phenyl azide or azidobenzene.",
      'parent' => 3865,
    ),
    array(
      'tid' => 127,
      'name' => "Isoindoles",
      'description' => "Heteropolycyclic compounds with a structure containing isoindole, a benzo-fused pyrrole.",
      'parent' => 1819,
    ),
    array(
      'tid' => 128,
      'name' => "Alkyl aryl ethers",
      'description' => "Organic compounds containing the alkyl aryl ether functional group with the generic formula R-O-R' , where R is an alkyl group and R' is an aryl group.",
      'parent' => 254,
    ),
    array(
      'tid' => 129,
      'name' => "Alcohols and polyols",
      'description' => "Organic compounds in which at least one hydroxyl functional group (-OH) is bound to a carbon atom, usually connected to other carbon or hydrogen atoms.",
      'parent' => 323,
    ),
    array(
      'tid' => 130,
      'name' => "Azaspirodecane derivatives",
      'description' => "Organic compounds containing a spirodecane moiety with at least one nitrogen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 131,
      'name' => "Enediols",
      'description' => "Compounds containing the enediol functional group, with the formula HO(R)C=C(R')OH.",
      'parent' => 323,
    ),
    array(
      'tid' => 132,
      'name' => "Enols",
      'description' => "Compounds containing the enol functional group, with the structure HO(R)C=CR'. Ketones that have one or more alpha-hydrogen atoms undergo keto-enol tautomerization, the tautomer being an enol.",
      'parent' => 323,
    ),
    array(
      'tid' => 133,
      'name' => "1,3-dicarbonyl compounds",
      'description' => "Carbonyl compounds with the generic formula O=C(R)C(H)C(R')=O, where R and R' can be any group.",
      'parent' => 1831,
    ),
    array(
      'tid' => 134,
      'name' => "Phenols",
      'description' => "Compounds containing a phenol moiety, which is a benzene bearing a hydroxyl group.",
      'parent' => 2448,
    ),
    array(
      'tid' => 135,
      'name' => "Catechols",
      'description' => "Compounds containing a 1,2-benzenediol moiety.",
      'parent' => 1286,
    ),
    array(
      'tid' => 136,
      'name' => "Hydroquinones",
      'description' => "Compounds containing a hydroquinone moiety, which consists of a benzene ring with a hydroxyl groups at positions 1 and 4.",
      'parent' => 1286,
    ),
    array(
      'tid' => 137,
      'name' => "Resorcinols",
      'description' => "Compounds containing a resorcinol moiety, which is a benzene ring bearing two hydroxyl groups at positions 1 and 3.",
      'parent' => 1286,
    ),
    array(
      'tid' => 138,
      'name' => "Anisoles",
      'description' => "Organic compounds containing a methoxybenzene or a derivative thereof.",
      'parent' => 2341,
    ),
    array(
      'tid' => 139,
      'name' => "Tyrosols and derivatives",
      'description' => "Compounds containing a hydroxyethyl group attached to the C4 carbon of a phenol group.",
      'parent' => 134,
    ),
    array(
      'tid' => 140,
      'name' => "Aminophenols",
      'description' => "Organic compounds containing an amino group attached to a phenol.",
      'parent' => 134,
    ),
    array(
      'tid' => 141,
      'name' => "Nitrophenols",
      'description' => "Compounds containing a nitrophenol moiety, which consists of a benzene ring bearing both a hydroxyl group and a nitro group on two different ring carbon atoms.",
      'parent' => 134,
    ),
    array(
      'tid' => 142,
      'name' => "Stilbene glycosides",
      'description' => "Compounds structurally characterized by the presence of a carbohydrate moiety glycosidically linked to the stilbene skeleton.",
      'parent' => 253,
    ),
    array(
      'tid' => 143,
      'name' => "Bisphenols",
      'description' => "Methylenediphenols, HOC6H4CH2C6H4OH, commonly p,p-methylenediphenol, and their substitution products (generally derived from condensation of two equivalent amounts of a phenol with an aldehyde or ketone).",
      'parent' => 369,
    ),
    array(
      'tid' => 144,
      'name' => "Chromones",
      'description' => "Compounds containing a benzopyran-4-one moiety.",
      'parent' => 3410,
    ),
    array(
      'tid' => 145,
      'name' => "Coumarins and derivatives",
      'description' => "Polycyclic aromatic compounds containing a 1-benzopyran moiety with a ketone group at the C2 carbon atom (1-benzopyran-2-one).",
      'parent' => 261,
    ),
    array(
      'tid' => 146,
      'name' => "Acylaminosugars",
      'description' => "Organic compounds containing a sugar linked to a chain through N-acyl group.",
      'parent' => 1148,
    ),
    array(
      'tid' => 147,
      'name' => "Macrolides and analogues",
      'description' => "Organic compounds containing a lactone ring of at least twelve members.",
      'parent' => 261,
    ),
    array(
      'tid' => 148,
      'name' => "Dithiazoles",
      'description' => "Compounds containing a dithiazole moiety, which consists of an unsaturated five-member ring containing two carbon atoms, one nitrogen atom, and two sulfur atoms.",
      'parent' => 436,
    ),
    array(
      'tid' => 149,
      'name' => "Aflatoxins",
      'description' => "Difuranocoumarin derivatives in which the coumarin is fused to either a cyclopentenone (difurocoumarocyclopentenone series) or a lactone (difurocoumarolactone series).",
      'parent' => 2568,
    ),
    array(
      'tid' => 150,
      'name' => "Dibenzoxazepines",
      'description' => "Compounds containing a dibenzoxazepine moiety, which consists of two benzene connected by an oxazepine ring.",
      'parent' => 319,
    ),
    array(
      'tid' => 151,
      'name' => "Anthraquinones",
      'description' => "Organic compounds containing either anthracene-9,10-quinone, 1,4-anthraquinone, or 1,2-anthraquinone.",
      'parent' => 18,
    ),
    array(
      'tid' => 152,
      'name' => "M-iminoquinones",
      'description' => "M-quinones that carry an imine group.",
      'parent' => 2851,
    ),
    array(
      'tid' => 153,
      'name' => "Naphthoquinones",
      'description' => "Compounds containing a naphthohydroquinone moiety, which consists of a benzene ring linearly fused to a bezene-1,4-dione (quinone).",
      'parent' => 23,
    ),
    array(
      'tid' => 154,
      'name' => "Pentacenequinones",
      'description' => "Compounds containing a pentacenequinone moiety, which consists of five linearly fused benzene ring, with at least one bearing two ketones.",
      'parent' => 2448,
    ),
    array(
      'tid' => 155,
      'name' => "Tetracenequinones",
      'description' => "Polyaromatic hydrocarbon derivatives containing a tetracyclic cycle made up of four linearly fused benzene rings, one of which bears two ketone groups at position 1 and 4.",
      'parent' => 22,
    ),
    array(
      'tid' => 156,
      'name' => "Adamantanones",
      'description' => "Organic compounds containing a ketone group is attached to the adamantane (tricyclo[3.3.1.1]decane) ring.",
      'parent' => 3487,
    ),
    array(
      'tid' => 157,
      'name' => "Carbodiimides",
      'description' => "Organic compounds containing a functional group consisting of the formula RN=C=NR.",
      'parent' => 278,
    ),
    array(
      'tid' => 158,
      'name' => "N-organohydroxylamines",
      'description' => "Organic compounds comprising the hydroxylamine functional group, with the general structure R1ON(R2)R3 (R1,R3=H, organyl; R2 = organyl).",
      'parent' => 278,
    ),
    array(
      'tid' => 159,
      'name' => "Epoxides",
      'description' => "Compounds containing a cyclic ether with three ring atoms(one oxygen and two carbon atoms).",
      'parent' => 2,
    ),
    array(
      'tid' => 160,
      'name' => "Lactams",
      'description' => "Compounds containing a lactam ring, which is a cyclic amide of amino carboxylic acids, having a 1-azacycloalkan-2-one structure (or an analogue having unsaturation or heteroatoms replacing one or more carbon atoms of the ring).",
      'parent' => 2,
    ),
    array(
      'tid' => 161,
      'name' => "Epothilones and analogues",
      'description' => "Macrolides consisting of a 16-member lactone ring conjugated at the carbon 16 with a 1-(2-methyl-1,3-thiazol-4-yl)prop-1-en-2-yl group. Some epothilone analogues containing a lactam ring instead of the lactone ring.",
      'parent' => 147,
    ),
    array(
      'tid' => 162,
      'name' => "Beta lactams",
      'description' => "Organic compounds containing a four-member lactam (a cyclic amide).",
      'parent' => 160,
    ),
    array(
      'tid' => 163,
      'name' => "Caprolactams",
      'description' => "Cyclic amides of caproic acid. Caproic acid is the carboxylic acid derived from hexane with the general formula C5H11COOH.",
      'parent' => 160,
    ),
    array(
      'tid' => 164,
      'name' => "Delta lactams",
      'description' => "Cyclic organic compounds containing a piperidin-2-one moiety.",
      'parent' => 160,
    ),
    array(
      'tid' => 165,
      'name' => "Gamma lactams",
      'description' => "Organic compounds containing a gamma-lactam moiety, which consists of a five-member lactam ring.",
      'parent' => 160,
    ),
    array(
      'tid' => 166,
      'name' => "Thiolactams",
      'description' => "Cyclic thioamides, obtained by replacing the oxygen atom from a lactam ring with sulfur.",
      'parent' => 2,
    ),
    array(
      'tid' => 167,
      'name' => "Carbapenems",
      'description' => "Beta-lactam derivatives in which the beta-lactam ring shares the nitrogen atom with a pyrrole-2-carboxylic acid.",
      'parent' => 162,
    ),
    array(
      'tid' => 168,
      'name' => "Cephems",
      'description' => "Organic compounds containing the 5-thia-1-azabicyclo[4.2.0]oct-2-en-8-one nucleus.",
      'parent' => 162,
    ),
    array(
      'tid' => 169,
      'name' => "Clavams",
      'description' => "Organic compounds containing a 4-oxa-1-azabicyclo[3.2.0]heptan-7-one moiety. Clavams are similar to penams, but with an oxygen substituted for the sulfur in the penam skeleton.",
      'parent' => 162,
    ),
    array(
      'tid' => 170,
      'name' => "Monobactams",
      'description' => "Compounds comprising beta-lactam ring is alone and not fused to another ring.",
      'parent' => 162,
    ),
    array(
      'tid' => 171,
      'name' => "Oxacephems",
      'description' => "Organic compounds containing the oxacepehem skeleton, which is similar to a cephem, but with oxygen substituted for the sulfur.",
      'parent' => 162,
    ),
    array(
      'tid' => 172,
      'name' => "Penams",
      'description' => "Organic heterocyclic compounds containing the 4-thia-1-azabicyclo[3.2.0]heptan-7-one structure.",
      'parent' => 162,
    ),
    array(
      'tid' => 173,
      'name' => "Cephalosporins",
      'description' => "Compounds containing a 1,2-thiazine fused to a 2-azetidinone to for a oxo-5-thia-1-azabicyclo[4.2.0]oct-2-ene-2-carboxylic acid moiety or a derivative thereof.",
      'parent' => 168,
    ),
    array(
      'tid' => 174,
      'name' => "Penicillins",
      'description' => "Organic compounds containing the penicillin core structure, which is structurally characterized by a penam ring bearing two methyl groups at position 2, and an amide group at position 6 [starting from the sulfur atom at position 1].",
      'parent' => 172,
    ),
    array(
      'tid' => 175,
      'name' => "Glycerolipids",
      'description' => "Lipids formed by joining fatty acids to glycerol by ester bonds.",
      'parent' => 12,
    ),
    array(
      'tid' => 176,
      'name' => "Benzoic acids and derivatives",
      'description' => "Organic compounds containing a carboxylic acid substituent attached to a benzene ring.",
      'parent' => 2279,
    ),
    array(
      'tid' => 177,
      'name' => "Imidazopyridinones",
      'description' => "Compounds containing an imidazopyridine moiety where the pyridine ring bears a ketone group.",
      'parent' => 328,
    ),
    array(
      'tid' => 178,
      'name' => "Benzamides",
      'description' => "Organic compounds containing a carboxamido substituent attached to a benzene ring.",
      'parent' => 176,
    ),
    array(
      'tid' => 179,
      'name' => "Hippuric acids and derivatives",
      'description' => "Compounds containing a hippuric acid or a derivative, with a structure characterized the presence of a benzoyl group linked to the N-terminal of a glycine.",
      'parent' => 178,
    ),
    array(
      'tid' => 180,
      'name' => "Oleanane triterpenoids",
      'description' => "Triterpenoids with a structure based on the oleanane skeleton, an 4,4,6a,8a,11,14b-heptamethyl-hexadecahydropicene derivative.",
      'parent' => 1553,
    ),
    array(
      'tid' => 181,
      'name' => "Tetracyclines",
      'description' => "Polyketides having an octahydrotetracene-2-carboxamide skeleton, substituted with many hydroxy and other groups.",
      'parent' => 261,
    ),
    array(
      'tid' => 182,
      'name' => "Catecholamines and derivatives",
      'description' => "Compounds containing 4-(2-Aminoethyl)pyrocatechol [4-(2-aminoethyl)benzene-1,2-diol] or a derivative thereof formed by substitution.",
      'parent' => 135,
    ),
    array(
      'tid' => 183,
      'name' => "Tryptamines and derivatives",
      'description' => "Compounds containing the tryptamine backbone, which is structurally characterized by an indole ring substituted at the 3-position by an ethanamine.",
      'parent' => 211,
    ),
    array(
      'tid' => 184,
      'name' => "Pheniramines",
      'description' => "Compounds containing a pheniramine moiety, which is structurally characterized by the presence of a 2-benzylpyridine linked to an dimethyl(propyl)amine to form a dimethyl[3-phenyl-3-(pyridin-2-yl)propyl]amine skeleton.",
      'parent' => 89,
    ),
    array(
      'tid' => 185,
      'name' => "Phenylmethylamines",
      'description' => "Compounds containing a phenylmethtylamine moiety, which consists of a phenyl group substituted by an methanamine.",
      'parent' => 2279,
    ),
    array(
      'tid' => 186,
      'name' => "Phenethylamines",
      'description' => "Compounds containing a phenethylamine moiety, which consists of a phenyl group substituted at the second position by an ethan-1-amine.",
      'parent' => 2279,
    ),
    array(
      'tid' => 187,
      'name' => "Phenylpropylamines",
      'description' => "Compounds containing a phenylpropylamine moiety, which consists of a phenyl group substituted at the third carbon by an propan-1-amine.",
      'parent' => 2279,
    ),
    array(
      'tid' => 188,
      'name' => "Amphetamines and derivatives",
      'description' => "Organic compounds containing or derived from 1-phenylpropan-2-amine.",
      'parent' => 186,
    ),
    array(
      'tid' => 189,
      'name' => "Piperazines",
      'description' => "Compounds containing a piperazine ring, which is a saturated aliphatic six-member heterocyclic with two nitrogen atoms at positions 1 and 4, as well as four carbon atoms.",
      'parent' => 2389,
    ),
    array(
      'tid' => 190,
      'name' => "Methoxyphenols",
      'description' => "Compounds containing a methoxy group attached to the benzene ring of a phenol moiety.",
      'parent' => 134,
    ),
    array(
      'tid' => 191,
      'name' => "Diazaspirononane derivatives",
      'description' => "Organic heterocyclic compounds that contain a nine-membered saturated bicyclic moiety, consisting of two aliphatic saturated rings in a spiro-configuration, each of which contain a nitrogen atom. The bicyclic moiety is made up of two nitrogen and seven carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 192,
      'name' => "Cyclopyrrolones",
      'description' => "Compounds belonging to a family of pyridin-2-ylpyrrole based chemicals. The pyrrole is usually fused to a benzene, pyrimidine, or dithiin.",
      'parent' => 343,
    ),
    array(
      'tid' => 193,
      'name' => "Dioxoles",
      'description' => "Compounds containing a dioxole ring, which is a five-membered unsaturated ring of two oxygen atoms and three carbon atoms. The dioxoles are divided in meta-dioxoles, and ortho-dioxoles.",
      'parent' => 2,
    ),
    array(
      'tid' => 194,
      'name' => "Nitrofurans",
      'description' => "Compounds containing a furan ring which bears a nitro group.",
      'parent' => 76,
    ),
    array(
      'tid' => 195,
      'name' => "Piperidines",
      'description' => "Compounds containing a piperidine ring, which is a saturated aliphatic six-member ring with one nitrogen atom and five carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 196,
      'name' => "Oxazolidinones",
      'description' => "Compounds containing an oxazolidinone moiety, which is an oxazolidine bearing a ketone group.",
      'parent' => 108,
    ),
    array(
      'tid' => 197,
      'name' => "Oxazolidinediones",
      'description' => "Compounds containing an oxazolidine ring which bears two ketones.",
      'parent' => 196,
    ),
    array(
      'tid' => 198,
      'name' => "Oligosaccharides",
      'description' => "Carbohydrates made up of 3 to 10 monosaccharide units linked to each other through glycosidic bonds.",
      'parent' => 11,
    ),
    array(
      'tid' => 199,
      'name' => "Thioxanthenes",
      'description' => "Organic polycyclic compounds containing a thioxanthene moiety, which is an aromatic tricycle derived from xanthene by replacing the oxygen atom with a sulfur atom.",
      'parent' => 3413,
    ),
    array(
      'tid' => 200,
      'name' => "Xanthenes",
      'description' => "Polycyclic aromatic compounds containing a xanthene moiety, which consists of two benzene rings joined to each other by a pyran ring.",
      'parent' => 2817,
    ),
    array(
      'tid' => 201,
      'name' => "Tocopherols",
      'description' => "Vitamin E derivatives containing a saturated trimethyltridecyl chain attached to the carbon C6 atom of a benzopyran ring system. The differ from tocotrienols that contain an unsaturated trimethyltrideca-3,7,11-trien-1-yl chain.",
      'parent' => 1546,
    ),
    array(
      'tid' => 202,
      'name' => "Psoralens",
      'description' => "Organic compounds containing a psoralen moiety, which consists of a furan fused to a chromenone to for 7H-furo[3,2-g]chromen-7-one.",
      'parent' => 2569,
    ),
    array(
      'tid' => 203,
      'name' => "Thioxanthones",
      'description' => "Compounds containing a thioxanthene moiety which bears an ketone group.",
      'parent' => 199,
    ),
    array(
      'tid' => 204,
      'name' => "Xanthones",
      'description' => "Polycyclic aromatic compounds containing a xanthene moiety conjugated to a ketone group at carbon 9. Xanthene is a tricyclic compound made up of two benzene rings linearly fused to each other through a pyran ring.",
      'parent' => 200,
    ),
    array(
      'tid' => 205,
      'name' => "Pyrazolones",
      'description' => "Compounds containing a pyrazole ring which bears a ketone.",
      'parent' => 88,
    ),
    array(
      'tid' => 206,
      'name' => "Cinnolines",
      'description' => "Organic aromatic compounds containing a benzene fused to a pyridazine ring.",
      'parent' => 4789,
    ),
    array(
      'tid' => 207,
      'name' => "Phthalazines",
      'description' => "Compounds containing a phthalazine moiety, which consists of a benzene ring fused to a pyridazine, forming a 2,3-benzodiazine skeleton.",
      'parent' => 4789,
    ),
    array(
      'tid' => 208,
      'name' => "Pyridazinones",
      'description' => "Compounds containing a pyridazine ring which bears a ketone.",
      'parent' => 74,
    ),
    array(
      'tid' => 209,
      'name' => "Phthalazinones",
      'description' => "Compounds containing a phthalazine bearing a ketone group.",
      'parent' => 207,
    ),
    array(
      'tid' => 210,
      'name' => "Carbazoles",
      'description' => "Compounds containing a three ring system containing a pyrrole ring fused on either side to a benzene ring.",
      'parent' => 211,
    ),
    array(
      'tid' => 211,
      'name' => "Indoles and derivatives",
      'description' => "Organic compounds containing an indole, which is a bicyclic ring system made up of a six-membered benzene ring fused to a five-membered nitrogen-containing pyrrole ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 212,
      'name' => "Porphyrins",
      'description' => "Compounds containing a fundamental skeleton of four pyrrole nuclei united through the alpha-positions by four methine groups to form a macrocyclic structure.",
      'parent' => 1455,
    ),
    array(
      'tid' => 213,
      'name' => "Pyrrolopyridines",
      'description' => "Compounds containing a pyrrolopyridine moiety, which consists of a pyrrole ring fused to a pyridine. Pyrrole is 5-membered ring consisting of four carbon atoms and one nitrogen atom. Pyridine is a 6-membered ring consisting of five carbon atoms and one nitrogen center.",
      'parent' => 2,
    ),
    array(
      'tid' => 214,
      'name' => "Hydroxyeicosapentaenoic acids",
      'description' => "Eicosanoic acids with an attached hydroxyl group and five CC double bonds.",
      'parent' => 513,
    ),
    array(
      'tid' => 215,
      'name' => "Sugar acids and derivatives",
      'description' => "Compounds containing a saccharide unit which bears a carboxylic acid group.",
      'parent' => 11,
    ),
    array(
      'tid' => 216,
      'name' => "Indolizines",
      'description' => "Polycyclic  compounds containing an indolizine moiety, which is characterized by the presence of a pyrrole ring fused to a pyridine(Pyrrolo[1,2-a]pyridine).",
      'parent' => 213,
    ),
    array(
      'tid' => 217,
      'name' => "Pyrazolidines",
      'description' => "Compounds containing a pyrazolidine ring, which is a five-member saturated aliphatic ring with two nitrogen atoms (at positions 1 and 2) and three carbon atoms.",
      'parent' => 2491,
    ),
    array(
      'tid' => 218,
      'name' => "Pyrrolidines",
      'description' => "Compounds containing a pyrrolidine ring, which is a five-membered saturated aliphatic heterocycle with one nitrogen atom and four carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 219,
      'name' => "Pyrrolizines",
      'description' => "Compounds containing a pyrrolizine moiety, which consists of a pyrrole ring fused to a pyrrolidine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 220,
      'name' => "Pyrrolizidines",
      'description' => "Compounds containing a pyrrolizidine, which is a bicyclic ring system made up of two fused pyrrolidine ring sharing a nitrogen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 221,
      'name' => "Quinolizidines",
      'description' => "Compounds containing a quinolizidine moiety, which is a  octahydro-2H-quinolizine derivative.",
      'parent' => 2,
    ),
    array(
      'tid' => 222,
      'name' => "Quinolizines",
      'description' => "Compounds containing a quinolizine moiety, which consists of two fused pyridine rings sharing a nitrogen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 223,
      'name' => "Hydrophenanthrenes",
      'description' => "A phenanthrene derivative where at least one ring CC bond is substituted by hydrogenation.",
      'parent' => 25,
    ),
    array(
      'tid' => 224,
      'name' => "Thiadiazines",
      'description' => "Cyclic organic compounds containing a thiadiazine ring, which is a six-member unsaturated heterocycle made up of one sulfur atom and two nitrogen atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 225,
      'name' => "Nitrothiazoles",
      'description' => "Compounds containing a thiazole ring which bears a nitro group.",
      'parent' => 95,
    ),
    array(
      'tid' => 226,
      'name' => "Thiazolidines",
      'description' => "Heterocyclic compounds containing a five-member saturated aliphatic ring with one nitrogen atom, one sulfur atom, three carbon atoms.",
      'parent' => 2491,
    ),
    array(
      'tid' => 227,
      'name' => "Thiazolidinones",
      'description' => "Heterocyclic compounds containing a thiazolidinone ring which bears one ketone group.",
      'parent' => 226,
    ),
    array(
      'tid' => 228,
      'name' => "Thiazolidinediones",
      'description' => "Heterocyclic compounds containing a thiazolidine ring which bears two ketone groups.",
      'parent' => 227,
    ),
    array(
      'tid' => 229,
      'name' => "Thiazolines",
      'description' => "Heterocyclic compounds containing a five-member unsaturated aliphatic ring with one nitrogen atom, one sulfur atom, three carbon atoms.",
      'parent' => 2490,
    ),
    array(
      'tid' => 230,
      'name' => "Organic superoxides",
      'description' => "Organic compounds containing a superoxide oxyanion.",
      'parent' => 463,
    ),
    array(
      'tid' => 231,
      'name' => "Benzothiepins",
      'description' => "Organic compounds containing a benzene fused to a thiepine ring (a seven-membered ring with six carbon atoms and one sulfur atom).",
      'parent' => 2,
    ),
    array(
      'tid' => 232,
      'name' => "Dibenzothiepins",
      'description' => "Compounds containing a dibenzothiepin moiety, which consists of two benzene connected by a thiepine ring.",
      'parent' => 231,
    ),
    array(
      'tid' => 233,
      'name' => "Thiolanes",
      'description' => "Organic compounds containing thiolane, a five-member saturated ring containing four carbon atoms and a sulfur atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 234,
      'name' => "Triazolones",
      'description' => "Compounds containing a triazole ring which bears a ketone group.",
      'parent' => 99,
    ),
    array(
      'tid' => 235,
      'name' => "Triazolidines",
      'description' => "Compounds containing  a five-member saturated aliphatic ring of two carbon atoms and three nitrogen atoms.",
      'parent' => 2491,
    ),
    array(
      'tid' => 236,
      'name' => "Ellagic acids and derivatives",
      'description' => "Compounds containing an ellagic acid moiety (4,4',5,5',6,6'-Hexahydroxydiphenic acid 2,6,2',6'-dilactone) or a derivative thereof.",
      'parent' => 2448,
    ),
    array(
      'tid' => 237,
      'name' => "Acyl monophosphates",
      'description' => "Organic compounds containing a monophosphate linked to an acyl group. They have the general structure  R-CO-P(O)(O)OH, R=H or organyl.",
      'parent' => 4781,
    ),
    array(
      'tid' => 238,
      'name' => "Tannins",
      'description' => "Naturally occurring polyphenols which be categorized into four main classes: hydrolyzable tannin (based on ellagic acid or gallic acid), condensed tannins (made of oligomeric or polymeric proanthocyanidins), complex tannins (made of a catechin bound to a gallotannin or elagitannin), and phlorotannins (oligomers of phloroglucinol).",
      'parent' => 261,
    ),
    array(
      'tid' => 239,
      'name' => "Indolizinoquinolines",
      'description' => "Polycyclic aromatic compounds containing an indolizine fused to a quinonline.",
      'parent' => 1253,
    ),
    array(
      'tid' => 240,
      'name' => "Camptothecins",
      'description' => "Heterocyclic compounds comprising a planar pentacyclic ring structure, that includes a pyrrolo[3,4-beta]-quinoline moiety (rings A, B and C), conjugated pyridone moiety (ring D) and one chiral center at position 20 within the alpha-hydroxy lactone ring with (S) configuration (the E-ring).",
      'parent' => 279,
    ),
    array(
      'tid' => 241,
      'name' => "Pyranoindolizines",
      'description' => "Polycyclic aromatic compounds containing a pyran ring fused to an indolizine moiety.",
      'parent' => 216,
    ),
    array(
      'tid' => 242,
      'name' => "Nitroimidazoles",
      'description' => "Compounds containing an imidazole ring which bears a nitro group.",
      'parent' => 2310,
    ),
    array(
      'tid' => 243,
      'name' => "Thienoimidazoles",
      'description' => "Heterocyclic compounds containing a thiophene ring fused to an imidazole ring. Thiophene is 5-membered ring consisting of four carbon atoms and one sulfur atom. Imidazole is 5-membered ring consisting of three carbon and two nitrogen centers at the 1- and 3-positions.",
      'parent' => 2,
    ),
    array(
      'tid' => 244,
      'name' => "Biotin and derivatives",
      'description' => "Organic compounds containing a ureido (tetrahydroimidizalone) ring fused with a tetrahydrothiophene ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 245,
      'name' => "Purines and purine derivatives",
      'description' => "Aromatic heterocyclic compounds containing a purine moiety, which is formed a pyrimidine-ring ring fused to an imidazole ring.",
      'parent' => 1797,
    ),
    array(
      'tid' => 246,
      'name' => "Hypoxanthines",
      'description' => "Compounds containing the purine derivative 1H-purin-6(9H)-one. Purine is a bicyclic aromatic compound made up of a pyrimidine ring fused to an imidazole ring.",
      'parent' => 597,
    ),
    array(
      'tid' => 247,
      'name' => "Xanthines",
      'description' => "Purine derivatives with a ketone group conjugated at carbons 2 and 6 of the purine moiety.",
      'parent' => 245,
    ),
    array(
      'tid' => 248,
      'name' => "1,2-dioxoles",
      'description' => "Organic compounds containing 1,2-dioxole, an aliphatic five-member ring with two oxygen atoms in ring positions 1 and 2, and a double bond.",
      'parent' => 193,
    ),
    array(
      'tid' => 249,
      'name' => "Thioxanthines",
      'description' => "Organic polycyclic compounds containing a thioxanthine moiety, which is an aromatic bicyclic structure derived from xanthine by replacing a carbonyl group with a thiocarbonyl group.",
      'parent' => 245,
    ),
    array(
      'tid' => 250,
      'name' => "Imidazolidines",
      'description' => "Organic compounds containing an imidazolidine ring, which is a saturated ring (derived from imidazole) with two nitrogen atoms at positions 1 and 3 respectively, and containing only single bonds.",
      'parent' => 2491,
    ),
    array(
      'tid' => 251,
      'name' => "Indolizidines",
      'description' => "Polycyclic compounds containing an indolizidine, which is a bicyclic heterocycle containing a saturated six-member ring fused to a saturated five-member ring, one of the bridging atoms being nitrogen.",
      'parent' => 2,
    ),
    array(
      'tid' => 252,
      'name' => "Quinuclidines",
      'description' => "Compounds containing a 1-azabicyclo[2.2.2]octane moiety.",
      'parent' => 2,
    ),
    array(
      'tid' => 253,
      'name' => "Stilbenes",
      'description' => "Organic compounds containing a 1,2-diphenylethylene moiety. Stilbenes (C6-C2-C6 ) are derived from the common phenylpropene (C6-C3) skeleton building block. The introduction of one or more hydroxyl groups  to a phenyl ring lead to stilbenoids.",
      'parent' => 261,
    ),
    array(
      'tid' => 254,
      'name' => "Ethers",
      'description' => "Compounds bearing an ether group with the formula Compounds ROR (R not H).",
      'parent' => 323,
    ),
    array(
      'tid' => 255,
      'name' => "Folic acids and derivatives",
      'description' => "Heterocyclic compounds based on the 4-[(pteridin-6-ylmethyl)amino]benzoic acid skeleton conjugated with one or more L-glutamate units (or derivatives thereof).",
      'parent' => 1228,
    ),
    array(
      'tid' => 256,
      'name' => "Glycerophospholipids",
      'description' => "Derivatives of glycerophosphoric acid that contains at least one O-acyl, or O-alkyl, or O-(1-alkenyl) group attached to the glycerol residue.",
      'parent' => 12,
    ),
    array(
      'tid' => 257,
      'name' => "Sphingolipids",
      'description' => "Lipids  containing backbone of sphingoid bases (e.g. Sphinogsine, sphinganine) usually bound to a fatty acid derivative through N-acylation.",
      'parent' => 12,
    ),
    array(
      'tid' => 258,
      'name' => "Steroids and steroid derivatives",
      'description' => "Compounds based on the cyclopenta[a]phenanthrene carbon skeleton, partially or completely hydrogenated; there are usually methyl groups at C-10 and C-13, and often an alkyl group at C-17. By extension, one or more bond scissions, ring expansions and/or ring contractions of the skeleton may have occurred.",
      'parent' => 12,
    ),
    array(
      'tid' => 259,
      'name' => "Prenol lipids",
      'description' => "Lipids synthesized from the five-carbon-unit precursors isopentenyl diphosphate and dimethylallyl diphosphate.",
      'parent' => 12,
    ),
    array(
      'tid' => 260,
      'name' => "Monohydroxy bile acids, alcohols and derivatives",
      'description' => "Bile acids, alcohols or any of their derivatives bearing a hydroxyl group.",
      'parent' => 2194,
    ),
    array(
      'tid' => 261,
      'name' => "Phenylpropanoids and polyketides",
      'description' => "Organic compounds that are synthesized either from the amino acid phenylalanine (phenylpropanoids) or the decarboxylative condensation of malonyl-CoA (polyketides). Phenylpropanoids are aromatic compounds based on the phenylpropane skeleton. Polyketides usually consist of alternating carbonyl and methylene groups (beta-polyketones), biogenetically derived from repeated condensation of acetyl coenzyme A (via malonyl coenzyme A), and usually the compounds derived from them by further condensations.",
      'parent' => 0,
    ),
    array(
      'tid' => 262,
      'name' => "Fatty acids and conjugates",
      'description' => "Aliphatic monocarboxylic acids with a saturated or unsaturated aliphatic tail (with at least 4 Carbon atoms).",
      'parent' => 3909,
    ),
    array(
      'tid' => 263,
      'name' => "Sesquiterpene glycosides",
      'description' => "Sesquiterpenoids linked to a saccharide moiety through a glycosidic bond.",
      'parent' => 2049,
    ),
    array(
      'tid' => 264,
      'name' => "Organic acids and derivatives",
      'description' => "Compounds an organic acid or a derivative thereof.",
      'parent' => 0,
    ),
    array(
      'tid' => 265,
      'name' => "Carboxylic acids and derivatives",
      'description' => "Compounds containing a carboxylic acid group with the formula -C(=O)OH or a derivative thereof.",
      'parent' => 264,
    ),
    array(
      'tid' => 266,
      'name' => "Short-chain hydroxy acids and derivatives",
      'description' => "Hydroxy acids with an alkyl chain the contains less than 6 carbon atoms.",
      'parent' => 472,
    ),
    array(
      'tid' => 267,
      'name' => "Organohalogen compounds",
      'description' => "Organic compounds containing a bond between a carbon atom and a halogen atom (At, F, Cl, Br, I).",
      'parent' => 0,
    ),
    array(
      'tid' => 268,
      'name' => "Organosulfenic acids and derivatives",
      'description' => "Compounds derived from sulfenic acid, with the general formula R1SR2 ( R1= organyl, R2=any heteroatom).",
      'parent' => 264,
    ),
    array(
      'tid' => 269,
      'name' => "Sulfinic acids and derivatives",
      'description' => "Compounds derived from sulfinic acid, with the general formula RS(=O)R' ( R not H, R'=any heteroatom).",
      'parent' => 264,
    ),
    array(
      'tid' => 270,
      'name' => "Organosulfonic acids and derivatives",
      'description' => "Compounds containing a sulfonic acid or derivative, with the general structure RS(=O)2X (R=alkyl, aryl; X=any heteroatom).",
      'parent' => 4434,
    ),
    array(
      'tid' => 271,
      'name' => "Carbamic acids",
      'description' => "Compounds containing the carbamic acid functional group, with the general structure RN(R')C(=O)OH or RN(R')C(=O)[O-] where R,R' = H or organyl group.",
      'parent' => 318,
    ),
    array(
      'tid' => 272,
      'name' => "1,3-dioxoles",
      'description' => "Organic compounds containing 1,3-dioxole, an aliphatic five-member ring with two oxygen atoms in ring positions 1 and 3 and a double bond.",
      'parent' => 193,
    ),
    array(
      'tid' => 273,
      'name' => "Miscellaneous chromates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is chromate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 274,
      'name' => "Acridines",
      'description' => "Organic compounds containing the acridine moiety, a linear tricyclic heterocycle which consists of two benzene rings joined by a pyridine ring.",
      'parent' => 1908,
    ),
    array(
      'tid' => 275,
      'name' => "Acryloyl compounds",
      'description' => "Organic compounds containing the acryloyl functional group (which has the core fragment but-3-en-2-one).",
      'parent' => 323,
    ),
    array(
      'tid' => 276,
      'name' => "Acyl glycines",
      'description' => "Organic compounds containing a glycine residue with the N-atom attached to another moiety through an N-ester bond.",
      'parent' => 2402,
    ),
    array(
      'tid' => 277,
      'name' => "Organoalkaline-earth metal compounds",
      'description' => "Organic compounds containing an alkaline earth metal atom.",
      'parent' => 462,
    ),
    array(
      'tid' => 278,
      'name' => "Organonitrogen compounds",
      'description' => "Organic compounds containing a nitrogen atom.",
      'parent' => 4707,
    ),
    array(
      'tid' => 279,
      'name' => "Alkaloids and derivatives",
      'description' => "Naturally occurring chemical compounds that contain mostly basic nitrogen atoms. This group also includes some related compounds with neutral and even weakly acidic properties. Also some synthetic compounds of similar structure are attributed to alkaloids. In addition to carbon, hydrogen and nitrogen, alkaloids may also contain oxygen, sulfur and more rarely other elements such as chlorine, bromine, and phosphorus.",
      'parent' => 0,
    ),
    array(
      'tid' => 280,
      'name' => "Beta-amino ketones",
      'description' => "Ketones containing a carboxylic acid, and an amine group attached to the beta carbon atom, relative to the C=O group.",
      'parent' => 118,
    ),
    array(
      'tid' => 281,
      'name' => "Aminobenzoic acids and derivatives",
      'description' => "Benzoic acids (or derivative thereof) containing an amine group attached to the benzene moiety.",
      'parent' => 176,
    ),
    array(
      'tid' => 282,
      'name' => "Aminoglycosides",
      'description' => "Molecules or a portion of a molecule composed of amino-modified sugars.",
      'parent' => 3305,
    ),
    array(
      'tid' => 283,
      'name' => "Aminopyridines and derivatives",
      'description' => "Organic heterocyclic compounds containing an amino group attached to a pyridine ring.",
      'parent' => 89,
    ),
    array(
      'tid' => 284,
      'name' => "Aniline and substituted anilines",
      'description' => "Organic compounds containing an aminobenzene moiety.",
      'parent' => 2279,
    ),
    array(
      'tid' => 285,
      'name' => "Anilides",
      'description' => "Organic heterocyclic compounds derived from oxoacids RkE(=O)l(OH)m (l not 0) by replacing an OH group by the NHPh group or derivative formed by ring substitution.",
      'parent' => 2279,
    ),
    array(
      'tid' => 286,
      'name' => "Primary alcohols",
      'description' => "Compounds comprising the primary alcohol functional group, with the general structure RCOH (R=alkyl, aryl).",
      'parent' => 129,
    ),
    array(
      'tid' => 287,
      'name' => "Organomagnesium compounds",
      'description' => "Organic compounds containing a bond between a carbon atom and magnesium atom.",
      'parent' => 277,
    ),
    array(
      'tid' => 288,
      'name' => "Thioanisoles",
      'description' => "Organic compounds in which the oxygen of an anisole has been replaced by a sulfur.",
      'parent' => 2279,
    ),
    array(
      'tid' => 289,
      'name' => "Nucleosides, nucleotides, and analogues",
      'description' => "Compounds containing a nucleobase linked to a ribose or deoxyribose sugar via a beta-glycosidic linkage. The ribose or deoxyribose moiety bears at least a phosphate group in case of nucleotides.",
      'parent' => 0,
    ),
    array(
      'tid' => 290,
      'name' => "Azulenes",
      'description' => "Polycyclic aromatic compounds containing the azulene skeleton, which consists of the cyclopentadiene ring fused to a cycloheptadiene ring.",
      'parent' => 2840,
    ),
    array(
      'tid' => 291,
      'name' => "Pyrimidones",
      'description' => "Compounds that contain a pyrimidine ring, which bears a ketone. Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions.",
      'parent' => 75,
    ),
    array(
      'tid' => 292,
      'name' => "Barbituric acid derivatives",
      'description' => "Compounds containing a perhydropyrimidine ring substituted at C-2, -4 and -6 by oxo groups.",
      'parent' => 291,
    ),
    array(
      'tid' => 293,
      'name' => "Benzazepines",
      'description' => "Organic compounds containing a benzene ring fused to an azepine ring (unsaturated seven-membered heterocycle with one nitrogen atom replacing a carbon atom).",
      'parent' => 2,
    ),
    array(
      'tid' => 294,
      'name' => "Benzimidazoles",
      'description' => "Organic compounds containing a benzene ring fused to an imidazole ring (five member ring containing a nitrogen atom, 4 carbon atoms, and two double bonds).",
      'parent' => 2,
    ),
    array(
      'tid' => 295,
      'name' => "Benzodiazepines",
      'description' => "Organic compounds containing a benzene ring fused to either isomers of diazepine(unsaturated seven-member heterocycle with two nitrogen atoms replacing two carbon atoms).",
      'parent' => 2,
    ),
    array(
      'tid' => 296,
      'name' => "Benzodioxoles",
      'description' => "Organic compounds containing a benzene ring fused to either isomers of dioxole. Dioxole is a five-membered unsaturated ring of two oxygen atoms and three carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 297,
      'name' => "Lysophosphatidylglycerols",
      'description' => "Glycerophosphoglycerols  (molecules containing a glycerol moiety attached to the phosphate group linked to a glycerol) in which only one fatty acid is bonded to the 1-glycerol moiety (through an ester linkage).",
      'parent' => 2216,
    ),
    array(
      'tid' => 298,
      'name' => "Fatty aldehydes",
      'description' => "Long chain aldehydes with a chain of at least 12 carbon atoms.",
      'parent' => 3909,
    ),
    array(
      'tid' => 299,
      'name' => "Medium-chain hydroxy acids and derivatives",
      'description' => "Hydroxy acids with a 6 to 12 carbon atoms long side chain.",
      'parent' => 472,
    ),
    array(
      'tid' => 300,
      'name' => "Benzarsoles",
      'description' => "Organic compounds containing a benzene ring fused to an arsole ring (five member ring containing an arsenic atom, 4 carbon atoms, and two double bonds).",
      'parent' => 2052,
    ),
    array(
      'tid' => 301,
      'name' => "Benzofurans",
      'description' => "Organic compounds containing a benzene ring fused to a furan. Furan is a five-membered aromatic ring with four carbon atoms and one oxygen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 302,
      'name' => "Benzoxazoles",
      'description' => "Organic compounds containing a benzene fused to an oxazole ring Oxazole is five-membered aromatic ring with a nitrogen and an oxygen atoms at the 1- and 3-position, respectively.",
      'parent' => 2,
    ),
    array(
      'tid' => 303,
      'name' => "Phenylpiperidines",
      'description' => "Compounds containing a phenylpiperidine skeleton, which consists of a piperidine bound to a phenyl group.",
      'parent' => 195,
    ),
    array(
      'tid' => 304,
      'name' => "Pyrazolopyridines",
      'description' => "Compounds containing a pyrazolopyridine skeleton, which consists of a pyrazole fused to a pyridine. Pyrazole is 5-membered ring consisting of three carbon atoms and two adjacent nitrogen centers. Pyridine is a 6-membered ring with four carbon and one nitrogen atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 305,
      'name' => "Pyrazolopyrimidines",
      'description' => "Compounds containing a pyrazolopyrimidine skeleton, which consists of a pyrazole fused to a pyrimidine. Pyrazole is 5-membered ring consisting of three carbon atoms and two adjacent nitrogen centers. Pyrimidine is 6-membered ring consisting of four carbon atoms and two adjacent nitrogen atoms at the 1- and 3- ring position.",
      'parent' => 2,
    ),
    array(
      'tid' => 306,
      'name' => "Phenyltetrazoles and derivatives",
      'description' => "Compounds containing a phenyltetrazole skeleton, which consists of a tetrazole bound to a phenyl group.",
      'parent' => 111,
    ),
    array(
      'tid' => 307,
      'name' => "Azepanes",
      'description' => "Organic compounds containing a saturated seven member heterocycle, with one nitrogen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 308,
      'name' => "Benzothiadiazines",
      'description' => "Organic compounds containing a benzene fused to a thiadiazine ring (a six-member ring with two nitrogen atoms and a sulfur atom).",
      'parent' => 224,
    ),
    array(
      'tid' => 309,
      'name' => "Benzothiazines",
      'description' => "Organic compounds containing a benzene fused to a thiazine ring (a six-membered ring with four carbon atoms, one nitrogen atom and one sulfur atom).",
      'parent' => 2,
    ),
    array(
      'tid' => 310,
      'name' => "Phenothiazines",
      'description' => "Polycyclic aromatic compounds containing a phenothiazine moiety, which is a linear tricyclic system that consists of a two benzene rings joined by a para-thiazine ring.",
      'parent' => 309,
    ),
    array(
      'tid' => 311,
      'name' => "Benzothiazoles",
      'description' => "Organic compounds containing a benzene fused to a thiazole ring (a five-membered ring with four carbon atoms, one nitrogen atom and one sulfur atom).",
      'parent' => 2,
    ),
    array(
      'tid' => 312,
      'name' => "Benzothiophenes",
      'description' => "Organic compounds containing a benzene fused to a thiepine ring (a five-membered ring with six carbon atoms and one sulfur atom).",
      'parent' => 2,
    ),
    array(
      'tid' => 313,
      'name' => "Triazolopyrazines",
      'description' => "Compounds containing a triazole ring fused to a pyrazine ring. Triazole is a five-membered ring consisting of two carbon atoms and three nitrogen atoms. Pyrazine is a 6-membered ring consisting of six carbon atoms and two nitrogen centers at ring positions 1 and 4.",
      'parent' => 2,
    ),
    array(
      'tid' => 314,
      'name' => "Triazolopyridines",
      'description' => "Compounds containing a triazole ring fused to a pyridine ring. Triazole is a five-membered ring consisting of two carbon atoms and three nitrogen atoms. Pyridine is a 6-membered ring consisting of five carbon atoms and one nitrogen center.",
      'parent' => 2,
    ),
    array(
      'tid' => 315,
      'name' => "Benzotriazoles",
      'description' => "Organic compounds containing a benzene fused to a triazole ring (a five-membered ring with two carbon atoms and three nitrogen atoms).",
      'parent' => 2,
    ),
    array(
      'tid' => 316,
      'name' => "Benzopyrenes",
      'description' => "Organic compounds containing a benzene fused to a pyrene(benzo[def]phenanthrene) ring system.",
      'parent' => 1851,
    ),
    array(
      'tid' => 317,
      'name' => "Benzothiazepines",
      'description' => "Organic compounds containing a benzene fused to a thiazepine ring (a seven-membered ring with a nitrogen atom and a sulfur atom replacing two carbon atoms).",
      'parent' => 2,
    ),
    array(
      'tid' => 318,
      'name' => "Carbamic acids and derivatives",
      'description' => "Compounds comprising the carbamic acid functional group or a derivative thereof. They have the general structure RN(R')C(=O)OH or RN(R')C(=O)R\", where R,R'= H or organyl group, R\"= OH, alkyloxy, acyloxy, or halogen.",
      'parent' => 347,
    ),
    array(
      'tid' => 319,
      'name' => "Benzoxazepines",
      'description' => "Organic compounds containing a benzene fused to an oxazepine ring (a seven-membered ring with four carbon atoms, one oxygen atom, and a nitrogen atom).",
      'parent' => 2,
    ),
    array(
      'tid' => 320,
      'name' => "Dibenzazepines",
      'description' => "Compounds with two benzene rings connected by an azepine ring. Azepine is an unsaturated seven-member heterocycle with one nitrogen atom replacing a carbon atom.",
      'parent' => 293,
    ),
    array(
      'tid' => 321,
      'name' => "Benzoyl derivatives",
      'description' => "Organic compounds containing an acyl moiety of benzoic acid with the formula (C6H5CO-).",
      'parent' => 2279,
    ),
    array(
      'tid' => 322,
      'name' => "Betaxanthins and derivatives",
      'description' => "Organic compounds containing an aminoethylpyridine-2,6-dicarboxylic acid derivative.",
      'parent' => 1435,
    ),
    array(
      'tid' => 323,
      'name' => "Organooxygen compounds",
      'description' => "Organic compounds containing a bond between a carbon atom and an oxygen atom.",
      'parent' => 4603,
    ),
    array(
      'tid' => 324,
      'name' => "Fatty acid esters",
      'description' => "Carboxylic ester derivatives of a fatty acid.",
      'parent' => 3909,
    ),
    array(
      'tid' => 325,
      'name' => "Biphenols",
      'description' => "Organic compounds containing two phenol groups linked together by a C-C bond.",
      'parent' => 2279,
    ),
    array(
      'tid' => 326,
      'name' => "Bipyridines and oligopyridines",
      'description' => "Organic compounds containing two pyridine rings linked to each other.",
      'parent' => 89,
    ),
    array(
      'tid' => 327,
      'name' => "Bisphosphonates",
      'description' => "Organic compounds containing two phosphonate groups linked together through a carbon atoms.",
      'parent' => 419,
    ),
    array(
      'tid' => 328,
      'name' => "Imidazopyridines",
      'description' => "Organic polycyclic compounds containing an imidazole ring fused to a pyridine ring. Imidazole is 5-membered ring consisting of three carbon atoms, and two nitrogen centers at the 1- and 3-positions. Pyridine is a 6-membered ring consisting of five carbon atoms and one nitrogen center.",
      'parent' => 2,
    ),
    array(
      'tid' => 329,
      'name' => "Phenylazirines",
      'description' => "Compounds containing a phenylazirine moiety, which consists of an azirine ring attached to a phenyl group.",
      'parent' => 104,
    ),
    array(
      'tid' => 330,
      'name' => "Phenylbenzimidazoles",
      'description' => "Compounds containing a phenylbenzimidazole skeleton, which consists of a benzimidazole moiety where its imidazole ring is attached to a phenyl group.",
      'parent' => 294,
    ),
    array(
      'tid' => 331,
      'name' => "Fatty amides",
      'description' => "Carboxylic acid amide derivatives of fatty acids, that are formed from a fatty acid and an amine.",
      'parent' => 3909,
    ),
    array(
      'tid' => 332,
      'name' => "Phosphatidylglycerophosphates",
      'description' => "Glycerophosphoglycerophosphates in which two fatty acids are bonded to the 1-glycerol moiety through ester linkages.",
      'parent' => 2217,
    ),
    array(
      'tid' => 333,
      'name' => "Straight chain fatty acids",
      'description' => "Fatty acids with a straight aliphatic chain.",
      'parent' => 262,
    ),
    array(
      'tid' => 334,
      'name' => "Flavonoids",
      'description' => "Plant secondary metabolites that contain the 2-phenylchromene skeleton. Plant secondary metabolites that contain the 2-phenylchromene skeleton.",
      'parent' => 261,
    ),
    array(
      'tid' => 335,
      'name' => "N-acylpiperidines",
      'description' => "Compounds containing an N-acyethanolamine moiety, which is characterized by an acyl group is linked to the nitrogen atom of a piperidine.",
      'parent' => 195,
    ),
    array(
      'tid' => 336,
      'name' => "Anthocyanidins",
      'description' => "Sugar-free counterparts of anthocyanins based on the flavylium ion or 2-phenylchromenylium ion.",
      'parent' => 334,
    ),
    array(
      'tid' => 337,
      'name' => "Flavans",
      'description' => "Compounds containing a flavan moiety, with a structure characterized by a 2-phenyl-3,4-dihydro-2H-1-benzopyran skeleton.",
      'parent' => 334,
    ),
    array(
      'tid' => 338,
      'name' => "Branched fatty acids",
      'description' => "Fatty acids containing a branched chain.",
      'parent' => 262,
    ),
    array(
      'tid' => 339,
      'name' => "Unsaturated fatty acids",
      'description' => "Fatty acids with a chain that contains at least one CC double bond.",
      'parent' => 262,
    ),
    array(
      'tid' => 340,
      'name' => "Hydroperoxy fatty acids",
      'description' => "Fatty acids containing a hydroperoxide group attached to the chain.",
      'parent' => 262,
    ),
    array(
      'tid' => 341,
      'name' => "Hydroxy fatty acids",
      'description' => "Fatty acids in which the chain bears a hydroxyl group.",
      'parent' => 262,
    ),
    array(
      'tid' => 342,
      'name' => "Pyridinylpyrimidines",
      'description' => "Compounds containing a pyridinylpyrimidine skeleton, which consists of a pyridine linked (not fused) to a pyrimidine by a bond.",
      'parent' => 75,
    ),
    array(
      'tid' => 343,
      'name' => "Pyrrolopyrazines",
      'description' => "Compounds containing a pyrrolopyrazine moiety, which consists of a pyrrole ring fused to a pyrazine. Pyrrole is 5-membered ring consisting of four carbon atoms and one nitrogen atom. Pyrazine is a 6-membered ring consisting of six carbon atoms and two nitrogen centers at ring positions 1 and 4.",
      'parent' => 2,
    ),
    array(
      'tid' => 344,
      'name' => "Thienopyridines",
      'description' => "Heterocyclic compounds containing a thiophene ring fused to a pyridine ring. Thiophene is 5-membered ring consisting of four carbon atoms and one sulfur atom. Pyridine is a 6-membered ring consisting of five carbon atoms and one nitrogen center.",
      'parent' => 2,
    ),
    array(
      'tid' => 345,
      'name' => "Azaborinanes",
      'description' => "Organic compounds containing a six-member saturated aliphatic ring containing a nitrogen atom, an arsenic atom, and four carbon atoms.",
      'parent' => 2052,
    ),
    array(
      'tid' => 346,
      'name' => "Dicarboxylic acids and derivatives",
      'description' => "Organic compounds containing exactly two carboxylic acid groups.",
      'parent' => 265,
    ),
    array(
      'tid' => 347,
      'name' => "Amino acids and derivatives",
      'description' => "Organic compounds containing an amine group, a carboxylic acid group (or a derivative thereof), and a side-chain that is specific to each amino acid.",
      'parent' => 13,
    ),
    array(
      'tid' => 348,
      'name' => "Peptides",
      'description' => "Compounds containing an amide derived from two or more amino carboxylic acid molecules (the same or different) by formation of a covalent bond from the carbonyl carbon of one to the nitrogen atom of another.",
      'parent' => 13,
    ),
    array(
      'tid' => 349,
      'name' => "Organoantimony compounds",
      'description' => "Compounds containing a bond between a carbon atom and an antimony atom.",
      'parent' => 1370,
    ),
    array(
      'tid' => 350,
      'name' => "Butyrophenones",
      'description' => "Compounds containing 1-phenylbutan-1-one moiety.",
      'parent' => 2279,
    ),
    array(
      'tid' => 351,
      'name' => "Biflorane and serrulatane diterpenoids",
      'description' => "Diterpenoids with a structure based either on the biflorane or the serrulatane skeleton.",
      'parent' => 1551,
    ),
    array(
      'tid' => 352,
      'name' => "Cobalamin derivatives",
      'description' => "Organic compounds containing a corrin ring, a cobalt atom, an a nucleotide moiety. Cobalamin Derivatives are actually derived from vitamin B12.",
      'parent' => 353,
    ),
    array(
      'tid' => 353,
      'name' => "Corrinoids",
      'description' => "Derivatives of the corrin nucleus, which contain four reduced or partly reduced pyrrole rings joined in a macrocycle by three =CH- groups and one direct carbon-carbon bond linking alpha positions.",
      'parent' => 1455,
    ),
    array(
      'tid' => 354,
      'name' => "Coumestans",
      'description' => "Polycyclic aromatic compounds containing a coumestan moiety, which consists of a benzoxole fused to a chromen-2-one to form 1-Benzoxolo[3,2-c]chromen-6-one. They are oxidation products of pterocarpan.",
      'parent' => 2506,
    ),
    array(
      'tid' => 355,
      'name' => "Cumenes",
      'description' => "Aromatic compounds containing a prop-2-ylbenzene moiety.",
      'parent' => 2279,
    ),
    array(
      'tid' => 356,
      'name' => "Curcuminoids",
      'description' => "Aromatic compounds containing a curcumin moiety, which is composed of two aryl buten-2-one (feruloyl) chromophores joined by a methylene group.",
      'parent' => 2651,
    ),
    array(
      'tid' => 357,
      'name' => "Sesquaterpenoids",
      'description' => "Terpenoids with at least 7 consecutive isoprene units.",
      'parent' => 259,
    ),
    array(
      'tid' => 358,
      'name' => "Furanocoumarins",
      'description' => "Polycyclic aromatic compounds containing a furan ring fused to a coumarin moiety.",
      'parent' => 145,
    ),
    array(
      'tid' => 359,
      'name' => "Thietanes",
      'description' => "Heterocyclic compounds containing a saturated four-member ring with three carbon atoms and one sulfur atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 360,
      'name' => "Thietes",
      'description' => "Heterocyclic compounds containing an unsaturated aliphatic four-member ring with three carbon atoms, one sulfur atom, and one double bond.",
      'parent' => 2,
    ),
    array(
      'tid' => 361,
      'name' => "Organic cyanamides",
      'description' => "Organic compounds comprising the cyanamide functional group, with the general structure R1N=C=NR2.",
      'parent' => 278,
    ),
    array(
      'tid' => 362,
      'name' => "Nitriles",
      'description' => "Compounds having the structure RC#N; thus C-substituted derivatives of hydrocyanic acid, HC#N.",
      'parent' => 4504,
    ),
    array(
      'tid' => 363,
      'name' => "Cyanates",
      'description' => "Organic compounds containing the cyanate functional group with the formula [OCN]-.",
      'parent' => 463,
    ),
    array(
      'tid' => 364,
      'name' => "Organic carbonic acids and derivatives",
      'description' => "Compounds comprising the organic carbonic acid or a derivative thereof.",
      'parent' => 264,
    ),
    array(
      'tid' => 365,
      'name' => "Cyclamates",
      'description' => "Compounds containing a cyclohexylsulfamic acid moiety.",
      'parent' => 39,
    ),
    array(
      'tid' => 366,
      'name' => "Nitrosimines",
      'description' => "Compounds containing the nitrosimine functional group, with the general structure O=NN=CR2.",
      'parent' => 4777,
    ),
    array(
      'tid' => 367,
      'name' => "Dihydropyridines",
      'description' => "Compounds containing a dihydropyridine moiety, which is a semi-saturated pyridine derivative with two double bonds.",
      'parent' => 2224,
    ),
    array(
      'tid' => 368,
      'name' => "Dioxanes",
      'description' => "Compounds containing a dioxane ring, which is a six-membered saturated ring of two oxygen atoms and four carbon atoms. The dioxanes are divided in 1,2-dioxanes, 1,3-dioxanes, and 1,4-dioxanes.",
      'parent' => 2,
    ),
    array(
      'tid' => 369,
      'name' => "Diphenylmethanes",
      'description' => "Compounds containing a diphenylmethane moiety, which consists of a methane wherein two hydrogen atoms are replaced by two phenyl groups.",
      'parent' => 2279,
    ),
    array(
      'tid' => 370,
      'name' => "Phenylmorpholines",
      'description' => "Aromatic compounds containing a morpholine ring and a benzene ring linked to each other through a CC or a CN bond.",
      'parent' => 392,
    ),
    array(
      'tid' => 371,
      'name' => "Ergotamines, dihydroergotamines, and derivatives",
      'description' => "Organic compounds containing an ergotamine moiety, which is structurally characterized by a benzyl substituent attached to the piperazine ring of the ergopeptine backbone.",
      'parent' => 2030,
    ),
    array(
      'tid' => 372,
      'name' => "Fentanyls",
      'description' => "Compounds containing the fentanyl moiety or a derivative, which is based on a N-(1-(2-phenylethyl)-4-piperidinyl)-N-phenylpropanamide skeleton.",
      'parent' => 195,
    ),
    array(
      'tid' => 373,
      'name' => "Glucosinolates",
      'description' => "Carbohydrate derivatives containing a  N-(sulfooxy)ethenimidothioic acid derivative attached to the C1 carbon of glucose moiety.",
      'parent' => 1498,
    ),
    array(
      'tid' => 374,
      'name' => "Glucuronides",
      'description' => "Compounds comprising the glucuronic acid linked to another substance via a glycosidic bond.",
      'parent' => 2094,
    ),
    array(
      'tid' => 375,
      'name' => "Guanidines",
      'description' => "Compounds containing a guanidine moiety, with the general structure (R1R2N)(R3R4N)C=N-R5.",
      'parent' => 278,
    ),
    array(
      'tid' => 376,
      'name' => "Hydroxamic acids",
      'description' => "Compounds containing a hydroxamic acid functional group in which a hydroxylamine is inserted into a carboxylic acid. Its general structure is R-CO-NH-OH, with an R as an organic residue.",
      'parent' => 1662,
    ),
    array(
      'tid' => 377,
      'name' => "Thiiranes",
      'description' => "Heterocyclic compounds containing a saturated three-member ring with two carbon atoms and one sulfur atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 378,
      'name' => "Dithietanes",
      'description' => "Compounds comprising a dithietane moiety, which is four-member saturated ring containing two divalent sulfur atoms and two carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 379,
      'name' => "Proanthocyanidins",
      'description' => "Molecules containing an oligomeric moiety of C4-C8 and/or C4-C6 and/or C2-C7 oligo/polymers of flavan-3-ols.",
      'parent' => 238,
    ),
    array(
      'tid' => 380,
      'name' => "Hydroxyquinols and derivatives",
      'description' => "Compounds containing a 1,2,4-trihydroxybenzene moiety.",
      'parent' => 1310,
    ),
    array(
      'tid' => 381,
      'name' => "Aporphines",
      'description' => "Quinoline alkaloids containing the dibenzo[de,g]quinoline ring system or a dehydrogenated derivative thereof.",
      'parent' => 279,
    ),
    array(
      'tid' => 382,
      'name' => "Phloroglucinols and derivatives",
      'description' => "Compounds containing a phloroglucinol (benzene-1,3,5-triol) moiety, which consists of a benzene ring bearing one hydroxyl group at positions 1,3, and 5.",
      'parent' => 1310,
    ),
    array(
      'tid' => 383,
      'name' => "Hydroperoxyeicosatrienoic acids",
      'description' => "Eicosanoic acids with an attached hydroperoxyl group and three CC double bonds.",
      'parent' => 513,
    ),
    array(
      'tid' => 384,
      'name' => "Alloxazines and isoalloxazines",
      'description' => "Organic compounds comprising the (iso)alloxazine structure (Benzo[g]pteridine-2,4-dione).",
      'parent' => 109,
    ),
    array(
      'tid' => 385,
      'name' => "Batrachotoxins and derivatives",
      'description' => "Potent cardiotoxic and neurotoxic alkaloids containing a C21-steroid backbone. They have been characterized  from skin extracts of different frog species. The batrachotoxins have a homomorpholine ring at the steroidal CD-ring junction, a 3,9-hemiketal bridge and, in some cases, a 20beta-2,4-dialkylpyrrole-3-carboxylate moiety.",
      'parent' => 2724,
    ),
    array(
      'tid' => 386,
      'name' => "Acyl cholines",
      'description' => "Acylated derivatives of choline. Choline or 2-Hydroxy-N,N,N-trimethylethanaminium is a quaternary ammonium salt with the chemical formula (CH3)3N+(CH2)2OH.",
      'parent' => 1012,
    ),
    array(
      'tid' => 387,
      'name' => "Hydroperoxyeicosatetraenoic acids",
      'description' => "Eicosanoic acids with an attached hydroperoxyl group and four CC double bonds.",
      'parent' => 513,
    ),
    array(
      'tid' => 388,
      'name' => "Ketenes",
      'description' => "Organic compounds in which a carbonyl group is connected by a double bond to an alkylidene group R2C=C=O.",
      'parent' => 323,
    ),
    array(
      'tid' => 389,
      'name' => "Keto acids and derivatives",
      'description' => "Organic compounds containing a ketone group and a carboxylic acid group.",
      'parent' => 264,
    ),
    array(
      'tid' => 390,
      'name' => "Indolequinones",
      'description' => "Polycyclic compounds containing an indolequinone moiety, which consists of an indole bearing two ketones at positions 5 and 6 (or 4 and 7).",
      'parent' => 211,
    ),
    array(
      'tid' => 391,
      'name' => "Mitomycins",
      'description' => "Polycyclic compounds with a structure based on an aziridine ring linked to a 7-amino-6-methyl-cyclohexa[b]pyrrolizine-5,8-dione.",
      'parent' => 4096,
    ),
    array(
      'tid' => 392,
      'name' => "Morpholines",
      'description' => "Organic compounds containing a morpholine moiety, which consists of a six-member aliphatic saturated ring with the formula C4H9NO, where the oxygen and nitrogen atoms lie at positions 1 and 4, respectively.",
      'parent' => 107,
    ),
    array(
      'tid' => 393,
      'name' => "Oxoeicosapolyenoic acids",
      'description' => "Eicosapolyenoic acids (C20 fatty acid with more than one C=C double bonds on the chain).",
      'parent' => 513,
    ),
    array(
      'tid' => 394,
      'name' => "Alpha amino acid esters",
      'description' => "Ester derivatives of alpha amino acids.",
      'parent' => 60,
    ),
    array(
      'tid' => 395,
      'name' => "Organic nitrates",
      'description' => "Organic compounds containing the nitrate oxoanion, with the formula NO3-.",
      'parent' => 463,
    ),
    array(
      'tid' => 396,
      'name' => "Organic nitrites",
      'description' => "Organic compounds containing the nitrite oxoanion, with the formula NO2-.",
      'parent' => 463,
    ),
    array(
      'tid' => 397,
      'name' => "Pyrogallols and derivatives",
      'description' => "Compounds containing a 1,2,3-trihydroxybenzene moiety.",
      'parent' => 1310,
    ),
    array(
      'tid' => 398,
      'name' => "Nitrogen mustard compounds",
      'description' => "Compounds having two beta-haloalkyl groups bound to a nitrogen atom.",
      'parent' => 278,
    ),
    array(
      'tid' => 399,
      'name' => "Phenylazides",
      'description' => "Compounds containing a phenylazide moiety, which consists of a linear azide substituent attached to a phenyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 400,
      'name' => "Organophosphorus compounds",
      'description' => "Organic compounds containing the phosphorus atom.",
      'parent' => 0,
    ),
    array(
      'tid' => 401,
      'name' => "Organic phosphines and derivatives",
      'description' => "Organic compounds containing a phosphine derivative, with the general formula B1P(R2)R3 (R1-R3=alkyl, aryl).",
      'parent' => 400,
    ),
    array(
      'tid' => 402,
      'name' => "Organic phosphoric acids and derivatives",
      'description' => "Organic compounds containing phosphoric acid or a derivative thereof.",
      'parent' => 264,
    ),
    array(
      'tid' => 403,
      'name' => "Organic sulfuric acids and derivatives",
      'description' => "Organic compounds containing the sulfuric acid or a derivative thereof.",
      'parent' => 264,
    ),
    array(
      'tid' => 404,
      'name' => "Miscellaneous chromites",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is chromite, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 405,
      'name' => "Organoarsenic compounds",
      'description' => "Compounds containing bond between a carbon atom and an arsenic atom.",
      'parent' => 1370,
    ),
    array(
      'tid' => 406,
      'name' => "Organolithium compounds",
      'description' => "Organic compounds containing a bond between a carbon atom and lithium atom.",
      'parent' => 1372,
    ),
    array(
      'tid' => 407,
      'name' => "Organomercurial compounds",
      'description' => "Organic compounds containing a bond between a carbon atom and mercury atom.",
      'parent' => 1371,
    ),
    array(
      'tid' => 408,
      'name' => "Phosphate esters",
      'description' => "Organic compounds containing phosphoric acid ester functional group, with the general structure R1P(=O)(R2)OR3. R1,R2 = O,N,  or halogen atom; R3 = organyl group.",
      'parent' => 402,
    ),
    array(
      'tid' => 409,
      'name' => "Keto fatty acids",
      'description' => "Fatty acids containing a ketone group attached to the acyl chain.",
      'parent' => 262,
    ),
    array(
      'tid' => 410,
      'name' => "Azo compounds",
      'description' => "Derivatives of diazene(diimide), HN=NH, wherein both hydrogens are substituted by hydrocarbyl groups, e.g. PhN=NPh azobenzene or diphenyldiazene.",
      'parent' => 278,
    ),
    array(
      'tid' => 411,
      'name' => "Oximes",
      'description' => "Compounds containing the oxime functional group, with the general structure R1(R2)C=NOH.",
      'parent' => 278,
    ),
    array(
      'tid' => 412,
      'name' => "Dioxetanes",
      'description' => "Compounds containing a dioxetane ring, which is a four-member ring of two oxygen atoms and two carbon atoms. The dioxetanes are divided in 1,2-dioxetanes, and 1,3-dioxetanes.",
      'parent' => 2,
    ),
    array(
      'tid' => 413,
      'name' => "Pentalenes",
      'description' => "Compounds containing a pentalene moiety, which consists of two fused cyclopentadiene rings.",
      'parent' => 2840,
    ),
    array(
      'tid' => 414,
      'name' => "Organic peroxides",
      'description' => "Organic compounds containing the peroxide group, with the formula  R1OOR2 (R1,R2=H, alkyl, aryl).",
      'parent' => 3940,
    ),
    array(
      'tid' => 415,
      'name' => "Boronic acids",
      'description' => "Compounds comprising the boronic acid functional group RB(O)O  (R,R'=alkyl, aryl).",
      'parent' => 498,
    ),
    array(
      'tid' => 416,
      'name' => "Phenazines and derivatives",
      'description' => "Polycyclic aromatic compounds containing a phenazine moiety, which is a linear tricyclic system that consists of a two benzene rings joined by a pyrazine ring.",
      'parent' => 486,
    ),
    array(
      'tid' => 417,
      'name' => "Phenoxyacetic acid derivatives",
      'description' => "Compounds containing an anisole where the methane group is linked to an acetic acid or a derivative.",
      'parent' => 2279,
    ),
    array(
      'tid' => 418,
      'name' => "Phenylacetic acids",
      'description' => "Compounds containing a phenylacetic acid moiety, which consists of a phenyl group substituted at the second position by an acetic acid.",
      'parent' => 2279,
    ),
    array(
      'tid' => 419,
      'name' => "Organic phosphonic acids and derivatives",
      'description' => "Organic compounds containing phosphonic acid or a derivative thereof.",
      'parent' => 264,
    ),
    array(
      'tid' => 420,
      'name' => "Chlorinated dibenzo-p-dioxins",
      'description' => "Organic compounds containing a chlorine atom attached to a dibenzo-p-dioxin moiety.",
      'parent' => 1381,
    ),
    array(
      'tid' => 421,
      'name' => "Methoxy fatty acids",
      'description' => "Lipids containing a methoxy group linked to a fatty acid chain.",
      'parent' => 262,
    ),
    array(
      'tid' => 422,
      'name' => "Homogeneous metal compounds",
      'description' => "Inorganic compounds that contain only metal atoms.",
      'parent' => 1,
    ),
    array(
      'tid' => 423,
      'name' => "Homogeneous non-metal compounds",
      'description' => "Inorganic compounds that contain only non-metal elements.",
      'parent' => 1,
    ),
    array(
      'tid' => 424,
      'name' => "Mixed metal/non-metal compounds",
      'description' => "Compounds that contains both metal and non metal atoms.",
      'parent' => 1,
    ),
    array(
      'tid' => 425,
      'name' => "Homogeneous alkali metal compounds",
      'description' => "Inorganic compounds containing only metal atoms,with the largest atom being a alkali metal atom.",
      'parent' => 422,
    ),
    array(
      'tid' => 426,
      'name' => "Homogeneous transition metal compounds",
      'description' => "Inorganic compounds containing only metal atoms,with the largest atom being a transition metal atom.",
      'parent' => 422,
    ),
    array(
      'tid' => 427,
      'name' => "Homogeneous post-transition metal compounds",
      'description' => "Inorganic compounds containing only metal atoms,with the largest atom being a post-transition metal atom.",
      'parent' => 422,
    ),
    array(
      'tid' => 428,
      'name' => "Homogeneous alkaline earth metal compounds",
      'description' => "Inorganic compounds containing only metal atoms,with the largest atom being a alkaline earth metal atom.",
      'parent' => 422,
    ),
    array(
      'tid' => 429,
      'name' => "Homogeneous lanthanide compounds",
      'description' => "Inorganic compounds containing only metal atoms, with the largest atom being a lanthanide atom.",
      'parent' => 422,
    ),
    array(
      'tid' => 430,
      'name' => "Homogeneous actinide compounds",
      'description' => "Inorganic compounds containing only metal atoms,with the largest atom being a transition metal atom.",
      'parent' => 422,
    ),
    array(
      'tid' => 431,
      'name' => "Homogeneous metalloid compounds",
      'description' => "Inorganic compounds containing only metal atoms,with the largest atom being a metalloid atom.",
      'parent' => 422,
    ),
    array(
      'tid' => 432,
      'name' => "Homogeneous halogens",
      'description' => "Inorganic non-metallic compounds in which the largest atom is a nobel gas.",
      'parent' => 423,
    ),
    array(
      'tid' => 433,
      'name' => "Homogeneous noble gases",
      'description' => "Inorganic non-metallic compounds in which the largest atom is a halogen atom.",
      'parent' => 423,
    ),
    array(
      'tid' => 434,
      'name' => "Homogeneous other non-metal compounds",
      'description' => "Inorganic non-metallic compounds in which the largest atom belongs to the class of 'other non-metals'.",
      'parent' => 423,
    ),
    array(
      'tid' => 435,
      'name' => "Non-metal oxoanionic compounds",
      'description' => "Inorganic non-metallic compounds containing an oxoanion.",
      'parent' => 423,
    ),
    array(
      'tid' => 436,
      'name' => "Azoles",
      'description' => "Organic compounds comprising a five-member nitrogen heterocyclic ring containing at least one other non-carbon atom of either nitrogen, sulfur, or oxygen. The parent compounds are aromatic and have two double bonds; there are successively reduced analogs (azolines and azolidines) with fewer.",
      'parent' => 2,
    ),
    array(
      'tid' => 437,
      'name' => "Other non-metal halides",
      'description' => "Inorganic compounds containing 'other non-metals' and halogen.",
      'parent' => 423,
    ),
    array(
      'tid' => 438,
      'name' => "Alkali metal salts",
      'description' => "Inorganic salt compounds in which the heaviest ionic metal atom is an alkali metal.",
      'parent' => 424,
    ),
    array(
      'tid' => 439,
      'name' => "Alkaline earth metal salts",
      'description' => "Inorganic halogenic compounds in which the heaviest metal atom is an alkaline earth metal.",
      'parent' => 424,
    ),
    array(
      'tid' => 440,
      'name' => "Lanthanide salts",
      'description' => "Inorganic halogenic compounds in which the heaviest metal atom is a lanthanide.",
      'parent' => 424,
    ),
    array(
      'tid' => 441,
      'name' => "Actinide salts",
      'description' => "Inorganic halogenic compounds in which the heaviest metal atom is an actinide.",
      'parent' => 424,
    ),
    array(
      'tid' => 442,
      'name' => "Metalloid salts",
      'description' => "Inorganic halogenic compounds in which the heaviest metal atom is a metalloid.",
      'parent' => 424,
    ),
    array(
      'tid' => 443,
      'name' => "Transition metal salts",
      'description' => "Inorganic halogenic compounds in which the heaviest metal atom is a transition metal.",
      'parent' => 424,
    ),
    array(
      'tid' => 444,
      'name' => "Post-transition metal salts",
      'description' => "Inorganic halogenic compounds in which the heaviest metal atom is a post-transition metal.",
      'parent' => 424,
    ),
    array(
      'tid' => 445,
      'name' => "Alkali metal oxoanionic compounds",
      'description' => "Inorganic oxoanionic compounds in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 424,
    ),
    array(
      'tid' => 446,
      'name' => "Alkaline earth metal oxoanionic compounds",
      'description' => "Inorganic oxoanionic compounds in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 424,
    ),
    array(
      'tid' => 447,
      'name' => "Lanthanide oxoanionic compounds",
      'description' => "Inorganic oxoanionic compounds in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 424,
    ),
    array(
      'tid' => 448,
      'name' => "Actinide oxoanionic compounds",
      'description' => "Inorganic oxoanionic compounds in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 424,
    ),
    array(
      'tid' => 449,
      'name' => "Metalloid oxoanionic compounds",
      'description' => "Inorganic oxoanionic compounds in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 424,
    ),
    array(
      'tid' => 450,
      'name' => "Transition metal oxoanionic compounds",
      'description' => "Inorganic oxoanionic compounds in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 424,
    ),
    array(
      'tid' => 451,
      'name' => "Post-transition metal oxoanionic compounds",
      'description' => "Inorganic oxoanionic compounds in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 424,
    ),
    array(
      'tid' => 452,
      'name' => "Metalloporphyrins",
      'description' => "Polycyclic compounds containing a porphyrin moiety and a metal atom.",
      'parent' => 1926,
    ),
    array(
      'tid' => 453,
      'name' => "Other non-metal organides",
      'description' => "Inorganic compounds belonging to either of the other non-metal Hydrides, other non-metal nitrides, other non-metal oxides, or the other non-metal sulfides.",
      'parent' => 423,
    ),
    array(
      'tid' => 454,
      'name' => "Halogen organides",
      'description' => "Inorganic compounds belonging to either the halogen hydrides, halogen nitrides, halogen oxides, or halogen sulfides.",
      'parent' => 423,
    ),
    array(
      'tid' => 455,
      'name' => "Actinide organides",
      'description' => "Organic compounds belonging to either the actinide hydrides, actinide nitrides, actinide oxides, or actinide sulfides.",
      'parent' => 424,
    ),
    array(
      'tid' => 456,
      'name' => "Alkali metal organides",
      'description' => "Inorganic compounds belonging either to the alkali metal hydrides, the alkali metal nitrides, the alkali metal oxides, or the alkali metal sulfides.",
      'parent' => 424,
    ),
    array(
      'tid' => 457,
      'name' => "Alkaline earth metal organides",
      'description' => "Inorganic compounds belonging either to the alkaline earth metal hydrides, the alkaline earth metal nitrides, the alkaline earth metal oxides, or the alkaline earth metal sulfides.",
      'parent' => 424,
    ),
    array(
      'tid' => 458,
      'name' => "Post-transition metal organides",
      'description' => "Inorganic compounds belonging either to the post-transition metal hydrides, post-transition metal nitrides, post-transition metal oxides, or the post-transition metal sulfides.",
      'parent' => 424,
    ),
    array(
      'tid' => 459,
      'name' => "Lanthanide organides",
      'description' => "Inorganic compounds belonging to either the lanthanide hydrides, lanthanide nitrides, lanthanide oxides, lanthanide sulfides.",
      'parent' => 424,
    ),
    array(
      'tid' => 460,
      'name' => "Metalloid organides",
      'description' => "Inorganic compounds belonging to either of the metalloid hydrides, metalloid nitrides, metalloid oxides, metalloid sulfides.",
      'parent' => 424,
    ),
    array(
      'tid' => 461,
      'name' => "Transition metal organides",
      'description' => "Inorganic compounds belonging to either the alkaline earth metal hydrides, alkaline earth metal nitrides, alkaline earth metal oxides, alkaline earth metal sulfides.",
      'parent' => 424,
    ),
    array(
      'tid' => 462,
      'name' => "Organometallic compounds",
      'description' => "Organic compounds containing a bond between a carbon atom and metal atom.",
      'parent' => 0,
    ),
    array(
      'tid' => 463,
      'name' => "Organic oxoanionic compounds",
      'description' => "Organic compounds containing an oxoanion.",
      'parent' => 4603,
    ),
    array(
      'tid' => 464,
      'name' => "Acetylenedicarboxylates",
      'description' => "Organic compounds containing but-2-ynedioic acid or a derivative thereof.",
      'parent' => 264,
    ),
    array(
      'tid' => 465,
      'name' => "Coumaric acid esters",
      'description' => "Aromatic compounds containing an ester derivative of coumaric acid.",
      'parent' => 3002,
    ),
    array(
      'tid' => 466,
      'name' => "Fulminates",
      'description' => "Organic compounds containing the fulminate ion, with the formula CNO-.",
      'parent' => 463,
    ),
    array(
      'tid' => 467,
      'name' => "Phenylcarbamic acids",
      'description' => "Compounds containing a phenylazide moiety, which consists of a carbamic acid substituent attached to a phenyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 468,
      'name' => "Dicarbonic acids and derivatives",
      'description' => "Compounds containing the divalent [-O-(C=O)-O-(C=O)-O-] or C2O52 functional group, which consists of two carbonate groups sharing an oxygen atom.",
      'parent' => 1240,
    ),
    array(
      'tid' => 469,
      'name' => "Monoalkylamines",
      'description' => "Organic compounds containing an primary aliphatic amine group.",
      'parent' => 2450,
    ),
    array(
      'tid' => 470,
      'name' => "Enamines",
      'description' => "Compounds containing the enamine functional group with the general structure R1N(R2)CR=C(R3)R4.",
      'parent' => 2449,
    ),
    array(
      'tid' => 471,
      'name' => "Nitro fatty acids",
      'description' => "Fatty acids containing a nitro group.",
      'parent' => 262,
    ),
    array(
      'tid' => 472,
      'name' => "Hydroxy acids and derivatives",
      'description' => "Compounds comprising one or more hydroxy acid groups.",
      'parent' => 264,
    ),
    array(
      'tid' => 473,
      'name' => "Organogold compounds",
      'description' => "Organic compounds containing a bond between a carbon atom and a gold atom.",
      'parent' => 1371,
    ),
    array(
      'tid' => 474,
      'name' => "Biguanides",
      'description' => "Organic compounds containing two N-linked guanidines.",
      'parent' => 375,
    ),
    array(
      'tid' => 475,
      'name' => "Carboxylic acid amides",
      'description' => "Carboxylic acid derivatives containing a carbonyl group in which the carbon atom is linked to a nitrogen atom (substituted or not). The general formula of the carboxylic acid amide is R1C(=O)N(R2)R3 (R1,R2,R3=H, alkyl, aryl).",
      'parent' => 1093,
    ),
    array(
      'tid' => 476,
      'name' => "Cinnamic acids and derivatives",
      'description' => "Organic aromatic compounds containing a benzene and a carboxylic acid group (or a derivative thereof) forming 3-phenylprop-2-enoic acid.",
      'parent' => 261,
    ),
    array(
      'tid' => 477,
      'name' => "Acyclic sesquiterpenoids",
      'description' => "Sesquiterpenoids (compounds made of three consecutive isoprene units) that do not contain a cycle.",
      'parent' => 1550,
    ),
    array(
      'tid' => 478,
      'name' => "Polyprenyl phosphates",
      'description' => "Prenol lipids in which the phosphate group is linked to one end of the polyprenol moiety.",
      'parent' => 1535,
    ),
    array(
      'tid' => 479,
      'name' => "Purine nucleosides",
      'description' => "Compounds comprising a purine base attached to a ribosyl or deoxyribosyl moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 480,
      'name' => "Pyrimidine nucleosides",
      'description' => "Compounds comprising a pyrimidine base attached to a ribosyl or deoxyribosyl moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 481,
      'name' => "Pyranones and derivatives",
      'description' => "Compounds containing a pyran ring which bears a ketone.",
      'parent' => 86,
    ),
    array(
      'tid' => 482,
      'name' => "Trithiolanes",
      'description' => "Organic compounds containing a six-member aliphatic saturated heterocycle made up of three sulfur atoms and two carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 483,
      'name' => "Halogenated fatty acids",
      'description' => "Fatty acids with a chain that carries a halogen atom (Cl,F,I,Br).",
      'parent' => 262,
    ),
    array(
      'tid' => 484,
      'name' => "Dithiolanes",
      'description' => "Compounds containing a dithiolane ring,  which consists of a sulfur heterocycle derived from cyclopentane by replacing two CH2 groups with thioether groups.",
      'parent' => 2,
    ),
    array(
      'tid' => 485,
      'name' => "Quinazolines",
      'description' => "Compounds containing a quinazoline moiety, which is made up of two fused six-member aromatic rings, a benzene ring and a pyrimidine ring.",
      'parent' => 4789,
    ),
    array(
      'tid' => 486,
      'name' => "Quinoxalines",
      'description' => "Compounds containing a quinoxaline moiety, a bicyclic heterocycle made up of a benzene ring fused to a pyrazine ring.",
      'parent' => 4789,
    ),
    array(
      'tid' => 487,
      'name' => "Salicylic acid and derivatives",
      'description' => "Compounds containing a 2-hydroxybenzoic acid moiety or a derivative thereof.",
      'parent' => 1248,
    ),
    array(
      'tid' => 488,
      'name' => "Organic nitric acids and derivatives",
      'description' => "Compounds containing an organonitric acid group or a derivative thereof.",
      'parent' => 264,
    ),
    array(
      'tid' => 489,
      'name' => "Amino fatty acids",
      'description' => "Fatty acids containing an amine group.",
      'parent' => 262,
    ),
    array(
      'tid' => 490,
      'name' => "Sulfonylureas",
      'description' => "Organic compounds containing a sulfonyl group with the structure R-S(=O)2-R', where R' is an urea.",
      'parent' => 278,
    ),
    array(
      'tid' => 491,
      'name' => "Sulfoxides",
      'description' => "Compounds containing a sulfoxide functional group, with the structure RS(=O)R' (R,R' not H).",
      'parent' => 4,
    ),
    array(
      'tid' => 492,
      'name' => "Tropane alkaloids",
      'description' => "Organic compounds containing the nitrogenous bicyclic alkaloid parent N-Methyl-8-azabicyclo[3.2.1]octane.",
      'parent' => 279,
    ),
    array(
      'tid' => 493,
      'name' => "Thiaziridines",
      'description' => "Organic heterocyclic compounds with a 3-membered saturated ring with a thioether group and an amine group in the 1 and 2 positions, respectively.",
      'parent' => 2,
    ),
    array(
      'tid' => 494,
      'name' => "Isoflavones",
      'description' => "Polycyclic compounds containing a 2-isoflavene skeleton which bears a ketone group at the C4 carbon atom.",
      'parent' => 2901,
    ),
    array(
      'tid' => 495,
      'name' => "Carbocyclic fatty acids",
      'description' => "Fatty acids containing a carbocyclic ring .",
      'parent' => 262,
    ),
    array(
      'tid' => 496,
      'name' => "Amine oxides and derivatives",
      'description' => "Organic compounds that contains the amine oxide functional group with the formula R3N+-O-, which substituted by at least one organic group.",
      'parent' => 2449,
    ),
    array(
      'tid' => 497,
      'name' => "Aminals",
      'description' => "Compounds having two amino groups bonded to the same carbon,  R2C(NR2)2 where R can by a hydrogen or an alkyl group.",
      'parent' => 278,
    ),
    array(
      'tid' => 498,
      'name' => "Boronic acid derivatives",
      'description' => "Compounds comprising any derivative of the boronic acid functional group, with the general structure RB(X)Y (R=alkyl, aryl; X,Y= any O, N, Hal residue).",
      'parent' => 264,
    ),
    array(
      'tid' => 499,
      'name' => "Imidoesters",
      'description' => "Organic ester derivatives of imidic acid. They have the general structure ROC(CR')=NR\", where R=organyl group, R'-R\"= H or organyl group.",
      'parent' => 2285,
    ),
    array(
      'tid' => 500,
      'name' => "Chlorinated biphenyls",
      'description' => "Organic compounds containing at least one chlorine atom attached to either benzene ring of the biphenyl moiety.",
      'parent' => 41,
    ),
    array(
      'tid' => 501,
      'name' => "Isocyanates",
      'description' => "Organic compounds containing the isocyanic acid tautomer, HN=C=O, of cyanic acid, HOC#N or its hydrocarbyl derivatives RN=C=O.",
      'parent' => 278,
    ),
    array(
      'tid' => 502,
      'name' => "Xanthanolides",
      'description' => "Sesquiterpenoids with a structure based on the xanthanolide skeleton consistsing of a cycloheptane ring usually attached to a four-carbon chain (at carbon 1 ) and a methyl group (at carbon 10), and fused to a five-member lactone ring (sharing carbons 7 and 8). The lactone ring can be conjugated with a methyl or methylene group at position 11.",
      'parent' => 1543,
    ),
    array(
      'tid' => 503,
      'name' => "Quaternary ammonium salts",
      'description' => "Compounds containing positively charged polyatomic ion of the structure NR4+, R being an alkyl group or an aryl group.",
      'parent' => 278,
    ),
    array(
      'tid' => 504,
      'name' => "Lineolic acids and derivatives",
      'description' => "Derivatives of lineolic acid. Lineolic acid is a polyunsaturated omega-6 18 carbon long fatty acid, with two CC double bonds at the 9- and 12-positions.",
      'parent' => 3909,
    ),
    array(
      'tid' => 505,
      'name' => "Sulfones",
      'description' => "Compounds containing a sulfonyl group( which as the general structure RS(=O)2R' (R,R' =alkyl, aryl)) attached to two carbon atoms.",
      'parent' => 1157,
    ),
    array(
      'tid' => 506,
      'name' => "Sulfonyl halides",
      'description' => "Compounds containing a sulfonyl (R-S(=O)2-R') functional group singly bonded to a halogen atom.",
      'parent' => 267,
    ),
    array(
      'tid' => 507,
      'name' => "Isoflavonoid O-glycosides",
      'description' => "O-glycosylated derivatives of isoflavonoids, which are natural products derived from 3-phenylchromen-4-one.",
      'parent' => 2506,
    ),
    array(
      'tid' => 508,
      'name' => "Organic sulfonium compounds",
      'description' => "Organic compounds containing the sulfonium cation, with the general formula [SR3]+ (R=any atom).",
      'parent' => 4,
    ),
    array(
      'tid' => 509,
      'name' => "Sultams",
      'description' => "Sulfonamides in which the S-N bond is part of a ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 510,
      'name' => "Thioamides",
      'description' => "Organic compounds containing the functional group with the general structure R-CS-NR'R, where R, R', and R are organic groups.",
      'parent' => 4,
    ),
    array(
      'tid' => 511,
      'name' => "12-oxophytodienoic acid metabolites",
      'description' => "Biologically active organic compounds containing 12-oxophytodienoic acid, which consists of an oxo-cyclopentene linked to both an octanoic acid chain and pentene chain.",
      'parent' => 504,
    ),
    array(
      'tid' => 512,
      'name' => "Jasmonic acids",
      'description' => "Lipids containing or derived from a jasmonic acid, with a structure characterized by the presence of an alkene chain linked to a 2-(3-oxocyclopentyl)acetic acid moiety.",
      'parent' => 504,
    ),
    array(
      'tid' => 513,
      'name' => "Eicosanoids",
      'description' => "Unsaturated C20 fatty acids or skeletally related compounds. These include prostaglandins, thromboxanes, leukotrienes and other oxygenated derivatives, which are produced primarily by three classes of enzymes, cyclooxygenases (COX-1 and COX-2), lipoxygenases (LOX) and cytochrome P450 mono-oxygenases.",
      'parent' => 3909,
    ),
    array(
      'tid' => 514,
      'name' => "Prostaglandins and related compounds",
      'description' => "Unsaturated carboxylic acids consisting of a 20 carbon skeleton that also contains a five member ring, and are based upon the fatty acid arachidonic acid.",
      'parent' => 513,
    ),
    array(
      'tid' => 515,
      'name' => "Leukotrienes",
      'description' => "Eicosanoids containing a hydroxyl group attached to the aliphatic chain of an arachidonic acid. Leukotrienes have four double bonds, three (and only three) of which are conjugated.",
      'parent' => 513,
    ),
    array(
      'tid' => 516,
      'name' => "Dihydroxy bile acids, alcohols and derivatives",
      'description' => "Compounds containing or derived from a bile acid or alcohol, and which bears exactly two carboxylic acid groups.",
      'parent' => 2194,
    ),
    array(
      'tid' => 517,
      'name' => "Ureas",
      'description' => "Compounds containing two amine groups joined by a carbonyl (C=O) functional group.",
      'parent' => 364,
    ),
    array(
      'tid' => 518,
      'name' => "Triphenylenes",
      'description' => "Compounds containing a triphenylene moiety, which consists of four fused benzene rings forming a 9,10-benzo[l]phenanthrene.",
      'parent' => 25,
    ),
    array(
      'tid' => 519,
      'name' => "Thromboxanes",
      'description' => "Eicosanoids structurally characterized by the presence of a 6-member ether containing ring.",
      'parent' => 513,
    ),
    array(
      'tid' => 520,
      'name' => "Actinide hydrides",
      'description' => "Inorganic hydride compounds in which the heaviest metal atom is an actinide.",
      'parent' => 455,
    ),
    array(
      'tid' => 521,
      'name' => "Actinide nitrides",
      'description' => "Inorganic compounds of nitrogen where nitrogen has a formal oxidation state of -3, and the heaviest metal atom is an actinide.",
      'parent' => 455,
    ),
    array(
      'tid' => 522,
      'name' => "Actinide oxides",
      'description' => "Inorganic compounds containing an oxygen atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is an actinide.",
      'parent' => 455,
    ),
    array(
      'tid' => 523,
      'name' => "Actinide sulfides",
      'description' => "Inorganic compounds containing a sulfur atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is an actinide.",
      'parent' => 455,
    ),
    array(
      'tid' => 524,
      'name' => "Alkali metal hydrides",
      'description' => "Inorganic hydride compounds in which the heaviest metal atom is an alkali metal.",
      'parent' => 456,
    ),
    array(
      'tid' => 525,
      'name' => "Alkali metal nitrides",
      'description' => "Inorganic compounds of nitrogen where nitrogen has a formal oxidation state of -3, and the heaviest metal atom is an alkali metal.",
      'parent' => 456,
    ),
    array(
      'tid' => 526,
      'name' => "Alkali metal oxides",
      'description' => "Inorganic compounds containing an oxygen atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is an alkali metal.",
      'parent' => 456,
    ),
    array(
      'tid' => 527,
      'name' => "Alkali metal sulfides",
      'description' => "Inorganic compounds containing a sulfur atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is an alkali metal.",
      'parent' => 456,
    ),
    array(
      'tid' => 528,
      'name' => "Post-transition metal hydrides",
      'description' => "Inorganic hydride compounds in which the heaviest metal atom is a post-transition metal.",
      'parent' => 458,
    ),
    array(
      'tid' => 529,
      'name' => "Post-transition metal nitrides",
      'description' => "Inorganic compounds of nitrogen where nitrogen has a formal oxidation state of -3, and the heaviest metal atom is a post-transition metal.",
      'parent' => 458,
    ),
    array(
      'tid' => 530,
      'name' => "Post-transition metal oxides",
      'description' => "Inorganic compounds containing an oxygen atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is a post-transition metal.",
      'parent' => 458,
    ),
    array(
      'tid' => 531,
      'name' => "Post-transition metal sulfides",
      'description' => "Inorganic compounds containing a sulfur atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is a post-transition metal.",
      'parent' => 458,
    ),
    array(
      'tid' => 532,
      'name' => "Metalloid hydrides",
      'description' => "Inorganic hydride compounds in which the heaviest metal atom is a metalloid.",
      'parent' => 460,
    ),
    array(
      'tid' => 533,
      'name' => "Metalloid nitrides",
      'description' => "Inorganic compounds of nitrogen where nitrogen has a formal oxidation state of -3, and the heaviest metal atom is a metalloid.",
      'parent' => 460,
    ),
    array(
      'tid' => 534,
      'name' => "Metalloid oxides",
      'description' => "Inorganic compounds containing an oxygen atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is a metalloid.",
      'parent' => 460,
    ),
    array(
      'tid' => 535,
      'name' => "Metalloid sulfides",
      'description' => "Inorganic compounds containing a sulfur atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is a metalloid.",
      'parent' => 460,
    ),
    array(
      'tid' => 536,
      'name' => "Transition metal hydrides",
      'description' => "Inorganic hydride compounds in which the heaviest metal atom is a transition metal.",
      'parent' => 461,
    ),
    array(
      'tid' => 537,
      'name' => "Transition metal nitrides",
      'description' => "Inorganic compounds of nitrogen where nitrogen has a formal oxidation state of -3, and the heaviest metal atom is a transition metal.",
      'parent' => 461,
    ),
    array(
      'tid' => 538,
      'name' => "Transition metal oxides",
      'description' => "Inorganic compounds containing an oxygen atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is a transition metal.",
      'parent' => 461,
    ),
    array(
      'tid' => 539,
      'name' => "Transition metal sulfides",
      'description' => "Inorganic compounds containing a sulfur atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is a transition metal.",
      'parent' => 461,
    ),
    array(
      'tid' => 540,
      'name' => "Lanthanide hydrides",
      'description' => "Inorganic halogenic compounds in which the heaviest metal atom is a lanthanide.",
      'parent' => 459,
    ),
    array(
      'tid' => 541,
      'name' => "Lanthanide nitrides",
      'description' => "Inorganic compounds of nitrogen where nitrogen has a formal oxidation state of -3, and the heaviest metal atom is a lanthanide.",
      'parent' => 459,
    ),
    array(
      'tid' => 542,
      'name' => "Lanthanide oxides",
      'description' => "Inorganic compounds containing an oxygen atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is a lanthanide.",
      'parent' => 459,
    ),
    array(
      'tid' => 543,
      'name' => "Lanthanide sulfides",
      'description' => "Inorganic compounds containing a sulfur atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is a lanthanide.",
      'parent' => 459,
    ),
    array(
      'tid' => 544,
      'name' => "Alkaline earth metal hydrides",
      'description' => "Inorganic halogenic compounds in which the heaviest metal atom is an alkaline earth metal.",
      'parent' => 457,
    ),
    array(
      'tid' => 545,
      'name' => "Alkaline earth metal nitrides",
      'description' => "Inorganic compounds of nitrogen where nitrogen has a formal oxidation state of -3, and the heaviest metal atom is an alkaline earth metal.",
      'parent' => 457,
    ),
    array(
      'tid' => 546,
      'name' => "Alkaline earth metal oxides",
      'description' => "Inorganic compounds containing an oxygen atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is an alkaline earth metal.",
      'parent' => 457,
    ),
    array(
      'tid' => 547,
      'name' => "Alkaline earth metal sulfides",
      'description' => "Inorganic compounds containing a sulfur atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is an alkaline earth metal.",
      'parent' => 457,
    ),
    array(
      'tid' => 548,
      'name' => "Halogen hydrides",
      'description' => "Inorganic compounds in which the heaviest atom bonded to a hydrogen atom is a halogen.",
      'parent' => 454,
    ),
    array(
      'tid' => 549,
      'name' => "Halogen nitrides",
      'description' => "Inorganic compounds of nitrogen where nitrogen has a formal oxidation state of -3, and the heaviest atom bonded to it is a halogen.",
      'parent' => 454,
    ),
    array(
      'tid' => 550,
      'name' => "Halogen oxides",
      'description' => "Inorganic compounds containing an oxygen atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is a halogen.",
      'parent' => 454,
    ),
    array(
      'tid' => 551,
      'name' => "Halogen sulfides",
      'description' => "Inorganic compounds containing a sulfur atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen is a halogen.",
      'parent' => 454,
    ),
    array(
      'tid' => 552,
      'name' => "Other non-metal hydrides",
      'description' => "Inorganic compounds in which the heaviest atom bonded to a hydrogen atom is belongs to the class of 'other non-metals'.",
      'parent' => 453,
    ),
    array(
      'tid' => 553,
      'name' => "Other non-metal nitrides",
      'description' => "Inorganic compounds of nitrogen where nitrogen has a formal oxidation state of -3, and the heaviest atom bonded to it belongs to the class of 'other non-metals'.",
      'parent' => 453,
    ),
    array(
      'tid' => 554,
      'name' => "Other non-metal oxides",
      'description' => "Inorganic compounds containing an oxygen atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen belongs to the class of 'other non-metals'.",
      'parent' => 453,
    ),
    array(
      'tid' => 555,
      'name' => "Other non-metal sulfides",
      'description' => "Inorganic compounds containing a sulfur atom of an oxidation state of -2, in which the heaviest atom bonded to the oxygen belongs to the class of other non-metals.",
      'parent' => 453,
    ),
    array(
      'tid' => 556,
      'name' => "Actinide astatides",
      'description' => "Inorganic compounds in which the largest halogen atom is Astatine, and the heaviest metal atom is an actinide.",
      'parent' => 441,
    ),
    array(
      'tid' => 557,
      'name' => "Actinide bromides",
      'description' => "Inorganic compounds in which the largest halogen atom is Bromine, and the heaviest metal atom an actinide.",
      'parent' => 441,
    ),
    array(
      'tid' => 558,
      'name' => "Actinide chlorides",
      'description' => "Inorganic compounds in which the largest halogen atom is Chlorine, and the heaviest metal atom is an actinide.",
      'parent' => 441,
    ),
    array(
      'tid' => 559,
      'name' => "Actinide fluorides",
      'description' => "Inorganic compounds in which the largest halogen atom is fluorine, and the heaviest metal atom is an actinide.",
      'parent' => 441,
    ),
    array(
      'tid' => 560,
      'name' => "Actinide iodides",
      'description' => "Inorganic compounds in which the largest halogen atom is Iodine, and the heaviest metal atom is an actinide.",
      'parent' => 441,
    ),
    array(
      'tid' => 561,
      'name' => "Alkali metal astatides",
      'description' => "Inorganic compounds in which the largest halogen atom is Chlorine, and the heaviest metal atom is an alkali metal.",
      'parent' => 438,
    ),
    array(
      'tid' => 562,
      'name' => "Alkali metal bromides",
      'description' => "Inorganic compounds in which the largest halogen atom is Bromine, and the heaviest metal atom an alkali metal.",
      'parent' => 438,
    ),
    array(
      'tid' => 563,
      'name' => "Alkali metal chlorides",
      'description' => "Inorganic compounds in which the largest halogen atom is Chlorine, and the heaviest metal atom is an alkali metal.",
      'parent' => 438,
    ),
    array(
      'tid' => 564,
      'name' => "Alkali metal fluorides",
      'description' => "Inorganic compounds in which the largest halogen atom is fluorine, and the heaviest metal atom is an alkali metal.",
      'parent' => 438,
    ),
    array(
      'tid' => 565,
      'name' => "Alkali metal iodides",
      'description' => "Inorganic compounds in which the largest halogen atom is Iodine, and the heaviest metal atom is an alkali metal.",
      'parent' => 438,
    ),
    array(
      'tid' => 566,
      'name' => "Alkaline earth metal astatides",
      'description' => "Inorganic compounds in which the largest halogen atom is Astatine, and the heaviest metal atom is a lanthanide.",
      'parent' => 439,
    ),
    array(
      'tid' => 567,
      'name' => "Alkaline earth metal bromides",
      'description' => "Inorganic compounds in which the largest halogen atom is Bromine, and the heaviest metal atom a lanthanide.",
      'parent' => 439,
    ),
    array(
      'tid' => 568,
      'name' => "Alkaline earth metal chlorides",
      'description' => "Inorganic compounds in which the largest halogen atom is Chlorine, and the heaviest metal atom is a lanthanide.",
      'parent' => 439,
    ),
    array(
      'tid' => 569,
      'name' => "Alkaline earth metal fluorides",
      'description' => "Inorganic compounds in which the largest halogen atom is fluorine, and the heaviest metal atom is a lanthanide.",
      'parent' => 439,
    ),
    array(
      'tid' => 570,
      'name' => "Alkaline earth metal iodides",
      'description' => "Inorganic compounds in which the largest halogen atom is Iodine, and the heaviest metal atom is an alkaline earth metal.",
      'parent' => 439,
    ),
    array(
      'tid' => 571,
      'name' => "Post-transition metal astatides",
      'description' => "Inorganic compounds in which the largest halogen atom is Astatine, and the heaviest metal atom is a post-transition metal.",
      'parent' => 444,
    ),
    array(
      'tid' => 572,
      'name' => "Post-transition metal bromides",
      'description' => "Inorganic compounds in which the largest halogen atom is Bromine, and the heaviest metal atom a post-transition metal.",
      'parent' => 444,
    ),
    array(
      'tid' => 573,
      'name' => "Post-transition metal chlorides",
      'description' => "Inorganic compounds in which the largest halogen atom is Chlorine, and the heaviest metal atom is a post-transition metal.",
      'parent' => 444,
    ),
    array(
      'tid' => 574,
      'name' => "Post-transition metal fluorides",
      'description' => "Inorganic compounds in which the largest halogen atom is fluorine, and the heaviest metal atom is a post-transition metal.",
      'parent' => 444,
    ),
    array(
      'tid' => 575,
      'name' => "Post-transition metal iodides",
      'description' => "Inorganic compounds in which the largest halogen atom is Iodine, and the heaviest metal atom is a post-transition metal.",
      'parent' => 444,
    ),
    array(
      'tid' => 576,
      'name' => "Lanthanide astatides",
      'description' => "Inorganic compounds in which the largest halogen atom is Astatine, and the heaviest metal atom is a lanthanide.",
      'parent' => 440,
    ),
    array(
      'tid' => 577,
      'name' => "Lanthanide bromides",
      'description' => "Inorganic compounds in which the largest halogen atom is Bromine, and the heaviest metal atom a lanthanide.",
      'parent' => 440,
    ),
    array(
      'tid' => 578,
      'name' => "Lanthanide chlorides",
      'description' => "Inorganic compounds in which the largest halogen atom is Chlorine, and the heaviest metal atom is a lanthanide.",
      'parent' => 440,
    ),
    array(
      'tid' => 579,
      'name' => "Lanthanide fluorides",
      'description' => "Inorganic compounds in which the largest halogen atom is fluorine, and the heaviest metal atom is a lanthanide.",
      'parent' => 440,
    ),
    array(
      'tid' => 580,
      'name' => "Lanthanide iodides",
      'description' => "Inorganic compounds in which the largest halogen atom is Iodine, and the heaviest metal atom is a lanthanide.",
      'parent' => 440,
    ),
    array(
      'tid' => 581,
      'name' => "Metalloid astatides",
      'description' => "Inorganic compounds in which the largest halogen atom is Astatine, and the heaviest metal atom is a metalloid.",
      'parent' => 442,
    ),
    array(
      'tid' => 582,
      'name' => "Metalloid bromides",
      'description' => "Inorganic compounds in which the largest halogen atom is Bromine, and the heaviest metal atom a metalloid.",
      'parent' => 442,
    ),
    array(
      'tid' => 583,
      'name' => "Metalloid chlorides",
      'description' => "Inorganic compounds in which the largest halogen atom is Chlorine, and the heaviest metal atom is a metalloid.",
      'parent' => 442,
    ),
    array(
      'tid' => 584,
      'name' => "Metalloid fluorides",
      'description' => "Inorganic compounds in which the largest halogen atom is fluorine, and the heaviest metal atom is a metalloid.",
      'parent' => 442,
    ),
    array(
      'tid' => 585,
      'name' => "Metalloid iodides",
      'description' => "Inorganic compounds in which the largest halogen atom is Iodine, and the heaviest metal atom is a metalloid.",
      'parent' => 442,
    ),
    array(
      'tid' => 586,
      'name' => "Transition metal astatides",
      'description' => "Inorganic compounds in which the largest halogen atom is Astatine, and the heaviest metal atom is a transition metal.",
      'parent' => 443,
    ),
    array(
      'tid' => 587,
      'name' => "Transition metal bromides",
      'description' => "Inorganic compounds in which the largest halogen atom is Bromine, and the heaviest metal atom a transition metal.",
      'parent' => 443,
    ),
    array(
      'tid' => 588,
      'name' => "Transition metal chlorides",
      'description' => "Inorganic compounds in which the largest halogen atom is Chlorine, and the heaviest metal atom is a transition metal.",
      'parent' => 443,
    ),
    array(
      'tid' => 589,
      'name' => "Transition metal fluorides",
      'description' => "Inorganic compounds in which the largest halogen atom is fluorine, and the heaviest metal atom is a transition metal.",
      'parent' => 443,
    ),
    array(
      'tid' => 590,
      'name' => "Transition metal iodides",
      'description' => "Inorganic compounds in which the largest halogen atom is Iodine, and the heaviest metal atom is a transition metal.",
      'parent' => 443,
    ),
    array(
      'tid' => 591,
      'name' => "Actinide bromates",
      'description' => "Inorganic compounds in which the largest oxoanion is bromate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 592,
      'name' => "Actinide chlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 593,
      'name' => "Actinide chlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 594,
      'name' => "Actinide chromates",
      'description' => "Inorganic compounds in which the largest oxoanion is chromate, and in which the heaviest atom is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 595,
      'name' => "Actinide chromites",
      'description' => "Inorganic compounds in which the largest oxoanion is chromite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 596,
      'name' => "Actinide cyanates",
      'description' => "Inorganic compounds in which the largest oxoanion is cyanate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 597,
      'name' => "Purinones",
      'description' => "Purines in which the purine moiety bears a C=O group. Purine is a bicyclic aromatic compound made up of a pyrimidine ring fused to an imidazole ring.",
      'parent' => 245,
    ),
    array(
      'tid' => 598,
      'name' => "Actinide hydroxides",
      'description' => "Inorganic compounds in which the largest oxoanion is hydroxide, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 599,
      'name' => "Actinide hypobromites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypobromite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 600,
      'name' => "Actinide hypochlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypochlorite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 601,
      'name' => "Actinide hyponitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyponitrite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 602,
      'name' => "Actinide hypophosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypophosphite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 603,
      'name' => "Actinide iodates",
      'description' => "Inorganic compounds in which the largest oxoanion is iodate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 604,
      'name' => "Actinide nitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 605,
      'name' => "Actinide nitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 606,
      'name' => "Actinide orthonitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthonitrate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 607,
      'name' => "Actinide perbromates",
      'description' => "Inorganic compounds in which the largest oxoanion is perbromate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 608,
      'name' => "Actinide perchlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is perchlorate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 609,
      'name' => "Actinide periodates",
      'description' => "Inorganic compounds in which the largest oxoanion is periodate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 610,
      'name' => "Actinide permanganates",
      'description' => "Inorganic compounds in which the largest oxoanion is permanganate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 611,
      'name' => "Actinide peroxynitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 612,
      'name' => "Actinide peroxynitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 613,
      'name' => "Actinide perrhenates",
      'description' => "Inorganic compounds in which the largest oxoanion is perrhenate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 614,
      'name' => "Actinide pertechnetates",
      'description' => "Inorganic compounds in which the largest oxoanion is pertechnetate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 615,
      'name' => "Actinide phosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 616,
      'name' => "Actinide phosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 617,
      'name' => "Actinide pyrophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrophosphate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 618,
      'name' => "Actinide selenates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 619,
      'name' => "Actinide selenites",
      'description' => "Inorganic compounds in which the largest oxoanion is selenite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 620,
      'name' => "Actinide sulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 621,
      'name' => "Actinide sulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 622,
      'name' => "Actinide superoxides",
      'description' => "Inorganic compounds in which the largest oxoanion is superoxide, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 623,
      'name' => "N,N-diphenylcarbamic acids",
      'description' => "Compounds containing two phenyl groups linked to the nitrogen atom of a carbamic acid.",
      'parent' => 467,
    ),
    array(
      'tid' => 624,
      'name' => "Actinide peroxomonosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxomonosulfate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 625,
      'name' => "Actinide peroxodisulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxodisulfate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 626,
      'name' => "Actinide pyrosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrosulfate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 627,
      'name' => "Actinide tetrathionates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrathionate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 628,
      'name' => "Actinide thiosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiosulfate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 629,
      'name' => "Actinide dithionites",
      'description' => "Inorganic compounds in which the largest oxoanion is dithionite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 630,
      'name' => "Actinide hyposulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyposulfite, and in which the heaviest atom  not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 631,
      'name' => "Alkali metal bromates",
      'description' => "Inorganic compounds in which the largest oxoanion is bromate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 632,
      'name' => "Alkali metal chlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 633,
      'name' => "Alkali metal chlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 634,
      'name' => "Alkali metal chromates",
      'description' => "Inorganic compounds in which the largest oxoanion is chromate, and in which the heaviest atom is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 635,
      'name' => "Alkali metal chromites",
      'description' => "Inorganic compounds in which the largest oxoanion is chromite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 636,
      'name' => "Alkali metal cyanates",
      'description' => "Inorganic compounds in which the largest oxoanion is cyanate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 637,
      'name' => "Glycosylglycerols",
      'description' => "Glycerolipids structurally characterized by the presence of one or more sugar residues attached to glycerol via a glycosidic linkage.",
      'parent' => 175,
    ),
    array(
      'tid' => 638,
      'name' => "Alkali metal hydroxides",
      'description' => "Inorganic compounds in which the largest oxoanion is hydroxide, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 639,
      'name' => "Alkali metal hypobromites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypobromite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 640,
      'name' => "Alkali metal hypochlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypochlorite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 641,
      'name' => "Alkali metal hyponitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyponitrite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 642,
      'name' => "Alkali metal hypophosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypophosphite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 643,
      'name' => "Alkali metal iodates",
      'description' => "Inorganic compounds in which the largest oxoanion is iodate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 644,
      'name' => "Alkali metal nitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 645,
      'name' => "Alkali metal nitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 646,
      'name' => "Alkali metal orthonitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthonitrate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 647,
      'name' => "Alkali metal perbromates",
      'description' => "Inorganic compounds in which the largest oxoanion is perbromate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 648,
      'name' => "Alkali metal perchlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is perchlorate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 649,
      'name' => "Alkali metal periodates",
      'description' => "Inorganic compounds in which the largest oxoanion is periodate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 650,
      'name' => "Alkali metal permanganates",
      'description' => "Inorganic compounds in which the largest oxoanion is permanganate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 651,
      'name' => "Alkali metal peroxynitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 652,
      'name' => "Alkali metal peroxynitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 653,
      'name' => "Alkali metal perrhenates",
      'description' => "Inorganic compounds in which the largest oxoanion is perhenate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 654,
      'name' => "Alkali metal pertechnetates",
      'description' => "Inorganic compounds in which the largest oxoanion is pertechnetate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 655,
      'name' => "Alkali metal phosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 656,
      'name' => "Alkali metal phosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 657,
      'name' => "Alkali metal pyrophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrophosphate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 658,
      'name' => "Alkali metal selenates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 659,
      'name' => "Alkali metal selenites",
      'description' => "Inorganic compounds in which the largest oxoanion is selenite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 660,
      'name' => "Alkali metal sulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 661,
      'name' => "Alkali metal sulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 662,
      'name' => "Alkali metal superoxides",
      'description' => "Inorganic compounds in which the largest oxoanion is superoxide, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 663,
      'name' => "Benzimidazole ribonucleosides and ribonucleotides",
      'description' => "Nucleosides with a structure that consists of an  imidazole moiety of benzimidazole is N-linked to a ribose (or deoxyribose). Nucleotides have a phosphate group linked to the C5 carbon of the ribose (or deoxyribose) moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 664,
      'name' => "Alkali metal peroxomonosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxomonosulfate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 665,
      'name' => "Alkali metal peroxodisulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxodisulfate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 666,
      'name' => "Alkali metal pyrosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrosulfate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 667,
      'name' => "Alkali metal tetrathionates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrathionate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 668,
      'name' => "Alkali metal thiosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiosulfate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 669,
      'name' => "Alkali metal dithionites",
      'description' => "Inorganic compounds in which the largest oxoanion is dithionite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 670,
      'name' => "Alkali metal hyposulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyposulfite, and in which the heaviest atom  not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 671,
      'name' => "Alkaline earth metal bromates",
      'description' => "Inorganic compounds in which the largest oxoanion is bromate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 672,
      'name' => "Alkaline earth metal chlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 673,
      'name' => "Alkaline earth metal chlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 674,
      'name' => "Alkaline earth metal chromates",
      'description' => "Inorganic compounds in which the largest oxoanion is chromate, and in which the heaviest atom is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 675,
      'name' => "Alkaline earth metal cyanates",
      'description' => "Inorganic compounds in which the largest oxoanion is cyanate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 676,
      'name' => "Taxanes and derivatives",
      'description' => "Diterpenoids with a structure based either on the taxane skeleton, or a derivative thereof. In term of phytochemistry, several derivatives of the taxane skeleton exist: 2(3->20)-abeotaxane, 3,11-cyclotaxane, 11(15->1),11(10->9)-abeotaxane, 3,8-seco-taxane, and 11(15->1)-abeotaxane, among others. More complex skeletons have been found recently, which include the taxane-derived [3.3.3] propellane ring system.",
      'parent' => 1551,
    ),
    array(
      'tid' => 677,
      'name' => "Alkaline earth metal hydroxides",
      'description' => "Inorganic compounds in which the largest oxoanion is hydroxide, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 678,
      'name' => "Alkaline earth metal hypobromites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypobromite, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 679,
      'name' => "Alkaline earth metal hypochlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypochlorite, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 680,
      'name' => "Alkaline earth metal hyponitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyponitrite, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 681,
      'name' => "Alkaline earth metal hypophosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypophosphite, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 682,
      'name' => "Alkaline earth metal iodates",
      'description' => "Inorganic compounds in which the largest oxoanion is iodate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 683,
      'name' => "Alkaline earth metal nitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrite, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 684,
      'name' => "Alkaline earth metal nitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 685,
      'name' => "Alkaline earth metal orthonitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthonitrate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 686,
      'name' => "Alkaline earth metal perbromates",
      'description' => "Inorganic compounds in which the largest oxoanion is perbromate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 687,
      'name' => "Alkaline earth metal perchlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is perchlorate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 688,
      'name' => "Alkaline earth metal periodates",
      'description' => "Inorganic compounds in which the largest oxoanion is periodate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 689,
      'name' => "Alkaline earth metal permanganates",
      'description' => "Inorganic compounds in which the largest oxoanion is permanganate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 690,
      'name' => "Alkaline earth metal peroxynitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 691,
      'name' => "Alkaline earth metal peroxynitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 692,
      'name' => "Alkaline earth metal perrhenates",
      'description' => "Inorganic compounds in which the largest oxoanion is perhenate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 693,
      'name' => "Alkaline earth metal pertechnetates",
      'description' => "Inorganic compounds in which the largest oxoanion is pertechnetate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 694,
      'name' => "Alkaline earth metal phosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphite, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 695,
      'name' => "Alkaline earth metal phosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 696,
      'name' => "Alkaline earth metal pyrophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrophosphate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 697,
      'name' => "Alkaline earth metal selenates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 698,
      'name' => "Alkaline earth metal selenites",
      'description' => "Inorganic compounds in which the largest oxoanion is selenite, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 699,
      'name' => "Alkaline earth metal sulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 700,
      'name' => "Alkaline earth metal sulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfite, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 701,
      'name' => "Alkaline earth metal superoxides",
      'description' => "Inorganic compounds in which the largest oxoanion is superoxide, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 702,
      'name' => "Sesterterpene lactones",
      'description' => "Sesterterpenoids containing a lactone ring.",
      'parent' => 1283,
    ),
    array(
      'tid' => 703,
      'name' => "Alkaline earth metal peroxomonosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxomonosulfate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 704,
      'name' => "Alkaline earth metal peroxodisulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxodisulfate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 705,
      'name' => "Alkaline earth metal pyrosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrosulfate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 706,
      'name' => "Alkaline earth metal tetrathionates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrathionate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 707,
      'name' => "Alkaline earth metal thiosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiosulfate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 708,
      'name' => "Alkaline earth metal dithionites",
      'description' => "Inorganic compounds in which the largest oxoanion is dithionite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 709,
      'name' => "Alkaline earth metal hyposulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyposulfite, and in which the heaviest atom  not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 710,
      'name' => "Post-transition metal bromates",
      'description' => "Inorganic compounds in which the largest oxoanion is bromate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 711,
      'name' => "Post-transition metal chlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 712,
      'name' => "Post-transition metal chlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 713,
      'name' => "Post-transition metal chromates",
      'description' => "Inorganic compounds in which the largest oxoanion is chromate, and in which the heaviest atom is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 714,
      'name' => "Post-transition metal chromites",
      'description' => "Inorganic compounds in which the largest oxoanion is chromite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 715,
      'name' => "Post-transition metal cyanates",
      'description' => "Inorganic compounds in which the largest oxoanion is cyanate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 716,
      'name' => "Chlorins",
      'description' => "Large heterocyclic aromatic ring systems consisting, at the core, of three pyrroles and one pyrroline coupled through four methine linkages.",
      'parent' => 1455,
    ),
    array(
      'tid' => 717,
      'name' => "Post-transition metal hydroxides",
      'description' => "Inorganic compounds in which the largest oxoanion is hydroxide, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 718,
      'name' => "Post-transition metal hypobromites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypobromite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 719,
      'name' => "Post-transition metal hypochlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypochlorite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 720,
      'name' => "Post-transition metal hyponitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyponitrite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 721,
      'name' => "Post-transition metal hypophosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypophosphite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 722,
      'name' => "Post-transition metal iodates",
      'description' => "Inorganic compounds in which the largest oxoanion is iodate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 723,
      'name' => "Post-transition metal nitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 724,
      'name' => "Post-transition metal nitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 725,
      'name' => "Post-transition metal orthonitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthonitrate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 726,
      'name' => "Post-transition metal perbromates",
      'description' => "Inorganic compounds in which the largest oxoanion is perbromate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 727,
      'name' => "Post-transition metal perchlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is perchlorate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 728,
      'name' => "Post-transition metal periodates",
      'description' => "Inorganic compounds in which the largest oxoanion is periodate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 729,
      'name' => "Post-transition metal permanganates",
      'description' => "Inorganic compounds in which the largest oxoanion is permanganate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 730,
      'name' => "Post-transition metal peroxynitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 731,
      'name' => "Post-transition metal peroxynitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 732,
      'name' => "Post-transition metal perrhenates",
      'description' => "Inorganic compounds in which the largest oxoanion is perhenate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 733,
      'name' => "Post-transition metal pertechnetates",
      'description' => "Inorganic compounds in which the largest oxoanion is pertechnetate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 734,
      'name' => "Post-transition metal phosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 735,
      'name' => "Post-transition metal phosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 736,
      'name' => "Post-transition metal pyrophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrophosphate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 737,
      'name' => "Post-transition metal selenates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 738,
      'name' => "Post-transition metal selenites",
      'description' => "Inorganic compounds in which the largest oxoanion is selenite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 739,
      'name' => "Post-transition metal sulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 740,
      'name' => "Post-transition metal sulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 741,
      'name' => "Post-transition metal superoxides",
      'description' => "Inorganic compounds in which the largest oxoanion is superoxide, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 742,
      'name' => "Phospholanes",
      'description' => "Compounds containing a phospholane ring, which is a five-member saturated aliphatic heterocycle with one phosphorus atom and four carbon atoms.",
      'parent' => 2052,
    ),
    array(
      'tid' => 743,
      'name' => "Post-transition metal peroxomonosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxomonosulfate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 744,
      'name' => "Post-transition metal peroxodisulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxodisulfate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 745,
      'name' => "Post-transition metal pyrosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrosulfate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 746,
      'name' => "Post-transition metal tetrathionates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrathionate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 747,
      'name' => "Post-transition metal thiosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiosulfate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 748,
      'name' => "Post-transition metal dithionites",
      'description' => "Inorganic compounds in which the largest oxoanion is dithionite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 749,
      'name' => "Post-transition metal hyposulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyposulfite, and in which the heaviest atom  not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 750,
      'name' => "Lanthanide bromates",
      'description' => "Inorganic compounds in which the largest oxoanion is bromate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 751,
      'name' => "Lanthanide chlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 752,
      'name' => "Lanthanide chlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 753,
      'name' => "Lanthanide chromates",
      'description' => "Inorganic compounds in which the largest oxoanion is chromate, and in which the heaviest atom is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 754,
      'name' => "Lanthanide chromites",
      'description' => "Inorganic compounds in which the largest oxoanion is chromite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 755,
      'name' => "Lanthanide cyanates",
      'description' => "Inorganic compounds in which the largest oxoanion is cyanate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 756,
      'name' => "Imidazothiazoles",
      'description' => "Organic polycyclic compounds containing an imidazole ring fused to a thiazole ring. Imidazole is 5-membered ring consisting of three carbon atoms, and two nitrogen centers at the 1- and 3-positions. Thiazole is a 6-membered ring that contains both sulfur and nitrogen.",
      'parent' => 2,
    ),
    array(
      'tid' => 757,
      'name' => "Lanthanide hydroxides",
      'description' => "Inorganic compounds in which the largest oxoanion is hydroxide, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 758,
      'name' => "Lanthanide hypobromites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypobromite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 759,
      'name' => "Lanthanide hypochlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypochlorite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 760,
      'name' => "Lanthanide hyponitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyponitrite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 761,
      'name' => "Lanthanide hypophosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypophosphite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 762,
      'name' => "Lanthanide iodates",
      'description' => "Inorganic compounds in which the largest oxoanion is iodate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 763,
      'name' => "Lanthanide nitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 764,
      'name' => "Lanthanide nitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 765,
      'name' => "Lanthanide orthonitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthonitrate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 766,
      'name' => "Lanthanide perbromates",
      'description' => "Inorganic compounds in which the largest oxoanion is perbromate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 767,
      'name' => "Lanthanide perchlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is perchlorate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 768,
      'name' => "Lanthanide periodates",
      'description' => "Inorganic compounds in which the largest oxoanion is periodate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 769,
      'name' => "Lanthanide permanganates",
      'description' => "Inorganic compounds in which the largest oxoanion is permanganate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 770,
      'name' => "Lanthanide peroxynitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 771,
      'name' => "Lanthanide peroxynitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 772,
      'name' => "Lanthanide perrhenates",
      'description' => "Inorganic compounds in which the largest oxoanion is perhenate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 773,
      'name' => "Lanthanide pertechnetates",
      'description' => "Inorganic compounds in which the largest oxoanion is pertechnetate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 774,
      'name' => "Lanthanide phosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 775,
      'name' => "Lanthanide phosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 776,
      'name' => "Lanthanide pyrophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrophosphate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 777,
      'name' => "Lanthanide selenates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 778,
      'name' => "Lanthanide selenites",
      'description' => "Inorganic compounds in which the largest oxoanion is selenite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 779,
      'name' => "Lanthanide sulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 780,
      'name' => "Lanthanide sulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 781,
      'name' => "Lanthanide superoxides",
      'description' => "Inorganic compounds in which the largest oxoanion is superoxide, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 782,
      'name' => "Oxaphospholanes",
      'description' => "Compounds containing an oxaphospholane moiety, which consists of a saturated aliphatic five-member ring with two oxygen atoms, a phosphorus atom, and two carbon atoms. Isomers  of oxaphospholane include 1,2-oxaphosphane, and 1,3-oxaphospholane.",
      'parent' => 2,
    ),
    array(
      'tid' => 783,
      'name' => "Lanthanide peroxomonosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxomonosulfate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 784,
      'name' => "Lanthanide peroxodisulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxodisulfate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 785,
      'name' => "Lanthanide pyrosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrosulfate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 786,
      'name' => "Lanthanide tetrathionates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrathionate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 787,
      'name' => "Lanthanide thiosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiosulfate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 788,
      'name' => "Lanthanide dithionites",
      'description' => "Inorganic compounds in which the largest oxoanion is dithionite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 789,
      'name' => "Lanthanide hyposulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyposulfite, and in which the heaviest atom  not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 790,
      'name' => "Metalloid bromates",
      'description' => "Inorganic compounds in which the largest oxoanion is bromate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 791,
      'name' => "Metalloid chlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 792,
      'name' => "Metalloid chlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 793,
      'name' => "Metalloid chromates",
      'description' => "Inorganic compounds in which the largest oxoanion is chromate, and in which the heaviest atom is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 794,
      'name' => "Metalloid chromites",
      'description' => "Inorganic compounds in which the largest oxoanion is chromite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 795,
      'name' => "Metalloid cyanates",
      'description' => "Inorganic compounds in which the largest oxoanion is cyanate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 796,
      'name' => "Imidazodithiazoles",
      'description' => "Organic compounds containing an imidazole ring fused to a dithiazole ring. Imidazole is 5-membered ring consisting of three carbon atoms, and two nitrogen centers at the 1- and 3-positions. Dithiazole is a five-membered heterocycle containing two sulfur atoms, one nitrogen atom, three carbon atoms and two double bonds",
      'parent' => 2,
    ),
    array(
      'tid' => 797,
      'name' => "Metalloid hydroxides",
      'description' => "Inorganic compounds in which the largest oxoanion is hydroxide, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 798,
      'name' => "Metalloid hypobromites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypobromite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 799,
      'name' => "Metalloid hypochlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypochlorite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 800,
      'name' => "Metalloid hyponitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyponitrite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 801,
      'name' => "Metalloid hypophosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypophosphite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 802,
      'name' => "Metalloid iodates",
      'description' => "Inorganic compounds in which the largest oxoanion is iodate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 803,
      'name' => "Metalloid nitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 804,
      'name' => "Metalloid nitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 805,
      'name' => "Metalloid orthonitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthonitrate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 806,
      'name' => "Metalloid perbromates",
      'description' => "Inorganic compounds in which the largest oxoanion is perbromate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 807,
      'name' => "Metalloid perchlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is perchlorate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 808,
      'name' => "Metalloid periodates",
      'description' => "Inorganic compounds in which the largest oxoanion is periodate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 809,
      'name' => "Metalloid permanganates",
      'description' => "Inorganic compounds in which the largest oxoanion is permanganate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 810,
      'name' => "Metalloid peroxynitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 811,
      'name' => "Metalloid peroxynitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 812,
      'name' => "Metalloid perrhenates",
      'description' => "Inorganic compounds in which the largest oxoanion is perhenate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 813,
      'name' => "Metalloid pertechnetates",
      'description' => "Inorganic compounds in which the largest oxoanion is pertechnetate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 814,
      'name' => "Metalloid phosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 815,
      'name' => "Metalloid phosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 816,
      'name' => "Metalloid pyrophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrophosphate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 817,
      'name' => "Metalloid selenates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 818,
      'name' => "Metalloid selenites",
      'description' => "Inorganic compounds in which the largest oxoanion is selenite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 819,
      'name' => "Metalloid sulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 820,
      'name' => "Metalloid sulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 449,
    ),
    array(
      'tid' => 821,
      'name' => "Metalloid superoxides",
      'description' => "Inorganic compounds in which the largest oxoanion is superoxide, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 822,
      'name' => "Dioxaphospholanes",
      'description' => "Cyclic organic compounds containing a five-member aliphatic single-bonded ring, with a phosphorine atom and two oxygen atoms at the ring positions 1, 2, and 3 respectively.",
      'parent' => 2,
    ),
    array(
      'tid' => 823,
      'name' => "Metalloid peroxomonosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxomonosulfate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 824,
      'name' => "Metalloid peroxodisulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxodisulfate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 825,
      'name' => "Metalloid pyrosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrosulfate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 826,
      'name' => "Metalloid tetrathionates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrathionate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 827,
      'name' => "Metalloid thiosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiosulfate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 828,
      'name' => "Metalloid dithionites",
      'description' => "Inorganic compounds in which the largest oxoanion is dithionite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 829,
      'name' => "Metalloid hyposulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyposulfite, and in which the heaviest atom  not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 830,
      'name' => "Transition metal bromates",
      'description' => "Inorganic compounds in which the largest oxoanion is bromate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 831,
      'name' => "Transition metal chlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 832,
      'name' => "Transition metal chlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is chlorite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 833,
      'name' => "Transition metal chromates",
      'description' => "Inorganic compounds in which the largest oxoanion is chromate, and in which the heaviest atom is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 834,
      'name' => "Transition metal chromites",
      'description' => "Inorganic compounds in which the largest oxoanion is chromite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 835,
      'name' => "Transition metal cyanates",
      'description' => "Inorganic compounds in which the largest oxoanion is cyanate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 836,
      'name' => "Imidazodithiazolethiones",
      'description' => "Organic compounds containing an imidazole ring fused to a dithiazolethione ring.",
      'parent' => 796,
    ),
    array(
      'tid' => 837,
      'name' => "Transition metal hydroxides",
      'description' => "Inorganic compounds in which the largest oxoanion is hydroxide, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 838,
      'name' => "Transition metal hypobromites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypobromite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 839,
      'name' => "Transition metal hypochlorites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypochlorite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 840,
      'name' => "Transition metal hyponitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyponitrite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 841,
      'name' => "Transition metal hypophosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is hypophosphite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 842,
      'name' => "Transition metal iodates",
      'description' => "Inorganic compounds in which the largest oxoanion is iodate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 843,
      'name' => "Transition metal nitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 844,
      'name' => "Transition metal orthonitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthonitrate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 845,
      'name' => "Transition metal perbromates",
      'description' => "Inorganic compounds in which the largest oxoanion is perbromate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 846,
      'name' => "Transition metal perchlorates",
      'description' => "Inorganic compounds in which the largest oxoanion is perchlorate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 847,
      'name' => "Transition metal periodates",
      'description' => "Inorganic compounds in which the largest oxoanion is periodate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 848,
      'name' => "Transition metal permanganates",
      'description' => "Inorganic compounds in which the largest oxoanion is permanganate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 849,
      'name' => "Transition metal peroxynitrates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 850,
      'name' => "Transition metal peroxynitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxynitrate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 851,
      'name' => "Transition metal perrhenates",
      'description' => "Inorganic compounds in which the largest oxoanion is perhenate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 852,
      'name' => "Transition metal pertechnetates",
      'description' => "Inorganic compounds in which the largest oxoanion is pertechnetate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 853,
      'name' => "Transition metal phosphites",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 854,
      'name' => "Transition metal phosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 855,
      'name' => "Transition metal pyrophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrophosphate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 856,
      'name' => "Transition metal selenates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 857,
      'name' => "Transition metal selenites",
      'description' => "Inorganic compounds in which the largest oxoanion is selenite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 858,
      'name' => "Transition metal sulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 859,
      'name' => "Transition metal sulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is sulfite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 860,
      'name' => "Transition metal superoxides",
      'description' => "Inorganic compounds in which the largest oxoanion is superoxide, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 861,
      'name' => "Phospholes",
      'description' => "Compounds containing a phosphole ring, which is a five-member aromatic heterocycle with one phosphorus atom and four carbon atoms.",
      'parent' => 2052,
    ),
    array(
      'tid' => 862,
      'name' => "Transition metal peroxomonosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxomonosulfate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 863,
      'name' => "Transition metal peroxodisulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is peroxodisulfate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 864,
      'name' => "Transition metal pyrosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is pyrosulfate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 865,
      'name' => "Transition metal tetrathionates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrathionate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 866,
      'name' => "Transition metal thiosulfates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiosulfate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 867,
      'name' => "Transition metal dithionites",
      'description' => "Inorganic compounds in which the largest oxoanion is dithionite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 868,
      'name' => "Transition metal hyposulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is hyposulfite, and in which the heaviest atom  not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 869,
      'name' => "Actinide aluminates",
      'description' => "Inorganic compounds in which the largest oxoanion is aluminate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 870,
      'name' => "Actinide antimonates",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 871,
      'name' => "Actinide antimonites",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 872,
      'name' => "Actinide arsenates",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 873,
      'name' => "Actinide arsenites",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 874,
      'name' => "Actinide bisulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is bisulfite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 875,
      'name' => "Actinide borates",
      'description' => "Inorganic compounds in which the largest oxoanion is borate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 876,
      'name' => "Actinide ferrates",
      'description' => "Inorganic compounds in which the largest oxoanion is ferrate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 877,
      'name' => "Actinide manganates",
      'description' => "Inorganic compounds in which the largest oxoanion is manganate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 878,
      'name' => "Actinide molybdates",
      'description' => "Inorganic compounds in which the largest oxoanion is molybdate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 879,
      'name' => "Actinide plumbates",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 880,
      'name' => "Actinide plumbites",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 881,
      'name' => "Actinide silicates",
      'description' => "Inorganic compounds in which the largest oxoanion is silicate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 882,
      'name' => "Actinide stannates",
      'description' => "Inorganic compounds in which the largest oxoanion is stannate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 883,
      'name' => "Actinide stannites",
      'description' => "Inorganic compounds in which the largest oxoanion is stannite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 884,
      'name' => "Actinide tellurates",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 885,
      'name' => "Actinide tellurites",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurite, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 886,
      'name' => "Actinide tetrahydroxyborates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrahydroxyborate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 887,
      'name' => "Actinide tungstates",
      'description' => "Inorganic compounds in which the largest oxoanion is tungstate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 888,
      'name' => "Actinide orthovanadates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthovanadate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 889,
      'name' => "Alkali metal aluminates",
      'description' => "Inorganic compounds in which the largest oxoanion is aluminate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 890,
      'name' => "Alkali metal antimonates",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 891,
      'name' => "Alkali metal antimonites",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 892,
      'name' => "Alkali metal arsenates",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 893,
      'name' => "Alkali metal arsenites",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 894,
      'name' => "Alkali metal bisulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is bisulfite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 895,
      'name' => "Alkali metal borates",
      'description' => "Inorganic compounds in which the largest oxoanion is borate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 896,
      'name' => "Alkali metal ferrates",
      'description' => "Inorganic compounds in which the largest oxoanion is ferrate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 897,
      'name' => "Alkali metal manganates",
      'description' => "Inorganic compounds in which the largest oxoanion is manganate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 898,
      'name' => "Alkali metal molybdates",
      'description' => "Inorganic compounds in which the largest oxoanion is molybdate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 899,
      'name' => "Alkali metal plumbates",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 900,
      'name' => "Alkali metal plumbites",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 901,
      'name' => "Alkali metal silicates",
      'description' => "Inorganic compounds in which the largest oxoanion is silicate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 902,
      'name' => "Alkali metal stannates",
      'description' => "Inorganic compounds in which the largest oxoanion is stannate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 903,
      'name' => "Alkali metal stannites",
      'description' => "Inorganic compounds in which the largest oxoanion is stannite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 904,
      'name' => "Alkali metal tellurates",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 905,
      'name' => "Alkali metal tellurites",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurite, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 906,
      'name' => "Alkali metal tetrahydroxyborates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrahydroxyborate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 907,
      'name' => "Alkali metal tungstates",
      'description' => "Inorganic compounds in which the largest oxoanion is tungstate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 908,
      'name' => "Alkali metal orthovanadates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthovanadate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 909,
      'name' => "Alkaline earth metal aluminates",
      'description' => "Inorganic compounds in which the largest oxoanion is aluminate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 910,
      'name' => "Alkaline earth metal antimonates",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 911,
      'name' => "Alkaline earth metal antimonites",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 912,
      'name' => "Alkaline earth metal arsenates",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 913,
      'name' => "Alkaline earth metal arsenites",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 914,
      'name' => "Alkaline earth metal bisulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is bisulfite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 915,
      'name' => "Alkaline earth metal borates",
      'description' => "Inorganic compounds in which the largest oxoanion is borate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 916,
      'name' => "Alkaline earth metal ferrates",
      'description' => "Inorganic compounds in which the largest oxoanion is ferrate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 446,
    ),
    array(
      'tid' => 917,
      'name' => "Alkaline earth metal manganates",
      'description' => "Inorganic compounds in which the largest oxoanion is manganate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 918,
      'name' => "Alkaline earth metal molybdates",
      'description' => "Inorganic compounds in which the largest oxoanion is molybdate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 919,
      'name' => "Alkaline earth metal plumbates",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 920,
      'name' => "Alkaline earth metal plumbites",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbite, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 921,
      'name' => "Alkaline earth metal silicates",
      'description' => "Inorganic compounds in which the largest oxoanion is silicate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 922,
      'name' => "Alkaline earth metal stannates",
      'description' => "Inorganic compounds in which the largest oxoanion is stannate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 923,
      'name' => "Alkaline earth metal stannites",
      'description' => "Inorganic compounds in which the largest oxoanion is stannite, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 924,
      'name' => "Alkaline earth metal tellurates",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 925,
      'name' => "Alkaline earth metal tellurites",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurite, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 926,
      'name' => "Alkaline earth metal tetrahydroxyborates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrahydroxyborate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 927,
      'name' => "Alkaline earth metal tungstates",
      'description' => "Inorganic compounds in which the largest oxoanion is tungstate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 928,
      'name' => "Alkaline earth metal orthovanadates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthovanadate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 929,
      'name' => "Post-transition metal aluminates",
      'description' => "Inorganic compounds in which the largest oxoanion is aluminate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 930,
      'name' => "Post-transition metal antimonates",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 931,
      'name' => "Post-transition metal antimonites",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 932,
      'name' => "Post-transition metal arsenates",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 933,
      'name' => "Post-transition metal arsenites",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 934,
      'name' => "Post-transition metal bisulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is bisulfite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 935,
      'name' => "Post-transition metal borates",
      'description' => "Inorganic compounds in which the largest oxoanion is borate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 936,
      'name' => "Post-transition metal ferrates",
      'description' => "Inorganic compounds in which the largest oxoanion is ferrate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 937,
      'name' => "Post-transition metal manganates",
      'description' => "Inorganic compounds in which the largest oxoanion is manganate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 938,
      'name' => "Post-transition metal molybdates",
      'description' => "Inorganic compounds in which the largest oxoanion is molybdate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 939,
      'name' => "Post-transition metal plumbates",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 940,
      'name' => "Post-transition metal plumbites",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 941,
      'name' => "Post-transition metal silicates",
      'description' => "Inorganic compounds in which the largest oxoanion is silicate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 942,
      'name' => "Post-transition metal stannates",
      'description' => "Inorganic compounds in which the largest oxoanion is stannate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 943,
      'name' => "Post-transition metal stannites",
      'description' => "Inorganic compounds in which the largest oxoanion is stannite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 944,
      'name' => "Post-transition metal tellurates",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 945,
      'name' => "Post-transition metal tellurites",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurite, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 946,
      'name' => "Post-transition metal tetrahydroxyborates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrahydroxyborate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 947,
      'name' => "Post-transition metal tungstates",
      'description' => "Inorganic compounds in which the largest oxoanion is tungstate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 948,
      'name' => "Post-transition metal orthovanadates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthovanadate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 949,
      'name' => "Lanthanide aluminates",
      'description' => "Inorganic compounds in which the largest oxoanion is aluminate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 950,
      'name' => "Lanthanide antimonates",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 951,
      'name' => "Lanthanide antimonites",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 952,
      'name' => "Lanthanide arsenates",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 953,
      'name' => "Lanthanide arsenites",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 954,
      'name' => "Lanthanide bisulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is bisulfite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 955,
      'name' => "Lanthanide borates",
      'description' => "Inorganic compounds in which the largest oxoanion is borate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 956,
      'name' => "Lanthanide ferrates",
      'description' => "Inorganic compounds in which the largest oxoanion is ferrate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 957,
      'name' => "Lanthanide manganates",
      'description' => "Inorganic compounds in which the largest oxoanion is manganate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 958,
      'name' => "Lanthanide molybdates",
      'description' => "Inorganic compounds in which the largest oxoanion is molybdate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 959,
      'name' => "Lanthanide plumbates",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 960,
      'name' => "Lanthanide plumbites",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 961,
      'name' => "Lanthanide silicates",
      'description' => "Inorganic compounds in which the largest oxoanion is silicate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 962,
      'name' => "Lanthanide stannates",
      'description' => "Inorganic compounds in which the largest oxoanion is stannate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 963,
      'name' => "Lanthanide stannites",
      'description' => "Inorganic compounds in which the largest oxoanion is stannite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 964,
      'name' => "Lanthanide tellurates",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 965,
      'name' => "Lanthanide tellurites",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurite, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 966,
      'name' => "Lanthanide tetrahydroxyborates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrahydroxyborate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 967,
      'name' => "Lanthanide tungstates",
      'description' => "Inorganic compounds in which the largest oxoanion is tungstate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 968,
      'name' => "Lanthanide orthovanadates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthovanadate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 969,
      'name' => "Metalloid aluminates",
      'description' => "Inorganic compounds in which the largest oxoanion is aluminate, and in which the heaviest atom not in an oxoanion is a metalloid metal.",
      'parent' => 449,
    ),
    array(
      'tid' => 970,
      'name' => "Metalloid antimonates",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 971,
      'name' => "Metalloid antimonites",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 972,
      'name' => "Metalloid arsenates",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 449,
    ),
    array(
      'tid' => 973,
      'name' => "Metalloid arsenites",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 974,
      'name' => "Metalloid bisulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is bisulfite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 975,
      'name' => "Metalloid borates",
      'description' => "Inorganic compounds in which the largest oxoanion is borate, and in which the heaviest atom not in an oxoanion is a  metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 976,
      'name' => "Metalloid ferrates",
      'description' => "Inorganic compounds in which the largest oxoanion is ferrate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 977,
      'name' => "Metalloid manganates",
      'description' => "Inorganic compounds in which the largest oxoanion is manganate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 978,
      'name' => "Metalloid molybdates",
      'description' => "Inorganic compounds in which the largest oxoanion is molybdate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 979,
      'name' => "Metalloid plumbates",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 980,
      'name' => "Metalloid silicates",
      'description' => "Inorganic compounds in which the largest oxoanion is silicate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 981,
      'name' => "Metalloid stannates",
      'description' => "Inorganic compounds in which the largest oxoanion is stannate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 982,
      'name' => "Metalloid stannites",
      'description' => "Inorganic compounds in which the largest oxoanion is stannite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 983,
      'name' => "Metalloid tellurates",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 984,
      'name' => "Metalloid tellurites",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 985,
      'name' => "Metalloid tetrahydroxyborates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrahydroxyborate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 986,
      'name' => "Metalloid tungstates",
      'description' => "Inorganic compounds in which the largest oxoanion is tungstate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 987,
      'name' => "Metalloid orthovanadates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthovanadate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 988,
      'name' => "Transition metal aluminates",
      'description' => "Inorganic compounds in which the largest oxoanion is aluminate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 989,
      'name' => "Transition metal antimonates",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 990,
      'name' => "Transition metal antimonites",
      'description' => "Inorganic compounds in which the largest oxoanion is antimonite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 991,
      'name' => "Transition metal arsenates",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 992,
      'name' => "Transition metal arsenites",
      'description' => "Inorganic compounds in which the largest oxoanion is arsenite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 993,
      'name' => "Transition metal bisulfites",
      'description' => "Inorganic compounds in which the largest oxoanion is bisulfite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 994,
      'name' => "Transition metal borates",
      'description' => "Inorganic compounds in which the largest oxoanion is borate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 995,
      'name' => "Transition metal manganates",
      'description' => "Inorganic compounds in which the largest oxoanion is manganate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 996,
      'name' => "Transition metal molybdates",
      'description' => "Inorganic compounds in which the largest oxoanion is molybdate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 997,
      'name' => "Transition metal plumbates",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 998,
      'name' => "Transition metal plumbites",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 999,
      'name' => "Transition metal silicates",
      'description' => "Inorganic compounds in which the largest oxoanion is silicate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 1000,
      'name' => "Transition metal stannates",
      'description' => "Inorganic compounds in which the largest oxoanion is stannate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 1001,
      'name' => "Transition metal stannites",
      'description' => "Inorganic compounds in which the largest oxoanion is stannite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 1002,
      'name' => "Transition metal tellurates",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 1003,
      'name' => "Transition metal tellurites",
      'description' => "Inorganic compounds in which the largest oxoanion is tellurite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 1004,
      'name' => "Transition metal tetrahydroxyborates",
      'description' => "Inorganic compounds in which the largest oxoanion is tetrahydroxyborate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 1005,
      'name' => "Transition metal tungstates",
      'description' => "Inorganic compounds in which the largest oxoanion is tungstate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 1006,
      'name' => "Transition metal orthovanadates",
      'description' => "Inorganic compounds in which the largest oxoanion is orthovanadate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 1007,
      'name' => "Lipoxins",
      'description' => "Eicosanoids with a trihydroxyicosatetraenoic acid skeleton (a c20-fatty acid, with the chain bearing three hydroxyl groups and four double bonds). Lipoxins have four double bonds, which are all conjugated. In some cases a hydroxyl group is substituted by a C=O group.",
      'parent' => 46,
    ),
    array(
      'tid' => 1008,
      'name' => "Dibenzazecins",
      'description' => "Polycyclic aromatic compounds containing two benzene rings joined by an azecin ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 1009,
      'name' => "Enol ethers",
      'description' => "Compounds containing the enol ether functional group, with the formula R3OCR2=CR1.",
      'parent' => 254,
    ),
    array(
      'tid' => 1010,
      'name' => "Oxime ethers",
      'description' => "Compounds containing the oxime ether functional group, with the general structure R1(R2)C=NOR3 ( R3 not H).",
      'parent' => 411,
    ),
    array(
      'tid' => 1011,
      'name' => "Hydroperoxyeicosapentaenoic acids",
      'description' => "Eicosanoic acids with an attached hydroperoxyl group and five CC double bonds.",
      'parent' => 513,
    ),
    array(
      'tid' => 1012,
      'name' => "Cholines",
      'description' => "Organic compounds containing a N,N,N-trimethylethanolammonium cation.",
      'parent' => 503,
    ),
    array(
      'tid' => 1013,
      'name' => "Steroidal glycosides",
      'description' => "Sterol lipids containing a carbohydrate moiety glycosidically linked to the steroid skeleton.",
      'parent' => 258,
    ),
    array(
      'tid' => 1014,
      'name' => "Glycinamide ribonucleotides",
      'description' => "Compounds in which the amide N atom of glycineamide is linked to the C-1 of a ribosyl (or deoxyribosyl) moiety. Nucleotides have a phosphate group linked to the C5 carbon of the ribose (or deoxyribose) moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 1015,
      'name' => "Epoxyeicosatrienoic acids",
      'description' => "Eicosatrienoic acids containing an oxirane ring as part of its aliphatic chain.",
      'parent' => 513,
    ),
    array(
      'tid' => 1016,
      'name' => "Cycloalkanes",
      'description' => "Saturated monocyclic hydrocarbons (with or without side chains).",
      'parent' => 4474,
    ),
    array(
      'tid' => 1017,
      'name' => "Acyl bromides",
      'description' => "Organic compounds containing the functional group -CO-Br.",
      'parent' => 2865,
    ),
    array(
      'tid' => 1018,
      'name' => "Inorganic cyanides",
      'description' => "Inorganic compounds that contain the cyano group (-[C-]#[N+]).",
      'parent' => 1568,
    ),
    array(
      'tid' => 1019,
      'name' => "Alkadienes",
      'description' => "Acyclic hydrocarbons that contain exactly two carbon-to-carbon double bonds.",
      'parent' => 2839,
    ),
    array(
      'tid' => 1020,
      'name' => "Hepoxilins",
      'description' => "Eicosanoids containing an oxirane group attached to the fatty acyl chain.",
      'parent' => 513,
    ),
    array(
      'tid' => 1021,
      'name' => "Clavulones and derivatives",
      'description' => "Ester derivatives of prostanoids.",
      'parent' => 513,
    ),
    array(
      'tid' => 1022,
      'name' => "Acyl chlorides",
      'description' => "Organic compounds containing the functional group -CO-Cl.",
      'parent' => 2865,
    ),
    array(
      'tid' => 1023,
      'name' => "Acyl fluorides",
      'description' => "Organic compounds containing the functional group -CO-F.",
      'parent' => 2865,
    ),
    array(
      'tid' => 1024,
      'name' => "Acyl iodides",
      'description' => "Organic compounds containing the functional group -CO-I.",
      'parent' => 2865,
    ),
    array(
      'tid' => 1025,
      'name' => "Alkyl bromides",
      'description' => "Organic compounds containing the alkyl bromide functional group with formula R-Br, where R is an alkyl group.",
      'parent' => 2867,
    ),
    array(
      'tid' => 1026,
      'name' => "Alkyl chlorides",
      'description' => "Organic compounds containing the alkyl chloride functional group with formula R-Cl , where R is an alkyl group.",
      'parent' => 2867,
    ),
    array(
      'tid' => 1027,
      'name' => "Alkyl fluorides",
      'description' => "Organic compounds containing the alkyl fluoride functional group with formula R-F , where R is an alkyl group.",
      'parent' => 2867,
    ),
    array(
      'tid' => 1028,
      'name' => "Alkyl iodides",
      'description' => "Organic compounds containing the alkyl iodide functional group with formula R-I , where R is an alkyl group.",
      'parent' => 2867,
    ),
    array(
      'tid' => 1029,
      'name' => "Aryl bromides",
      'description' => "Organic compounds containing the acyl bromide functional group.",
      'parent' => 2866,
    ),
    array(
      'tid' => 1030,
      'name' => "Aryl chlorides",
      'description' => "Organic compounds containing the acyl chloride functional group.",
      'parent' => 2866,
    ),
    array(
      'tid' => 1031,
      'name' => "Aryl fluorides",
      'description' => "Organic compounds containing the acyl fluoride functional group.",
      'parent' => 2866,
    ),
    array(
      'tid' => 1032,
      'name' => "Aryl iodides",
      'description' => "Organic compounds containing the acyl iodide functional group.",
      'parent' => 2866,
    ),
    array(
      'tid' => 1033,
      'name' => "Imidoyl bromides",
      'description' => "Imidoyl halides with the general formula R(Br)C=NR' where X is a bromine atom.",
      'parent' => 2870,
    ),
    array(
      'tid' => 1034,
      'name' => "Imidoyl chlorides",
      'description' => "Imidoyl halides with the general formula R(Br)C=NR' where X is a chlorine atom.",
      'parent' => 2870,
    ),
    array(
      'tid' => 1035,
      'name' => "Imidoyl fluorides",
      'description' => "Imidoyl halides with the general formula R(Br)C=NR' where X is a fluorine atom.",
      'parent' => 2870,
    ),
    array(
      'tid' => 1036,
      'name' => "Imidoyl iodides",
      'description' => "Imidoyl halides with the general formula R(Br)C=NR' where X is a iodine atom.",
      'parent' => 2870,
    ),
    array(
      'tid' => 1037,
      'name' => "Organic sulfuryl bromides",
      'description' => "Organic compounds containing the sulfuryl bromide functional group.",
      'parent' => 2869,
    ),
    array(
      'tid' => 1038,
      'name' => "Organic sulfuryl chlorides",
      'description' => "Organic compounds containing the sulfuryl chloride functional group.",
      'parent' => 2869,
    ),
    array(
      'tid' => 1039,
      'name' => "Organic sulfuryl fluorides",
      'description' => "Organic compounds containing the sulfuryl fluoride functional group.",
      'parent' => 2869,
    ),
    array(
      'tid' => 1040,
      'name' => "Organic sulfuryl iodides",
      'description' => "Organic compounds containing the sulfuryl iodide functional group.",
      'parent' => 2869,
    ),
    array(
      'tid' => 1041,
      'name' => "Sulfonyl bromides",
      'description' => "Compounds containing a sulfonyl (R-S(=O)2-R') functional group singly bonded to a bromine atom.",
      'parent' => 506,
    ),
    array(
      'tid' => 1042,
      'name' => "Sulfonyl chlorides",
      'description' => "Compounds containing a sulfonyl (R-S(=O)2-R') functional group singly bonded to a chlorine atom.",
      'parent' => 506,
    ),
    array(
      'tid' => 1043,
      'name' => "Sulfonyl fluorides",
      'description' => "Compounds containing a sulfonyl (R-S(=O)2-R') functional group singly bonded to a fluorine atom.",
      'parent' => 506,
    ),
    array(
      'tid' => 1044,
      'name' => "Sulfonyl iodides",
      'description' => "Compounds containing a sulfonyl (R-S(=O)2-R') functional group singly bonded to an iodine atom.",
      'parent' => 506,
    ),
    array(
      'tid' => 1045,
      'name' => "Carboxamidines",
      'description' => "Carboxylic acid derivatives containing the amidine group.",
      'parent' => 7,
    ),
    array(
      'tid' => 1046,
      'name' => "Sulfinamidines",
      'description' => "Compounds containing a sulfinamidine group, with the general structure RS(=NR)NR2.",
      'parent' => 7,
    ),
    array(
      'tid' => 1047,
      'name' => "Phosphinamidines",
      'description' => "Compounds containing a phosphinamidine group, with the general structure  R2P(=NR)NR2.",
      'parent' => 7,
    ),
    array(
      'tid' => 1048,
      'name' => "Non-metal bromates",
      'description' => "Inorganic non-metallic compounds containing a bromate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1049,
      'name' => "Non-metal chlorates",
      'description' => "Inorganic non-metallic compounds containing a chlorate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1050,
      'name' => "Non-metal chlorites",
      'description' => "Inorganic non-metallic compounds containing a chlorite as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1051,
      'name' => "Non-metal chromates",
      'description' => "Inorganic non-metallic compounds containing a chromate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1052,
      'name' => "Non-metal chromites",
      'description' => "Inorganic non-metallic compounds containing a chromite as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1053,
      'name' => "Non-metal cyanates",
      'description' => "Inorganic non-metallic compounds containing a cyanate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1054,
      'name' => "Phenyldithiazoles",
      'description' => "Compounds containing a phenyldithiazole moiety, which consists of an dithiazole ring attached to a phenyl group.",
      'parent' => 1128,
    ),
    array(
      'tid' => 1055,
      'name' => "Non-metal hydroxides",
      'description' => "Inorganic non-metallic compounds containing the hydroxide group as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1056,
      'name' => "Non-metal hypobromites",
      'description' => "Inorganic non-metallic compounds containing a hypobromite as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1057,
      'name' => "Non-metal hypochlorites",
      'description' => "Inorganic non-metallic compounds containing a hypochlorite as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1058,
      'name' => "Non-metal hyponitrites",
      'description' => "Inorganic non-metallic compounds containing a hyponitrite as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1059,
      'name' => "Non-metal hypophosphites",
      'description' => "Inorganic non-metallic compounds containing a hypophosphite as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1060,
      'name' => "Non-metal iodates",
      'description' => "Inorganic non-metallic compounds containing a iodate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1061,
      'name' => "Non-metal nitrites",
      'description' => "Inorganic non-metallic compounds containing a nitrite as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1062,
      'name' => "Non-metal nitrates",
      'description' => "Inorganic non-metallic compounds containing a nitrate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1063,
      'name' => "Non-metal orthonitrates",
      'description' => "Inorganic non-metallic compounds containing a orthonitrate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1064,
      'name' => "Non-metal perbromates",
      'description' => "Inorganic non-metallic compounds containing a perbromate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1065,
      'name' => "Non-metal perchlorates",
      'description' => "Inorganic non-metallic compounds containing a perchlorate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1066,
      'name' => "Non-metal periodates",
      'description' => "Inorganic non-metallic compounds containing a periodate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1067,
      'name' => "Non-metal permanganates",
      'description' => "Inorganic non-metallic compounds containing a permanganate as its largest oxoanion.",
      'parent' => 1442,
    ),
    array(
      'tid' => 1068,
      'name' => "Non-metal peroxynitrates",
      'description' => "Inorganic non-metallic compounds containing a peroxynitrate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1069,
      'name' => "Non-metal peroxynitrites",
      'description' => "Inorganic non-metallic compounds containing a peroxynitrite as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1070,
      'name' => "Non-metal perrhenates",
      'description' => "Inorganic non-metallic compounds containing a perrhenate as its largest oxoanion.",
      'parent' => 1442,
    ),
    array(
      'tid' => 1071,
      'name' => "Non-metal pertechnetates",
      'description' => "Inorganic non-metallic compounds containing a pertechnetate as its largest oxoanion.",
      'parent' => 1442,
    ),
    array(
      'tid' => 1072,
      'name' => "Non-metal phosphites",
      'description' => "Inorganic non-metallic compounds containing a phosphite as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1073,
      'name' => "Non-metal phosphates",
      'description' => "Inorganic non-metallic compounds containing a phosphate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1074,
      'name' => "Non-metal pyrophosphates",
      'description' => "Inorganic non-metallic compounds containing a pyrophosphate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1075,
      'name' => "Non-metal selenates",
      'description' => "Inorganic non-metallic compounds containing a selenate as its largest oxoanion.",
      'parent' => 1442,
    ),
    array(
      'tid' => 1076,
      'name' => "Non-metal selenites",
      'description' => "Inorganic non-metallic compounds containing a selenite as its largest oxoanion.",
      'parent' => 1442,
    ),
    array(
      'tid' => 1077,
      'name' => "Non-metal sulfates",
      'description' => "Inorganic non-metallic compounds containing a sulfate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1078,
      'name' => "Non-metal sulfites",
      'description' => "Inorganic non-metallic compounds containing a sulfite as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1079,
      'name' => "Non-metal superoxides",
      'description' => "Inorganic non-metallic compounds containing a superoxide as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1080,
      'name' => "Tetrazolines",
      'description' => "Organic compounds containing a tetrazoline ring, which is a five-member unsaturated aliphatic heterocycle made up of four nitrogen atoms, a one carbon atom, and one double bond.",
      'parent' => 2490,
    ),
    array(
      'tid' => 1081,
      'name' => "Non-metal peroxomonosulfates",
      'description' => "Inorganic non-metallic compounds containing a peroxomonosulfate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1082,
      'name' => "Non-metal peroxodisulfates",
      'description' => "Inorganic non-metallic compounds containing a peroxodisulfate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1083,
      'name' => "Non-metal pyrosulfates",
      'description' => "Inorganic non-metallic compounds containing a pyrosulfate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1084,
      'name' => "Non-metal tetrathionates",
      'description' => "Inorganic non-metallic compounds containing a tetrathionate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1085,
      'name' => "Non-metal thiosulfates",
      'description' => "Inorganic non-metallic compounds containing a thiosulfate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1086,
      'name' => "Non-metal dithionites",
      'description' => "Inorganic non-metallic compounds containing a dithionite as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1087,
      'name' => "Non-metal hyposulfites",
      'description' => "Inorganic non-metallic compounds containing a hyposulfite as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1088,
      'name' => "Hemiaminals",
      'description' => "Compounds comprising the hemiaminal functional group, with the general formula R2C(OH)NR2 where R can by a hydrogen or an alkyl group.",
      'parent' => 2460,
    ),
    array(
      'tid' => 1089,
      'name' => "Gal- (Gala series)",
      'description' => "Neutral glycosphingolipids in which the oligosaccharide root structure is made up of two 1-4 linked galactose molecules.",
      'parent' => 1419,
    ),
    array(
      'tid' => 1090,
      'name' => "Acyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to an acyl chain.",
      'parent' => 3327,
    ),
    array(
      'tid' => 1091,
      'name' => "Toluenes",
      'description' => "Compounds containing a benzene ring which bears a methane group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 1092,
      'name' => "Hemiacetals",
      'description' => "Compounds comprising the hemiacetal functional group, with the general formula R2C(OH)OR' ( R' not Hydrogen ).",
      'parent' => 254,
    ),
    array(
      'tid' => 1093,
      'name' => "Carboxylic acid derivatives",
      'description' => "Derivatives of carboxylic acid.",
      'parent' => 265,
    ),
    array(
      'tid' => 1094,
      'name' => "Imidothioesters",
      'description' => "Organic thioester derivatives of imidic acid. They have the general structure RSC(CR')=NR\", where R=organyl group, R'-R\"= H or organyl group.",
      'parent' => 4,
    ),
    array(
      'tid' => 1095,
      'name' => "Acyl carnitines",
      'description' => "Organic compounds containing a fatty acid with the carboxylic acid attached to carnitine through an ester bond.",
      'parent' => 324,
    ),
    array(
      'tid' => 1096,
      'name' => "N-acyl amines",
      'description' => "Compounds containing a fatty acid moiety linked to an amine group through an ester linkage.",
      'parent' => 331,
    ),
    array(
      'tid' => 1097,
      'name' => "Benzyloxycarbonyls",
      'description' => "Organic compounds containing a carbonyl group substituted with a benzyloxyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 1098,
      'name' => "Bromobenzenes",
      'description' => "Organic compounds containing a bromine atom attached to a benzene ring.",
      'parent' => 35,
    ),
    array(
      'tid' => 1099,
      'name' => "Chlorobenzenes",
      'description' => "Compounds containing one or more chlorine atoms attached to a benzene moiety.",
      'parent' => 35,
    ),
    array(
      'tid' => 1100,
      'name' => "Fluorobenzenes",
      'description' => "Compounds containing one or more fluorine atoms attached to a benzene ring.",
      'parent' => 35,
    ),
    array(
      'tid' => 1101,
      'name' => "Iodobenzenes",
      'description' => "Aromatic compounds containing one or more iodine atoms attached to a benzene.",
      'parent' => 35,
    ),
    array(
      'tid' => 1102,
      'name' => "Acyl homoserine lactones",
      'description' => "N-acyl-homoserine-lactones attached to a long aliphatic chain.",
      'parent' => 331,
    ),
    array(
      'tid' => 1103,
      'name' => "Endocannabinoids",
      'description' => "Arachidonic acid derivatives containing either an N-acetylethanolamine(type 1) or a glycerol(types 2 and 3) moiety attached to the aliphatic tail.",
      'parent' => 12,
    ),
    array(
      'tid' => 1104,
      'name' => "Trihydroxy bile acids, alcohols and derivatives",
      'description' => "Prenol lipids structurally characterized by a bile acid or alcohol which bears three hydroxyl groups.",
      'parent' => 2194,
    ),
    array(
      'tid' => 1105,
      'name' => "Phthalic acid and derivatives",
      'description' => "Compounds containing a phthalic acid moiety (or a derivative thereof), which is a benzene ring bearing a carboxylic acid group at two different ring positions. Isomers of phthalic acid include meta-phthalic acid (benzene-1,3-dioic acid), ortho-phthalic acid (benzene-1,2-dioic acid), and para-phthalic acid (benzene-1,4-dioic acid).",
      'parent' => 176,
    ),
    array(
      'tid' => 1106,
      'name' => "M-phthalic acid and derivatives",
      'description' => "Aromatic compounds containing a benzene ring bearing a carboxylic acid group at ring carbon atoms 1 and 2.",
      'parent' => 1105,
    ),
    array(
      'tid' => 1107,
      'name' => "O-phthalic acid and derivatives",
      'description' => "Compounds containing a benzene ring bearing a carboxylic acid group at ring carbon atoms 1 and 3.",
      'parent' => 1105,
    ),
    array(
      'tid' => 1108,
      'name' => "P-phthalic acid and derivatives",
      'description' => "Compounds containing a benzene ring bearing a carboxylic acid group at ring carbon atoms 1 and 4.",
      'parent' => 1105,
    ),
    array(
      'tid' => 1109,
      'name' => "Phthalic anhydrides",
      'description' => "Compounds containing a phthalic anhydride moiety (or a derivative thereof), which consists of a benzene fused to a furan-1,3-dione.",
      'parent' => 1578,
    ),
    array(
      'tid' => 1110,
      'name' => "Tetrahydroxy bile acids, alcohols and derivatives",
      'description' => "Prenol lipids structurally characterized by a bile acid or alcohol which bears four hydroxyl groups.",
      'parent' => 2194,
    ),
    array(
      'tid' => 1111,
      'name' => "Flavonoid glycosides",
      'description' => "Compounds containing a carbohydrate moiety which is glycosidically linked to one of the flavonoid backbones (2-phenylchromen-4-one, 3-phenylchromen-4-one or 4-phenylcoumarin).",
      'parent' => 334,
    ),
    array(
      'tid' => 1112,
      'name' => "Thiocarboxylic acids and derivatives",
      'description' => "Organic compounds containing a derivative of thiocarboxylic acid, with the general structure RC(=S)R' (R=H, alkyl, aryl; R'=any heteroatom).",
      'parent' => 264,
    ),
    array(
      'tid' => 1113,
      'name' => "Alpha-keto acids and derivatives",
      'description' => "Organic compounds containing an aldehyde substituted with a keto group on the adjacent carbon.",
      'parent' => 389,
    ),
    array(
      'tid' => 1114,
      'name' => "Beta-keto acids and derivatives",
      'description' => "Organic compounds containing an aldehyde substituted with a keto group on the C3 carbon atom.",
      'parent' => 389,
    ),
    array(
      'tid' => 1115,
      'name' => "Gamma-keto acids and derivatives",
      'description' => "Organic compounds containing an aldehyde substituted with a keto group on the C4 carbon atom.",
      'parent' => 389,
    ),
    array(
      'tid' => 1116,
      'name' => "Lipoic acids and derivatives",
      'description' => "Compounds containing a lipoic acid moiety (or a derivative thereof), which consists of a pentanoic acid (or derivative) attached to the C3 carbon atom of a 1,2-dithiolane ring.",
      'parent' => 484,
    ),
    array(
      'tid' => 1117,
      'name' => "Polyprenyl phospho carbohydrates",
      'description' => "Polyprenyl phosphates with a carbohydrate moiety attached to it.",
      'parent' => 1535,
    ),
    array(
      'tid' => 1118,
      'name' => "Gamma-amino ketones",
      'description' => "Organic compounds containing a carboxylic acid, and an amine group attached to the C4 carbon atom.",
      'parent' => 118,
    ),
    array(
      'tid' => 1119,
      'name' => "Sulfonyl-1,2,3-triazoles",
      'description' => "Cyclic compounds containing a sulfonyl group attached to a 1,2,3-triazole ring.",
      'parent' => 99,
    ),
    array(
      'tid' => 1120,
      'name' => "Sulfonyl-1,2,4-triazoles",
      'description' => "Cyclic compounds containing a sulfonyl group attached to a 1,2,4-triazole ring.",
      'parent' => 99,
    ),
    array(
      'tid' => 1121,
      'name' => "N-sulfonyl-1,2,3-triazoles",
      'description' => "Cyclic compounds containing a sulfonyl group attached to an N atoms of a 1,2,3-triazole ring.",
      'parent' => 1119,
    ),
    array(
      'tid' => 1122,
      'name' => "Thiobarbituric acid derivatives",
      'description' => "Organic compounds containing a 2-thioxodihydropyrimidine-4,6(1H,5H)-dione skeleton.",
      'parent' => 291,
    ),
    array(
      'tid' => 1123,
      'name' => "Triazolopyridinones",
      'description' => "Compounds containing triazolopyridine moiety which bears a ketone group. Triazolopyridine is a bicyclic compound consisting of a triazole fused to a pyridine ring.",
      'parent' => 314,
    ),
    array(
      'tid' => 1124,
      'name' => "Glycinated bile acids and derivatives",
      'description' => "Compounds with a structure characterized by the presence of a glycine linked to a bile acid skeleton.",
      'parent' => 1445,
    ),
    array(
      'tid' => 1125,
      'name' => "Steroid lactones",
      'description' => "Sterol lipids containing a lactone moiety linked to the steroid skeleton.",
      'parent' => 258,
    ),
    array(
      'tid' => 1126,
      'name' => "2,3-diphenylfurans",
      'description' => "Organic heterocyclic compounds that contain a furan ring substituted with a phenyl group only the C2- and C3-positions.",
      'parent' => 3491,
    ),
    array(
      'tid' => 1127,
      'name' => "Acyclic monoterpenoids",
      'description' => "Monoterpenes that do not contain a cycle.",
      'parent' => 1549,
    ),
    array(
      'tid' => 1128,
      'name' => "Dithiazolethiones",
      'description' => "Compounds containing a dithiazole bearing a thioketone group.",
      'parent' => 148,
    ),
    array(
      'tid' => 1129,
      'name' => "Diacylglycerols",
      'description' => "Glycerides consisting of two fatty acid chains covalently bonded to a glycerol molecule through ester linkages.",
      'parent' => 3809,
    ),
    array(
      'tid' => 1130,
      'name' => "1,2,4-dithiazole-3-thiones",
      'description' => "Organic compounds containing a 1,2,4-dithiazole ring with a thioketone group at ring position 3.",
      'parent' => 1128,
    ),
    array(
      'tid' => 1131,
      'name' => "Sphingomyelins",
      'description' => "Sphingolipids containing a backbone formed of an alcohol - sphingosine, a phosphate group, a choline and fatty acid chain.",
      'parent' => 3392,
    ),
    array(
      'tid' => 1132,
      'name' => "Pyrimidodiazepines",
      'description' => "Compounds containing a pyrimidoazepine moiety, which consists of a pyrimidine fused to a piperazine ring by a bond. Pyrimidine is 6-membered ring consisting of five carbon atoms and two nitrogen atoms at ring positions 1 and 3. Diazepine is a 7-membered ring consisting of five carbon atoms and two nitrogen centers.",
      'parent' => 2,
    ),
    array(
      'tid' => 1133,
      'name' => "Monoacylglycerols",
      'description' => "Glycerides consisting of one fatty acid chain covalently bonded to a glycerol molecule through an ester linkage.",
      'parent' => 3808,
    ),
    array(
      'tid' => 1134,
      'name' => "Thionucleosides",
      'description' => "Nucleoside analogues that contain a thiolane or a thietane that is 1,3-disubstituted with a hydroxyl group and pyrimidine or purine base, at the 1- and 3-position, respectively.",
      'parent' => 3737,
    ),
    array(
      'tid' => 1135,
      'name' => "Triacylglycerols",
      'description' => "Glycerides consisting of three fatty acid chains covalently bonded to a glycerol molecule through ester linkages.",
      'parent' => 3815,
    ),
    array(
      'tid' => 1136,
      'name' => "Flavonols",
      'description' => "Compounds that contain a flavone (2-phenyl-1-benzopyran-4-one) backbone carrying a hydroxyl group at the 3-position.",
      'parent' => 1615,
    ),
    array(
      'tid' => 1137,
      'name' => "Monocarboxylic acids and derivatives",
      'description' => "Carboxylic acids containing exactly one carboxyl groups.",
      'parent' => 265,
    ),
    array(
      'tid' => 1138,
      'name' => "Leucoanthocyanidins",
      'description' => "Flavonoids consisting of a flavan (3,4-dihydro-2-phenyl-2H-1-benzopyran) moiety that carries two hydroxy groups at the C3- and C4-positions.",
      'parent' => 337,
    ),
    array(
      'tid' => 1139,
      'name' => "Phosphatidylinositol phosphates",
      'description' => "Phosphorylated derivatives of phosphatidylinositols, which are glycerophosphoinositols where the glycerol is esterified with two fatty acids.",
      'parent' => 2220,
    ),
    array(
      'tid' => 1140,
      'name' => "Harmala alkaloids",
      'description' => "Compounds with a structure based on harmaline, harmine, harmalol, harman or a derivative of those parents. These parents are beta-carbolines, consisting of a pyrimidine fused to the pyrrole moiety of an indole to form a pyrido[3,4-b]indole.",
      'parent' => 279,
    ),
    array(
      'tid' => 1141,
      'name' => "Sulfonylanilines",
      'description' => "Compounds containing an aniline moiety, which is para-substituted by a sulfonyl group.",
      'parent' => 284,
    ),
    array(
      'tid' => 1142,
      'name' => "Chrysenes",
      'description' => "Compounds containing the polyaromatic chrysene moiety, which consists of a benzene ring fused to a phenanthrene ring system to form Benzo[a]phenanthrene.",
      'parent' => 25,
    ),
    array(
      'tid' => 1143,
      'name' => "Coenzyme A and derivatives",
      'description' => "Derivative of vitamin B5 containing a 4'-phosphopantetheine moiety attached to a diphospho-adenosine.",
      'parent' => 2209,
    ),
    array(
      'tid' => 1144,
      'name' => "Fluoroquinolones",
      'description' => "Compounds containing a fluorine atom attached to a quinolone. Quinolone or benzo[b]pyridine is a bicyclic compound that consists of benzene fused to a pyridine, and bears a ketone group.",
      'parent' => 56,
    ),
    array(
      'tid' => 1145,
      'name' => "N-acylethanolamines",
      'description' => "Compounds containing an N-acyethanolamine moiety, which is characterized by an acyl group is linked to the nitrogen atom of ethanolamine.",
      'parent' => 1897,
    ),
    array(
      'tid' => 1146,
      'name' => "Indolines",
      'description' => "Compounds containing an indole moiety, which consists of pyrrolidine ring fused to benzene  to form 2,3-dihydroindole.",
      'parent' => 211,
    ),
    array(
      'tid' => 1147,
      'name' => "Sphaeroane diterpenoids",
      'description' => "Diterpenoids with a structure based on the 3a,6,9-trimethyl-3-(propan-2-yl)-tetradecahydrocyclohexa[e]azulene skeleton or formally 2,7-cyclodolabellane.",
      'parent' => 1551,
    ),
    array(
      'tid' => 1148,
      'name' => "Amino sugars",
      'description' => "Sugars having one alcoholic hydroxy group replaced by an amino group; systematically known as x-amino-x-deoxymonosaccharides.  These compounds do not include Glycosylamines.",
      'parent' => 3305,
    ),
    array(
      'tid' => 1149,
      'name' => "Imidazolidinones",
      'description' => "Organic compounds containing an imidazolidinone moiety, which is an imidazolidine ring bearing a ketone.",
      'parent' => 250,
    ),
    array(
      'tid' => 1150,
      'name' => "Imidazolidinediones",
      'description' => "Organic compounds containing an imidazolidinedione moiety, which is an imidazolidine ring bearing two ketones.",
      'parent' => 1149,
    ),
    array(
      'tid' => 1151,
      'name' => "Indanones",
      'description' => "Compounds containing an indane ring bearing a ketone group.",
      'parent' => 27,
    ),
    array(
      'tid' => 1152,
      'name' => "Organic nitro compounds",
      'description' => "Compounds having the nitro group, -NO2 (free valence on nitrogen), which may be attached to carbon, nitrogen (as in nitramines), or oxygen (as in nitrates), among other elements (in the absence of specification, C-nitro compounds are usually implied).",
      'parent' => 3631,
    ),
    array(
      'tid' => 1153,
      'name' => "Organic plumbates",
      'description' => "Organic compounds containing a plumbate oxoanion, with the formula [PbO3]2-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1154,
      'name' => "Lipoamides",
      'description' => "Compounds containing a lipoamide moiety, which consists of a pentanamide attached to the C3 carbon atom of a 1,2-dithiolane ring.",
      'parent' => 484,
    ),
    array(
      'tid' => 1155,
      'name' => "Nitroquinolines and derivatives",
      'description' => "Compounds containing a nitro group attached to a quinoline moiety.",
      'parent' => 1253,
    ),
    array(
      'tid' => 1156,
      'name' => "Phenylaziridines",
      'description' => "Compounds containing a phenylaziridine moiety, which consists of an aziridine ring attached to a phenyl group.",
      'parent' => 103,
    ),
    array(
      'tid' => 1157,
      'name' => "Sulfonyls",
      'description' => "Compounds containing the sulfonyl group, with the general structure RS(=O)2R' ( R,R' must not be H).",
      'parent' => 4,
    ),
    array(
      'tid' => 1158,
      'name' => "Pyrrolidones",
      'description' => "Compounds containing a pyrrolidine ring which bears a C=O group.",
      'parent' => 218,
    ),
    array(
      'tid' => 1159,
      'name' => "Taurinated bile acids and derivatives",
      'description' => "Bile acid derivatives containing a taurine conjugated to the bile acid moiety.",
      'parent' => 1445,
    ),
    array(
      'tid' => 1160,
      'name' => "Pyridinones",
      'description' => "Compounds containing a pyridine ring, which bears a ketone.",
      'parent' => 2224,
    ),
    array(
      'tid' => 1161,
      'name' => "Thiosulfinic acid esters",
      'description' => "Organic compounds containing an ester of thiosulfinic acid with the general structure RS(=S)OR' (R, R'=alkyl, aryl).",
      'parent' => 264,
    ),
    array(
      'tid' => 1162,
      'name' => "Carbamate esters",
      'description' => "Compounds containing an ester of carbamic acid with the general structure R2NC(=O)OR' (R' not H). They are esters of carbamic acids.",
      'parent' => 318,
    ),
    array(
      'tid' => 1163,
      'name' => "Organic thiophosphonic acid derivatives",
      'description' => "Organic compounds containing thiophosphonic acid functional group. Thiophosphonic acid is a phosphorus compound with the formula OP(O)(=S).",
      'parent' => 264,
    ),
    array(
      'tid' => 1164,
      'name' => "Amidrazones",
      'description' => "Organic compounds containing the carboxylic acid amidrazone functional group.",
      'parent' => 475,
    ),
    array(
      'tid' => 1165,
      'name' => "Carboxylic acid hydrazides",
      'description' => "Carboxylic acid derivatives containing a carbonyl group in which the carbon is directly linked to a hydrazide group (N-N).",
      'parent' => 1093,
    ),
    array(
      'tid' => 1166,
      'name' => "Carboxylic acid salts",
      'description' => "Ionic derivatives of carboxylic acid.",
      'parent' => 1093,
    ),
    array(
      'tid' => 1167,
      'name' => "Dialkyl ethers",
      'description' => "Organic compounds containing the dialkyl ether functional group, with the formula ROR', where R and R' are alkyl groups.",
      'parent' => 254,
    ),
    array(
      'tid' => 1168,
      'name' => "Ketene acetals",
      'description' => "Organic compounds comprising the ketene acetal functional group, with the general structure XC(Y)=C(R3)R4 (R1,R2=H, alkyl, aryl; X,Y=any hetero atom).",
      'parent' => 323,
    ),
    array(
      'tid' => 1169,
      'name' => "Phosphonic acid esters",
      'description' => "Organic compounds containing phosphonic acid ester functional group,  with the general structure ROP(=O)OH (R = organyl group).",
      'parent' => 419,
    ),
    array(
      'tid' => 1170,
      'name' => "Epoxide amino acids and derivatives",
      'description' => "Sugar amino acids containing an oxirane ring between the carboxy- and the amino terminals of the amino acid chain.",
      'parent' => 1366,
    ),
    array(
      'tid' => 1171,
      'name' => "Steroidal acyl CoAs",
      'description' => "Acyl CoAs where the group acylated to the coenzyme A moiety is a steroid.",
      'parent' => 1090,
    ),
    array(
      'tid' => 1172,
      'name' => "Organosulfenic acid amides",
      'description' => "Compounds derived from a sulfenic acid, RSOH (R= organyl, not H), by replacement of -OH by -NR2.",
      'parent' => 268,
    ),
    array(
      'tid' => 1173,
      'name' => "Sulfenic acid esters",
      'description' => "Compounds containing a sulfenic acid ester functional group with the general structure RSOR' (R,R'=alkyl, aryl).",
      'parent' => 268,
    ),
    array(
      'tid' => 1174,
      'name' => "Organosulfenic acid halides",
      'description' => "Compounds derived from a sulfenic acid, RSOH (R = organyl, not H), where the hydroxyl group is replace by a halogen atom.",
      'parent' => 268,
    ),
    array(
      'tid' => 1175,
      'name' => "Sulfinic acid amides",
      'description' => "Compounds derived from a sulfinic acid, RS(=O)OH (R not H), by replacement of -OH by -NR2.",
      'parent' => 269,
    ),
    array(
      'tid' => 1176,
      'name' => "Sulfinic acid esters",
      'description' => "Compounds containing a sulfinic acid ester functional group with the general structure RS(=O)OR' (R,R'=alkyl, aryl).",
      'parent' => 269,
    ),
    array(
      'tid' => 1177,
      'name' => "Sulfinic acid halides",
      'description' => "Compounds derived from a sulfinic acid, RS(=O)OH (R = organyl, not H), where the hydroxyl group is replace by a halogen atom.",
      'parent' => 269,
    ),
    array(
      'tid' => 1178,
      'name' => "Organosulfonic acid esters",
      'description' => "Esters of sulfonic acid, which have the general structure RS(=O)2OR' (R,R' = organyl, not H).",
      'parent' => 270,
    ),
    array(
      'tid' => 1179,
      'name' => "Organosulfonic acids",
      'description' => "Compounds containing the sulfonic acid group, which has the general structure RS(=O)2OH (R is not a hydrogen atom).",
      'parent' => 270,
    ),
    array(
      'tid' => 1180,
      'name' => "Organic sulfuric acids",
      'description' => "Organic compounds containing the sulfuric acid functional group, with the generic structure HOS(=O)(=O)OH.",
      'parent' => 403,
    ),
    array(
      'tid' => 1181,
      'name' => "Sulfuric acid monoamides",
      'description' => "Organic compounds containing the sulfuric acid amid functional group, with the generic structure ROS(=O)(=O)N(R')R'' (R = any atom, R' = organyl, R''=H or organyl).",
      'parent' => 403,
    ),
    array(
      'tid' => 1182,
      'name' => "Corroles",
      'description' => "Compounds containing a corrole nucleus, which contains four pyrrole rings joined in a macrocycle by three  groups and one direct carbon-carbon bond linking alpha positions.",
      'parent' => 1455,
    ),
    array(
      'tid' => 1183,
      'name' => "Sulfuric acid diamides",
      'description' => "Organic compounds containing the sulfuric acid diamide functional group, with the generic structure R1N(R2)S(=O)(=O)ON(R3)R4 (R1-R4 = H or organyl.",
      'parent' => 403,
    ),
    array(
      'tid' => 1184,
      'name' => "Sulfuric acid diesters",
      'description' => "Organic compounds containing the sulfuric acid diester functional group with the generic structure ROS(OR')(=O)=O, (R,R'=organyl group).",
      'parent' => 3455,
    ),
    array(
      'tid' => 1185,
      'name' => "Sulfuric acid monoesters",
      'description' => "Organic compounds containing the sulfuric acid monoester functional group, with the generic structure ROS(O)(=O)=O, (R=organyl group).",
      'parent' => 3455,
    ),
    array(
      'tid' => 1186,
      'name' => "Sulfuric acid amide esters",
      'description' => "Organic compounds containing the sulfuric acid amide ester functional group, with the generic structure ROS(=O)(=O)N(R')R'' (R = organyl, R',R''=H or organyl).",
      'parent' => 403,
    ),
    array(
      'tid' => 1187,
      'name' => "Thioacetals",
      'description' => "Organic compounds containing either the monothiacetal functional group (R2C(OR')(SR')) or the dithioacetal (R2C(SR')2) functional group .",
      'parent' => 4,
    ),
    array(
      'tid' => 1188,
      'name' => "Thioaldehydes",
      'description' => "An organic compounds in which the oxygen of an aldehyde has been replaced by divalent sulfur, RC(=S)H. Thioaldehydes interconvert with thioketones.",
      'parent' => 1198,
    ),
    array(
      'tid' => 1189,
      'name' => "N-acyl-alpha amino acids and derivatives",
      'description' => "Compounds containing an alpha amino acid (or a derivative thereof) which bears an acyl group at its terminal nitrogen atom.",
      'parent' => 60,
    ),
    array(
      'tid' => 1190,
      'name' => "Thiocarbamic acid esters",
      'description' => "Organic compounds containing a functional group with the general structure R1OC(=S)N(R2)R3 (R1=alkyl, aryl; R2,R3=H, alkyl, aryl).",
      'parent' => 1368,
    ),
    array(
      'tid' => 1191,
      'name' => "Thiocarbamic acid halides",
      'description' => "Organic compounds containing a functional group with the general structure R1C(=S)N(R2)R3 (R1=halogen; R2,R3=H, alkyl, aryl).",
      'parent' => 1368,
    ),
    array(
      'tid' => 1192,
      'name' => "Carbamic acid halides",
      'description' => "Compounds containing a carbamic acid derivative linked to a halogen atom.",
      'parent' => 318,
    ),
    array(
      'tid' => 1193,
      'name' => "Organic thiocarbonic acids",
      'description' => "Organic compounds comprising the thiocarbonic acid group, with the general structure HOC(=S)OH.",
      'parent' => 1672,
    ),
    array(
      'tid' => 1194,
      'name' => "Oxosteroids",
      'description' => "Steroid derivatives carrying a C=O group attached to steroid skeleton.",
      'parent' => 258,
    ),
    array(
      'tid' => 1195,
      'name' => "Thiocarbonic acid ester halides",
      'description' => "Organic compounds containing a diester derivative of thiocarbonic acid, with the general formula XOC(=S)OR (X=F, I, Cl, Br; R=alkyl, aryl).",
      'parent' => 1672,
    ),
    array(
      'tid' => 1196,
      'name' => "Thiocarbonic acid monoesters",
      'description' => "Organic compounds containing a monoester derivative of thiocarbonic acid, with the general formula HOC(=S)OR (R=alkyl, aryl).",
      'parent' => 1672,
    ),
    array(
      'tid' => 1197,
      'name' => "Thiocarbonic acid diesters",
      'description' => "Organic compounds containing a diester derivative of thiocarbonic acid, with the general formula ROC(=S)OR' (R,R'=alkyl, aryl).",
      'parent' => 1672,
    ),
    array(
      'tid' => 1198,
      'name' => "Thiocarbonyl compounds",
      'description' => "Organic compounds containing a functional group with the general structure R1C(=S)R2 (R1, R2=H, alkyl, aryl).",
      'parent' => 4,
    ),
    array(
      'tid' => 1199,
      'name' => "Thiocarboxylic acids",
      'description' => "Organic compounds containing a thiocarboxylic acid functional group, with the general structure HOC(=S)OH.",
      'parent' => 1112,
    ),
    array(
      'tid' => 1200,
      'name' => "Thioesters",
      'description' => "Organic compounds containing an ester of thiocarboxylic acid, with the general structure RC(=S)XR' (R=H, alkyl, aryl; R'=alkyl, aryl; X=O,S).",
      'parent' => 1112,
    ),
    array(
      'tid' => 1201,
      'name' => "Thiocyanates",
      'description' => "Salts or esters of thiocyanic acid, with the general formula RSC#N (R=alkyl, aryl).",
      'parent' => 4,
    ),
    array(
      'tid' => 1202,
      'name' => "Thioethers",
      'description' => "Compounds containing the ester derivative of thiocarboxylic acid, with the general structure R-S-R' (R,R'=alkyl, aryl).",
      'parent' => 4,
    ),
    array(
      'tid' => 1203,
      'name' => "Phenyldithiazolethiones",
      'description' => "Compounds containing a phenyldithiazolethione skeleton, which consists of an dithiazolethione moiety attached to a phenyl group.",
      'parent' => 1054,
    ),
    array(
      'tid' => 1204,
      'name' => "Organic phosphoramides",
      'description' => "Organic compounds containing the phosphoric acid amide functional group.",
      'parent' => 402,
    ),
    array(
      'tid' => 1205,
      'name' => "Carboxylic acids",
      'description' => "Compounds containing a carboxylic acid group with the formula -C(=O)OH.",
      'parent' => 265,
    ),
    array(
      'tid' => 1206,
      'name' => "Organic phosphoric acid halides",
      'description' => "Organic compounds containing the phosphoric acid halide functional group with the general structure OP(O)(=O)OX (X = halogen atom).",
      'parent' => 402,
    ),
    array(
      'tid' => 1207,
      'name' => "Thiosemicarbazides",
      'description' => "Compounds containing a derivative of thiosemicarbazide with the general structure R1N(R2)N(R3)C(=S)N(R4)R5 (R1-R5=H, alkyl, aryl) where the ketone group has carbonyl group has been replaced with a thiocarbonyl group.",
      'parent' => 112,
    ),
    array(
      'tid' => 1208,
      'name' => "Thiosemicarbazones",
      'description' => "Compounds containing the thiosemicarbazone functional group obtained by replacing the carbonyl group by a thiocarbonyl group.",
      'parent' => 1207,
    ),
    array(
      'tid' => 1209,
      'name' => "Thioureas",
      'description' => "Organic compounds containing the thiourea functional group, a derivative of urea with the general structure (R1(N)R2C(=S)(R3)R4, R1-R4=H, alkyl, aryl), obtained by replacing the carbonyl group of urea with a thiocarbonyl group.",
      'parent' => 4,
    ),
    array(
      'tid' => 1210,
      'name' => "Ynamines",
      'description' => "N,N-Disubstituted alk-1-yn-1-amines RC≡CNR2.",
      'parent' => 2449,
    ),
    array(
      'tid' => 1211,
      'name' => "Dihydropyranones",
      'description' => "Compounds containing a hydrogenated pyran ring which bears a ketone, and contains one double bond.",
      'parent' => 481,
    ),
    array(
      'tid' => 1212,
      'name' => "Alkylthiols",
      'description' => "Organic compounds containing the thiol functional group linked to an alkyl chain.",
      'parent' => 2485,
    ),
    array(
      'tid' => 1213,
      'name' => "Pyridoindoles",
      'description' => "Compounds containing a pyridoindole, which consists of a pyridine fused to an indole. Pyridine is a 6-membered ring consisting of five carbon atoms and one nitrogen center. Indole is a bicyclic  compound consisting of a six-membered benzene ring fused to a five-membered nitrogen-containing pyrrole ring.",
      'parent' => 211,
    ),
    array(
      'tid' => 1214,
      'name' => "Thiolactones",
      'description' => "Cyclic thioesters obtained by replacing the oxygen atom from a lactone ring with sulfur.",
      'parent' => 2,
    ),
    array(
      'tid' => 1215,
      'name' => "Heterocyclic diaryl ethers",
      'description' => "Heterocyclic compounds comprising the diaryl ether functional group, with the general formula ROR' (R,R'=aryl).",
      'parent' => 2463,
    ),
    array(
      'tid' => 1216,
      'name' => "Homocyclic diaryl ethers",
      'description' => "Homocyclic compounds comprising the diaryl ether functional group, with the general formula ROR' (R,R'=aryl).",
      'parent' => 2463,
    ),
    array(
      'tid' => 1217,
      'name' => "Diphenyltetrazoles and derivatives",
      'description' => "Organic compounds containing a dioxane ring, which is an aliphatic six-member ring with two oxygen atoms.",
      'parent' => 306,
    ),
    array(
      'tid' => 1218,
      'name' => "Inorganic isocyanides",
      'description' => "Inorganic compounds that contain the isocyano group (-[N+]#[C-]).",
      'parent' => 1568,
    ),
    array(
      'tid' => 1219,
      'name' => "Organic thiophosphoric acids",
      'description' => "Organic compounds containing the thiophosphoric acid group ([H]OP(=S)(O[H])O[H]).",
      'parent' => 1303,
    ),
    array(
      'tid' => 1220,
      'name' => "Benzyl cyanides",
      'description' => "Organic compounds containing an acetonitrile with one hydrogen replaced by a phenyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 1221,
      'name' => "Precorrins",
      'description' => "Intermediates formed by methylation at one or more of the four rings prior to the formation of the macrocyclic corrin ring.",
      'parent' => 353,
    ),
    array(
      'tid' => 1222,
      'name' => "Organic perrhenates",
      'description' => "Organic compounds containing the perrhenate oxoanion, with the formula [ReO4]-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1223,
      'name' => "Alpha-diketones",
      'description' => "Organic compounds containing two ketone groups on two adjacent carbon atoms.",
      'parent' => 118,
    ),
    array(
      'tid' => 1224,
      'name' => "N-carbamoyl-alpha amino acids and derivatives",
      'description' => "Compounds containing an alpha amino acid (or a derivative thereof) which bears an carbamoyl group at its terminal nitrogen atom.",
      'parent' => 60,
    ),
    array(
      'tid' => 1225,
      'name' => "Aminoimidazoles",
      'description' => "Organic compounds containing an amino group linked to an imidazole ring.",
      'parent' => 2310,
    ),
    array(
      'tid' => 1226,
      'name' => "Imidazole carboxylic acids and derivatives",
      'description' => "Organic compounds containing a carboxylic acid group (or a derivative thereof) linked to an imidazole ring.",
      'parent' => 2310,
    ),
    array(
      'tid' => 1227,
      'name' => "Imidazolyl carboxylic acids and derivatives",
      'description' => "Organic compounds containing a carboxylic acid chain (of at least 2 carbon atoms) linked to an imidazole ring.",
      'parent' => 2310,
    ),
    array(
      'tid' => 1228,
      'name' => "Pteroic acids and derivatives",
      'description' => "Compounds that are composed of a pterin with a 4-aminobenzoic acid (or a derivative) at the 6 position on the pteridine ring. Pteridine is a ring system made up of a pyrazine fused to a pyrimidine.",
      'parent' => 110,
    ),
    array(
      'tid' => 1229,
      'name' => "Nitrosoureas",
      'description' => "Compounds containing a nitro group and an urea group N-N linked together, with the general structure R1N(R2)C(=O)N(R3)N=O.",
      'parent' => 517,
    ),
    array(
      'tid' => 1230,
      'name' => "Thiocarboxylic acid amides",
      'description' => "Organic compounds containing an amide of thiocarboxylic acid, with the general structure R1C(=S)N(R2)R3 (R1-R3=H, alkyl, aryl).",
      'parent' => 1112,
    ),
    array(
      'tid' => 1231,
      'name' => "Isoureas",
      'description' => "Organic compounds containing the isourea group, with the general structure R1N(R2)C(=NR3)OR4, or its hydrocarbyl derivatives (R1,R2,R3,R4=H, alkyl, aryl).",
      'parent' => 2484,
    ),
    array(
      'tid' => 1232,
      'name' => "Isothioureas",
      'description' => "Organic compounds containing the isothiourea group, with the general structure R1SC(=NR2)N(R3)R4 (R1,R2,R3,R4=H, alkyl, aryl).",
      'parent' => 4,
    ),
    array(
      'tid' => 1233,
      'name' => "Cardiolipins",
      'description' => "Glycerophospholipids in which the O1 and O3 oxygen atoms of the central glycerol moiety are each linked to one 1,2-diacylglycerol chain. Their general formula is OC(COP(O)(=O)OC[C@@H](CO[R1])O[R2])COP(O)(=O)OC[C@@H](CO[R3])O[R4], where R1-R4 are four fatty acyl chains.",
      'parent' => 3389,
    ),
    array(
      'tid' => 1234,
      'name' => "Isothiocyanates",
      'description' => "Organic compounds containing the isothiocyanate group, an isocyanate analogue with the general formula RN=C=S.",
      'parent' => 4,
    ),
    array(
      'tid' => 1235,
      'name' => "Organosulfenic acids",
      'description' => "Compounds containing a sulfenic acid functional group, with the general structure RSOH (R not H).",
      'parent' => 268,
    ),
    array(
      'tid' => 1236,
      'name' => "Orthocarboxylic acid derivatives",
      'description' => "Organic compounds containing the orhtocarboxylic acid functional group, with the RC(X)(X)X (R=H, alkyl, aryl; X=OH, alkoxy, aryloxy, substituted amino, etc.).",
      'parent' => 264,
    ),
    array(
      'tid' => 1237,
      'name' => "Carboxylic acid orthoesters",
      'description' => "Carboxylic acid derivatives containing a carbon atom form three single bonds, each with one oxygen atom.",
      'parent' => 1236,
    ),
    array(
      'tid' => 1238,
      'name' => "Carboxylic acid esters",
      'description' => "Carboxylic acid derivatives in which the carbon atom from the carbonyl group is attached to an alkyl or an aryl moiety through an oxygen atom (forming an ester group).",
      'parent' => 1093,
    ),
    array(
      'tid' => 1239,
      'name' => "Carboxylic acid azides",
      'description' => "Carboxylic acid derivatives a carbonyl group in which the carbon is directly linked to an azide group (-N=N+=N-).",
      'parent' => 1093,
    ),
    array(
      'tid' => 1240,
      'name' => "Carboxylic acid anhydrides",
      'description' => "Carboxylic acid derivatives two carbonyl groups where the carbon atoms are both linked to the same oxygen atom.",
      'parent' => 1093,
    ),
    array(
      'tid' => 1241,
      'name' => "Caprolactones",
      'description' => "Cyclic esters of caproic acid. Caproic acid is the carboxylic acid derived from hexane with the general formula C5H11COOH.",
      'parent' => 50,
    ),
    array(
      'tid' => 1242,
      'name' => "Phenylthiazoles",
      'description' => "Compounds containing a phenylthiazole moiety, which consists of an thiazole ring attached to a phenyl group.",
      'parent' => 95,
    ),
    array(
      'tid' => 1243,
      'name' => "Beta propiolactones",
      'description' => "Organic compounds containing a four-member lactone (a cyclic ester).",
      'parent' => 50,
    ),
    array(
      'tid' => 1244,
      'name' => "Delta valerolactones",
      'description' => "Cyclic organic compounds containing an oxan-2- one moiety.",
      'parent' => 50,
    ),
    array(
      'tid' => 1245,
      'name' => "Gamma butyrolactones",
      'description' => "Compounds containing a gamma butyrolactone moiety, which consists of an aliphatic five-member ring with four carbon atoms, one oxygen atom, and bears a ketone group on the carbon adjacent to the oxygen atom.",
      'parent' => 50,
    ),
    array(
      'tid' => 1246,
      'name' => "Metalloid plumbites",
      'description' => "Inorganic compounds in which the largest oxoanion is plumbite, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 1247,
      'name' => "Organic fluorophosphonic acids and derivatives",
      'description' => "Organic compounds containing fluorophosphonic acid or a derivative thereof.",
      'parent' => 400,
    ),
    array(
      'tid' => 1248,
      'name' => "Hydroxybenzoic acid derivatives",
      'description' => "Compounds containing a hydroxybenzoic acid (or a derivative), which is a benzene ring bearing a carboxyl and a hydroxyl groups.",
      'parent' => 176,
    ),
    array(
      'tid' => 1249,
      'name' => "Flavins",
      'description' => "Compounds containing a flavin (7,8-dimethyl-benzo[g]pteridine-2,4-dione) moiety, with a structure characterized by an isoalloaxzine tricyclic ring.",
      'parent' => 384,
    ),
    array(
      'tid' => 1250,
      'name' => "Phosphocholines",
      'description' => "Compounds containing a [2-(trimethylazaniumyl)ethoxy]phosphonic acid or derivative.",
      'parent' => 1012,
    ),
    array(
      'tid' => 1251,
      'name' => "Gallic acid and derivatives",
      'description' => "Compounds containing a 3,4,5-trihydroxybenzoic acid moiety.",
      'parent' => 1248,
    ),
    array(
      'tid' => 1252,
      'name' => "Indole-3-acetic acid derivatives",
      'description' => "Compounds containing an acetic acid (or a derivative) linked to the C3 carbon atom of an indole.",
      'parent' => 1290,
    ),
    array(
      'tid' => 1253,
      'name' => "Quinolines and derivatives",
      'description' => "Compounds containing a quinoline moiety, which consists of a benzene ring fused to a pyrimidine ring to form benzo[b]azabenzene.",
      'parent' => 2,
    ),
    array(
      'tid' => 1254,
      'name' => "1Z-alkenylglycero-3-phosphates",
      'description' => "Compounds containing glycerophosphate moiety attached to a 1-alkenyl group.",
      'parent' => 2214,
    ),
    array(
      'tid' => 1255,
      'name' => "Imidazole carboxamides",
      'description' => "Organic compounds containing a carboxamide group linked to an imidazole ring.",
      'parent' => 1226,
    ),
    array(
      'tid' => 1256,
      'name' => "CDP-diacylglycerols",
      'description' => "Glycerolipids containing a diacylglycerol, with a cytidine diphosphate attached to the oxygen O1 or O2 of the glycerol part.",
      'parent' => 1263,
    ),
    array(
      'tid' => 1257,
      'name' => "Phenylacetaldehydes",
      'description' => "Compounds containing a phenylacetaldehyde moiety, which consists of a phenyl group substituted at the second position by an acetalydehyde.",
      'parent' => 2279,
    ),
    array(
      'tid' => 1258,
      'name' => "Neuraminic acids and derivatives",
      'description' => "Compounds containing or derived from a neuraminic acid moiety (5-amino-3,5-dideoxy-D-glycero-D-galacto-non-2-ulosonic acid), which is a 9-carbon monosaccharide.",
      'parent' => 1697,
    ),
    array(
      'tid' => 1259,
      'name' => "Organic bromates",
      'description' => "Organic compounds containing the bromate oxoanion, with the formula BrO3-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1260,
      'name' => "Organic chlorates",
      'description' => "Organic compounds containing the chlorate oxoanion, with the formula  ClO3-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1261,
      'name' => "Organic chlorites",
      'description' => "Organic compounds containing the chlorite oxoanion, with the formula  ClO2-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1262,
      'name' => "Aminopyrimidines and derivatives",
      'description' => "Organic compounds containing an amino group attached to a pyrimidine ring. Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions.",
      'parent' => 75,
    ),
    array(
      'tid' => 1263,
      'name' => "CDP-glycerols",
      'description' => "Glycerolipids with a cytidine diphosphate attached to the oxygen O1 or O2 of the glycerol part. As is the case with diacylglycerols, phosphatidylserines can have many different combinations of fatty acids of varying lengths and saturation attached to the C-1 and C-2 atoms.",
      'parent' => 256,
    ),
    array(
      'tid' => 1264,
      'name' => "CDP-monoacylglycerols",
      'description' => "Glycerolipids containing a monoacylglycerol, with a cytidine diphosphate attached to the oxygen O1 or O2 of the glycerol part.",
      'parent' => 1263,
    ),
    array(
      'tid' => 1265,
      'name' => "N-sulfinylhydrazines",
      'description' => "Organonitrogen compounds with the general formula RN(R')N=S=O (R,R' = H or organyl).",
      'parent' => 3130,
    ),
    array(
      'tid' => 1266,
      'name' => "Phosphoethanolamines",
      'description' => "Compounds containing a phosphate linked to the second carbon of an ethanolamine.",
      'parent' => 408,
    ),
    array(
      'tid' => 1267,
      'name' => "Aldimines",
      'description' => "Organic compounds containing the aldimine functional group.",
      'parent' => 117,
    ),
    array(
      'tid' => 1268,
      'name' => "Nicotinamide nucleotides",
      'description' => "Pyridine nucleotides, in which the pyridine base is nicotinamide or a derivative thereof.",
      'parent' => 1297,
    ),
    array(
      'tid' => 1269,
      'name' => "Sulfinic acids",
      'description' => "Compounds containing a sulfinic acid functional group, with the general structure RS(=O)OH (R = organyl, not H).",
      'parent' => 269,
    ),
    array(
      'tid' => 1270,
      'name' => "Miscellaneous mixed metal/non-metals",
      'description' => "Inorganic compounds containing non-metal as well as metal atoms but not belonging to afore mentioned classes.",
      'parent' => 424,
    ),
    array(
      'tid' => 1271,
      'name' => "Thiodiacetic acid derivatives",
      'description' => "Compounds containing a thiodiacetic acid group (or esters/salts thereof) which is made up of two 2-sulfanylacetic (OC(=O)CS) acid moieties sharing their sulfur atom.",
      'parent' => 346,
    ),
    array(
      'tid' => 1272,
      'name' => "Cresols",
      'description' => "Aromatic compounds containing a methoxyphenol moiety.",
      'parent' => 134,
    ),
    array(
      'tid' => 1273,
      'name' => "Meta cresols",
      'description' => "Aromatic compounds containing a meta-cresol moiety, which consists of a benzene ring bearing a methyl group and a hydroxyl group at ring positions 1 and 3, respectively.",
      'parent' => 1272,
    ),
    array(
      'tid' => 1274,
      'name' => "Ortho cresols",
      'description' => "Organic compounds containing an ortho-cresol moiety, which consists of a benzene bearing one hydroxyl group at ring positions 1 and 2, respectively.",
      'parent' => 1272,
    ),
    array(
      'tid' => 1275,
      'name' => "Para cresols",
      'description' => "Compounds containing a para cresol moiety, which consists of a benzene ring bearing one hydroxyl group at ring positions 1 and 4.",
      'parent' => 1272,
    ),
    array(
      'tid' => 1276,
      'name' => "Phenylpyruvic acid derivatives",
      'description' => "Compounds containing a phenylpyruvic acid moiety, which consists of a phenyl group substituted at the second position by an pyruvic acid.",
      'parent' => 2279,
    ),
    array(
      'tid' => 1277,
      'name' => "Carotenoids",
      'description' => "Organic compounds formed by eight consecutive isoprene fragments. Carotenoids are a subgroup of tetraterpenes, and are subdivided in two categories: Carotenes and Xanthophylls.",
      'parent' => 1554,
    ),
    array(
      'tid' => 1278,
      'name' => "Organic chromates",
      'description' => "Organic compounds containing the chromate oxoanion, with the formula   [CrO4]2-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1279,
      'name' => "Sulfur mustard compounds",
      'description' => "Compounds containing having two beta-haloalkyl groups bound to a sulfur atom.",
      'parent' => 1202,
    ),
    array(
      'tid' => 1280,
      'name' => "Alpha ketoaldehydes",
      'description' => "Organic compounds containing an aldehyde substituted with a keto group on the adjacent carbon.",
      'parent' => 124,
    ),
    array(
      'tid' => 1281,
      'name' => "Decamethonium compounds",
      'description' => "Quaternary ammonium compounds containing a trimethyl-(10-trimethylammoniodecyl)ammonium moiety.",
      'parent' => 503,
    ),
    array(
      'tid' => 1282,
      'name' => "Hexamethonium compounds",
      'description' => "Organic compounds containing a N,N,N,N',N',N'-hexamethylhexane-1,6-diaminium moiety.",
      'parent' => 503,
    ),
    array(
      'tid' => 1283,
      'name' => "Terpene lactones",
      'description' => "Prenol lipids containing a lactone ring.",
      'parent' => 259,
    ),
    array(
      'tid' => 1284,
      'name' => "Strigolactones",
      'description' => "Terpene lactones structurally characterized by the presence of an indeno[1,2-b]furan and a 2,5-dihydrofuran-2-one linked together to form a 3-methyl-5-{8-methyl-2-oxo-indeno[1,2-b]furan-3-ylidene]methoxy}-2,5-dihydrofuran-2-one skeleton.",
      'parent' => 1283,
    ),
    array(
      'tid' => 1285,
      'name' => "Thiamines",
      'description' => "Compounds containing a thiamine moiety, which is structurally characterized by a 3-[(4-Amino-2-methyl-pyrimidin-5-yl)methyl]-4-methyl-thiazol-5-yl backbone.",
      'parent' => 75,
    ),
    array(
      'tid' => 1286,
      'name' => "Benzenediols",
      'description' => "Organic compounds containing two hydroxyl groups attached to a benzene ring.",
      'parent' => 134,
    ),
    array(
      'tid' => 1287,
      'name' => "Thiamine phosphates",
      'description' => "Thiamine derivatives in which the hydroxyl group of the ethanol moiety is substituted by a phosphate group.",
      'parent' => 1285,
    ),
    array(
      'tid' => 1288,
      'name' => "Dialkylglycerophosphates",
      'description' => "Glycerophosphates in which the glycerol moiety is bonded to two aliphatic (saturated or unsaturated) chains through ether linkages.",
      'parent' => 2214,
    ),
    array(
      'tid' => 1289,
      'name' => "Dialkylglycerol-3-phosphocholines",
      'description' => "Glycerophosphocholines in which the glycerol moiety is bonded to two aliphatic (saturated or unsaturated) chains through ether linkages.",
      'parent' => 2213,
    ),
    array(
      'tid' => 1290,
      'name' => "Indolyl carboxylic acids and derivatives",
      'description' => "Compounds containing a carboxylic acid chain (of at least 2 carbon atoms) linked to an indole ring.",
      'parent' => 211,
    ),
    array(
      'tid' => 1291,
      'name' => "Pyranoquinolines",
      'description' => "Polycyclic compounds containing a pyran ring fused to a quinoline moiety.  Quinoline or benzo[b]pyridine is a bicyclic compound that consists of benzene fused to a pyridine.",
      'parent' => 56,
    ),
    array(
      'tid' => 1292,
      'name' => "Cyclic alcohols and derivatives",
      'description' => "Organic compounds containing an aliphatic ring substituted with at least one hydroxyl group.",
      'parent' => 129,
    ),
    array(
      'tid' => 1293,
      'name' => "Purine nucleotide sugars",
      'description' => "Purine nucleotides bound to a saccharide derivative through the terminal phosphate group.",
      'parent' => 1506,
    ),
    array(
      'tid' => 1294,
      'name' => "Polyprenylbenzoquinones",
      'description' => "Compounds containing a polyisoprene chain attached to a quinone at the second ring position.",
      'parent' => 2802,
    ),
    array(
      'tid' => 1295,
      'name' => "Hydroxysteroids",
      'description' => "Compounds containing an steroid backbone, with at least one hydrogen substituted by a hydroxyl group.",
      'parent' => 258,
    ),
    array(
      'tid' => 1296,
      'name' => "Pyrimidine nucleotide sugars",
      'description' => "Pyrimidine nucleotides bound to a saccharide derivative through the terminal phosphate group.",
      'parent' => 1509,
    ),
    array(
      'tid' => 1297,
      'name' => "Pyridine nucleotides",
      'description' => "Compounds containing a (deoxy)ribose phosphate with the ribose unit N-linked to a pyridine ring.",
      'parent' => 289,
    ),
    array(
      'tid' => 1298,
      'name' => "1-acyl,2-alkylglycerophosphoglycerols",
      'description' => "Glycerophosphoglycerols that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O1-position,  and one acyl chain attached through an ether linkage at the O2-position.",
      'parent' => 2216,
    ),
    array(
      'tid' => 1299,
      'name' => "1,2-diacylglycerol-3-phosphates",
      'description' => "Glycerol-3-phosphates in which the glycerol moiety is bonded to two aliphatic chains through ester linkages.",
      'parent' => 1504,
    ),
    array(
      'tid' => 1300,
      'name' => "Nicotinic acid nucleotides",
      'description' => "Pyridine nucleotides, in which the pyridine base is nicotinic acid or a derivative thereof.",
      'parent' => 1297,
    ),
    array(
      'tid' => 1301,
      'name' => "Alkynes",
      'description' => "acyclic branched or unbranched hydrocarbons having a carbon-carbon triple bond and the general formula CnH2n-2.",
      'parent' => 2847,
    ),
    array(
      'tid' => 1302,
      'name' => "Organic phosphonic acids",
      'description' => "Organic compounds containing phosphonic acid.",
      'parent' => 419,
    ),
    array(
      'tid' => 1303,
      'name' => "Organic thiophosphoric acids and derivatives",
      'description' => "Organic compounds containing the thiophosphoric acid functional group or a derivative thereof, with the general structure RP(R')(R'')=S, where R,R',R'' = O,N, halogen residue.",
      'parent' => 264,
    ),
    array(
      'tid' => 1304,
      'name' => "Brevetoxins and derivatives",
      'description' => "A group of cyclic polyether compounds produced naturally by a species of dinoflagellate known as Karenia brevis. They contain a Pentaoxapentacycloheptacos- 23-en-7-one derivative (type a brevetoxin) or a pentaoxapentacyclotetracosa- 8,23-dien-7-one derivative (type b brevetoxin).",
      'parent' => 261,
    ),
    array(
      'tid' => 1306,
      'name' => "Organic isocyanides",
      'description' => "Organic compounds containing the isomer HN+#C- of hydrocyanic acid, HC#N, or its hydrocarbyl derivatives RNC (RN+#C-).",
      'parent' => 278,
    ),
    array(
      'tid' => 1307,
      'name' => "Organic chromites",
      'description' => "Organic compounds containing the chromate oxoanion, with the formula Cr(O2)−.",
      'parent' => 463,
    ),
    array(
      'tid' => 1308,
      'name' => "Organic hydroperoxides",
      'description' => "Organic compounds comprising the hydroperoxide functional group, with the general formula [O-O]2-.",
      'parent' => 4603,
    ),
    array(
      'tid' => 1309,
      'name' => "Organophosphine oxides",
      'description' => "Organic compounds containing the phosphine oxide group, with the general formula R3P=O or R3P+O-.",
      'parent' => 401,
    ),
    array(
      'tid' => 1310,
      'name' => "Benzenetriols and derivatives",
      'description' => "Organic compounds containing three hydroxyl groups attached to a benzene ring.",
      'parent' => 134,
    ),
    array(
      'tid' => 1311,
      'name' => "Isoprenoid phosphates",
      'description' => "Prenol lipids containing a phosphate group linked to an isoprene (2-methylbuta-1,3-diene) unit.",
      'parent' => 259,
    ),
    array(
      'tid' => 1312,
      'name' => "1,2-dioxanes",
      'description' => "Organic compounds containing 1,2-dioxane, an aliphatic six-member ring with two oxygen atoms in ring positions 1 and 2.",
      'parent' => 368,
    ),
    array(
      'tid' => 1313,
      'name' => "1,4-dioxanes",
      'description' => "Organic compounds containing 1,4-dioxane, an aliphatic six-member ring with two oxygen atoms in ring positions 1 and 4.",
      'parent' => 368,
    ),
    array(
      'tid' => 1314,
      'name' => "1,3-dioxanes",
      'description' => "Organic compounds containing 1,3-dioxane, an aliphatic six-member ring with two oxygen atoms in ring positions 1 and 3.",
      'parent' => 368,
    ),
    array(
      'tid' => 1315,
      'name' => "1,2-dioxolanes",
      'description' => "Organic compounds containing 1,2-dioxolane, an aliphatic five-member ring with two oxygen atoms in ring positions 1 and 2.",
      'parent' => 105,
    ),
    array(
      'tid' => 1316,
      'name' => "1,3-dioxolanes",
      'description' => "Organic compounds containing 1,3-dioxolane, an aliphatic five-member ring with two oxygen atoms in ring positions 1 and 3.",
      'parent' => 105,
    ),
    array(
      'tid' => 1317,
      'name' => "Transition metal ferrates",
      'description' => "Inorganic compounds in which the largest oxoanion is ferrate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 1318,
      'name' => "Hippuric acids",
      'description' => "Compounds containing hippuric acid, which consists of a of a benzoyl group linked to the N-terminal of a glycine.",
      'parent' => 179,
    ),
    array(
      'tid' => 1319,
      'name' => "Pyrimidinecarboxylic acids and derivatives",
      'description' => "Compounds containing a pyrimidine ring which bears a carboxylic acid group (or a derivative thereof).",
      'parent' => 75,
    ),
    array(
      'tid' => 1320,
      'name' => "Lysophosphatidic acids",
      'description' => "Glycerophosphates where the glycerol is esterified with one fatty acid linked to the phosphate group at position O-3.",
      'parent' => 1683,
    ),
    array(
      'tid' => 1321,
      'name' => "Pyrimidinecarboxamides",
      'description' => "Compounds containing a pyrimidine ring which bears a carboxamide.",
      'parent' => 1319,
    ),
    array(
      'tid' => 1322,
      'name' => "Pyridinecarboxylic acids and derivatives",
      'description' => "Compounds containing a pyridine ring bearing a carboxylic acid group or a derivative thereof.",
      'parent' => 89,
    ),
    array(
      'tid' => 1323,
      'name' => "Pyrrolizidinones",
      'description' => "Compounds containing a pyrrolizidine moiety which bears a ketone. Pyrrolizidine is a bicyclic ring system made up of two fused pyrrolidine ring sharing a nitrogen atom.",
      'parent' => 220,
    ),
    array(
      'tid' => 1324,
      'name' => "Phosphatidylinositol monophosphates",
      'description' => "Glycerophosphoinositol phosphates where the glycerol is esterified with two fatty acids.",
      'parent' => 1139,
    ),
    array(
      'tid' => 1325,
      'name' => "Quinolizidinones",
      'description' => "Compounds containing a quinolizidine moiety which bears a ketone group.",
      'parent' => 221,
    ),
    array(
      'tid' => 1326,
      'name' => "Pyridinecarboxamides",
      'description' => "Compounds containing a pyridine ring bearing a carboxamide.",
      'parent' => 1322,
    ),
    array(
      'tid' => 1327,
      'name' => "Triazolidinones",
      'description' => "Compounds containing a triazolidine ring which bears a ketone group.",
      'parent' => 235,
    ),
    array(
      'tid' => 1328,
      'name' => "3-oxo-acyl CoAs",
      'description' => "Organic compounds containing a 3-oxo acylated coenzyme A derivative.",
      'parent' => 1090,
    ),
    array(
      'tid' => 1329,
      'name' => "Flavin nucleotides",
      'description' => "Nucleotides containing a flavin moiety. Flavin is a compound that contains the tricyclic isoalloxazine ring system, which bears 2 oxo groups at the 2- and 4-positions.",
      'parent' => 289,
    ),
    array(
      'tid' => 1330,
      'name' => "Lysophosphatidylinositol monophosphates",
      'description' => "Glycerophosphoinositol monophosphates where the glycerol is esterified with one fatty acid.",
      'parent' => 2220,
    ),
    array(
      'tid' => 1331,
      'name' => "Benzoins",
      'description' => "Organic compounds containing a 1,2-hydroxy ketone attached to two phenyl groups.",
      'parent' => 253,
    ),
    array(
      'tid' => 1332,
      'name' => "Indolizidinones",
      'description' => "Polycyclic compounds containing an indolizine moiety bearing a ketone.",
      'parent' => 251,
    ),
    array(
      'tid' => 1333,
      'name' => "Inorganic sulfuryl halides",
      'description' => "Inorganic compounds containing the sulfuryl chloride functional group, with the general structure XS(R)(=O)=O (X=Br,Cl,F,I; R=hetero atom).",
      'parent' => 1568,
    ),
    array(
      'tid' => 1334,
      'name' => "Fatty alcohols",
      'description' => "Aliphatic alcohols consisting of a chain of a least six carbon atoms.",
      'parent' => 3909,
    ),
    array(
      'tid' => 1335,
      'name' => "1,2-diazepines",
      'description' => "Organic compounds containing 1,2-diazepine, a seven-member heterocyclic ring with two nitrogen atoms in positions 1 and 2.",
      'parent' => 71,
    ),
    array(
      'tid' => 1336,
      'name' => "1,4-diazepines",
      'description' => "Organic compounds containing 1,4-diazepine, a seven-member heterocyclic ring with two nitrogen atoms in positions 1 and 4.",
      'parent' => 71,
    ),
    array(
      'tid' => 1337,
      'name' => "1,3-diazepines",
      'description' => "Organic compounds containing 1,3-diazepine, a seven-member heterocyclic ring with two nitrogen atoms in positions 1 and 3.",
      'parent' => 71,
    ),
    array(
      'tid' => 1338,
      'name' => "1,2-oxazepines",
      'description' => "Organic compounds containing an aromatic seven-membered ring containing a nitrogen and an oxygen atom, a positions 1 and 2, respectively.",
      'parent' => 66,
    ),
    array(
      'tid' => 1339,
      'name' => "1,4-oxazepines",
      'description' => "Organic compounds containing an aromatic seven-membered wring containing a nitrogen and an oxygen atom, a positions 1 and 4, respectively.",
      'parent' => 66,
    ),
    array(
      'tid' => 1340,
      'name' => "1,3-oxazepines",
      'description' => "Organic compounds containing an aromatic seven-membered wring containing a nitrogen and an oxygen atom, a positions 1 and 3, respectively.",
      'parent' => 66,
    ),
    array(
      'tid' => 1341,
      'name' => "1,3-oxazines",
      'description' => "Organic compounds containing 1,3-oxazine, a six-member ring with a nitrogen and an oxygen atoms in ring positions 1 and 3 respectively, as well as two double bonds.",
      'parent' => 82,
    ),
    array(
      'tid' => 1342,
      'name' => "1,4-oxazines",
      'description' => "Organic compounds containing 1,4-oxazine, a six-member ring with a nitrogen and an oxygen atoms in ring positions 1 and 4 respectively, as well as two double bonds.",
      'parent' => 82,
    ),
    array(
      'tid' => 1343,
      'name' => "1,2-oxazines",
      'description' => "Organic compounds containing 1,2-oxazine, a six-member ring with a nitrogen and an oxygen atoms in ring positions 1 and 2 respectively, as well as two double bonds.",
      'parent' => 82,
    ),
    array(
      'tid' => 1344,
      'name' => "Phosphatidylinositols",
      'description' => "Glycerophosphoinositols where the glycerol is esterified with two fatty acids.",
      'parent' => 2219,
    ),
    array(
      'tid' => 1345,
      'name' => "Benzaldehydes",
      'description' => "Organic compounds containing a benzene ring with a formyl substituent.",
      'parent' => 3213,
    ),
    array(
      'tid' => 1346,
      'name' => "Diazines",
      'description' => "Organic compounds containing a five-member heterocyclic compound with five nitrogen atoms, and two nitrogen atoms at positions 1 and 2 (Pyridazines), 1 and 3 (Pyrimidines), or 1 and 4 (Pyrazines).",
      'parent' => 2,
    ),
    array(
      'tid' => 1347,
      'name' => "1,3-thiazines",
      'description' => "Organic compounds containing 1,3-thiazine, a six-member ring with a nitrogen and a sulfur atoms in ring positions 1 and 3 respectively, as well as two double bonds.",
      'parent' => 94,
    ),
    array(
      'tid' => 1348,
      'name' => "1,2-thiazines",
      'description' => "Organic compounds containing 1,2-thiazine, a six-member ring with a nitrogen and a sulfur atoms in ring positions 1 and 2 respectively, as well as two double bonds.",
      'parent' => 94,
    ),
    array(
      'tid' => 1349,
      'name' => "1,4-thiazines",
      'description' => "Organic compounds containing 1,4-thiazine, a six-member ring with a nitrogen and a sulfur atoms in ring positions 1 and 4 respectively, as well as two double bonds.",
      'parent' => 94,
    ),
    array(
      'tid' => 1350,
      'name' => "Benzoic acid esters",
      'description' => "Ester derivatives of benzoic acid.",
      'parent' => 176,
    ),
    array(
      'tid' => 1351,
      'name' => "Acyclic triterpenoids",
      'description' => "Triterpenoids that do not contain a cycle.",
      'parent' => 1553,
    ),
    array(
      'tid' => 1352,
      'name' => "Meta thiazepines",
      'description' => "Aromatic compounds containing meta thiazepine moiety, which is an unsaturated seven-member heterocyclic compound, with five carbon atoms, and two sulfur atoms at position 1 and 3.",
      'parent' => 68,
    ),
    array(
      'tid' => 1353,
      'name' => "Ortho thiazepines",
      'description' => "Compounds containing a thiazepine ring, in which the sulfur and nitrogen atoms are at positions 1 and 2 respectively.",
      'parent' => 68,
    ),
    array(
      'tid' => 1354,
      'name' => "Para thiazepines",
      'description' => "Compounds containing a para thiazepine moiety, which consists of an unsaturated seven-member ring with one nitrogen atom and one sulfur at positions 1 and 4, respectively, as well as two CC double bonds.",
      'parent' => 68,
    ),
    array(
      'tid' => 1355,
      'name' => "Lysophosphatidylinositols",
      'description' => "Glycerophosphoinositols  (molecules containing an inositol moiety attached to the phosphate group linked to a glycerol) where the glycerol is esterified with one fatty acid.",
      'parent' => 2219,
    ),
    array(
      'tid' => 1356,
      'name' => "Trioses",
      'description' => "Monosaccharides with a single carbohydrate unit, which contains three carbon atoms.",
      'parent' => 1540,
    ),
    array(
      'tid' => 1357,
      'name' => "Acyclic diterpenoids",
      'description' => "Diterpenoids (compounds made of four consecutive isoprene units) that do not contain a cycle.",
      'parent' => 1551,
    ),
    array(
      'tid' => 1358,
      'name' => "Phosphatidylglycerols",
      'description' => "Glycerophosphoglycerols in which two fatty acids are bonded to the 1-glycerol moiety through ester linkages. As is the case with diacylglycerols, phosphatidylglycerols can have many different combinations of fatty acids of varying lengths and saturation attached to the C-1 and C-2 positions.",
      'parent' => 2216,
    ),
    array(
      'tid' => 1359,
      'name' => "Alpha hydroxy acids and derivatives",
      'description' => "Organic compounds containing a carboxylic acid substituted with a hydroxyl group on the adjacent carbon.",
      'parent' => 472,
    ),
    array(
      'tid' => 1360,
      'name' => "Intermetallic alkali metal compounds",
      'description' => "Inorganic compounds containing only metal atoms of at least two different types, where the heaviest atom is an alkali metal.",
      'parent' => 422,
    ),
    array(
      'tid' => 1361,
      'name' => "Anthocyanins",
      'description' => "Organic compounds containing a flavylium ion or 2-phenylchromenylium based skeleton bound to a sugar.",
      'parent' => 1583,
    ),
    array(
      'tid' => 1362,
      'name' => "Flavanonols",
      'description' => "Compounds containing a flavan-3-one moiety, with a structure characterized by a 2-phenyl-3,4-dihydro-2H-1-benzopyran bearing a hydroxyl group and a ketone at the carbon C2 and C3, respectively.",
      'parent' => 1632,
    ),
    array(
      'tid' => 1363,
      'name' => "Enones",
      'description' => "Compounds containing the enone functional group, with the structure RC(=O)CR'.",
      'parent' => 3672,
    ),
    array(
      'tid' => 1364,
      'name' => "Organic hydroxides",
      'description' => "Organic compounds comprising the hydroxide functional group, with the general formula OH-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1365,
      'name' => "Alkaline earth metal chromites",
      'description' => "Inorganic compounds in which the largest oxoanion is chromite, and in which the heaviest atom not in an oxoanion is a alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 1366,
      'name' => "Sugar amino acids and derivatives",
      'description' => "Organic compounds containing a saccharide unit that bears both an amine group and a carboxylic acid group.",
      'parent' => 215,
    ),
    array(
      'tid' => 1367,
      'name' => "Phosphatidylserines",
      'description' => "Glycerophosphoserines in which two fatty acids are bonded to the glycerol moiety through ester linkages. As is the case with diacylglycerols, phosphatidylserines can have many different combinations of fatty acids of varying lengths and saturation attached to the C-1 and C-2 positions.",
      'parent' => 2218,
    ),
    array(
      'tid' => 1368,
      'name' => "Thiocarbamic acid derivatives",
      'description' => "Organic compounds containing a functional group with the general structure OC(=S)NR2 or SC(=O)NR2.",
      'parent' => 1198,
    ),
    array(
      'tid' => 1369,
      'name' => "Boronic acid esters",
      'description' => "Compounds comprising the boronic acid ester functional group RN(X)OR' (R,R'=alkyl, aryl; X= any O, N, Hal residue).",
      'parent' => 498,
    ),
    array(
      'tid' => 1370,
      'name' => "Organometalloid compounds",
      'description' => "Organic compounds containing a metalloid atom.",
      'parent' => 462,
    ),
    array(
      'tid' => 1371,
      'name' => "Organotransition metal compounds",
      'description' => "Organic compounds containing a transition metal atom.",
      'parent' => 462,
    ),
    array(
      'tid' => 1372,
      'name' => "Organo-alkali-metal compounds",
      'description' => "Organic compounds containing an alkali metal atom.",
      'parent' => 462,
    ),
    array(
      'tid' => 1373,
      'name' => "Ynones",
      'description' => "Organic compounds containing the ynone functional group, an alpha,beta unsaturated ketone group with the general structure  RC#C-C(=O)R' (R'  not H).",
      'parent' => 3672,
    ),
    array(
      'tid' => 1374,
      'name' => "Pyridoindolones",
      'description' => "Pyridoindoles with a structure that contains an indole moiety bearing a ketone. Indole is a bicyclic  compound consisting of a six-membered benzene ring fused to a five-membered nitrogen-containing pyrrole ring.",
      'parent' => 1213,
    ),
    array(
      'tid' => 1375,
      'name' => "Cyanohydrins",
      'description' => "Organic compounds containing the cyanohydrin functional group, -C(OH)CN.",
      'parent' => 362,
    ),
    array(
      'tid' => 1376,
      'name' => "Beta ketoaldehydes",
      'description' => "Organic compounds containing an aldehyde substituted with a keto group on the second carbon atom.",
      'parent' => 124,
    ),
    array(
      'tid' => 1377,
      'name' => "Lysophosphatidylserines",
      'description' => "Glycerophosphoserines  (molecules containing a serine moiety attached to the phosphate group linked to a glycerol) with one fatty acid bonded to the glycerol moiety through an ester linkage.",
      'parent' => 2218,
    ),
    array(
      'tid' => 1378,
      'name' => "Chlorinated dibenzofurans",
      'description' => "Organic compounds containing a chlorine atom attached to a dibenzofuran moiety.",
      'parent' => 15,
    ),
    array(
      'tid' => 1379,
      'name' => "Benzo-p-dioxins",
      'description' => "Organic compounds containing a benzene ring fused to a 1,4-dioxin ring.",
      'parent' => 2100,
    ),
    array(
      'tid' => 1380,
      'name' => "N-acyl-alpha-hexosamine-1-phosphates",
      'description' => "N-acyl hexosamines in which the hexose is substituted by a phosphate group at position 1.",
      'parent' => 2276,
    ),
    array(
      'tid' => 1381,
      'name' => "Dibenzo-p-dioxins",
      'description' => "Compounds containing a dibenzo-p-dioxin moiety, which consists of two benzene connected by a para-dioxin ring.",
      'parent' => 1379,
    ),
    array(
      'tid' => 1382,
      'name' => "Benzo-o-dioxins",
      'description' => "Organic compounds containing a benzene ring fused to a 1,2-dioxin ring.",
      'parent' => 2100,
    ),
    array(
      'tid' => 1383,
      'name' => "Benzo-m-dioxins",
      'description' => "Organic compounds containing a benzene ring fused to a 1,3-dioxin ring.",
      'parent' => 2100,
    ),
    array(
      'tid' => 1384,
      'name' => "Dioxins",
      'description' => "Compounds containing a dioxin ring, which is a six-membered unsaturated ring of two oxygen atoms and four carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 1385,
      'name' => "Ortho dioxins",
      'description' => "Compounds containing a dioxin ring, in which the two oxygen atoms are at positions 1 and 2 respectively.",
      'parent' => 1384,
    ),
    array(
      'tid' => 1386,
      'name' => "Para dioxins",
      'description' => "Compounds containing a para dioxin moiety, which consists of an unsaturated six-member ring with two oxygen atoms at positions 1 and 4, as well as two CC double bonds.",
      'parent' => 1384,
    ),
    array(
      'tid' => 1387,
      'name' => "Sultims",
      'description' => "Tautomeric forms of sultams, having a sulfur-nitrogen double bond as part of a ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 1388,
      'name' => "Glucuronosphingolipids",
      'description' => "Sphingolipids in which the sphingosine base is linked to a glucuronic acid moiety.",
      'parent' => 3258,
    ),
    array(
      'tid' => 1389,
      'name' => "Neoflavones",
      'description' => "Neoflavonoids with a structure based on the 4-phenylcoumarin skeleton.",
      'parent' => 1614,
    ),
    array(
      'tid' => 1390,
      'name' => "Colchicines",
      'description' => "Compounds containing the benzo[a]heptalene based colchicin moiety or a derivative thereof. Colchicine is a tricyclic compound consisting of a benzene ring angularly fused to a tetrahydroheptalene  that carries a N-acetamide group.",
      'parent' => 279,
    ),
    array(
      'tid' => 1391,
      'name' => "Hydroxycinnamic acids and derivatives",
      'description' => "Compounds containing an cinnamic acid (or a derivative thereof) where the benzene ring is hydroxylated.",
      'parent' => 476,
    ),
    array(
      'tid' => 1392,
      'name' => "Lignans, neolignans and related compounds",
      'description' => "Plant products of low molecular weight formed primarily from oxidative coupling of two p-propylphenol moieties. They can also be described as micromolecules with two phenylpropanoid units coupled together. They can be attached in various manners, like C5-C5', C8-C8'. Most known natural lignans are oxidized at C9 and C9´ and, based upon the way in which oxygen is incorporated into the skeleton and on the cyclization patterns, a wide range of lignans of very different structural types can be formed.",
      'parent' => 0,
    ),
    array(
      'tid' => 1393,
      'name' => "Phosphatidylethanolamines",
      'description' => "Glycerophosphoetahnolamines in which two fatty acids are bonded to the glycerol moiety through ester linkages.",
      'parent' => 2215,
    ),
    array(
      'tid' => 1394,
      'name' => "Ceramide phosphoethanolamines",
      'description' => "Ceramides with phosphoethanolamine as substituent. Phosphoethanolamine is an organophosphorus compound with the general structure NCCOP(O)(O)=O.",
      'parent' => 1427,
    ),
    array(
      'tid' => 1395,
      'name' => "1-alkyl,2-acyl-glycerol-3-phosphoserines",
      'description' => "Glycerophosphoserines that contain exactly two fatty acyl chains attached to the glycerol moiety, one through an ester and the other through an ether linkage.",
      'parent' => 2218,
    ),
    array(
      'tid' => 1396,
      'name' => "Benzoxazines",
      'description' => "Organic compounds containing a benzene fused to an oxazine ring (a six-membered aliphatic ring with four carbon atoms, one oxygen atom, and one nitrogen atom).",
      'parent' => 2,
    ),
    array(
      'tid' => 1397,
      'name' => "1-(1Z-alkenyl),2-acyl-glycerophosphates",
      'description' => "Glycerophosphates that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O2-position,  and one 1Z-alkenyl chain attached through an ether linkage at the O1-position.",
      'parent' => 2214,
    ),
    array(
      'tid' => 1398,
      'name' => "Non-metal bisulfites",
      'description' => "Inorganic non-metallic compounds containing a bisulfite as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 1399,
      'name' => "Ceramide phosphoinositols",
      'description' => "Ceramides with phosphoinositol as substituent.",
      'parent' => 1427,
    ),
    array(
      'tid' => 1400,
      'name' => "Organic nitrosamines",
      'description' => "Organic compounds containing the nitrosamine functional group, with the structure R2NN=O.",
      'parent' => 4777,
    ),
    array(
      'tid' => 1401,
      'name' => "Menthane monoterpenoids",
      'description' => "Monoterpenoids with a structure based on the o-, m-, or p-menthane backbone. P-menthane consists of the cyclohexane ring with a methyl group and a (2-methyl)-propyl group at the 1 and 4 ring position, respectively. The o- and m- menthanes are much rarer, and presumably arise by alkyl migration of p-menthanes.",
      'parent' => 1549,
    ),
    array(
      'tid' => 1402,
      'name' => "Imidazolinones",
      'description' => "Organic compounds containing an imidazolinone moiety, which is an imidazoline ring bearing a ketone.",
      'parent' => 79,
    ),
    array(
      'tid' => 1403,
      'name' => "Ergosterols and derivatives",
      'description' => "Steroids containing ergosta-5,7,22-trien-3beta-ol or a  derivative thereof, which is based on the 3beta-hydroxylated ergostane skeleton.",
      'parent' => 3567,
    ),
    array(
      'tid' => 1404,
      'name' => "1-alkyl,2-acylglycerophosphates",
      'description' => "Glycerophosphates  in which the O-1 atom of the glycerol is bonded to a fatty acid (saturated or unsaturated) through an ether linkage, and the O-2 atom is bonded to another fatty acid through an ester linkage.",
      'parent' => 2214,
    ),
    array(
      'tid' => 1405,
      'name' => "Lysophosphatidylethanolamines",
      'description' => "Glycerophosphoetahnolamines  (molecules containing an ethanolamine moiety attached to the phosphate group linked to a glycerol) with one  fatty acid chain bonded to the glycerol moiety through an ester linkage.",
      'parent' => 2215,
    ),
    array(
      'tid' => 1406,
      'name' => "Monoalkylglycerophosphates",
      'description' => "Compounds containing glycerophosphate moiety attached to an fatty acyl chain through an ether bond.",
      'parent' => 2214,
    ),
    array(
      'tid' => 1407,
      'name' => "1-(1Z-alkenyl),2-acylglycerophosphoserines",
      'description' => "Glycerophosphoserines that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O2-position,  and one 1Z-alkenyl chain attached through an ether linkage at the O1-position.",
      'parent' => 2218,
    ),
    array(
      'tid' => 1408,
      'name' => "Phosphatidylcholines",
      'description' => "Glycerophosphocholines in which the two free -OH are attached to one fatty acid each through an ester linkage.",
      'parent' => 2213,
    ),
    array(
      'tid' => 1409,
      'name' => "1-acyl,2-alkylglycerophosphoethanolamines",
      'description' => "Glycerophosphoethanolamines that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O1-position,  and one alkyl chain attached through an ether linkage at the O2-position.",
      'parent' => 2215,
    ),
    array(
      'tid' => 1410,
      'name' => "Xanthophylls",
      'description' => "Carotenoids containing an oxygenated carotene backbone. Carotenes are characterized by the presence of two end-groups (mostly cyclohexene rings, but also cyclopentene rings or acyclic groups) linked by a long branched alkyl chain. Carotenes belonging form a subgroup of the carotenoids family. Xanthophylls arise by oxygenation of the carotene backbone.",
      'parent' => 1277,
    ),
    array(
      'tid' => 1411,
      'name' => "Carotenes",
      'description' => "A type of unsaturated hydrocarbons containing eight consecutive isoprene units. They are characterized by the presence of two end-groups (mostly cyclohexene rings, but also cyclopentene rings or acyclic groups) linked by a long branched alkyl chain. Carotenes belonging form a subgroup of the carotenoids family.",
      'parent' => 1277,
    ),
    array(
      'tid' => 1412,
      'name' => "1-phosphoribosyl-imidazoles",
      'description' => "Organic compounds containing the imidazole ring linked to a ribose phosphate through a 1-2 bond.",
      'parent' => 1997,
    ),
    array(
      'tid' => 1413,
      'name' => "Lysophosphatidylcholines",
      'description' => "Glycerophosphocholines (molecules containing a choline moiety attached to the phosphate group linked to a glycerol) in which the glycerol is esterified with  one fatty acid each through an ester linkage.",
      'parent' => 2213,
    ),
    array(
      'tid' => 1414,
      'name' => "Monoalkylglycerophosphocholines",
      'description' => "Compounds containing glycerophosphocholine moiety attached to an fatty acyl chain through an ether bond.",
      'parent' => 2213,
    ),
    array(
      'tid' => 1415,
      'name' => "Medium-chain keto acids and derivatives",
      'description' => "Keto acids with a 6 to 12  carbon atoms long side chain.",
      'parent' => 389,
    ),
    array(
      'tid' => 1416,
      'name' => "Short-chain keto acids and derivatives",
      'description' => "Keto acids with an alkyl chain the contains less than 6 carbon atoms.",
      'parent' => 389,
    ),
    array(
      'tid' => 1417,
      'name' => "1-phosphoribosyl-imidazolecarboxamides",
      'description' => "Organic compounds containing the imidazolecarboxamide linked to a ribose phosphate through a 1-2 bond.",
      'parent' => 1420,
    ),
    array(
      'tid' => 1418,
      'name' => "Ceramides",
      'description' => "Lipid molecules containing a sphingosine in which the amine group is linked to a fatty acid.",
      'parent' => 257,
    ),
    array(
      'tid' => 1419,
      'name' => "Neutral glycosphingolipids",
      'description' => "Glycosphingolipids in which the ceramide skeleton  is bound to an oligosaccharide (usually 3 to 5 units) moiety made up of a glucose (as primary unit bound to the ceramide moiety) and galactose (Gal), N-acetylglucosamine (GlcNAc), N-acetylgalactosamine (GalNAc) or mannose (Man) as the other monosaccharides.",
      'parent' => 3258,
    ),
    array(
      'tid' => 1420,
      'name' => "1-ribosyl-imidazolecarboxamides",
      'description' => "Organic compounds containing the imidazole ring linked to a ribose ring through a 1-2 bond.",
      'parent' => 1997,
    ),
    array(
      'tid' => 1421,
      'name' => "Glycidol esters",
      'description' => "Compounds containing an ester derivative of glycidol (2,3-Epoxy-1-propanol).",
      'parent' => 324,
    ),
    array(
      'tid' => 1422,
      'name' => "Other hydroxyeicosapolyenoic acids",
      'description' => "Hydroxyeicosapolyenoic acids which do not belong to the Hydroxyeicosapentaenoic acids, the Hydroxyeicosatetraenoic acids, or the Hydroxyeicosatrienoic acids.",
      'parent' => 513,
    ),
    array(
      'tid' => 1423,
      'name' => "Thia fatty acids",
      'description' => "Fatty acid derivatives obtained by insertion of a sulfur atom at specific positions in the chain.",
      'parent' => 262,
    ),
    array(
      'tid' => 1424,
      'name' => "Lysosphingomyelins and lysoglycosphingolipids",
      'description' => "Lipids containing either the sphingosine-phosphocholine, or the sphinganine-phosphocholine core structure.",
      'parent' => 257,
    ),
    array(
      'tid' => 1425,
      'name' => "Sulfated fatty acids",
      'description' => "Fatty acids containing linked to a sulfate group linked to its tail.",
      'parent' => 262,
    ),
    array(
      'tid' => 1426,
      'name' => "Pyrophosphatidic acids",
      'description' => "Lipids structurally characterized by the presence of a glycerol moiety bonded to two aliphatic chains through ester linkages, and to a pyrophosphate group.",
      'parent' => 3807,
    ),
    array(
      'tid' => 1427,
      'name' => "Phosphoceramides",
      'description' => "Compounds containing an n-acyl-ceramide phosphate skeleton.",
      'parent' => 3392,
    ),
    array(
      'tid' => 1428,
      'name' => "Simple glycosylceramides",
      'description' => "Compounds containing a ceramide linked to a simple glycosyl moiety.",
      'parent' => 1419,
    ),
    array(
      'tid' => 1429,
      'name' => "GalNAcb1-3Gala1-4Galb1-4Glc- (Globo series)",
      'description' => "Neutral glycosphingolipids in which the root sequence of the oligosaccharide moiety is GalNAcb1-3Gala1-4Galb1-4Glc.",
      'parent' => 1419,
    ),
    array(
      'tid' => 1430,
      'name' => "GalNAcb1-4GlcNAcb1-3Manb1-4Glc- (Arthro series)",
      'description' => "Neutral glycosphingolipids in which the root sequence is GalNAcb1-4GlcNAcb1-3Manb1-4Glc.",
      'parent' => 1419,
    ),
    array(
      'tid' => 1431,
      'name' => "Galb1-3GlcNAcb1-3Galb1-4Glc- (Lacto series)",
      'description' => "Neutral glycosphingolipids in which the root sequence of the oligosaccharide moiety is Galb1-3GlcNAcb1-3Galb1-4Glc.",
      'parent' => 1419,
    ),
    array(
      'tid' => 1432,
      'name' => "Galb1-4GlcNAcb1-3Galb1-4Glc- (Neolacto series)",
      'description' => "Neutral glycosphingolipids in which the root sequence of the oligosaccharide moiety is Galb1-4GlcNAcb1-3Galb1-4Glc. The differ from lacto series because of their 1-4 (instead of 1-3) bond between Galb and GlcNacb.",
      'parent' => 1419,
    ),
    array(
      'tid' => 1433,
      'name' => "GalNAcb1-3Gala1-3Galb1-4Glc- (Isoglobo series)",
      'description' => "Neutral glycosphingolipids in which the root sequence of the oligosaccharide moiety is GalNAcb1-3Gala1-3Galb1-4Glcb. The differ from lacto series because of their 1-3 (instead of 1-4) bond between Gala and Glacb.",
      'parent' => 1419,
    ),
    array(
      'tid' => 1434,
      'name' => "Betacyanins and derivatives",
      'description' => "Organic compounds containing a glycoside of indolium-2-carboxylic acid attached, with the nitrogen ring of the indolium ring attached to an ethylpyridine-2,6-dicarboxylic acid derivative. Betacyanins are red nitrogenous pigments found in certain plants, such as beetroots.",
      'parent' => 1435,
    ),
    array(
      'tid' => 1435,
      'name' => "Betalains",
      'description' => "Organic compounds belonging to the class of Betaxanthins or Betacyanins. This class also contains derivatives of betalamic acid, which is the precursor of betalains.",
      'parent' => 279,
    ),
    array(
      'tid' => 1436,
      'name' => "GlcNAcb1-2Mana1-3Manb1-4Glc- (Mollu series)",
      'description' => "Neutral glycosphingolipids in which the root sequence of the oligosaccharide moiety is GlcNAcb1-2Mana1-3Manb1-4Glc.",
      'parent' => 1419,
    ),
    array(
      'tid' => 1437,
      'name' => "Benzoxazinones",
      'description' => "Organic compounds containing a benzene fused to an oxazine ring (a six-member aliphatic ring with four carbon atoms, one oxygen atom, and one nitrogen atom) bearing a ketone group.",
      'parent' => 1396,
    ),
    array(
      'tid' => 1438,
      'name' => "Organothiophosphorus compounds",
      'description' => "Organic derivatives of thiophosphonic acid, thiophosphoric acid, dithiophosphoric acid, or phosphorotrithioic acid, or derivatives thereof. Thiophosphonic acid, dithiophosphoric acid, thiophosphoric acid, and phosphorotrithioic acid are thiophosphorus compounds with the formula OP(O)(=S), OP(S)(=S)O, OP(O)(=S)O, and OP(=S)(S)S, respectively.",
      'parent' => 400,
    ),
    array(
      'tid' => 1439,
      'name' => "Gangliosides",
      'description' => "Lipid molecules composed of a glycosphingolipid (ceramide and saccharide) with one or more sialic acids linked on the sugar chain. They are usually oligoglycosylceramides derived from lactosylceramide and containing a sialic acid residue such as N-acetylneuraminic acid.",
      'parent' => 3258,
    ),
    array(
      'tid' => 1440,
      'name' => "Sulfatides",
      'description' => "An hydrogen sulfate esters of glycosphingolipids.",
      'parent' => 3258,
    ),
    array(
      'tid' => 1441,
      'name' => "Alpha-amino acyl ester of carbohydrates",
      'description' => "Compounds containing an amino acid esterified with a carbohydrate.",
      'parent' => 394,
    ),
    array(
      'tid' => 1442,
      'name' => "Other mixed metal/non-metal oxoanionic compounds",
      'description' => "Inorganic compounds containing a non-metal atom linked to a metallic oxoanionic moiety.",
      'parent' => 424,
    ),
    array(
      'tid' => 1443,
      'name' => "Triazolopyrimidines",
      'description' => "Polycyclic aromatic compounds containing triazole ring fused to a pyrimidine ring. Triazole is a five-membered ring consisting of two carbon atoms and three nitrogen atoms. Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions.",
      'parent' => 2,
    ),
    array(
      'tid' => 1444,
      'name' => "Organic hypobromites",
      'description' => "Organic compounds containing the hypobromite oxoanion, with the formula BrO-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1445,
      'name' => "Bile acids, alcohols and derivatives",
      'description' => "Organic compounds containing an alcohol or acid derivative of cholic acid.",
      'parent' => 258,
    ),
    array(
      'tid' => 1446,
      'name' => "Thienoimidazolidines",
      'description' => "Heterocyclic compounds containing a thiophene ring fused to an imidazolidine ring. Thiophene is 5-membered ring consisting of four carbon atoms and one sulfur atom. Imidazolidine is 5-membered saturated ring of three carbon atoms, and two nitrogen centers at the 1- and 3-positions.",
      'parent' => 2,
    ),
    array(
      'tid' => 1447,
      'name' => "Steroid glucuronide conjugates",
      'description' => "Sterol lipids containing a glucuronide moiety linked to the steroid skeleton.",
      'parent' => 1013,
    ),
    array(
      'tid' => 1448,
      'name' => "Furoic acids",
      'description' => "Organic compounds containing a furoic acid moiety, with a structure characterized by a furan ring bearing a carboxylic acid group at the C2 or C3 carbon atom.",
      'parent' => 4758,
    ),
    array(
      'tid' => 1449,
      'name' => "Intermetallic alkaline earth metal compounds",
      'description' => "Inorganic compounds containing only metal atoms of at least two different types, where the heaviest atom is a lanthanide.",
      'parent' => 422,
    ),
    array(
      'tid' => 1450,
      'name' => "Intermetallic lanthanide compounds",
      'description' => "Inorganic compounds containing only metal atoms of at least two different types, where the heaviest atom is lanthanide.",
      'parent' => 422,
    ),
    array(
      'tid' => 1451,
      'name' => "Intermetallic actinide compounds",
      'description' => "Inorganic compounds containing only metal atoms of at least two different types, where the heaviest atom is a actinide metal.",
      'parent' => 422,
    ),
    array(
      'tid' => 1452,
      'name' => "Intermetallic metalloid compounds",
      'description' => "Compounds containing only metal atoms of at least two different types, where the heaviest atom is a metalloid.",
      'parent' => 422,
    ),
    array(
      'tid' => 1453,
      'name' => "Intermetallic transition metal compounds",
      'description' => "Inorganic compounds containing only metal atoms of at least two different types, where the heaviest atom is a transition metal.",
      'parent' => 422,
    ),
    array(
      'tid' => 1454,
      'name' => "Intermetallic post-transition metal compounds",
      'description' => "Inorganic compounds containing only metal atoms of at least two different types, where the heaviest atom is a post-transition metal.",
      'parent' => 422,
    ),
    array(
      'tid' => 1455,
      'name' => "Tetrapyrroles and derivatives",
      'description' => "Polycyclic aromatic compounds containing four pyrrole rings joined by one-carbon units linking position 2 of one pyrrole ring to position 5 of the next.",
      'parent' => 2,
    ),
    array(
      'tid' => 1456,
      'name' => "Cephams",
      'description' => "Organic compounds containing the 5-thia-1-azabicyclo[4.2.0]octan-8-one nucleus.",
      'parent' => 162,
    ),
    array(
      'tid' => 1457,
      'name' => "Penems",
      'description' => "Organic heterocyclic compounds containing a penem moiety, which is a 2,3-didehydropenam derivative.",
      'parent' => 162,
    ),
    array(
      'tid' => 1458,
      'name' => "Cephamycins",
      'description' => "Compounds containing a the cephalosporin (oxo-5-thia-1-azabicyclo[4.2.0]oct-2-ene-2-carboxylic acid) nucleus, with an alkyloxy group attached to the C6 carbon atom.",
      'parent' => 173,
    ),
    array(
      'tid' => 1459,
      'name' => "Glycosylglycerophospholipids",
      'description' => "Glycerolipids structurally characterized by the presence of one or more sugar residues attached to the glycerol moiety of a glycerophosphate via a glycosidic linkage.",
      'parent' => 256,
    ),
    array(
      'tid' => 1460,
      'name' => "Vitamin D and derivatives",
      'description' => "Compounds containing a secosteroid backbone, usually secoergostane or secocholestane.",
      'parent' => 258,
    ),
    array(
      'tid' => 1461,
      'name' => "Pyrethroids",
      'description' => "Organic compounds similar to the pyrethrins. Some pyrethroids containing a chrysanthemic acid esterified with a cyclopentenone (pyrethrins), or with a phenoxybenzyl group.",
      'parent' => 324,
    ),
    array(
      'tid' => 1462,
      'name' => "Mannosylerythritol lipids",
      'description' => "Lipids containing a mannosylerylthritol skeleton, which is 1-O-b-mannopyranosyl-meso-erythritol.",
      'parent' => 1766,
    ),
    array(
      'tid' => 1463,
      'name' => "3-(3-hydroxyalkanoyloxy)alkanoic acids",
      'description' => "Organic compounds containing a 3-hydroxyalkanoic acid linked to another 3-hydroxyalkanoic acid through the hydroxyl group at the 3-position.",
      'parent' => 324,
    ),
    array(
      'tid' => 1464,
      'name' => "4-hydroxy-2-alkylquinolines",
      'description' => "Organic compounds containing a quinoline moiety with a hydroxyl group attached to the C4 atom, and an alkyl chain attached to the C2 atom.",
      'parent' => 1253,
    ),
    array(
      'tid' => 1465,
      'name' => "Anatoxins",
      'description' => "Organic compounds containing or derived from anatoxin, homoanatoxin or other analogues. Anatoxins constitute a class of potent neurotoxic alkaloids.",
      'parent' => 279,
    ),
    array(
      'tid' => 1466,
      'name' => "Estrane steroids",
      'description' => "Steroids with a structure based on the estrane skeleton.",
      'parent' => 258,
    ),
    array(
      'tid' => 1467,
      'name' => "Androgens and derivatives",
      'description' => "3-hydroxylated C19 steroid hormones. They are known to favor the development of masculine characteristics. They also show profound effects on scalp and body hair in humans.",
      'parent' => 3568,
    ),
    array(
      'tid' => 1468,
      'name' => "Gluco/mineralocorticoids, progestogins and derivatives",
      'description' => "Steroids with a structure based on a hydroxylated prostane moiety.",
      'parent' => 3569,
    ),
    array(
      'tid' => 1469,
      'name' => "Cholesterols and derivatives",
      'description' => "Compounds containing a 3-hydroxylated cholestane core.",
      'parent' => 3566,
    ),
    array(
      'tid' => 1470,
      'name' => "Miscellaneous metallic oxoanionic compounds",
      'description' => "Inorganic compounds containing a metallic oxoanion to which either no atom or a non metal atom is bonded.",
      'parent' => 1270,
    ),
    array(
      'tid' => 1471,
      'name' => "Miscellaneous aluminates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is aluminate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1472,
      'name' => "Miscellaneous antimonates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is antimonate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1473,
      'name' => "Miscellaneous antimonites",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is antimonite, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1474,
      'name' => "Miscellaneous arsenates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is arsenate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1475,
      'name' => "Miscellaneous arsenites",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is arsenite, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1476,
      'name' => "Miscellaneous borates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is borate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1477,
      'name' => "Miscellaneous ferrates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is ferrate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1478,
      'name' => "Miscellaneous manganates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is manganate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1479,
      'name' => "Miscellaneous molybdates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is molybdate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1480,
      'name' => "Miscellaneous plumbates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is plumbate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1481,
      'name' => "Miscellaneous plumbites",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is plumbite, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1482,
      'name' => "Miscellaneous silicates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is silicate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1483,
      'name' => "Miscellaneous stannates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is stannate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1484,
      'name' => "Miscellaneous stannites",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is stannite, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1485,
      'name' => "Miscellaneous tellurates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is tellurate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1486,
      'name' => "Miscellaneous tellurites",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is tellurite, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1487,
      'name' => "Miscellaneous tetrahydroxyborates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is tetrahydroxyborate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1488,
      'name' => "Miscellaneous tungstates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is tungstate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1489,
      'name' => "Miscellaneous orthovanadates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is orthovanadate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 1490,
      'name' => "Cholesteryl esters",
      'description' => "Compounds containing an esterified cholestane moiety.",
      'parent' => 1691,
    ),
    array(
      'tid' => 1491,
      'name' => "Cyclic purine nucleotides",
      'description' => "Purine nucleotides where one ribose group of the hydroxyl moiety and one phosphate group form a ring.",
      'parent' => 1506,
    ),
    array(
      'tid' => 1492,
      'name' => "Cyclic pyrimidine nucleotides",
      'description' => "Pyrimidine nucleotides where one ribose group of the hydroxyl moiety and one phosphate group form a ring.",
      'parent' => 1509,
    ),
    array(
      'tid' => 1493,
      'name' => "Epibatidine analogues",
      'description' => "Compounds containing an epibatidine moiety, with a structure characterized by a 2-chloropyridine moiety connected to an 7-azabicyclo[2.2.1]heptane in exo position.",
      'parent' => 279,
    ),
    array(
      'tid' => 1494,
      'name' => "2',3'-cyclic purine nucleotides",
      'description' => "Purine nucleotides in which the oxygen atoms linked to the C2 and C3 carbon atoms of the ribose moiety are both bonded the same phosphorus atom of the phosphate group.",
      'parent' => 1491,
    ),
    array(
      'tid' => 1495,
      'name' => "2',3'-cyclic pyrimidine nucleotides",
      'description' => "Pyrimidine nucleotides in which the oxygen atoms linked to the C2 and C3 carbon atoms of the ribose moiety are both bonded the same phosphorus atom of the phosphate group.",
      'parent' => 1492,
    ),
    array(
      'tid' => 1496,
      'name' => "Tetroses",
      'description' => "Monosaccharides with a sugar unit made up of 4 atoms.",
      'parent' => 1540,
    ),
    array(
      'tid' => 1497,
      'name' => "Pentoses",
      'description' => "Monosaccharides in which the carbohydrate moiety contains five carbon atoms.",
      'parent' => 1540,
    ),
    array(
      'tid' => 1498,
      'name' => "Hexoses",
      'description' => "Monosaccharides in which the sugar unit is a is a six-carbon containing moeity.",
      'parent' => 1540,
    ),
    array(
      'tid' => 1499,
      'name' => "Heptoses",
      'description' => "Monosaccharides in which the sugar unit is a seven-carbon containing moeity.",
      'parent' => 1540,
    ),
    array(
      'tid' => 1500,
      'name' => "Octoses",
      'description' => "Monosaccharide compounds in which the sugar moiety is an octose (8 carbon atoms).",
      'parent' => 1540,
    ),
    array(
      'tid' => 1501,
      'name' => "Nonoses",
      'description' => "Monosaccharide compounds in which the sugar moiety is an octose (9 carbon atoms).",
      'parent' => 1540,
    ),
    array(
      'tid' => 1502,
      'name' => "3',5'-cyclic purine nucleotides",
      'description' => "Purine nucleotides in which the oxygen atoms linked to the C3 and C5 carbon atoms of the ribose moiety are both bonded the same phosphorus atom of the phosphate group.",
      'parent' => 1491,
    ),
    array(
      'tid' => 1503,
      'name' => "3',5'-cyclic pyrimidine nucleotides",
      'description' => "Pyrimidine nucleotides in which the oxygen atoms linked to the C3 and C5 carbon atoms of the ribose moiety are both bonded the same phosphorus atom of the phosphate group.",
      'parent' => 1492,
    ),
    array(
      'tid' => 1504,
      'name' => "Diacylglycerophosphates",
      'description' => "Glycerophosphates in which the glycerol is esterified ta two positions with to fatty acids.",
      'parent' => 2214,
    ),
    array(
      'tid' => 1505,
      'name' => "6-oxopurines",
      'description' => "Purines that carry a C=O group at position 6. Purine is a bicyclic aromatic compound made up of a pyrimidine ring fused to an imidazole ring.",
      'parent' => 597,
    ),
    array(
      'tid' => 1506,
      'name' => "Purine nucleotides",
      'description' => "Nucleotides with a purine base attached to the ribosyl moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 1507,
      'name' => "Thiocarbamic acids",
      'description' => "Organic compounds containing a functional group with the general structure HOC(=S)N(R1)R2 (R=halogen; R1,R2=H, alkyl, aryl).",
      'parent' => 264,
    ),
    array(
      'tid' => 1508,
      'name' => "Organic oxoazanium compounds",
      'description' => "Organic compounds comprising the oxoazanium cation, with the formula N+=O.",
      'parent' => 4603,
    ),
    array(
      'tid' => 1509,
      'name' => "Pyrimidine nucleotides",
      'description' => "Nucleotides containing a pyrimidine base.",
      'parent' => 289,
    ),
    array(
      'tid' => 1510,
      'name' => "Lignan lactones",
      'description' => "Lignans that contain a lactone moiety. They include 1-aryltetralin lactones, dibenzylbutyrolactone lignans, and podophyllotoxins, among others.",
      'parent' => 1392,
    ),
    array(
      'tid' => 1511,
      'name' => "Lignan glycosides",
      'description' => "Aromatic polycyclic compounds containing a carbohydrate component glycosidically linked to a lignan moiety. They include 1-aryltetralin lactones.",
      'parent' => 1392,
    ),
    array(
      'tid' => 1512,
      'name' => "Other glycerolipids",
      'description' => "Glycerolipids that do not belong to either the class Alk(en)yl Diacylglycerols, Diacylglycerols, Glycosylglycerols, Monoacylglycerols, Other Glycerolipids or Triacylglycerols.",
      'parent' => 175,
    ),
    array(
      'tid' => 1513,
      'name' => "Quinoline-3-sulfonamides",
      'description' => "Quinolines in which the quinoline ring system is substituted by one sulfonamide group at the 3-position.",
      'parent' => 1253,
    ),
    array(
      'tid' => 1514,
      'name' => "Organoastatides",
      'description' => "Compounds containing a chemical bond between a carbon atom and an astatin atom.",
      'parent' => 267,
    ),
    array(
      'tid' => 1515,
      'name' => "Organobromides",
      'description' => "Compounds containing a chemical bond between a carbon atom and a bromine atom.",
      'parent' => 267,
    ),
    array(
      'tid' => 1516,
      'name' => "Organochlorides",
      'description' => "Compounds containing a chemical bond between a carbon atom and a chlorine atom.",
      'parent' => 267,
    ),
    array(
      'tid' => 1517,
      'name' => "Organofluorides",
      'description' => "Compounds containing a chemical bond between a carbon atom and a fluorine atom.",
      'parent' => 267,
    ),
    array(
      'tid' => 1518,
      'name' => "Organoiodides",
      'description' => "Compounds containing a chemical bond between a carbon atom and an iodine atom.",
      'parent' => 267,
    ),
    array(
      'tid' => 1519,
      'name' => "Acyl astatides",
      'description' => "Organic compounds containing the functional group -CO-As.",
      'parent' => 2865,
    ),
    array(
      'tid' => 1520,
      'name' => "Organic nitrosonium compounds",
      'description' => "Organic compounds containing the nitrosonium cation, with the general formula NO+.",
      'parent' => 278,
    ),
    array(
      'tid' => 1521,
      'name' => "Organic carbonic acids",
      'description' => "Compounds comprising the carbonic acid functional group.",
      'parent' => 364,
    ),
    array(
      'tid' => 1522,
      'name' => "Acyltrehaloses",
      'description' => "Lipids containing a trehalose molecule linked to at least one fatty acid through an ester bond.",
      'parent' => 3918,
    ),
    array(
      'tid' => 1523,
      'name' => "Organo-post-transition metal compounds",
      'description' => "Organic compounds containing a post-transition metal atom.",
      'parent' => 462,
    ),
    array(
      'tid' => 1524,
      'name' => "Organotin compounds",
      'description' => "Compounds containing bond between a carbon atom and a tin atom.",
      'parent' => 1523,
    ),
    array(
      'tid' => 1525,
      'name' => "Other hydroperoxyeicosapolyenoic acids",
      'description' => "Hydroperoxyeicosapolyenoic acids which do not belong to the hydroperoxyeicosapentaenoic acids, the hydroperoxyeicosatetraenoic acids, or the hydroperoxyeicosatrienoic acids.",
      'parent' => 513,
    ),
    array(
      'tid' => 1526,
      'name' => "Organic hypochlorites",
      'description' => "Organic compounds containing the hypochlorite oxoanion, with the formula ClO-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1527,
      'name' => "Diphenylacetonitriles",
      'description' => "Cyclic aromatic compounds containing a diphenylacetonitrile moiety, which consists of a diphenylmethane linked to and acetonitrile to form 2,2-diphenylacetonitrile.",
      'parent' => 2279,
    ),
    array(
      'tid' => 1528,
      'name' => "Furanoid fatty acids",
      'description' => "Fatty acids containing a 5-alkylfuran-2-alkanoic acid.",
      'parent' => 1989,
    ),
    array(
      'tid' => 1529,
      'name' => "Organoaluminium compounds",
      'description' => "Compounds containing bond between a carbon atom and an aluminum atom.",
      'parent' => 1523,
    ),
    array(
      'tid' => 1530,
      'name' => "Benzonitriles",
      'description' => "Organic compounds containing a benzene bearing a nitrile substituent.",
      'parent' => 2279,
    ),
    array(
      'tid' => 1531,
      'name' => "Urofuranic acids",
      'description' => "Fatty acids structurally characterized by the presence of a furanoid ring substituted at the positions 1, 2, 3, and 4 by a short fatty acid chain, a carboxylic acid group, a methyl group, and an alkyl chain, respectively.",
      'parent' => 1528,
    ),
    array(
      'tid' => 1532,
      'name' => "Difurocoumarocyclopentenones",
      'description' => "Polycyclic aromatic compounds containing a cyclopenten-2-one ring fused to the coumarin moiety of the difurocoumarin skeleton.",
      'parent' => 149,
    ),
    array(
      'tid' => 1533,
      'name' => "Difurocoumarolactones",
      'description' => "Polycyclic aromatic compounds containing a delta-valerolactone ring fused to the coumarin moiety of the difurocoumarin skeleton.",
      'parent' => 149,
    ),
    array(
      'tid' => 1534,
      'name' => "Quinone and hydroquinone lipids",
      'description' => "Lipids structurally characterized by the presence of a quinone or hydroquinone moiety.",
      'parent' => 259,
    ),
    array(
      'tid' => 1535,
      'name' => "Polyprenols",
      'description' => "Prenols with more than 4 consecutive isoprene units.",
      'parent' => 259,
    ),
    array(
      'tid' => 1536,
      'name' => "Difurocoumarins",
      'description' => "Polycyclic aromatic compounds containing difurocoumarin moiety consisting of a system of two fused furan rings, which is linked to the benzene ring of a coumarin.",
      'parent' => 145,
    ),
    array(
      'tid' => 1537,
      'name' => "Epoxy fatty acids",
      'description' => "Fatty acids containing an oxirane ring as part of the aliphatic chain.",
      'parent' => 1989,
    ),
    array(
      'tid' => 1538,
      'name' => "Diterpene lactones",
      'description' => "Diterpenoids containing a lactone moiety.",
      'parent' => 1283,
    ),
    array(
      'tid' => 1539,
      'name' => "Polysaccharides",
      'description' => "Compounds containing more than ten saccharide units.",
      'parent' => 3297,
    ),
    array(
      'tid' => 1540,
      'name' => "Monosaccharides",
      'description' => "Compounds containing one carbohydrate unit not glycosidically linked to another such unit, and no set of two or more glycosidically linked carbohydrate units. Monosaccharides have the general formula CnH2nOn.",
      'parent' => 11,
    ),
    array(
      'tid' => 1541,
      'name' => "Monosaccharide phosphates",
      'description' => "Monosaccharides comprising a phosphated group linked to the carbohydrate unit.",
      'parent' => 1540,
    ),
    array(
      'tid' => 1542,
      'name' => "Disaccharides",
      'description' => "Compounds containing two carbohydrate moieties linked to each to each other through a glycosidic bond, no set of three or more glycosidically linked carbohydrate units.",
      'parent' => 11,
    ),
    array(
      'tid' => 1543,
      'name' => "Sesquiterpene lactones",
      'description' => "Sesquiterpenoids containing a lactone ring.",
      'parent' => 1283,
    ),
    array(
      'tid' => 1544,
      'name' => "Purine ribonucleotides",
      'description' => "Nucleotides consisting of a purine base linked to a ribose to which at least one phosphate group is attached.",
      'parent' => 1506,
    ),
    array(
      'tid' => 1545,
      'name' => "Ubiquinones",
      'description' => "Coenzyme Q derivatives containing a 5, 6-dimethoxy-3-methyl(1,4-benzoquinone) moiety to which an isoprenyl group is attached at ring position 2(or 6).",
      'parent' => 2802,
    ),
    array(
      'tid' => 1546,
      'name' => "Vitamin E compounds",
      'description' => "A group of fat-soluble compounds containing or derived either from a tocopherol or a tocotrienol skeleton.",
      'parent' => 1534,
    ),
    array(
      'tid' => 1547,
      'name' => "Vitamin K compounds",
      'description' => "Quinone lipids containing a methylated naphthoquinone ring structure, and vary in the aliphatic side chain attached at the 3-position.",
      'parent' => 1534,
    ),
    array(
      'tid' => 1548,
      'name' => "Alpha-halocarboxylic acids and derivatives",
      'description' => "Carboxylic acids (or derivative thereof) containing a halogen atom bonded to the alpha carbon atom.",
      'parent' => 265,
    ),
    array(
      'tid' => 1549,
      'name' => "Monoterpenoids",
      'description' => "Compounds containing a chain of two isoprene units.",
      'parent' => 259,
    ),
    array(
      'tid' => 1550,
      'name' => "Sesquiterpenoids",
      'description' => "Terpenes with three consecutive isoprene units.",
      'parent' => 259,
    ),
    array(
      'tid' => 1551,
      'name' => "Diterpenoids",
      'description' => "Terpene compounds formed by four isoprene units.",
      'parent' => 259,
    ),
    array(
      'tid' => 1552,
      'name' => "Sesterterpenoids",
      'description' => "Terpenes composed of five consecutive isoprene units.",
      'parent' => 259,
    ),
    array(
      'tid' => 1553,
      'name' => "Triterpenoids",
      'description' => "Terpene molecules containing 8 isoprene units.",
      'parent' => 259,
    ),
    array(
      'tid' => 1554,
      'name' => "Tetraterpenoids",
      'description' => "Terpenoid molecules containing 10 consecutively linked isoprene units.",
      'parent' => 259,
    ),
    array(
      'tid' => 1555,
      'name' => "Cardenolides and derivatives",
      'description' => "Steroid lactones containing a furan-2-one moiety linked to the C17 atom of a cyclopenta[a]phenanthrene derivative.",
      'parent' => 1125,
    ),
    array(
      'tid' => 1556,
      'name' => "1,3-diacylglycerol-2-phosphates",
      'description' => "Glycerol-2-phosphates in which the glycerol moiety is bonded to two aliphatic chains through ester linkages.",
      'parent' => 1504,
    ),
    array(
      'tid' => 1557,
      'name' => "Bufanolides and derivatives",
      'description' => "Steroid lactones containing a pyran-2-one moiety linked to the C17 atom of a cyclopenta[a]phenanthrene derivative.",
      'parent' => 1125,
    ),
    array(
      'tid' => 1558,
      'name' => "Bufanolide glycosides and derivatives",
      'description' => "Bufanolides that are glycosidically linked to a glucose moiety.",
      'parent' => 1557,
    ),
    array(
      'tid' => 1559,
      'name' => "Cardenolide glycosides and derivatives",
      'description' => "Compounds containing a carbohydrate glycosidically bound to the cardenolide moiety.",
      'parent' => 1555,
    ),
    array(
      'tid' => 1560,
      'name' => "Withanolides and derivatives",
      'description' => "C28 steroids structurally characterized by an ergostane skeleton usually functionalized at carbons 1, 22 and 26 to form a lactone ring.",
      'parent' => 1125,
    ),
    array(
      'tid' => 1561,
      'name' => "Withanolide glycosides and derivatives",
      'description' => "Withanolides in which at least one hydroxyl group is glycosylated.",
      'parent' => 1560,
    ),
    array(
      'tid' => 1562,
      'name' => "Dihydropyridinecarboxylic acids and derivatives",
      'description' => "Compounds containing a dihydropyridine moiety bearing a carboxylic acid group.",
      'parent' => 367,
    ),
    array(
      'tid' => 1563,
      'name' => "Monocyclic monoterpenoids",
      'description' => "Monoterpenoids containing 1 ring in the isoprene chain.",
      'parent' => 1549,
    ),
    array(
      'tid' => 1564,
      'name' => "Bicyclic monoterpenoids",
      'description' => "Monoterpenoids containing exactly 2 rings, which are fused to each other.",
      'parent' => 1549,
    ),
    array(
      'tid' => 1565,
      'name' => "Iridoids and derivatives",
      'description' => "Monoterpenes containing a skeleton structurally characterized by the presence of a cylopentane fused to a pyran ( forming a 4,7-dimethylcyclopenta[c]pyran), or a derivative where the pentane moiety is open.",
      'parent' => 1549,
    ),
    array(
      'tid' => 1566,
      'name' => "Enynes",
      'description' => "Hydrocarbons containing an alkene and an alkyne group.",
      'parent' => 4475,
    ),
    array(
      'tid' => 1567,
      'name' => "Pumiliotoxins, homopumiliotoxins, and allopumiliotoxins",
      'description' => "Neurotoxic alkaloids, containing a 8-methyl-octahydroindolizin-8-ol or 1-methyl-octahydro-1H-quinolizin-1-ol moiety.",
      'parent' => 279,
    ),
    array(
      'tid' => 1568,
      'name' => "Miscellaneous inorganic compounds",
      'description' => "Inorganic compounds of miscellaneous structure, which can be a mixture of chemical elements of different types.",
      'parent' => 1,
    ),
    array(
      'tid' => 1569,
      'name' => "Inorganic phosphorotrithioic acids and derivatives",
      'description' => "Inorganic compounds containing a phosphorotrithioic acid group, with the structure OP(S)(S)=S (or SP(S)(S)=O).",
      'parent' => 1568,
    ),
    array(
      'tid' => 1570,
      'name' => "Organophosphorotrithioic acids and derivatives",
      'description' => "Organic compounds containing the organophosphorotrithioic acid structure or a derivative thereof. They have the general structure ROP(=S)(SR')SR\", where R-R\"= any atom.",
      'parent' => 1438,
    ),
    array(
      'tid' => 1571,
      'name' => "Organic thiophosphoric acid amides",
      'description' => "Organic compounds containing the thiophosphoric acid amide functional group RN(R')OP(O)(O)=S, R,R'=H, alkyl, or aryl group.",
      'parent' => 1303,
    ),
    array(
      'tid' => 1572,
      'name' => "Thiophosphoric acid esters",
      'description' => "Organic compounds containing the thiophosphoric acid functional group or a derivative thereof, with the general structure ROP(OR')(OR'')=S, where at least one R-group is an organyl group.",
      'parent' => 1303,
    ),
    array(
      'tid' => 1573,
      'name' => "Organic thiophosphoric acid halides",
      'description' => "Organic compounds containing the thiophosphoric acid halide functional group, with the general structure RP(R')(X)=S, where R,R',R'' = O,N and X = halogen group.",
      'parent' => 1303,
    ),
    array(
      'tid' => 1574,
      'name' => "Organic phosphoric acids",
      'description' => "Organic compounds containing phosphoric acid, with the general structure OP(O)(=O)O.",
      'parent' => 402,
    ),
    array(
      'tid' => 1575,
      'name' => "Retinoid esters",
      'description' => "Ester derivatives of retinoic acid. These are obtained by formal condensation of the hydroxy group of retinol with the carboxy group of any carboxylic acid.",
      'parent' => 1606,
    ),
    array(
      'tid' => 1576,
      'name' => "Allylic alcohols",
      'description' => "Organic compounds containing an alcohol group attached to the allyl functional group CH2=CHCH2.",
      'parent' => 129,
    ),
    array(
      'tid' => 1577,
      'name' => "Organic hyponitrites",
      'description' => "Organic compounds containing the hyponitrite oxoanion, with the formula ([ON=NO]2-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1578,
      'name' => "Benzofuranones",
      'description' => "Organic compounds containing a benzene ring fused to a furanone.",
      'parent' => 301,
    ),
    array(
      'tid' => 1579,
      'name' => "Quinodimethanes",
      'description' => "Compounds containing a cyclohexene or cyclohexadiene ring that bears two methylidene groups.",
      'parent' => 4150,
    ),
    array(
      'tid' => 1580,
      'name' => "Triterpene glycosides",
      'description' => "Triterpenoids in which an isoprene unit is glycosylated.",
      'parent' => 2049,
    ),
    array(
      'tid' => 1581,
      'name' => "Piperidinones",
      'description' => "Compounds containing a piperidine ring which bears a ketone.",
      'parent' => 195,
    ),
    array(
      'tid' => 1582,
      'name' => "Piperidinediones",
      'description' => "Compounds containing a piperidine ring which bears two ketones.",
      'parent' => 1581,
    ),
    array(
      'tid' => 1583,
      'name' => "Flavonoid O-glycosides",
      'description' => "Compounds containing a carbohydrate moiety which is O-glycosidically linked to the 2-phenylchromen-4-one flavonoid backbone.",
      'parent' => 1111,
    ),
    array(
      'tid' => 1584,
      'name' => "Catechins",
      'description' => "Compounds containing a catechin moiety, which is a 3,4-dihydro-2-chromene-3,5.7-tiol.",
      'parent' => 3012,
    ),
    array(
      'tid' => 1585,
      'name' => "Organosulfonamides",
      'description' => "Compounds containing the sulfonamide functional group, an amide of sulfonic acid with the general structure R1S(=O)2N(R2)R3 (R1=alkyl, aryl; R2,R3=H, alkyl, aryl).",
      'parent' => 270,
    ),
    array(
      'tid' => 1586,
      'name' => "Biflavonoids and polyflavonoids",
      'description' => "Organic compounds containing at least two flavan/flavone units. These units are usually linked through CC or C-O-C bonds. Some examples include C2-O-C3, C2-O-C4, C3'-C3''', and C6-C8''.",
      'parent' => 334,
    ),
    array(
      'tid' => 1587,
      'name' => "Catechin gallates",
      'description' => "Organic compounds containing a gallate moiety glycosidically linked to a catechin.",
      'parent' => 1584,
    ),
    array(
      'tid' => 1588,
      'name' => "N-epsilon-acyl lysines",
      'description' => "Lysine derivatives containing an acyl group linked to the N-epsilon atom of lysine.",
      'parent' => 2404,
    ),
    array(
      'tid' => 1589,
      'name' => "Organic hypophosphites",
      'description' => "Organic compounds containing the hypophosphite oxoanion, with the formula PO2−.",
      'parent' => 463,
    ),
    array(
      'tid' => 1590,
      'name' => "Organic iodates",
      'description' => "Organic compounds containing the iodate oxoanion, with the formula IO3-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1591,
      'name' => "Inorganic sulfuryl bromides",
      'description' => "Inorganic compounds containing the sulfuryl bromide functional group, with the general structure BrS(R)(=O)=O (R=hetero atom).",
      'parent' => 1333,
    ),
    array(
      'tid' => 1592,
      'name' => "Pterofurans",
      'description' => "Compounds containing a 3-hydroxy-2,4-dimethoxyphenyl linked to the C2 atom of a benzofuran moiety.",
      'parent' => 301,
    ),
    array(
      'tid' => 1593,
      'name' => "Bilirubins",
      'description' => "Organic compounds containing a dicarboxylic acyclic tetrapyrrole derivative.",
      'parent' => 1455,
    ),
    array(
      'tid' => 1594,
      'name' => "Epigallocatechins",
      'description' => "Compounds containing epigallocatechin or a derivative. Epigallocatechin is a flavan-3-ol containing a benzopyran-3,5,7-triol linked to a 3,4,5-hydroxyphenyl moiety.",
      'parent' => 1584,
    ),
    array(
      'tid' => 1595,
      'name' => "Spatane and 4,10-secospatane diterpenoids",
      'description' => "Diterpenoids with a structure based on the spatane or 4,10-secospatane skeleton. The spatane skeleton is formally derived from a prenylgermacrane by 1,5- and 6,10-cyclisation.",
      'parent' => 1551,
    ),
    array(
      'tid' => 1596,
      'name' => "Acyclic sesterterpenoids",
      'description' => "Sesterterpenoids (compounds made of five consecutive isoprene units) that do not contain a cycle.",
      'parent' => 1552,
    ),
    array(
      'tid' => 1597,
      'name' => "1-monoacylglycerols",
      'description' => "Monoacylglycerols containing a glycerol acylated at the 1-position.",
      'parent' => 1133,
    ),
    array(
      'tid' => 1598,
      'name' => "Hydroxyanthraquinones",
      'description' => "Compounds containing a hydroxyanthraquinone moiety, which consists of an anthracene bearing a quinone, and hydroxyl group.",
      'parent' => 151,
    ),
    array(
      'tid' => 1599,
      'name' => "Disaccharide phosphates",
      'description' => "Disaccharides carrying  one or more phosphate group on a sugar unit.",
      'parent' => 1542,
    ),
    array(
      'tid' => 1600,
      'name' => "Anthraquinone glycosides",
      'description' => "Organic compounds containing an anthraquinone moiety glycosidically bound to a carbohydrate moiety.",
      'parent' => 151,
    ),
    array(
      'tid' => 1601,
      'name' => "Cyclosporins",
      'description' => "Cyclic depsipeptides containing the cyclosporin backbone.",
      'parent' => 1939,
    ),
    array(
      'tid' => 1602,
      'name' => "M-quinodimethanes",
      'description' => "Organic compounds containing a benzene ring conjugated to two methylidene groups at carbon atoms 1 and 3, respectively.",
      'parent' => 1579,
    ),
    array(
      'tid' => 1603,
      'name' => "2-monoacylglycerols",
      'description' => "Monoacylglycerols containing a glycerol acylated at the 2-position.",
      'parent' => 1133,
    ),
    array(
      'tid' => 1604,
      'name' => "Tetrahydrofuran lignans",
      'description' => "Lignans with a structure that contains a tetrahydrofuran ring that arises from the joining of the two phenylpropanoid units.",
      'parent' => 3686,
    ),
    array(
      'tid' => 1605,
      'name' => "Carbonyl hydrates",
      'description' => "Organic compounds containing two hydroxyl groups attached to a carbon atom.",
      'parent' => 129,
    ),
    array(
      'tid' => 1606,
      'name' => "Retinoids",
      'description' => "Oxygenated derivatives of 3,7-dimethyl-1-(2,6,6-trimethylcyclohex-1-enyl)nona-1,3,5,7-tetraene and derivatives thereof.",
      'parent' => 259,
    ),
    array(
      'tid' => 1607,
      'name' => "Rotenoids",
      'description' => "Phenolic compounds containing a cis-fused tetrahydrochromeno[3,4-b]chromene nucleus. Many rotenoids contain an additional ring, e.g. rotenone. They are isoflavonoids characterized by the presence of an extra carbon atom in an additional heterocyclic ring.",
      'parent' => 2506,
    ),
    array(
      'tid' => 1608,
      'name' => "Pterocarpans",
      'description' => "Benzo-pyrano-furano-benzene compounds, containing the  6H-[1]benzofuro[3,2-c]chromene skeleton. They are derivatives of isoflavonoids.",
      'parent' => 2617,
    ),
    array(
      'tid' => 1609,
      'name' => "Carnitines",
      'description' => "Organic compounds containing the quaternary ammonium compound carnitine.",
      'parent' => 503,
    ),
    array(
      'tid' => 1610,
      'name' => "Arylnaphthalene lignans",
      'description' => "Lignans containing the arylnaphthalene skeleton, especially 9-(2H-1,3-benzodioxol-5-yl)-1H,3H-naphtho[2,3-c]furan-1-one or a derivative thereof. Arylnaphthalene lignans occur in nature and exhibit diverse biological activities.",
      'parent' => 1392,
    ),
    array(
      'tid' => 1611,
      'name' => "Carbonic acid diesters",
      'description' => "Compounds comprising the carbonic acid diester functional group.",
      'parent' => 364,
    ),
    array(
      'tid' => 1612,
      'name' => "Isoflavans",
      'description' => "Polycyclic compounds with a structure based on the 3-phenyl-3,4-dihydro-2H-1-benzopyran skeleton.",
      'parent' => 2506,
    ),
    array(
      'tid' => 1613,
      'name' => "Dibenzylbutyrolactone lignans",
      'description' => "Lignan compounds containing a 3,4-dibenzyloxolan-2-one moiety.",
      'parent' => 3424,
    ),
    array(
      'tid' => 1614,
      'name' => "Neoflavonoids",
      'description' => "Compounds with a structure based on the 4-phenylchromene backbone.",
      'parent' => 261,
    ),
    array(
      'tid' => 1615,
      'name' => "Flavones",
      'description' => "Flavonoids with a structure based on the backbone of 2-phenylchromen-4-one (2-phenyl-1-benzopyran-4-one).",
      'parent' => 334,
    ),
    array(
      'tid' => 1616,
      'name' => "Transition metal nitrites",
      'description' => "Inorganic compounds in which the largest oxoanion is nitrite, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 1617,
      'name' => "Purine ribonucleoside monophosphates",
      'description' => "Nucleotides consisting of a purine base linked to a ribose to which one monophosphate group is attached.",
      'parent' => 1544,
    ),
    array(
      'tid' => 1618,
      'name' => "Purine ribonucleoside diphosphates",
      'description' => "Purine ribobucleotides with diphosphate group linked to the ribose moiety.",
      'parent' => 1544,
    ),
    array(
      'tid' => 1619,
      'name' => "Purine ribonucleoside triphosphates",
      'description' => "Purine ribobucleotides with a triphosphate group  linked to the ribose moiety.",
      'parent' => 1544,
    ),
    array(
      'tid' => 1620,
      'name' => "Pyrimidine ribonucleoside monophosphates",
      'description' => "Pyrimidine ribobucleotides with monophosphate group  linked to the ribose moiety.",
      'parent' => 2147,
    ),
    array(
      'tid' => 1621,
      'name' => "Pyrimidine ribonucleoside diphosphates",
      'description' => "Pyrimidine ribonucleotides with diphosphate group  linked to the ribose moiety.",
      'parent' => 2147,
    ),
    array(
      'tid' => 1622,
      'name' => "Pyrimidine ribonucleoside triphosphates",
      'description' => "Pyrimidine ribobucleotides with triphosphate group  linked to the ribose moiety.",
      'parent' => 2147,
    ),
    array(
      'tid' => 1623,
      'name' => "Dibenzocyclooctadiene lignans",
      'description' => "Compounds containing a dibenzocyclooctadiene moiety, which consists of two hydroxylated benzene connected by a cycloheptene ring.",
      'parent' => 1392,
    ),
    array(
      'tid' => 1624,
      'name' => "Dibenzylbutanediol lignans",
      'description' => "Lignan compounds containing a 2,3-dibenzylbutane-1,4-diol moiety.",
      'parent' => 1969,
    ),
    array(
      'tid' => 1625,
      'name' => "1-aryltetralin lactones",
      'description' => "Lignans with a structure containing the 1-aryltetralin skeleton, where the C9 and C9' atoms are joined to an oxygen atom to form a cyclopentanone.",
      'parent' => 3425,
    ),
    array(
      'tid' => 1626,
      'name' => "Phenanthrolines",
      'description' => "Aromatic polycyclic compounds containing the phenanthroline skeleton, which is a derivative of phenanthrene, and consists of two pyridine rings non-linearly joined by a benzene ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 1627,
      'name' => "Purine ribonucleoside polyphosphates",
      'description' => "Purine ribobucleotides with polyphosphate (with 4 or more phosphate) group linked to the ribose moiety.",
      'parent' => 1544,
    ),
    array(
      'tid' => 1628,
      'name' => "Pyrimidine ribonucleoside polyphosphates",
      'description' => "Pyrimidine ribobucleotides with polyphosphate (with 4 or more phosphate) group  linked to the ribose moiety.",
      'parent' => 2147,
    ),
    array(
      'tid' => 1629,
      'name' => "Benzopyrazoles",
      'description' => "Organic compounds containing a benzene ring fused to a pyrazole ring. Pyrazole is a 5-membered ring consisting of three carbon atoms and two adjacent nitrogen centers.",
      'parent' => 2,
    ),
    array(
      'tid' => 1630,
      'name' => "Chalcones and dihydrochalcones",
      'description' => "Organic compounds containing 1,3-Diphenylpropenone (benzylideneacetophenone), ArCH=CH(=O)Ar, or its derivatives formed by substitution.",
      'parent' => 3467,
    ),
    array(
      'tid' => 1631,
      'name' => "Aurone flavonoids",
      'description' => "Flavonoids containing a 2-Benzylidene-1-benzofuran-3-one based core. Aurone flavonoids provide the bright yellow color of some important ornamental flowers, such as snapdragon (Antirrhinum majus).",
      'parent' => 261,
    ),
    array(
      'tid' => 1632,
      'name' => "Flavanones",
      'description' => "Compounds containing a flavan-3-one moiety, with a structure characterized by a 2-phenyl-3,4-dihydro-2H-1-benzopyran bearing a ketone at the carbon C3.",
      'parent' => 337,
    ),
    array(
      'tid' => 1633,
      'name' => "Homoisoflavones",
      'description' => "Homoisoflavonoids with a structure based on the chromone system. Chromone is a bicyclic compound consisting of a 1-benzopyran, which bears a ketone group at the 4-position.",
      'parent' => 2507,
    ),
    array(
      'tid' => 1634,
      'name' => "Naphthofurans",
      'description' => "Compounds containing a furan ring fused to a naphthalene moiety. Furan is a 5 membered- ring aromatic ring with four carbon and one oxygen atoms. Naphthalene is a polycyclic aromatic hydrocarbon  made up of two fused benzene rings.",
      'parent' => 2,
    ),
    array(
      'tid' => 1635,
      'name' => "Pyridoxal 5'-phosphates",
      'description' => "Pyridoxals (or derivative) containing a phosphate linked to the carbaldehyde group.",
      'parent' => 28,
    ),
    array(
      'tid' => 1636,
      'name' => "Inorganic sulfuryl chlorides",
      'description' => "Inorganic compounds containing the sulfuryl chloride functional group, with the general structure ClS(R)(=O)=O (R=hetero atom).",
      'parent' => 1333,
    ),
    array(
      'tid' => 1637,
      'name' => "Serotonins",
      'description' => "Compounds containing a serotonin moiety, which consists of an indole that bears an aminoethyl a position 2 and a hydroxyl group at position 5.",
      'parent' => 183,
    ),
    array(
      'tid' => 1638,
      'name' => "1-acyl-sn-glycero-3-phosphocholines",
      'description' => "Glycerophosphocholines in which the glycerol is esterified with a fatty acid at O-1 position, and linked at position 3 to a phosphocholine.",
      'parent' => 1413,
    ),
    array(
      'tid' => 1639,
      'name' => "Tetrodotoxins",
      'description' => "Compounds structurally characterized by the presence of the tetrodotoxin skeleton, which is based on 5,7-(epoxymethanooxy)quinazolin-10-olate moiety.",
      'parent' => 485,
    ),
    array(
      'tid' => 1640,
      'name' => "Naphthopyrans",
      'description' => "Compounds containing a pyran ring fused to a naphthalene moiety. Furan is a 6 membered-ring non-aromatic ring with five carbon and one oxygen atoms. Naphthalene is a polycyclic aromatic hydrocarbon  made up of two fused benzene rings.",
      'parent' => 2,
    ),
    array(
      'tid' => 1641,
      'name' => "Naphthopyranones",
      'description' => "Compounds containing a naphthopyran skeleton where a ring carbon bears a carboxylic acid group. Naphthtopyran is made up of the pyran ring fused to a naphthalene ring system.",
      'parent' => 1640,
    ),
    array(
      'tid' => 1642,
      'name' => "Inorganic sulfuryl fluorides",
      'description' => "Inorganic compounds containing the sulfuryl fluoride functional group, with the general structure FS(R)(=O)=O (R=hetero atom).",
      'parent' => 1333,
    ),
    array(
      'tid' => 1643,
      'name' => "2-acyl-sn-glycero-3-phosphocholines",
      'description' => "Glycerophosphocholines in which the glycerol is esterified with a fatty acid at O-2 position, and linked at position 3 to a phosphocholine.",
      'parent' => 1413,
    ),
    array(
      'tid' => 1644,
      'name' => "1,2-diacylglycerols",
      'description' => "Diacylglycerols containing a glycerol acylated at positions 1 and 2.",
      'parent' => 1129,
    ),
    array(
      'tid' => 1645,
      'name' => "Depsides and depsidones",
      'description' => "Polycyclic compounds that is either a polyphenolic compound composed of two or more monocyclic aromatic units linked by an ester bond (depside), or a compound containing the depsidone structure (depsidone).",
      'parent' => 261,
    ),
    array(
      'tid' => 1646,
      'name' => "Naphthopyranone glycosides",
      'description' => "Compounds containing a carbohydrate moiety glycosidically linked to a naphthopyranone moiety.",
      'parent' => 1641,
    ),
    array(
      'tid' => 1647,
      'name' => "1,3-diacylglycerols",
      'description' => "Diacylglycerols containing a glycerol acylated at positions 1 and 3.",
      'parent' => 1129,
    ),
    array(
      'tid' => 1648,
      'name' => "Tyrosol esters",
      'description' => "Tyrosol derivatives in the hydroxyl group of the hydroxyethyl moiety is replaced an o-ester group.",
      'parent' => 139,
    ),
    array(
      'tid' => 1649,
      'name' => "Isochromanequinones",
      'description' => "Polycyclic compounds containing an isochromanequinone, which is structurally characterized by a quinone fused to an isochromane, and forming a naphtho[2,3-c]pyran-6,9-dione skeleton.",
      'parent' => 261,
    ),
    array(
      'tid' => 1650,
      'name' => "Tropones",
      'description' => "Compounds containing a tropone ring, which is a cycloheptatrienone ring bearing a ketone group.",
      'parent' => 4150,
    ),
    array(
      'tid' => 1651,
      'name' => "Biopterins and derivatives",
      'description' => "Coenzymes containing a 2-amino-pteridine-4-one derivative. They are mainly synthesized in several parts of the body, including the pineal gland.",
      'parent' => 110,
    ),
    array(
      'tid' => 1652,
      'name' => "Carbonic acid ester halides",
      'description' => "Compounds comprising the carbonic acid ester halide functional group.",
      'parent' => 364,
    ),
    array(
      'tid' => 1653,
      'name' => "Long-chain fatty acyl CoAs",
      'description' => "Acyl CoAs where the group acylated to the coenzyme A moiety is a long aliphatic chain of 13 to 21 carbon atoms.",
      'parent' => 1090,
    ),
    array(
      'tid' => 1654,
      'name' => "Benzyl esters",
      'description' => "Aromatic compounds containing an esterified benzyl group.",
      'parent' => 1097,
    ),
    array(
      'tid' => 1655,
      'name' => "Carbonic acid monoesters",
      'description' => "Compounds comprising the carbonic acid monoester functional group.",
      'parent' => 364,
    ),
    array(
      'tid' => 1656,
      'name' => "Acetals",
      'description' => "Compounds having the structure R2C(OR')2 ( R' not Hydrogen) and thus diethers of geminal diols. Originally, the term was confined to derivatives of aldehydes (one R = H), but it now applies equally to derivatives of ketones (neither R = H ). Mixed acetals have different R' groups.",
      'parent' => 254,
    ),
    array(
      'tid' => 1657,
      'name' => "Carboxylic acid imides",
      'description' => "Carboxylic acid derivatives containing two carbonyl groups where the carbon atoms are both linked to the same nitrogen atom.",
      'parent' => 1093,
    ),
    array(
      'tid' => 1658,
      'name' => "N-substituted carboxylic acid imides",
      'description' => "Compounds comprising an N-substituted carboxylic acid imide group, with the general structure R1N(C(R2)=O)C(R3)=O (R2,R3=H, alkyl, aryl; R1=Anything but H).",
      'parent' => 1657,
    ),
    array(
      'tid' => 1659,
      'name' => "N-unsubstituted carboxylic acid imides",
      'description' => "Compounds comprising an N-unsubstituted carboxylic acid imide group, with the general structure R1N(C(R2)=O)C(R3)=O (R1,R2,R3=H, alkyl, aryl).",
      'parent' => 1657,
    ),
    array(
      'tid' => 1660,
      'name' => "Acyl cyanides",
      'description' => "Organic compounds containing the cyanide functional group attached to an alkyl chain through an ester bond.",
      'parent' => 362,
    ),
    array(
      'tid' => 1661,
      'name' => "Secondary alcohols",
      'description' => "Compounds containing a secondary alcohol functional group, with the general structure HOC(R)(R') (R,R'=alkyl, aryl).",
      'parent' => 129,
    ),
    array(
      'tid' => 1662,
      'name' => "Primary carboxylic acid amides",
      'description' => "Compounds comprising primary carboxylic acid amide functional group, with the general structure RC(=O)NH2.",
      'parent' => 475,
    ),
    array(
      'tid' => 1663,
      'name' => "Secondary carboxylic acid amides",
      'description' => "Compounds containing a secondary carboxylic acid amide functional group, with the general structure RC(=O)N(R')H (R,R'=alkyl, aryl).",
      'parent' => 475,
    ),
    array(
      'tid' => 1664,
      'name' => "Tertiary carboxylic acid amides",
      'description' => "Compounds containing an amide derivative of carboxylic acid, with the general structure RN(R1)C(R2)=O (R1-R2 any atom but H).",
      'parent' => 475,
    ),
    array(
      'tid' => 1665,
      'name' => "Enolates",
      'description' => "Deprotonated anions of enols. They have diverse forms with either of the general structure [R1]C([R2])=C([R3])[O-], RC([CH2-])=O, or R1C(R1)=COM (M=metal).",
      'parent' => 323,
    ),
    array(
      'tid' => 1666,
      'name' => "Thiohemiaminal derivatives",
      'description' => "Compounds containing the thiohemiaminal group with the general structure R1SC(R2)(R3)N(R4)R5 (R1-R5=H, alkyl, aryl).",
      'parent' => 4,
    ),
    array(
      'tid' => 1667,
      'name' => "Carboxylic acid amide acetals",
      'description' => "Carboxylic acid derivatives two hydroxyl groups attached to a carbon atom, which in turn is linked to a nitrogen atom(substituted or not).",
      'parent' => 1236,
    ),
    array(
      'tid' => 1668,
      'name' => "Organic diazonium salts",
      'description' => "Organic compounds comprising the diazonium functional group, with the general structure R-N=N+.",
      'parent' => 278,
    ),
    array(
      'tid' => 1669,
      'name' => "Long-chain ceramides",
      'description' => "Ceramides bearing a long chain fatty acid.",
      'parent' => 1418,
    ),
    array(
      'tid' => 1670,
      'name' => "Tertiary alcohols",
      'description' => "Compounds in which a hydroxy group, -OH, is attached to a saturated carbon atom R3COH (R not H ).",
      'parent' => 129,
    ),
    array(
      'tid' => 1671,
      'name' => "Physalins and derivatives",
      'description' => "Steroidal constituents of Physalis plants which possess an unusual 13,14-seco-16,24-cyclo-steroidal ring skeleton (where the bond that is normally present between the 13 and 14 positions in other steroids is broken while a new bond between positions 16 and 24 is formed).",
      'parent' => 258,
    ),
    array(
      'tid' => 1672,
      'name' => "Organic thiocarbonic acid derivatives",
      'description' => "Organic compounds containing the thiocarbonic acid structure or a derivative thereof.",
      'parent' => 1198,
    ),
    array(
      'tid' => 1673,
      'name' => "Ketimines",
      'description' => "Organic compounds bearing the ketimine functional group, with the general structure R2C=NR' ( R is not a hydrogen ).",
      'parent' => 117,
    ),
    array(
      'tid' => 1674,
      'name' => "Tropolones",
      'description' => "Compounds containing tropone ring with a hydroxyl group at ring position 2.",
      'parent' => 1650,
    ),
    array(
      'tid' => 1675,
      'name' => "Aminocyclitol glycosides",
      'description' => "Organic compounds containing an amicocyclitol moiety glycosidically linked to a carbohydrate moiety. There are two major classes of aminoglycosides containing a 2-streptamine core. They are called 4,5- and 4,6-disubstituted 2-deoxystreptamines.",
      'parent' => 282,
    ),
    array(
      'tid' => 1676,
      'name' => "Phosphatidylinositol-4,5-bisphosphates",
      'description' => "Phosphatidylinositol bisphosphates in which the two phosphate groups are at C-4 and C-5 of the inositol moiety.",
      'parent' => 1139,
    ),
    array(
      'tid' => 1677,
      'name' => "1-acyl-sn-glycero-3-phosphoethanolamines",
      'description' => "Glycerophoethanolamines in which the glycerol is esterified with a fatty acid at O-1 position, and linked at position 3 to a phosphoethanolamine.",
      'parent' => 1405,
    ),
    array(
      'tid' => 1678,
      'name' => "Acyclic allenes",
      'description' => "Acyclic hydrocarbons (and by extension, derivatives formed by substitution) having two double bonds from one carbon atom to two others.",
      'parent' => 16,
    ),
    array(
      'tid' => 1679,
      'name' => "Cyclic allenes",
      'description' => "Cyclic hydrocarbons (and by extension, derivatives formed by substitution) having two double bonds from one carbon atom to two others.",
      'parent' => 16,
    ),
    array(
      'tid' => 1680,
      'name' => "2-acyl-sn-glycero-3-phosphoethanolamines",
      'description' => "Glycerophoethanolamines in which the glycerol is esterified with a fatty acid at O-2 position, and linked at position 3 to a phosphoethanolamine.",
      'parent' => 1405,
    ),
    array(
      'tid' => 1681,
      'name' => "1-acyl-glycerol-3-phosphoserines",
      'description' => "Monoacylglycerol-3-phosphoserines with a fatty acyl chain linked to the O1-atom of the glycerol moiety.",
      'parent' => 1377,
    ),
    array(
      'tid' => 1682,
      'name' => "2-acyl-glycerol-3-phosphoserines",
      'description' => "Monoacylglycerol-3-phosphoserines with a fatty acyl chain linked to the O2-atom of the glycerol moiety.",
      'parent' => 1377,
    ),
    array(
      'tid' => 1683,
      'name' => "Monoacylglycerophosphates",
      'description' => "Monacylglyerophosphates in which the glycerol moiety is esterified at only position, and is attached to a phosphate group.",
      'parent' => 2214,
    ),
    array(
      'tid' => 1684,
      'name' => "1-acylglycerol-2-phosphates",
      'description' => "Monacylglyerophosphates in which the glycerol moiety is esterified at position 1 and attached to a phosphate group through the O-2 atom.",
      'parent' => 1683,
    ),
    array(
      'tid' => 1685,
      'name' => "1-acylglycerol-3-phosphates",
      'description' => "Lysophosphatidic acids where the glycerol is esterified with a fatty acid at O-1 position.",
      'parent' => 1320,
    ),
    array(
      'tid' => 1686,
      'name' => "Cucurbitacins",
      'description' => "Polycyclic compounds containing the tetracyclic cucurbitane nucleus skeleton, 19-(10->9b)-abeo-10alanost-5-ene (also known as 9b-methyl-19-nor lanosta-5-ene), with a variety of oxygenation functionalities at different positions.",
      'parent' => 258,
    ),
    array(
      'tid' => 1687,
      'name' => "Cucurbitacin glycosides",
      'description' => "Polycyclic compounds containing a carbohydrate derivative glycosidically linked to a curcubitane nucleus.",
      'parent' => 2364,
    ),
    array(
      'tid' => 1688,
      'name' => "2-acylglycerol-3-phosphates",
      'description' => "Lysophosphatidic acids where the glycerol is esterified with a fatty acid at O-2 position.",
      'parent' => 1320,
    ),
    array(
      'tid' => 1689,
      'name' => "Long-chain 1-acylglycerol-3-phosphates",
      'description' => "1-Acylglycerophosphates in which a long-chain fatty acid is esterified to the glycerol moiety.",
      'parent' => 1685,
    ),
    array(
      'tid' => 1690,
      'name' => "Polysaccharide phosphates",
      'description' => "Carbohydrates containing more than 10 sugar units, one of which bear one or more phosphate groups.",
      'parent' => 1539,
    ),
    array(
      'tid' => 1691,
      'name' => "Steroid esters",
      'description' => "Compounds containing a steroid moiety which bears a carboxylic acid ester group.",
      'parent' => 258,
    ),
    array(
      'tid' => 1692,
      'name' => "Sulfated steroids",
      'description' => "Sterol lipids containing a sulfate group attached to the steroid skeleton.",
      'parent' => 258,
    ),
    array(
      'tid' => 1693,
      'name' => "Aminotriazines",
      'description' => "Organic compounds containing an amino group attached to a triazine ring.",
      'parent' => 98,
    ),
    array(
      'tid' => 1694,
      'name' => "Aminopyrazines",
      'description' => "Organic compounds containing an amino group attached to a pyrazine ring.",
      'parent' => 67,
    ),
    array(
      'tid' => 1695,
      'name' => "Oxetane amino acids and derivatives",
      'description' => "Sugar amino acids containing an oxetane ring between the carboxy- and the amino terminals of the amino acid chain.",
      'parent' => 1366,
    ),
    array(
      'tid' => 1696,
      'name' => "Furanoid amino acids and derivatives",
      'description' => "Sugar amino acids containing a furan ring.",
      'parent' => 1366,
    ),
    array(
      'tid' => 1697,
      'name' => "Pyranoid amino acids and derivatives",
      'description' => "Compounds containing a (hydro)pyran ring bearing unprotected amino and carboxylic acid functionalities.",
      'parent' => 1366,
    ),
    array(
      'tid' => 1698,
      'name' => "Bicyclic amino acids and derivatives",
      'description' => "Sugar amino acids in which the amino acid is attached to or partly borne within a bicyclic ring system.",
      'parent' => 1366,
    ),
    array(
      'tid' => 1699,
      'name' => "Glycopeptides and derivatives",
      'description' => "Compounds in which a carbohydrate component is linked to a peptide through any covalent bond.",
      'parent' => 348,
    ),
    array(
      'tid' => 1700,
      'name' => "Spirostanes and derivatives",
      'description' => "Steroidal alkaloids with a structure containing a spirostane skeleton. Spirostanes are 16b,22:22,26-diepoxycholestanes, or 22,26-epoxyfurostans. The sixth ring so formed is known as ring F. Chemically, the spiro centre at C-22 has the character of an internal acetal derived from a 16b, 26-dihydroxycholestan-22-one.",
      'parent' => 258,
    ),
    array(
      'tid' => 1701,
      'name' => "Furostanes and derivatives",
      'description' => "Compounds containing or derived from the steroid parent furostane, which is a 16b,22-epoxycholestane derivative, the extra ring being labeled as\nring E.",
      'parent' => 258,
    ),
    array(
      'tid' => 1702,
      'name' => "Furospirostanes and derivatives",
      'description' => "Heterocyclic steroids containing a furospirostane moiety, which a skeleton characterized by the presence of a 1,6-dioxaspiro[4.4]nonane ring system and an androstane moiety.",
      'parent' => 258,
    ),
    array(
      'tid' => 1703,
      'name' => "Solanidines and derivatives",
      'description' => "Steroids with a structure based on the solanidane skeleton.  Solanidane arises from the conversion of a cholestane side-chain into a bicyclic system.",
      'parent' => 2724,
    ),
    array(
      'tid' => 1704,
      'name' => "Spirosolanes and derivatives",
      'description' => "Steroidal alkaloids with a structure containing a spirosolane skeleton. Siporosolane is a polycyclic compound that is characterized by a 1-oxa-6-azaspiro[4.5]decane moiety where the oxolane ring is fused to a docosahydronaphth[2,1:4',5']indene ring system. Spirosolane arises from the conversion of a cholestane side-chain into a bicyclic system containing a piperidine and a tetrahydrofuran ring.",
      'parent' => 2724,
    ),
    array(
      'tid' => 1705,
      'name' => "Gingerols",
      'description' => "Compounds containing a gingerol moiety, which is structurally characterized by a 4-hydroxy-3-methoxyphenyl group substituted at the C6 carbon atom by a 5-hydroxy-alkane-3-one.",
      'parent' => 190,
    ),
    array(
      'tid' => 1706,
      'name' => "Gingerdiols",
      'description' => "Compounds containing a gingerdiol moiety, which is structurally characterized by a 4-hydroxy-3-methoxyphenyl group substituted at the C6 carbon atom by an alkane-2,4-diol.",
      'parent' => 190,
    ),
    array(
      'tid' => 1707,
      'name' => "Gingerdiones",
      'description' => "Compounds containing a gingerdione moiety, which is structurally characterized by a 4-hydroxy-3-methoxyphenyl group substituted at the C6 carbon atom by an alkane-2,4-dione.",
      'parent' => 190,
    ),
    array(
      'tid' => 1708,
      'name' => "Shogaols",
      'description' => "Ginger derivatives containing a shogaol moiety, which consists of a benzene ring bearing a dec-4-en-3-one moiety, a methoxyphenyl group, a hydroxyl group and at positions 1, 3, and 4, respectively.",
      'parent' => 190,
    ),
    array(
      'tid' => 1709,
      'name' => "Paradols",
      'description' => "Compounds containing a paradol moiety, which is consists of a benzene ring with a decan-3-one moiety, a methoxyl group, and a hydroxyl group at positions 1,3, and 4 respectively.",
      'parent' => 190,
    ),
    array(
      'tid' => 1710,
      'name' => "Hydrolyzable tannins",
      'description' => "Tannins with a structure characterized by either of the following models. In model 1, the structure contains galloyl units (in some cases, shikimic acid units) that are linked to diverse polyol carbohydrate-, catechin-, or triterpenoid units. In model 2, contains at least two galloyl units C-C coupled to each other, and do not contain a glycosidically linked catechin unit.",
      'parent' => 238,
    ),
    array(
      'tid' => 1711,
      'name' => "Phlorotannins",
      'description' => "Tannins which is formed by oligomerization of phloroglucinol. Phloroglucinol is an aromatic compound, which consists of a benzene ring bearing one hydroxyl group at the 1-,3-, and 5-positions.",
      'parent' => 238,
    ),
    array(
      'tid' => 1712,
      'name' => "Complex tannins",
      'description' => "Tannins made of a catechin bound to a gallotannin or elagitannin.",
      'parent' => 238,
    ),
    array(
      'tid' => 1713,
      'name' => "Beta hydroxy acids and derivatives",
      'description' => "Compounds containing a carboxylic acid substituted with a hydroxyl group on the C3 carbon atom.",
      'parent' => 472,
    ),
    array(
      'tid' => 1714,
      'name' => "Hydroxyquinolones",
      'description' => "Compounds containing a quinoline moiety bearing a hydroxyl group and a ketone. Quinoline or benzo[b]pyridine is a bicyclic compound that consists of benzene fused to a pyridine.",
      'parent' => 56,
    ),
    array(
      'tid' => 1715,
      'name' => "Hydroquinolines",
      'description' => "Derivatives of  quinoline in which in which at least one double bond in the quinoline moiety are reduced by adding two hydrogen atoms.",
      'parent' => 1253,
    ),
    array(
      'tid' => 1716,
      'name' => "Hydroquinolones",
      'description' => "Compounds containing a hydrogenated quinoline bearing a ketone group.",
      'parent' => 56,
    ),
    array(
      'tid' => 1717,
      'name' => "Oxaborine derivatives",
      'description' => "Compounds containing a six-member aliphatic heterocycle made up of one oxygen atom, a boron atom, and three carbon atoms.",
      'parent' => 2052,
    ),
    array(
      'tid' => 1718,
      'name' => "Other glycerophosphoinositol phosphates",
      'description' => "Glycerophosphoinositol phosphates not belonging to Lysophosphatidylinositol Phosphates, or the Phosphatidylinositol Phosphates.",
      'parent' => 2220,
    ),
    array(
      'tid' => 1719,
      'name' => "Diacylglycerophosphodiradylglycerols",
      'description' => "Glycerophosphodiradylglycerols that carry exactly two acyl chains attached to the glycerol moiety through ester linkages.",
      'parent' => 2216,
    ),
    array(
      'tid' => 1720,
      'name' => "Lysophosphatidylglycerophosphates",
      'description' => "Glycerophosphates (molecules containing a phosphate group linked to a glycerol) where the glycerol is esterified with one fatty acid.",
      'parent' => 2217,
    ),
    array(
      'tid' => 1721,
      'name' => "Phosphoglycosphingolipids",
      'description' => "Sphingolipids containing a carbohydrate linked to the sphingoid base (sphingosine, sphinganine) through a phosphate group.",
      'parent' => 256,
    ),
    array(
      'tid' => 1722,
      'name' => "Fatty alcohol esters",
      'description' => "Ester derivatives of a fatty alcohol.",
      'parent' => 3909,
    ),
    array(
      'tid' => 1723,
      'name' => "Wax esters",
      'description' => "Mixtures of long-chain apolar lipids. They are usually esters of an alcohol other than glycerol and a long chain acid.",
      'parent' => 324,
    ),
    array(
      'tid' => 1724,
      'name' => "Pyrethrins",
      'description' => "Pyrethroids with a structure based on a skeleton that is characterized by the presence of a chrysanthemic acid esterified with a cyclopentenone derivative.",
      'parent' => 1461,
    ),
    array(
      'tid' => 1725,
      'name' => "Chloropropanol esters",
      'description' => "Compounds containing an ester derivative of chloropropanol.",
      'parent' => 324,
    ),
    array(
      'tid' => 1726,
      'name' => "3-MCPD monoesters",
      'description' => "Compounds containing a 3-monochloropropane-1,2-diol skeleton that is esterified either at the C1 or C3 terminal carbon atom only.",
      'parent' => 1725,
    ),
    array(
      'tid' => 1727,
      'name' => "Diacylglycosylglycerophospholipids",
      'description' => "Glycosylglycerophospholipids, where the glycerol moiety is esterified with two fatty acyl chains.",
      'parent' => 1459,
    ),
    array(
      'tid' => 1728,
      'name' => "Quinacridines",
      'description' => "Compounds containing a quinacridine moiety, which consists of a quinoline fused to an acridine.",
      'parent' => 274,
    ),
    array(
      'tid' => 1729,
      'name' => "Oxepanes",
      'description' => "Compounds containing an oxepane ring, which is a seven-member saturated aliphatic heterocycle with one oxygen and six carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 1730,
      'name' => "Piperidinylpyridines",
      'description' => "Compounds containing a piperidinylpyridine moiety, which consists of a piperidine linked to a pyridine by a single bond that is not pat of a ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 1731,
      'name' => "Dioxopiperazines",
      'description' => "Compounds containing a piperazine ring bearing two ketone groups. These include the alkaloid class of naturally occurring 2,5-dioxopiperazines.",
      'parent' => 189,
    ),
    array(
      'tid' => 1732,
      'name' => "Thiodioxopiperazines",
      'description' => "Compounds containing a piperazine ring which bears two ketone groups and a sulfanyl group.",
      'parent' => 3684,
    ),
    array(
      'tid' => 1733,
      'name' => "Pyrroloindoles",
      'description' => "Compounds containing a pyrroloindole moiety, which is a tricyclic heterocycle which consists of a pyrrole ring fused to an indole. Pyrrole is 5-membered ring consisting of four carbon atoms and one nitrogen atom. Indole is a bicyclic  compound consisting of a six-membered benzene ring fused to a five-membered nitrogen-containing pyrrole ring.",
      'parent' => 211,
    ),
    array(
      'tid' => 1734,
      'name' => "Pyrroloquinolines",
      'description' => "Compounds containing a pyrroloquinoline moiety, which consists of a pyrrole ring fused to a quinoline.",
      'parent' => 1253,
    ),
    array(
      'tid' => 1735,
      'name' => "Furanochromones",
      'description' => "Polycyclic aromatic compounds containing a furan ring fused to a 1-benzopyran-4-one ring system.",
      'parent' => 144,
    ),
    array(
      'tid' => 1736,
      'name' => "Benzochromones",
      'description' => "Organic compounds containing a benzene ring fused to the benzene moiety of chromone (1,4-benzopyrone).",
      'parent' => 144,
    ),
    array(
      'tid' => 1737,
      'name' => "Flavonoid C-glycosides",
      'description' => "Compounds containing a carbohydrate moiety which is C-glycosidically linked to the 2-phenylchromen-4-one flavonoid backbone.",
      'parent' => 1111,
    ),
    array(
      'tid' => 1738,
      'name' => "Aurone O-glycosides",
      'description' => "Aurone flavonoids containing a carbohydrate moiety O-glycosidically bound to the aurone skeleton.",
      'parent' => 1583,
    ),
    array(
      'tid' => 1739,
      'name' => "Chalcone- and dihydrochalcone O-glycosides",
      'description' => "Compounds containing a O-glycosylated chalcone or dihydrochalcone moiety.",
      'parent' => 1583,
    ),
    array(
      'tid' => 1740,
      'name' => "Organic antimonates",
      'description' => "Organic compounds containing the antimonate oxoanion, with the formula Sb(OH)6-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1741,
      'name' => "Rotenoid O-glycosides",
      'description' => "Compounds containing a carbohydrate moiety glycosidically linked to the rotenoid backbone at the C8-position.",
      'parent' => 1583,
    ),
    array(
      'tid' => 1742,
      'name' => "Coumaronochromones",
      'description' => "Polycyclic aromatic compounds containing a 1-benzopyran-4-one and a benzofuran, where the furan ring and the pyran ring are fused together.",
      'parent' => 2506,
    ),
    array(
      'tid' => 1743,
      'name' => "Coumarin glycosides",
      'description' => "Aromatic compounds containing a carbohydrate moiety glycosidically bound to a coumarin moiety.",
      'parent' => 145,
    ),
    array(
      'tid' => 1744,
      'name' => "Cyanolipids",
      'description' => "Lipids containing a five-carbon backbone that comprises a nitrile moiety together with a methylene group or double bond, and one or two hydroxyl groups. Cyanolipids are divided in four categories (type I-IV).",
      'parent' => 324,
    ),
    array(
      'tid' => 1745,
      'name' => "Type 1 cyanolipids",
      'description' => "Diesters of 1-cyano-2-hydroxymethylprop-2-en-1-ol.",
      'parent' => 1744,
    ),
    array(
      'tid' => 1746,
      'name' => "Type 2 cyanolipids",
      'description' => "Diesters of 1-cyano-2-hydroxymethylprop-1-en-3-ol.",
      'parent' => 1744,
    ),
    array(
      'tid' => 1747,
      'name' => "Type 3 cyanolipids",
      'description' => "Monoesters of 1-cyano-2-hydroxymethylprop-1-ene.",
      'parent' => 1744,
    ),
    array(
      'tid' => 1748,
      'name' => "Type 4 cyanolipids",
      'description' => "Monoesters of 1-cyano-2-methylprop-2-en-1-ol.",
      'parent' => 1744,
    ),
    array(
      'tid' => 1749,
      'name' => "Lysobisphosphatidic acids",
      'description' => "Lipids with a structure based on a bis(monoacylglycero)phosphate skeleton.",
      'parent' => 256,
    ),
    array(
      'tid' => 1750,
      'name' => "Semilysobisphosphatidic acids",
      'description' => "Bisphosphatidic acid analogues with three moles of fatty acid per mole of lipid.",
      'parent' => 256,
    ),
    array(
      'tid' => 1751,
      'name' => "Bisphosphatidic acids",
      'description' => "Organic compounds containing two 1,2-diacylglycerol moieties linked to the O1 and O4 oxygen atoms of a phosphate group.",
      'parent' => 256,
    ),
    array(
      'tid' => 1752,
      'name' => "8,2'-cyclic purine nucleotides",
      'description' => "Purine nucleotides in which the atom linked to the C2 carbon atom of the ribose moiety is bonded the C8 carbon atom of the purine moiety.",
      'parent' => 1491,
    ),
    array(
      'tid' => 1753,
      'name' => "Benzoylindoles",
      'description' => "Organic compounds containing an indole attached to a benzoyl moiety through the acyl group.",
      'parent' => 211,
    ),
    array(
      'tid' => 1754,
      'name' => "Simplexides",
      'description' => "Glycolipids composed of a long chain secondary alcohol glycosylated by an alpha-D-glucosyl-(1->4)-beta-D-galactosyl disaccharide residue.",
      'parent' => 2125,
    ),
    array(
      'tid' => 1755,
      'name' => "Diterpene glycosides",
      'description' => "Diterpenoids in which an isoprene unit is glycosylated.",
      'parent' => 2049,
    ),
    array(
      'tid' => 1756,
      'name' => "Steviol glycosides",
      'description' => "Prenol lipids containing a carbohydrate moiety glycosidically linked to a steviol (a diterpenoid based on a 13-Hydroxykaur-16-en-18-oic acid) moiety.",
      'parent' => 1755,
    ),
    array(
      'tid' => 1757,
      'name' => "Colensane and clerodane diterpenoids",
      'description' => "Diterpenoids with a structure based on the clerodane or the colensane skeleton. Clerodanes arise from labdanes by two methyl migrations.",
      'parent' => 1551,
    ),
    array(
      'tid' => 1758,
      'name' => "Dalbergiones",
      'description' => "Quinone derivatives containing a dalbergione moiety, which consists of a 1-4 quinone conjugated to a phenyl group  at ring carbon 2.",
      'parent' => 1614,
    ),
    array(
      'tid' => 1759,
      'name' => "Furanoflavones",
      'description' => "Polycyclic aromatic compounds containing a furan ring fused to a flavan-3-one.",
      'parent' => 1615,
    ),
    array(
      'tid' => 1760,
      'name' => "Dolabellane and neodolabellane diterpenoids",
      'description' => "Diterpenoids with a structure based on the dolabellane skeleton (3a,6,10-trimethyl-1-(propan-2-yl)-cyclopenta[11]annulene) or the neodolabellane skeleton.",
      'parent' => 1551,
    ),
    array(
      'tid' => 1761,
      'name' => "Kavalactones",
      'description' => "Lactones, which is structurally characterized by a benzene ring and a pyranone moiety, linked to each other to form a 4-methoxy-6-(2-phenylethyl)-2H-pyran-2-one skeleton.",
      'parent' => 261,
    ),
    array(
      'tid' => 1762,
      'name' => "Pyrroloacridines",
      'description' => "Compounds containing a pyrroloacridine moiety, which is a tetracyclic heterocycle which consists of a pyrrole ring fused to an acridine.",
      'parent' => 274,
    ),
    array(
      'tid' => 1763,
      'name' => "Pyridoacridines",
      'description' => "Compounds containing a pyridoacridine ring system, which consists of a pyridine fused to an acridine.",
      'parent' => 274,
    ),
    array(
      'tid' => 1764,
      'name' => "Pyridinium derivatives",
      'description' => "Compounds containing a pyridinium ring, which is the cationic form of pyridine.",
      'parent' => 89,
    ),
    array(
      'tid' => 1765,
      'name' => "Rhamnolipids",
      'description' => "Glycolipids structurally characterized by a glycosyl head group, in this case a rhamnose moiety, and a 3-(hydroxyalkanoyloxy)alkanoic acid (HAA) fatty acid tail.",
      'parent' => 1766,
    ),
    array(
      'tid' => 1766,
      'name' => "Fatty acyl glycosides",
      'description' => "Compounds containing fatty acyl chain linked to a carbohydrate moiety through a glycosidic bond. Fatty acyl glycosides are composed of a glycosyl moiety (one or several units) linked to one hydroxyl group of a fatty alcohol or of a phosphorylated alcohol (phosphoprenols), a hydroxy fatty acid or to one carboxyl group of a fatty acid (ester linkage) or to an amino alcohol.",
      'parent' => 3909,
    ),
    array(
      'tid' => 1767,
      'name' => "Gibberellins",
      'description' => "Diterpenoids containing the gibberellane skeleton ((8S)-4,4,8-trimethyl-13-methylidenetetracyclo[10.2.1.0^{1,9}.0^{3,8}]pentadecane), an aliphatic four-ring system.",
      'parent' => 1551,
    ),
    array(
      'tid' => 1768,
      'name' => "Ginkgolides and bilobalides",
      'description' => "Diterpene lactones with a structure based either on the gingkolide or the bilobalide skeleton. The ginkgolide skeleton is a very rigid structure consisting of hexacyclic C20 trilactone. The cis-fused F/A/D/C ring junction forms an empty semi-ball hole, the D ring contains a cage form tetrahydrofuran ring which occupies the center of the empty hole, and the oxygen atoms of the D,C and F ring and 10-hydroxyl group consist of an analogous crown ether structure.",
      'parent' => 1538,
    ),
    array(
      'tid' => 1769,
      'name' => "Pyrroloindolizines",
      'description' => "Compounds containing a pyrroloindolizine moiety, which consists of a pyrrole ring fused to an indolizine.",
      'parent' => 216,
    ),
    array(
      'tid' => 1770,
      'name' => "Guaianolides and derivatives",
      'description' => "Diterpene lactones with a structure characterized by the presence of a gamma-lactone fused to a guaiane, forming 3,6,9-trimethyl-azuleno[4,5-b]furan-2-one or a derivative.",
      'parent' => 1543,
    ),
    array(
      'tid' => 1771,
      'name' => "Germacranolides and derivatives",
      'description' => "Sesquiterpene lactones with a structure based on the germacranolide skeleton, characterized by a gamma lactone fused to a 1,7-dimethylcyclodec-1-ene moiety.",
      'parent' => 1543,
    ),
    array(
      'tid' => 1772,
      'name' => "Eudesmanolides, secoeudesmanolides, and derivatives",
      'description' => "Terpenoids with a structure based on the eudesmanolide (a 3,5a,9-trimethyl-naphtho[1,2-b]furan-2-one derivative) or secoeudesmanolide (a 3,6-dimethyl-5-(pentan-2-yl)-1-benzofuran-2-one derivative) skeleton.",
      'parent' => 1543,
    ),
    array(
      'tid' => 1773,
      'name' => "Glycosylmonoacylglycerols",
      'description' => "Glycosylglycerols carrying exactly one fatty acyl chain attached to the glycerol moiety through an ester linkage.",
      'parent' => 3819,
    ),
    array(
      'tid' => 1774,
      'name' => "Brassinolides and derivatives",
      'description' => "Cholestane based steroid lactones containing benzo[c]indeno[5,4-e]oxepin-3-one.",
      'parent' => 1125,
    ),
    array(
      'tid' => 1775,
      'name' => "Amaryllidaceae alkaloids",
      'description' => "Isoquinoline alkaloids with a skeleton deriving from lycorine, norbelladine, homolycorine, hemanthamine, crinine, tazettine, montanine, plicamine, galanthindole, galanthamine, gracilline, among others. Amaryllidaceae Alkaloids represent a large group of biogenetically related isoquinoline alkaloids that are found exclusively in plants belonging to this family of Amaryllidaceae. This group of alkaloids is also derived from two tyrosine units which combine, with loss of one carbon atom, to give a benzylphenylethylamine precursor unit, e.g. Norbelladine, which by various oxidative cyclisation processes, prominent among which are phenol oxidative coupling reactions, can give rise to the nine major skeletal groups.",
      'parent' => 279,
    ),
    array(
      'tid' => 1776,
      'name' => "Melleolides and analogues",
      'description' => "Compounds with a structure characterized by the presence of a 2-hydroxy-4-methoxy-6-methylbenzoic acid derivative linked to a 3,6,6,7b-tetramethyl-cyclobuta[e]indene moiety.",
      'parent' => 1777,
    ),
    array(
      'tid' => 1777,
      'name' => "Illudanes and illudins",
      'description' => "Sesquiterpenoids containing either the illudane moiety (based on a 3,6,6,7b-tetramethyl-decahydro-1H-cyclobuta[e]indene ring system), the illudin moiety (2',2',4',6'-tetramethyl-octahydrospiro[cyclopropane-1,5'-indene]), or a derivative thereof.",
      'parent' => 1550,
    ),
    array(
      'tid' => 1778,
      'name' => "O-quinodimethanes",
      'description' => "Compounds containing a benzene ring conjugated to two methylidene groups at carbon atoms 1 and 2, respectively.",
      'parent' => 1579,
    ),
    array(
      'tid' => 1779,
      'name' => "Guanidinobenzoic acids and derivatives",
      'description' => "Aromatic compounds containing a guanidine group linked to the benzene ring of a benzoic acid (or a derivative thereof).",
      'parent' => 281,
    ),
    array(
      'tid' => 1780,
      'name' => "Dihydrofuranoquinolines",
      'description' => "Organic heterocyclic compounds with a structure based on the dihydrofuranoquinoline skeleton.",
      'parent' => 1253,
    ),
    array(
      'tid' => 1781,
      'name' => "Aromadendrane sesquiterpenoids",
      'description' => "Sesquiterpenoids with a structure based on an aromadendrane (a cyclopropa[e]azulene derivative) skeleton. Some aromadendrane sesquiterpenoids are found in essential oils. Certain aromadendrane Sesquiterpenoids from the Leaves of Xylopia brasiliensis were found to possess antifungal activities.",
      'parent' => 1550,
    ),
    array(
      'tid' => 1782,
      'name' => "Erythrina alkaloids",
      'description' => "Organic compounds with a structure based on a backbone containing a indole-6-ol sharing its nitrogen atom with an isoquinoline ring system.",
      'parent' => 279,
    ),
    array(
      'tid' => 1783,
      'name' => "Curan alkaloids",
      'description' => "Compounds containing the pentacyclic curan skeleton, which is structurally characterized by the presence of a pentacyclic 3,5-ethanopyrrolo[2,3-d]carbazole framework.",
      'parent' => 279,
    ),
    array(
      'tid' => 1784,
      'name' => "Thiaergolines",
      'description' => "Ergoline analogues, obtained by replacing the oxygen atom in the indole moiety (of the ergoline backbone) by a sulfur atom.",
      'parent' => 279,
    ),
    array(
      'tid' => 1785,
      'name' => "Oxamorphinans",
      'description' => "Polycyclic compounds with a four-ring skeleton with three condensed six-member rings forming a partially hydrogenated naphthopyran moiety, one of which is aromatic while the two others are alicyclic.",
      'parent' => 279,
    ),
    array(
      'tid' => 1786,
      'name' => "Yohimbine alkaloids",
      'description' => "Alkaloids containing the pentacyclic yohimban skeleton. The Yohimbinoid alkaloids contain a carbocyclic ring E arising through C-17 to C-18 bond formation in a corynantheine precursor.",
      'parent' => 279,
    ),
    array(
      'tid' => 1787,
      'name' => "Ochratoxins and related substances",
      'description' => "A group of chemically related metabolites containing a 3,4-dihydro-3-methylisocoumarin moiety linked through a carboxyl group to L-beta-phenylalanine by a secondary amine bond.",
      'parent' => 261,
    ),
    array(
      'tid' => 1788,
      'name' => "Zearalenones",
      'description' => "Macrolides which contains a fourteen-member lactone fused to 1,3-dihydroxybenzene.",
      'parent' => 147,
    ),
    array(
      'tid' => 1789,
      'name' => "Trichothecenes",
      'description' => "Sesquiterpene mycotoxins structurally characterized by the presence of an epoxide ring and a benzopyran derivative with a variant number of hydroxyl, acetyl, or other substituents. The most important structural features causing the biological activities of trichothecenes are the 12,13-epoxy ring, the presence of hydroxyl or acetyl groups at appropriate positions on the trichothecene nucleus and the structure and position of the side-chain.",
      'parent' => 1550,
    ),
    array(
      'tid' => 1790,
      'name' => "Epipolythiodioxopiperazines",
      'description' => "Compounds containing an epipolythiodioxopiperazine moiety, which consists of a 2,3-dithia-5,7-diazabicyclo[2.2.2]octane-6,8-dione ring system. One distinct characteristics of Epipolythiodioxopiperazines is the presence of unique di- or polysulfide bridges.",
      'parent' => 1732,
    ),
    array(
      'tid' => 1791,
      'name' => "Gliotoxins",
      'description' => "Polycyclic compounds containing the gliotoxin skeleton, which is structurally characterized by a epipolythiodioxopiperazine moiety fused to the pyrrolidine ring of an indol-7-ol derivative.",
      'parent' => 1790,
    ),
    array(
      'tid' => 1792,
      'name' => "Fumonisins",
      'description' => "Diesters of propane-1,2,3-tricarboxylic acid (TCA) and similar long-chain aminopolyol backbones (for FB1: 2S-amino-12S,16R-dimethyl-3S,5R,10R,14S,15R-pentahydroxyeicosane). Structurally, fumonisins resemble the sphingoid bases sphinganine (SA) and sphingosine (SO) to which TCA groups have been added at the C-14 and C-15 positions.",
      'parent' => 265,
    ),
    array(
      'tid' => 1793,
      'name' => "Ellipticine alkaloids",
      'description' => "Compounds containing a pyrido[4,3-b]carbazole moiety.",
      'parent' => 279,
    ),
    array(
      'tid' => 1794,
      'name' => "Ajmaline-sarpagine alkaloids",
      'description' => "Organic compounds containing either of the ajmalan, sarpagan skeleton, or derivative thereof. The Sarpagine (Akuammidine) group, based on the sarpagan nucleus, arises from bond formation between C-16 and C-5 of the corynantheine precursor.  Ajmaline alkaloids are based on a 17,19-secoyohimban skeleton (oxayohimban) which is invariably present as an ether.",
      'parent' => 279,
    ),
    array(
      'tid' => 1795,
      'name' => "Sparteine, lupanine, and related alkaloids",
      'description' => "Alkaloids with a structure based on either sparteine, lupanine, or derivatives thereof. These are tetracyclic compounds made of two fused quinolizidine ring systems.",
      'parent' => 2719,
    ),
    array(
      'tid' => 1796,
      'name' => "Oxocins",
      'description' => "Compounds containing an oxocin ring, which is a eight-member unsaturated aromatic ring containing one oxygen atom and seven carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 1797,
      'name' => "Imidazopyrimidines",
      'description' => "Organic polycyclic compounds containing an imidazole ring fused to a pyrimidine ring. Imidazole is 5-membered ring consisting of three carbon atoms, and two nitrogen centers at the 1- and 3-positions. Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions.",
      'parent' => 2,
    ),
    array(
      'tid' => 1798,
      'name' => "Pyrrolotriazines",
      'description' => "Compounds containing a pyrrolotriazine moiety, which consists of a pyrrole ring fused to a triazine ring. Pyrrole is 5-membered ring consisting of four carbon atoms and one nitrogen atom. Triazine is a 6-membered ring consisting of three carbon atoms and three nitrogen centers.",
      'parent' => 2,
    ),
    array(
      'tid' => 1799,
      'name' => "Pyrrolopyrimidines",
      'description' => "Compounds containing a pyrrolopyrimidine moiety, which consists of a pyrrole ring fused to a pyrimidine. Pyrrole is 5-membered ring consisting of four carbon atoms and one nitrogen atom. Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions.",
      'parent' => 2,
    ),
    array(
      'tid' => 1800,
      'name' => "Saxitoxins, gonyautoxins, and derivatives",
      'description' => "Compounds with a structure based on a 2,6-diamino-4-methyl-pyrrolo[1,2-c]purin-10-ol skeleton.",
      'parent' => 261,
    ),
    array(
      'tid' => 1801,
      'name' => "Kainoids",
      'description' => "Non-proteigenous amino acids with a structure characterized by the presence of a pyrrolidine ring bearing two dicarboxylic acid groups.",
      'parent' => 347,
    ),
    array(
      'tid' => 1802,
      'name' => "Okadaic acids and derivatives",
      'description' => "Marine heterocyclic polyethers containing the okadaic acid skeleton.",
      'parent' => 261,
    ),
    array(
      'tid' => 1803,
      'name' => "Pectenotoxins and derivatives",
      'description' => "A group of poly-ether-lactone toxins.",
      'parent' => 147,
    ),
    array(
      'tid' => 1804,
      'name' => "Organic pyrophosphates",
      'description' => "Organic compounds containing the pyrophosphate oxoanion, with the structure OP([O-])(=O)OP(O)([O-])=O.",
      'parent' => 463,
    ),
    array(
      'tid' => 1805,
      'name' => "Quinuclidones",
      'description' => "Compounds containing a quinuclidine moiety which bears a ketone group.",
      'parent' => 252,
    ),
    array(
      'tid' => 1806,
      'name' => "Organic arsenates",
      'description' => "Organic compounds containing the arsenate oxoanion, with the formula AsO43-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1807,
      'name' => "Spironolactones and derivatives",
      'description' => "Steroid lactones with a structure based on the spironolactone skeleton.",
      'parent' => 1125,
    ),
    array(
      'tid' => 1808,
      'name' => "Ciguatera toxins",
      'description' => "Lipid-soluble polyether compounds consisting of 13 to 14 rings fused by ether linkages into a most rigid ladder-like structure.",
      'parent' => 261,
    ),
    array(
      'tid' => 1809,
      'name' => "Quinacridones",
      'description' => "Compounds containing a quinacridone skeleton, which consists of a quinoline fused to an acridone.",
      'parent' => 1728,
    ),
    array(
      'tid' => 1810,
      'name' => "Pyridoacridones",
      'description' => "Pyridoacridines with a structure that contains an acridine moiety bearing a ketone. Acridine is a linear tricyclic heterocycle which consists of two benzene rings joined by a pyridine ring.",
      'parent' => 1763,
    ),
    array(
      'tid' => 1811,
      'name' => "Acridones",
      'description' => "Acridines containing a ketone group attached to the C9 carbon atom of the acridine moiety.",
      'parent' => 274,
    ),
    array(
      'tid' => 1812,
      'name' => "Glycosyl-amino acids",
      'description' => "Compounds consisting of saccharide linked through a glycosyl linkage (O-, N-, or S-) to an amino acid.",
      'parent' => 347,
    ),
    array(
      'tid' => 1813,
      'name' => "Peptidomimetics",
      'description' => "Compounds containing non-peptidic structural elements that is capable of mimicking or antagonizing the biological action(s) of a natural parent peptide.",
      'parent' => 264,
    ),
    array(
      'tid' => 1814,
      'name' => "Phenylphosphines and derivatives",
      'description' => "Compounds containing a phenylphosphine, which consists of phosphine substituent bound to a phenyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 1815,
      'name' => "Glycopeptidomimetics",
      'description' => "Compounds in which a carbohydrate component is linked to a peptidomimetic component.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1816,
      'name' => "Furofurans",
      'description' => "Organic compounds containing a two furan rings fused to each other. Furan is a five-membered aromatic ring with four carbon atoms and one oxygen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 1817,
      'name' => "Sterigmatocystins",
      'description' => "A group of closely related fungal metabolites chemically characterized by a xanthone moiety fused to a dihydrodifurano or a tetrahydrodifurano moiety. The chemical difference among the various sterigmagocystins are the presence or absence of unsaturation at positions 2 and 3 of the difurano ring system, the substitution pattern on positions 6, 7, and 10 of the xanthone system and/or the substituent on position 3 of the difurano system. They are produced by Aspergilus spp. and Bipolaris spp.",
      'parent' => 261,
    ),
    array(
      'tid' => 1818,
      'name' => "Furopyrans",
      'description' => "Organic polycyclic compounds containing a furan ring fused to a pyran ring. Furan is a five-membered aromatic ring with four carbon atoms and one oxygen atom. Pyran a six-membered heterocyclic, non-aromatic ring, made up of five carbon atoms and one oxygen atom and containing two double bonds.",
      'parent' => 2,
    ),
    array(
      'tid' => 1819,
      'name' => "Isoindoles and derivatives",
      'description' => "Polycyclic compounds containing an isoindole moiety, which is structurally characterized by a cyclohexadiene fused to a pyrrole ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 1820,
      'name' => "Isoindolones",
      'description' => "Aromatic polycyclic compounds that an isoindole bearing a ketone.",
      'parent' => 2496,
    ),
    array(
      'tid' => 1821,
      'name' => "Cytochalasans",
      'description' => "Fungal metabolites structurally characterized by the presence of an isoindolone nucleus fused to a macrocyclic ring, which can either a lactone, as in cytochalasin B, a carbonate, as in cytochalasin E, or a carbocycle, as in cytochalasin D,  H, and K.",
      'parent' => 279,
    ),
    array(
      'tid' => 1822,
      'name' => "Oxadiazoles",
      'description' => "Organic compounds containing an oxadiazole ring, which is a five-member aromatic heterocycle with two nitrogen atoms, an oxygen atom, and a carbon atom.",
      'parent' => 436,
    ),
    array(
      'tid' => 1823,
      'name' => "Hopanoids",
      'description' => "Terpenoids containing hopane skeleton(A'-Neogammacerane), a pentacyclic structure with four cyclohexane rings and one cyclopentane ring (and often, a side chain emerging from C30).",
      'parent' => 259,
    ),
    array(
      'tid' => 1824,
      'name' => "Hopane triterpenoids",
      'description' => "Triterpenoids with a structure based on the hopane skeleton.",
      'parent' => 1823,
    ),
    array(
      'tid' => 1825,
      'name' => "Polyterpenoids",
      'description' => "Terpenoids consisting of more than eight isoprene units.",
      'parent' => 259,
    ),
    array(
      'tid' => 1826,
      'name' => "Bacteriohopanoids",
      'description' => "Bacterial terpenoids structurally characterized by a C30 skeleton, which is usually conjugated to a C5 (usually hydroxylated) unit linked by a carbon-carbon bond.",
      'parent' => 1823,
    ),
    array(
      'tid' => 1827,
      'name' => "Isoflavanones",
      'description' => "Polycyclic compounds containing an isoflavan skeleton which bears a ketone at position C4.",
      'parent' => 1612,
    ),
    array(
      'tid' => 1828,
      'name' => "Isoflavanols",
      'description' => "Polycyclic compounds containing a hydroxylated isoflavan skeleton.",
      'parent' => 1612,
    ),
    array(
      'tid' => 1829,
      'name' => "M-terphenyls",
      'description' => "Terphenyls with a structure containing the 1,3-diphenylbenzene skeleton.",
      'parent' => 2042,
    ),
    array(
      'tid' => 1830,
      'name' => "Inorganic sulfuryl iodides",
      'description' => "Inorganic compounds containing the sulfuryl fluoride functional group, with the general structure IS(R)(=O)=O (R=hetero atom).",
      'parent' => 1333,
    ),
    array(
      'tid' => 1831,
      'name' => "Carbonyl compounds",
      'description' => "Organic compounds containing a carbonyl group, with the general structure RC(=O)R', where R=organyl, R'=H, N, O, organyl group or halide group.",
      'parent' => 323,
    ),
    array(
      'tid' => 1832,
      'name' => "Thiocarbonyl s-imides",
      'description' => "Organic compounds containing a functional group with the general formula R1(R2)C=S-NR3 (R1,R3=alkyl, aryl; R2=H, alkyl, aryl).",
      'parent' => 1198,
    ),
    array(
      'tid' => 1833,
      'name' => "Thienopyrroles",
      'description' => "Heterocyclic compounds containing a thiophene ring fused to a pyrrole ring. Thiophene is 5-membered ring consisting of four carbon atoms and one sulfur atom. Pyrrole is 5-membered ring consisting of four carbon atoms and one nitrogen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 1834,
      'name' => "Pyrrolothiazoles",
      'description' => "Compounds containing a pyrrolothiazole moiety, which consists of a pyrrole ring fused to a thiazole ring. Pyrrole is 5-membered ring consisting of four carbon atoms and one nitrogen atom. Thiazole is a 6-membered ring that contains both sulfur and nitrogen.",
      'parent' => 2,
    ),
    array(
      'tid' => 1835,
      'name' => "Pyrrolizidine oximes",
      'description' => "Compounds containing a pyrrolizidine moiety which bears an oxime group at ring position 1. Pyrrolizidine is a bicyclic ring system made up of two fused pyrrolidine ring sharing a nitrogen atom.",
      'parent' => 220,
    ),
    array(
      'tid' => 1836,
      'name' => "O-terphenyls",
      'description' => "Terphenyls with a structure containing the 1,2-diphenylbenzene skeleton.",
      'parent' => 2042,
    ),
    array(
      'tid' => 1837,
      'name' => "Organic peroxynitrates",
      'description' => "Organic compounds containing the peroxynitrate oxoanion, with the formula [NO4]−.",
      'parent' => 463,
    ),
    array(
      'tid' => 1838,
      'name' => "Organic peroxynitrites",
      'description' => "Organic compounds containing the peroxonitrite oxoanion, with the formula  ONOO-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1839,
      'name' => "Organic aluminates",
      'description' => "Organic compounds containing an aluminate oxoanion, with the formula [AlO2]-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1840,
      'name' => "Organic stannates",
      'description' => "Organic compounds containing a stannate oxoanion, with the formula [SnO3]2-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1841,
      'name' => "Organic orthovanadates",
      'description' => "Organic compounds containing the orthovanadate oxoanion, with the formula [VO4]3-.",
      'parent' => 463,
    ),
    array(
      'tid' => 1842,
      'name' => "Tetrazolidines",
      'description' => "Organic compounds containing a tetrazolidine ring, which is a five-member saturated aliphatic heterocycle made up of four nitrogen atoms and a one carbon atom.",
      'parent' => 2491,
    ),
    array(
      'tid' => 1843,
      'name' => "Phenyltetrazolines and derivatives",
      'description' => "Compounds containing a phenyltetrazoline skeleton, which consists of a tetrazoline bound to a phenyl group.",
      'parent' => 1080,
    ),
    array(
      'tid' => 1844,
      'name' => "Flavonolignans",
      'description' => "Non-conventional lignans that derived from flavonoids. They are characterized by a p-dioxin ring substituted at one carbon atom by a C3C6 (phenylpropan) group and fused to the B-ring of the 2-phenylchromene moiety.",
      'parent' => 1392,
    ),
    array(
      'tid' => 1845,
      'name' => "Bromodiphenyl ethers",
      'description' => "Compounds that contain two benzene groups linked to each other via an ether bond, and where at least one ring is substituted with a bromo group.",
      'parent' => 4155,
    ),
    array(
      'tid' => 1846,
      'name' => "Acetanilides",
      'description' => "Organic compounds containing an acetamide group conjugated to a phenyl group.",
      'parent' => 285,
    ),
    array(
      'tid' => 1847,
      'name' => "1-(1Z-alkenyl)-glycero-3-phosphocholines",
      'description' => "Glycerophosphocholines that carry exactly one 1Z-alkenyl chain attached at the O1 position of a glycerol moiety through an ether linkage.",
      'parent' => 3823,
    ),
    array(
      'tid' => 1848,
      'name' => "Carbonucleotoids",
      'description' => "Organic peptide derivatives with monosaccharide units linked through Phosphate diester bonds.",
      'parent' => 11,
    ),
    array(
      'tid' => 1849,
      'name' => "Carbopeptoids",
      'description' => "Oligosaccharides having carbohydrate subunits linked to one another by amide bonds.",
      'parent' => 11,
    ),
    array(
      'tid' => 1850,
      'name' => "Thiophenols",
      'description' => "Compounds containing a thiophenol ring, which a phenol derivative obtained by replacing the oxygen atom from the hydroxyl group (attached to the benzene) by a sulfur atom.",
      'parent' => 2448,
    ),
    array(
      'tid' => 1851,
      'name' => "Pyrenes",
      'description' => "Compounds containing a pyrene moiety, which consists four fused benzene rings, resulting in a flat aromatic system.",
      'parent' => 2448,
    ),
    array(
      'tid' => 1852,
      'name' => "1,3-aminoalcohols",
      'description' => "Organic compounds containing an alkyl chain with an amine group bound to the C1 atom and an alcohol group bound to the C3 atom.",
      'parent' => 2460,
    ),
    array(
      'tid' => 1853,
      'name' => "Trioxanes",
      'description' => "Compounds containing a six-member aliphatic saturated heterocycle made up of three oxygen atoms and three carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 1854,
      'name' => "Trioxolanes",
      'description' => "Compounds containing a five-member aliphatic saturated heterocycle made up of three oxygen atoms and two carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 1855,
      'name' => "Phenoxazines",
      'description' => "Polycyclic aromatic compounds containing a phenoxazine moiety, which is a linear tricyclic system that consists of a two benzene rings joined by a 1,4-oxazine ring.",
      'parent' => 1396,
    ),
    array(
      'tid' => 1856,
      'name' => "Pyridazinoindazoles",
      'description' => "Compounds containing a pyridazinoindazole moiety, which consists of a pyridazine ring fused to an indazole.",
      'parent' => 80,
    ),
    array(
      'tid' => 1857,
      'name' => "Naphthyridines",
      'description' => "Compounds containing a naphthyridine moiety, a naphthalene in which a carbon atom has been replaced by a nitrogen in each of the two rings. The naphthyridine skeleton can also be described as an assembly two fused pyridine rings, which do not share their nitrogen atom.",
      'parent' => 4788,
    ),
    array(
      'tid' => 1858,
      'name' => "Naphthyridine carboxylic acids and derivatives",
      'description' => "Compounds containing a naphthyridine moiety, where one of the ring atoms bears a carboxylic acid group.",
      'parent' => 1857,
    ),
    array(
      'tid' => 1859,
      'name' => "Pyridopyrimidines",
      'description' => "Compounds containing a pyridopyrimidine, which consists of a pyridine fused to a pyrimidine. Pyridine is 6-membered ring consisting of five carbon atoms and a nitrogen atom. Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions.",
      'parent' => 2,
    ),
    array(
      'tid' => 1860,
      'name' => "Pyridopyrimidine carboxylic acids and derivatives",
      'description' => "Pyridopyrimidines with a structure that contains pyrimidine moiety bearing a carboxylic acid group, and a pyridine ring fused to the pyrimidine.",
      'parent' => 1859,
    ),
    array(
      'tid' => 1861,
      'name' => "Pyridinesulfonamides",
      'description' => "Heterocyclic compounds containing a pyridine ring substituted by one or more sulfonamide groups.",
      'parent' => 89,
    ),
    array(
      'tid' => 1862,
      'name' => "Trithianes",
      'description' => "Organic compounds containing a six-member aliphatic saturated heterocycle made up of three sulfur atoms and three carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 1863,
      'name' => "Dithianes",
      'description' => "Compounds containing a dithiane moiety, which is composed of a cyclohexane core structure wherein two methylene units are replaced by sulfur centres.",
      'parent' => 2,
    ),
    array(
      'tid' => 1864,
      'name' => "Oxirane carboxylic acids and derivatives",
      'description' => "Compounds containing an oxirane ring bearing a carboxylic acid group (or a derivative thereof).",
      'parent' => 159,
    ),
    array(
      'tid' => 1865,
      'name' => "Pyrrolocarbazoles",
      'description' => "Compounds containing a pyrrolocarbazole moiety, which is a tetracyclic heterocycle which consists of a pyrrole ring fused to a carbazole.",
      'parent' => 210,
    ),
    array(
      'tid' => 1866,
      'name' => "Indolocarbazoles",
      'description' => "Polycyclic aromatic compounds containing an indole fused to a carbazole.",
      'parent' => 1865,
    ),
    array(
      'tid' => 1867,
      'name' => "Benzotriazole ribonucleosides and ribonucleotides",
      'description' => "Nucleosides with a structure that consists of an  imidazole moiety of benzotriazole is N-linked to a ribose (or deoxyribose). Nucleotides have a phosphate group linked to the C5 carbon of the ribose (or deoxyribose) moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 1868,
      'name' => "Indazole ribonucleosides and ribonucleotides",
      'description' => "Compounds in which the C-1 of a ribose (or deoxyribose)  is linked to the N1-position of the indazole ring. Nucleotides have a phosphate group linked to the C5 carbon of the ribose (or deoxyribose) moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 1869,
      'name' => "Indole ribonucleosides and ribonucleotides",
      'description' => "Compounds in which the C-1 of a ribosyl (or deoxyribosyl) moiety is linked to the N1-position of an indole. Nucleotides have a phosphate group linked to the C5 carbon of the ribose (or deoxyribose) moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 1870,
      'name' => "Naphthohydroquinones",
      'description' => "Compounds containing a naphthohydroquinone moiety, which consists of a benzene ring fused to a bezene-1,4-diol (hydroquinone).",
      'parent' => 23,
    ),
    array(
      'tid' => 1871,
      'name' => "Naphthalenecarboxylic acids and derivatives",
      'description' => "Compounds containing a naphthalene moiety, which bears a carboxylic acid group or a derivative at one or more positions. Naphthalene is a bicyclic compound that is made up of two fused benzene ring.",
      'parent' => 23,
    ),
    array(
      'tid' => 1872,
      'name' => "P-quinodimethanes",
      'description' => "Compounds containing a benzene ring conjugated to two methylidene groups at carbon atoms 1 and 4, respectively..",
      'parent' => 1579,
    ),
    array(
      'tid' => 1873,
      'name' => "Phthalides",
      'description' => "Compounds containing a 3-hydrocarbylidene-2-benzofuran-1(3H)-one moiety,.",
      'parent' => 3409,
    ),
    array(
      'tid' => 1874,
      'name' => "Sulfonphthalides",
      'description' => "Compounds containing a sulfonphthalide moiety, which consists of a benzene ring fused to an oxathiole-1,1-dione.",
      'parent' => 1875,
    ),
    array(
      'tid' => 1875,
      'name' => "Benzoxathioles",
      'description' => "Organic compounds containing a benzene fused to an oxathiole ring (a five-membered ring with four carbon atoms, one oxygen atom, and one sulfur atom).",
      'parent' => 2,
    ),
    array(
      'tid' => 1876,
      'name' => "Azetidinecarboxylic acids or derivatives",
      'description' => "Organic compounds containing a carboxylic acid group (or a derivative thereof) attached to an azetidine ring.",
      'parent' => 102,
    ),
    array(
      'tid' => 1877,
      'name' => "Aziridinecarboxylic acids or derivatives",
      'description' => "Organic compounds containing a carboxylic acid group(or a derivative thereof) attached to an aziridine ring.",
      'parent' => 103,
    ),
    array(
      'tid' => 1878,
      'name' => "Beta amino acids and derivatives",
      'description' => "Amino acids having a (-NH2) group attached to the beta carbon atom.",
      'parent' => 347,
    ),
    array(
      'tid' => 1879,
      'name' => "Delta amino acids and derivatives",
      'description' => "Compounds containing a carboxylic acid group and an amino group at the C5 carbon atom.",
      'parent' => 347,
    ),
    array(
      'tid' => 1880,
      'name' => "Gamma amino acids and derivatives",
      'description' => "Amino acids having a (-NH2) group attached to the gamma carbon atom.",
      'parent' => 347,
    ),
    array(
      'tid' => 1881,
      'name' => "Thiazetidines",
      'description' => "Heterocyclic compounds containing a saturated four-member ring with two carbon atoms, one sulfur atom, and one nitrogen.",
      'parent' => 2,
    ),
    array(
      'tid' => 1882,
      'name' => "Beta sultams",
      'description' => "Organic compounds containing a sulfonamide group in which the N-S bond is part of a four member ring.",
      'parent' => 509,
    ),
    array(
      'tid' => 1883,
      'name' => "Gamma sultams",
      'description' => "Organic compounds containing a gamma-sultam moiety, a five-member cyclic sulfonamide, containing the NS bond, and three carbon atoms.",
      'parent' => 228,
    ),
    array(
      'tid' => 1884,
      'name' => "Thiazinanes",
      'description' => "Heterocyclic compounds containing a saturated six-member ring with four carbon atoms, one sulfur atom, and one nitrogen.",
      'parent' => 2,
    ),
    array(
      'tid' => 1885,
      'name' => "Delta sultams",
      'description' => "Cyclic organic compounds containing a 1,2-thiazinane-1,1-dione moiety.",
      'parent' => 1884,
    ),
    array(
      'tid' => 1886,
      'name' => "Oxathietanes",
      'description' => "Compounds containing an oxathietane moiety, which consists of a saturated aliphatic four-member ring with one oxygen atom, a sulfur atom, and two carbon atoms. Isomers  of oxaphospholane include 1,2-oxathietane, and 1,3-oxathietane.",
      'parent' => 2,
    ),
    array(
      'tid' => 1887,
      'name' => "Beta sultones",
      'description' => "Organic compounds containing a four-member cyclic ester of hydroxy sulfonic acid, analogous to lactones. Here, the O-S bond is part of the ring.",
      'parent' => 1886,
    ),
    array(
      'tid' => 1888,
      'name' => "Gamma sultones",
      'description' => "Organic compounds containing a gamma-sultone, a Intramolecular cyclic ester of hydroxy sulfonic acid, with a SO ring bond, and three ring carbon atoms.",
      'parent' => 106,
    ),
    array(
      'tid' => 1889,
      'name' => "Oxathianes",
      'description' => "Compounds containing an oxathiane moiety, which consists of a saturated aliphatic six-member ring with one oxygen atom, a sulfur atom, and four carbon atoms. Isomers  of oxaphospholane include 1,2-oxathiane, 1,3-oxathiane,and 1,4-oxathiane.",
      'parent' => 2,
    ),
    array(
      'tid' => 1890,
      'name' => "Isocoumarins and derivatives",
      'description' => "Polycyclic compounds containing an isochromane which bears a ketone at the carbon C1.",
      'parent' => 261,
    ),
    array(
      'tid' => 1891,
      'name' => "Sulfinylbenzimidazoles",
      'description' => "Polycyclic aromatic compounds containing a sulfinyl group attached at the position 2 of a benzimidazole moiety.",
      'parent' => 294,
    ),
    array(
      'tid' => 1892,
      'name' => "Biphenylcarbonitriles",
      'description' => "Organic compounds containing an acetonitrile with one hydrogen replaced by a biphenyl group.",
      'parent' => 41,
    ),
    array(
      'tid' => 1893,
      'name' => "Halopyrimidines",
      'description' => "Aromatic compounds containing a halogen atom linked to a pyrimidine ring. Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions.",
      'parent' => 75,
    ),
    array(
      'tid' => 1894,
      'name' => "Thianes",
      'description' => "Heterocyclic compounds containing a saturated six-member ring with five carbon atoms and one sulfur atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 1895,
      'name' => "Thiopyrans",
      'description' => "Compounds containing a six-member aliphatic heterocycle made up of one sulfur atom and five carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 1896,
      'name' => "Thienoquinolines",
      'description' => "Heterocyclic compounds containing a thiophene ring fused to a quinoline. Quinoline or benzo[b]pyridine is a bicyclic compound that consists of benzene fused to a pyridine.",
      'parent' => 56,
    ),
    array(
      'tid' => 1897,
      'name' => "1,2-aminoalcohols",
      'description' => "Organic compounds containing an alkyl chain with an amine group bound to the C1 atom and an alcohol group bound to the C2 atom.",
      'parent' => 2460,
    ),
    array(
      'tid' => 1898,
      'name' => "Organic triazenes",
      'description' => "Organic compounds containing the triazene group (-N-N=N), which consists of an amine directly bonding to an azo group.",
      'parent' => 278,
    ),
    array(
      'tid' => 1899,
      'name' => "Cylindrospermopsins",
      'description' => "Compounds containing a cylindrospermopsin moiety, which contains a triazaacenaphthylene moiety linked to a pyrimidinedione.",
      'parent' => 1859,
    ),
    array(
      'tid' => 1900,
      'name' => "Macrolide lactams",
      'description' => "Cyclic polyketides containing  both a cyclic amide and a cyclic ester group.",
      'parent' => 261,
    ),
    array(
      'tid' => 1901,
      'name' => "Beta-sulfonopeptides",
      'description' => "Peptide analogues containing two 2-sulfonylethan-1-amine groups linked together through a bond between the terminal nitrogen atom of one group and the sulfur atom (of the sulfonyl ) from the other group.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1902,
      'name' => "Alpha,beta-sulfonopeptides",
      'description' => "Peptide analogues containing a sulfonylmethanamine group and a 2-sulfonylethan-1-amine group linked together through a bond between the terminal nitrogen atom of one group and the sulfur atom (of the sulfonyl ) from the other group.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1903,
      'name' => "Pyrrolidine carboxylic acids and derivatives",
      'description' => "Compounds containing a pyrrolidine ring which bears a carboxylic acid or a derivative thereof. Pyrrolidine is a five-membered saturated aliphatic heterocycle with one nitrogen atom and four carbon atoms.",
      'parent' => 218,
    ),
    array(
      'tid' => 1904,
      'name' => "Pyrimidine ribonucleoside bisphosphates",
      'description' => "Pyrimidine ribobucleotides with one phosphate group attached to each of two different hydroxyl groups of the ribose moiety.",
      'parent' => 2147,
    ),
    array(
      'tid' => 1905,
      'name' => "Sulfinylamines",
      'description' => "Compounds containing the sulfinylamine functional group, with the general structure RN=S=O.",
      'parent' => 3130,
    ),
    array(
      'tid' => 1906,
      'name' => "Phenanthroindolizidines",
      'description' => "Aromatic polycyclic compounds containing the phenanthroindolizidine skeleton, which is structurally characterized by an indolizidine and a phenanthrene, where the indolizidine is fused to the second benzene ring of a phenanthrene.",
      'parent' => 25,
    ),
    array(
      'tid' => 1907,
      'name' => "Phenanthroquinolizidines",
      'description' => "Aromatic polycyclic compounds containing the phenanthroindolizidine skeleton, which is structurally characterized by an indolizidine and a phenanthrene, where the quinolizidine is fused to the second benzene ring of a phenanthrene.",
      'parent' => 25,
    ),
    array(
      'tid' => 1908,
      'name' => "Benzoquinolines",
      'description' => "Organic compounds containing a benzene fused to a quinoline ring system.",
      'parent' => 1253,
    ),
    array(
      'tid' => 1909,
      'name' => "Protoberberine alkaloids and derivatives",
      'description' => "Alkaloids with a structure based on a protoberberine moiety, which consists of a 5,6-dihydrodibenzene moiety fused to a quinolizinium and forming 5,6-Dihydrodibenzo(a,g)quinolizinium skeleton.",
      'parent' => 279,
    ),
    array(
      'tid' => 1910,
      'name' => "Benzoxepines",
      'description' => "Organic compounds containing a benzene ring fused to an oxepine ring (an unsaturated seven-membered heterocycle with one oxygen atom replacing a carbon atom).",
      'parent' => 2,
    ),
    array(
      'tid' => 1911,
      'name' => "Anthracenecarboxylic acids and derivatives",
      'description' => "Organic compounds containing a carboxylic acid group (or a derivative thereof) attached to an anthracene ring system.",
      'parent' => 18,
    ),
    array(
      'tid' => 1912,
      'name' => "Pyridoisoindoles",
      'description' => "Compounds containing a pyridoisoindole, which consists of a pyridine fused to an isoindole.",
      'parent' => 1819,
    ),
    array(
      'tid' => 1913,
      'name' => "Alpha carbolines",
      'description' => "Organic compounds containing a pyrido[2,3-b]indole core (which is a pyridine fused to an indole).",
      'parent' => 1213,
    ),
    array(
      'tid' => 1914,
      'name' => "Beta carbolines",
      'description' => "Compounds containing a 9H-pyrido[3,4-b]indole moiety.",
      'parent' => 1213,
    ),
    array(
      'tid' => 1915,
      'name' => "Delta carbolines",
      'description' => "Aromatic compounds containing a delta carboline moiety, which consists of a pyridine fused to and indole to form pyrido[3,2-b]indole.",
      'parent' => 1213,
    ),
    array(
      'tid' => 1916,
      'name' => "Gamma carbolines",
      'description' => "Polycyclic aromatic compounds containing a gamma-carbazole(5H-pyrido[4,3-b]indole) moiety, with a structure characterized by the presence of pyridine fused to the pyrrole ring of an indole.",
      'parent' => 1213,
    ),
    array(
      'tid' => 1917,
      'name' => "Aminobenzamides",
      'description' => "Organic compounds containing a benzamide moiety with an amine group attached to the benzene ring.",
      'parent' => 281,
    ),
    array(
      'tid' => 1918,
      'name' => "Furopyrroles",
      'description' => "Organic polycyclic compounds containing a furan ring fused to a pyrrole ring. Furan is a five-membered aromatic ring with four carbon atoms and one oxygen atom. Pyrrole is 5-membered ring consisting of four carbon atoms and one nitrogen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 1919,
      'name' => "Thiazinanethiones",
      'description' => "Heterocyclic compounds containing a thioketone group conjugated to a saturated six-member ring with four carbon atoms, one sulfur atom, and one nitrogen.",
      'parent' => 1884,
    ),
    array(
      'tid' => 1920,
      'name' => "Triazinones",
      'description' => "Compounds containing a triazine ring which bears a ketone group a carbon atom.",
      'parent' => 98,
    ),
    array(
      'tid' => 1921,
      'name' => "Pyrimidinethiones",
      'description' => "Compounds containing a pyrimidine ring that bears a thioketone. Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions.",
      'parent' => 75,
    ),
    array(
      'tid' => 1922,
      'name' => "Triazinethiones",
      'description' => "Compounds containing a triazine ring which bears a thioketone group.",
      'parent' => 98,
    ),
    array(
      'tid' => 1923,
      'name' => "Thiazolidinethiones",
      'description' => "Heterocyclic compounds containing a thiazolidinethione ring which bears one thioketone group.",
      'parent' => 226,
    ),
    array(
      'tid' => 1924,
      'name' => "Aminopyridazines",
      'description' => "Organic compounds containing an amino group attached to a pyridazine ring.",
      'parent' => 74,
    ),
    array(
      'tid' => 1925,
      'name' => "Aminobenzenesulfonamides",
      'description' => "Organic compounds containing a benzenesulfonamide moiety with an amine group attached to the benzene ring.",
      'parent' => 31,
    ),
    array(
      'tid' => 1926,
      'name' => "Metallotetrapyrroles",
      'description' => "Polycyclic compounds containing a tetrapyrrole skeleton combined with a metal atom.",
      'parent' => 1455,
    ),
    array(
      'tid' => 1927,
      'name' => "Nitropyrimidines",
      'description' => "Compounds containing a pyrimidine ring which bears a nitro group. Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions.",
      'parent' => 75,
    ),
    array(
      'tid' => 1928,
      'name' => "Thienothiazines",
      'description' => "Heterocyclic compounds containing a thiophene ring fused to a thiazine. Thiophene is 5-membered ring consisting of four carbon atoms and one sulfur atom. Thiazine is a 6-membered ring consisting of four carbon, one nitrogen and one sulfur atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 1929,
      'name' => "Thienothiazoles",
      'description' => "Heterocyclic compounds containing a thiophene ring fused to a thiazole. Thiophene is 5-membered ring consisting of four carbon atoms and one sulfur atom. Thiazole is a 6-membered ring that contains both sulfur and nitrogen.",
      'parent' => 2,
    ),
    array(
      'tid' => 1930,
      'name' => "Benzoxadiazoles",
      'description' => "Organic compounds containing a benzene fused to an oxadiazole ring (a five-membered ring with two carbon atoms, one nitrogen atom, and one oxygen atom).",
      'parent' => 2,
    ),
    array(
      'tid' => 1931,
      'name' => "Oxatriazoles",
      'description' => "Compounds containing an oxatriazole moiety, which consists of an unsaturated aliphatic five-member ring with one oxygen atom, three nitrogen, one carbon atom, and two double bonds. Isomers  of oxatriazole include 1,2,3,4-oxatriazole, and 1,2,3,5-oxatriazole.",
      'parent' => 436,
    ),
    array(
      'tid' => 1932,
      'name' => "Oxatriazolidines",
      'description' => "Organic compounds containing an oxatriazolidine ring, which is a five-member saturated aliphatic heterocycle with three nitrogen atoms, an oxygen atom, and a carbon atom.",
      'parent' => 2491,
    ),
    array(
      'tid' => 1933,
      'name' => "Oxadiazolidines",
      'description' => "Organic compounds containing an oxadiazole ring, which is a five-member saturated aliphatic heterocycle with two nitrogen atoms, an oxygen atom, and two carbon atoms.",
      'parent' => 2491,
    ),
    array(
      'tid' => 1934,
      'name' => "Tetrahydropyridines",
      'description' => "Derivatives of  pyridine in which two double bonds in the pyridine moiety are reduced by adding four hydrogen atoms.",
      'parent' => 2224,
    ),
    array(
      'tid' => 1935,
      'name' => "N-phenylureas",
      'description' => "Compounds containing a N-phenylurea moiety, which is structurally characterized by a phenyl group linked to one nitrogen atom of a urea group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 1936,
      'name' => "Aminothiophenes",
      'description' => "Organic compounds containing an amino group attached to a thiophene ring.",
      'parent' => 97,
    ),
    array(
      'tid' => 1937,
      'name' => "Polyprenyl quinols",
      'description' => "Compounds containing a polyisoprene chain attached to a quinol(hydroquinone) at the second ring position.",
      'parent' => 2801,
    ),
    array(
      'tid' => 1938,
      'name' => "Peptoids",
      'description' => "Peptidomimetics made of N-substituted amino acids, in which the side chains are attached to the nitrogen atom of the peptide backbone, rather than to the alpha-carbons. Alpha-peptoids (commonly referred to as peptoids) are N-substituted glycines. But in general, this class also extends to oligo- or polymers of beta-, gamma-, delta peptoid analogues of amino acids.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1939,
      'name' => "Peptoid-peptide hybrids",
      'description' => "Compounds containing a peptoid-peptide backbone, which consists alternating amino acid and n-substituted amino acids linked to each other by a peptide bond.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1940,
      'name' => "Urea peptoids",
      'description' => "Peptidomimetics structurally characterized by the presence of n-alkyl urea motifs linked in a repetitive manner.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1941,
      'name' => "Azatides",
      'description' => "Biomimetic oligomers consisting of alpha-amino acids linked in a repetitive manner.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1942,
      'name' => "Azapeptides",
      'description' => "Peptide analogues in which one or more of the amino residues is replaced by a semicarbazide.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1943,
      'name' => "Polyisoxazolines",
      'description' => "Peptidomimetics containing a polyisoxazoline backbone, which consists of isoxazoline rings linked together forming several 3-(4,5-dihydro-1,2-oxazol-5-ylmethyl)-4,5-dihydro-1,2-oxazole units.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1944,
      'name' => "Oligothioureas",
      'description' => "Compounds containing several thiourea groups linked to each other.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1945,
      'name' => "Vinylogous sulfonylpeptides",
      'description' => "Peptide analogues containing two (2E)-3-sulfonylprop-2-en-1-amine groups linked together through a bond between the terminal nitrogen atom of one group and the sulfur atom (of the sulfonyl ) from the other group to form (1E)-3-amino-N-[(2E)-3-sulfonylprop-2-en-1-yl]prop-1-ene-1-sulfonamide.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1946,
      'name' => "Vinylogous peptides",
      'description' => "Peptidomimetics made of  two (2E)-4-aminobut-2-enoic acid linked through a peptide bond.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1947,
      'name' => "Imidazole oligoamides",
      'description' => "Polycyclic aromatic peptidomimetics consisting of at least two imidazole rings connected by a carboxamide group to form a N-(1H-imidazol-4-yl)-1H-imidazole-2-carboxamide moiety.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1948,
      'name' => "Pyridoxines",
      'description' => "Pyridoxal derivatives in which the carbaldehyde group at position 2 of the pyridoxal moiety is replaced by a hydroxymethyl group.",
      'parent' => 89,
    ),
    array(
      'tid' => 1949,
      'name' => "Pyrrolin-4-one oligomers",
      'description' => "Compounds containing several 2,5-linked pyrrolin-4-ones.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1950,
      'name' => "Pyrrole oligoamides",
      'description' => "Compounds containing a pyrrole oligoamide backbone, which consists of 4-(pyrrole-2-amido)-pyrrole units.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1951,
      'name' => "Oligoureas",
      'description' => "Compounds containing several urea groups linked to each other. Urea is an organic compound with the formula CO(NH2)2.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1952,
      'name' => "Oligourea amides",
      'description' => "Compounds containing several urea-amide units (RNC(=O)CNC(=O)N(R')CN), which consists of alternating amide and urea functional groups.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1953,
      'name' => "Oligosulfoxides",
      'description' => "Compounds containing several sulfoxide groups linked to each other. They have the general formula R1(S(O)C(R2)C)nC (R1 = organyl; R2=any group).",
      'parent' => 1813,
    ),
    array(
      'tid' => 1954,
      'name' => "Oligosulfones",
      'description' => "Compounds containing several sulfone groups linked to each other.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1955,
      'name' => "Oligocarbamates",
      'description' => "Compounds containing several carbamate groups linked to each other.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1956,
      'name' => "Oligoanthrilamides",
      'description' => "Compounds containing several anthranilamide (2-aminobenzamide) moieties, where the amine group of one moiety is bound to the amide group of another moiety.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1957,
      'name' => "Imidazole-pyrrole oligo- and polyamides",
      'description' => "Polycyclic aromatic peptidomimetics consisting of alternating pyrrole and imidazole rings connected by a carboxamide group to form a N-(1H-pyrrol-3-yl)-1H-imidazole-2-carboxamide moiety.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1958,
      'name' => "Hydrazinopeptides",
      'description' => "Compounds in which one of the native CONH links is replaced by a CONHNH (hydrazido) fragment.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1959,
      'name' => "Alpha-sulfonopeptides",
      'description' => "Peptide analogues containing the 1-amino-N-(sulfonylmethyl)methanesulfonamide structure fragment.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1960,
      'name' => "Alpha-phosphonopeptides",
      'description' => "Peptide analogues containing a fragment consisting of  [(2-aminoacetamido)methyl]phosphonic acid.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1961,
      'name' => "Depsipeptides",
      'description' => "Natural or synthetic compounds having sequences of amino and hydroxy carboxylic acid residues (usually α-amino and α-hydroxy acids), commonly but not necessarily regularly alternating.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1962,
      'name' => "Aromatic urea oligo- and polyamides",
      'description' => "Peptide analogues containing at least one urea oligoamide fragment.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1963,
      'name' => "Aromatic oligo- and polyamides",
      'description' => "Peptide analogues containing at least one oligoamide fragment.",
      'parent' => 1813,
    ),
    array(
      'tid' => 1964,
      'name' => "Glycodepsipeptides",
      'description' => "Compounds in which a carbohydrate component is linked to a depsipeptide component.",
      'parent' => 1961,
    ),
    array(
      'tid' => 1965,
      'name' => "Thienopyrans",
      'description' => "Heterocyclic compounds containing a thiophene ring fused to a pyran ring. Thiophene is 5-membered ring consisting of four carbon atoms and one sulfur atom. Pyran a six-membered heterocyclic, non-aromatic ring, made up of five carbon atoms and one oxygen atom and containing two double bonds.",
      'parent' => 2,
    ),
    array(
      'tid' => 1966,
      'name' => "Pyridoxamines",
      'description' => "Pyridoxal derivatives in which the carbaldehyde moiety is substituted at position 2 by an amine.",
      'parent' => 89,
    ),
    array(
      'tid' => 1967,
      'name' => "Oxolanes",
      'description' => "Organic compounds containing an oxolane (tetrahydrofuran) ring, which is a saturated aliphatic five-member ring containing one oxygen and five carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 1968,
      'name' => "Dibenzylbutyrolactols",
      'description' => "Lignan compounds containing a 3,4-dibenzyloxolan-2-ol moiety.",
      'parent' => 3424,
    ),
    array(
      'tid' => 1969,
      'name' => "Dibenzylbutane lignans",
      'description' => "Lignan compounds containing a 2,3-dibenzylbutane moiety.",
      'parent' => 1392,
    ),
    array(
      'tid' => 1970,
      'name' => "Furan lignans",
      'description' => "Lignans with a structure based on 3,4-dibenzyloxolane or a (4-benzyl-2-phenyloxolan-3-yl)methanol skeleton.",
      'parent' => 3686,
    ),
    array(
      'tid' => 1971,
      'name' => "Furofuran lignans",
      'description' => "Lignans with a structure based on 1,4-diphenyl-hexahydrofuro[3,4-c]furan skeleton.",
      'parent' => 3686,
    ),
    array(
      'tid' => 1972,
      'name' => "Sphingosylphosphorylcholines",
      'description' => "Sphingolipids containing a sphingosine attached to the phosphate group of a phosphocholine.",
      'parent' => 3392,
    ),
    array(
      'tid' => 1973,
      'name' => "Benzoxazolones",
      'description' => "Organic compounds containing a benzene fused to an oxazole ring (a five-member aliphatic ring with three carbon atoms, one oxygen atom, and one nitrogen atom) bearing a ketone group.",
      'parent' => 302,
    ),
    array(
      'tid' => 1974,
      'name' => "Piperidinecarboxylic acids and derivatives",
      'description' => "Compounds containing a piperidine ring which bears a carboxylic acid group (or a derivative thereof).",
      'parent' => 195,
    ),
    array(
      'tid' => 1975,
      'name' => "Pyrrolidinylpyridines",
      'description' => "Compounds containing a pyrrolidinylpyridine ring system, which consists of a pyrrolidine ring linked to a pyridine ring.",
      'parent' => 89,
    ),
    array(
      'tid' => 1976,
      'name' => "Pyridinylpiperazines",
      'description' => "Compounds containing a pyridinylpiperazine skeleton, which consists of a pyridine linked (not fused) to a piperazine by a bond by a single bond that is not part of a ring.",
      'parent' => 189,
    ),
    array(
      'tid' => 1977,
      'name' => "Pyrimidinylpiperazines",
      'description' => "Compounds containing a pyrimidinylpiperazine skeleton, which consists of a pyrimidine linked (not fused) to a piperazine by a bond. Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions. Piperazine is a six-membered heterocyclic compound consisting of two nitrogen atoms and four carbon atoms.",
      'parent' => 75,
    ),
    array(
      'tid' => 1978,
      'name' => "Bipyrimidines and oligopyrimidines",
      'description' => "Organic compounds containing two or more pyrimidine rings directly linked to each other. Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions.",
      'parent' => 75,
    ),
    array(
      'tid' => 1979,
      'name' => "Imidazodiazepines",
      'description' => "Organic compounds containing an imidazole ring fused to a diazepine ring. Imidazole is 5-membered ring consisting of three carbon atoms, and two nitrogen centers at the 1- and 3-positions. Diazepine is a 7-membered ring consisting of five carbon and two nitrogen atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 1980,
      'name' => "Glycero-3-dithiophosphocholines",
      'description' => "Glycerolipids in which the glycerol moiety is esterified at two positions with a fatty acyl chain, and linked a third position (O3) with a dithiophosphocholine.",
      'parent' => 12,
    ),
    array(
      'tid' => 1981,
      'name' => "Glycero-3-thiophosphocholines",
      'description' => "Glycerolipids in which the glycerol moiety is esterified at two positions with a fatty acyl chain, and linked a third position (O3) with a thiophosphocholine.",
      'parent' => 12,
    ),
    array(
      'tid' => 1982,
      'name' => "Furanones",
      'description' => "Compounds containing a furan ring bearing a ketone group.",
      'parent' => 1983,
    ),
    array(
      'tid' => 1983,
      'name' => "Dihydrofurans",
      'description' => "Compounds containing a dihydrofuran moiety, which is a furan derivative with only one double bond.",
      'parent' => 2,
    ),
    array(
      'tid' => 1984,
      'name' => "Phenylpiperazines",
      'description' => "Compounds containing a phenylpiperazine skeleton, which consists of a piperazine bound to a phenyl group.",
      'parent' => 189,
    ),
    array(
      'tid' => 1985,
      'name' => "Dioxolopyrans",
      'description' => "Compounds containing a dioxolopyran moiety, which consists of a dioxole ring fused to a pyran ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 1986,
      'name' => "Tricarboxylic acids and derivatives",
      'description' => "Carboxylic acids containing exactly three carboxyl groups.",
      'parent' => 265,
    ),
    array(
      'tid' => 1987,
      'name' => "Isosorbides",
      'description' => "Organic polycyclic compounds containing an isosorbide(1,4-Dianhydrosorbitol) moiety, which consists of two -oxolan-3-ol rings.",
      'parent' => 1816,
    ),
    array(
      'tid' => 1988,
      'name' => "Dibenzoxepines",
      'description' => "Compounds containing a dibenzoxepine moiety, which consists of two benzene connected by an oxazepine ring.",
      'parent' => 1910,
    ),
    array(
      'tid' => 1989,
      'name' => "Heterocyclic fatty acids",
      'description' => "Fatty acids containing a heterocyclic attached to the acyl chain.",
      'parent' => 262,
    ),
    array(
      'tid' => 1990,
      'name' => "Pyrroloazepines",
      'description' => "Compounds containing a pyrroloazepine moiety, which is a bicyclic heterocycle which consists of a pyrrole ring fused to an azepine. Pyrrole is 5-membered ring consisting of four carbon atoms and one nitrogen atom. Azepine is a 7-membered ring consisting of six carbon and one nitrogen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 1991,
      'name' => "Pyran carboxylic acids and derivatives",
      'description' => "Compounds containing a pyran ring which bears a carboxylic acid group (or a derivative thereof).",
      'parent' => 86,
    ),
    array(
      'tid' => 1992,
      'name' => "Nitrobenzoic acids and derivatives",
      'description' => "Compounds containing a nitrobenzoic acid moiety, which consists of a benzene ring bearing both a carboxylic acid group and a nitro group on two different ring carbon atoms.",
      'parent' => 176,
    ),
    array(
      'tid' => 1993,
      'name' => "2',5'-cyclic purine nucleotides",
      'description' => "Purine nucleotides in which the oxygen atoms linked to the C2 and C5 carbon atoms of the ribose moiety are both bonded the same phosphorus atom of the phosphate group.",
      'parent' => 1491,
    ),
    array(
      'tid' => 1994,
      'name' => "Cyclic depsipeptides",
      'description' => "Natural or synthetic compounds having sequences of amino and hydroxy carboxylic acid residues (usually α-amino and α-hydroxy acids) connected in a ring. The residues are commonly but not necessarily regularly alternating.",
      'parent' => 1961,
    ),
    array(
      'tid' => 1995,
      'name' => "Cyclic peptides",
      'description' => "Compounds containing a cyclic moiety bearing a peptide backbone.",
      'parent' => 348,
    ),
    array(
      'tid' => 1996,
      'name' => "Cyclic glycopeptides and derivatives",
      'description' => "Compounds containing a carbohydrate covalently attached to a the backbone of a cyclic peptide.",
      'parent' => 1995,
    ),
    array(
      'tid' => 1997,
      'name' => "Imidazole ribonucleosides and ribonucleotides",
      'description' => "Organic compounds in which the C-1 of a ribosyl moiety is N-linked to an imidazole ring. Nucleotides have a phosphate group linked to the C5 carbon of the ribose (or deoxyribose) moiety. This class does not contain benzimidazole nucleosides and nucleotides.",
      'parent' => 289,
    ),
    array(
      'tid' => 1998,
      'name' => "Purinethiones",
      'description' => "Purines in which the purine moiety bears a thioketone.",
      'parent' => 245,
    ),
    array(
      'tid' => 1999,
      'name' => "Dithioxanthines",
      'description' => "Compounds containing a dithioxanthine moiety, a xanthine derivative obtained by replacing the two ketone groups by two thioketone groups.",
      'parent' => 245,
    ),
    array(
      'tid' => 2000,
      'name' => "Piperazinoazepines",
      'description' => "Compounds containing a piperazinoazepine skeleton, which consists of an azepine ring fused to a piperazine.",
      'parent' => 2,
    ),
    array(
      'tid' => 2001,
      'name' => "Imidazotetrazines",
      'description' => "Organic polycyclic compounds containing an imidazole ring fused to a tetrazine ring. Imidazole is 5-membered ring consisting of three carbon atoms, and two nitrogen centers at the 1- and 3-positions. Tetrazine is a six-membered aromatic heterocycle made up of four nitrogen atoms and a two carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2002,
      'name' => "Mutilin derivatives",
      'description' => "Tricyclic diterpenoids structurally characterized by the presence of a 1-oxo-decahydro-3a,9-propanocyclopenta[8]annulene skeleton.",
      'parent' => 2930,
    ),
    array(
      'tid' => 2003,
      'name' => "Pleuromutilin and derivatives",
      'description' => "Mutilins with a hydroxyacetate derivative attached to the C8 carbon atom of the cyclopenta[8]annulene moiety.",
      'parent' => 2002,
    ),
    array(
      'tid' => 2004,
      'name' => "Triquinane sesquiterpenoids",
      'description' => "Sesquiterpenoids with a structure based on the triquinane backbone.",
      'parent' => 1550,
    ),
    array(
      'tid' => 2005,
      'name' => "Pyrazolotriazines",
      'description' => "Compounds containing a pyrazolotriazine skeleton, which consists of a pyrazole fused to a triazine. Pyrazole is 5-membered ring consisting of three carbon atoms and two adjacent nitrogen centers. Triazine is a 6-membered ring consisting of three carbon atoms and three nitrogen centers.",
      'parent' => 2,
    ),
    array(
      'tid' => 2006,
      'name' => "Pyrazolylpyridines",
      'description' => "Compounds containing a pyrazolylpyridine skeleton, which consists of a pyrazole linked (not fused) to a pyridine by a bond.",
      'parent' => 89,
    ),
    array(
      'tid' => 2007,
      'name' => "Thiazolecarboxylic acids and derivatives",
      'description' => "Heterocyclic compounds containing a thiazole ring which bears a carboxylic acid group (or a derivative thereof).",
      'parent' => 95,
    ),
    array(
      'tid' => 2008,
      'name' => "Thiazolecarboxamides",
      'description' => "Heterocyclic compounds containing a thiazole ring which bears a carboxylic acid amide group.",
      'parent' => 2007,
    ),
    array(
      'tid' => 2009,
      'name' => "Hybrid glycopeptides",
      'description' => "Compounds containing a carbohydrate component linked to a hybrid peptide component.",
      'parent' => 2010,
    ),
    array(
      'tid' => 2010,
      'name' => "Hybrid peptides",
      'description' => "Compounds containing at least two different types of amino acids (alpha, beta, gamma, delta) linked to each other through a peptide bond.",
      'parent' => 1813,
    ),
    array(
      'tid' => 2011,
      'name' => "Pyranodioxins",
      'description' => "Polycyclic compounds containing a pyranodioxin moiety, which consists of a pyran ring fused to a dioxin ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 2012,
      'name' => "Oxanes",
      'description' => "Compounds containing an oxane (tetrahydropyran) ring, which is a six-member saturated aliphatic heterocycle with one oxygen atom and five carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2013,
      'name' => "Indolecarboxylic acids and derivatives",
      'description' => "Compounds containing a carboxylic acid group (or a derivative thereof) linked to an indole.",
      'parent' => 211,
    ),
    array(
      'tid' => 2014,
      'name' => "Indolecarboxamides and derivatives",
      'description' => "Compounds containing a carboxamide group attached to an indole.",
      'parent' => 2013,
    ),
    array(
      'tid' => 2015,
      'name' => "Thiadiazolidines",
      'description' => "Cyclic organic compounds containing a thiadiazole ring, which is a five-member saturated aliphatic  heterocycle made up of one sulfur atom and two nitrogen atoms.",
      'parent' => 2491,
    ),
    array(
      'tid' => 2016,
      'name' => "Thiadiazolines",
      'description' => "Cyclic organic compounds containing a thiadiazoline ring, which is a five-member unsaturated aliphatic  heterocycle made up of one sulfur atom and two nitrogen atoms.",
      'parent' => 2490,
    ),
    array(
      'tid' => 2017,
      'name' => "Thiophene carboxylic acids and derivatives",
      'description' => "Compounds containing a thiophene ring which bears a carboxylic acid group (or a salt/ester thereof).",
      'parent' => 97,
    ),
    array(
      'tid' => 2018,
      'name' => "Thiophene carboxamides",
      'description' => "Compounds containing a thiophene ring which bears a carboxamide.",
      'parent' => 2017,
    ),
    array(
      'tid' => 2019,
      'name' => "Phenylpyrazoles",
      'description' => "Compounds containing a phenylpyrazole skeleton, which consists of a pyrazole bound to a phenyl group.",
      'parent' => 87,
    ),
    array(
      'tid' => 2020,
      'name' => "Thienopyrimidines",
      'description' => "Heterocyclic compounds containing a thiophene ring fused to a pyrimidine ring. Thiophene is 5-membered ring consisting of four carbon atoms and one sulfur atom. Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions.",
      'parent' => 2,
    ),
    array(
      'tid' => 2021,
      'name' => "Bi- and oligothiophenes",
      'description' => "Organic compounds containing two or more linked thiophene rings. Thiophene is a five-member aromatic ring with one sulfur and four carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2022,
      'name' => "Ureides",
      'description' => "Compounds containing an ureide group with the general structure R1-CO-NH-CO-N(R)2R3, formally derived by the acylation of urea. They can be subdivided in N-acyl or N,N'-diacyl ureas.",
      'parent' => 517,
    ),
    array(
      'tid' => 2023,
      'name' => "N-acyl ureas",
      'description' => "Compounds containing an urea bearing a N-acyl group.",
      'parent' => 2022,
    ),
    array(
      'tid' => 2024,
      'name' => "N,N'-diacyl ureas",
      'description' => "Compounds containing a N-acyl group on each nitrogen atom of an urea.",
      'parent' => 2022,
    ),
    array(
      'tid' => 2025,
      'name' => "Thioketone s-oxides",
      'description' => "Organic compounds containing a functional group with the general structure R2C=S=O (R not H).",
      'parent' => 121,
    ),
    array(
      'tid' => 2026,
      'name' => "Dithiohemiacetals",
      'description' => "Compounds containing a dithiohemiacetal group with the general formula R2C(SR')SH, where R' != H.",
      'parent' => 2485,
    ),
    array(
      'tid' => 2027,
      'name' => "Seleninic acids and derivatives",
      'description' => "Compounds containing a seleninic acid moiety, with the general structure RSe(=O)OH.",
      'parent' => 264,
    ),
    array(
      'tid' => 2028,
      'name' => "Dipyrrins",
      'description' => "Compounds containing two pyrrole rings fused via a methine (-C=) group.",
      'parent' => 2257,
    ),
    array(
      'tid' => 2029,
      'name' => "Semioxamazones",
      'description' => "Compounds containing a semioxamazone functional group, with the structure R2C=NNHC(=O)C(=O)NH2, which is derived from the condensation of aldehydes or ketones with semioxamazide.",
      'parent' => 112,
    ),
    array(
      'tid' => 2030,
      'name' => "Ergopeptines",
      'description' => "Ergoline derivatives that contain a tripeptide structure attached to the basic ergoline ring in the same location as the amide group of the lysergic acid derivatives.",
      'parent' => 2680,
    ),
    array(
      'tid' => 2031,
      'name' => "Stigmastanes and derivatives",
      'description' => "Sterol lipids with a structure based on the stigmastane skeleton, which consists of a cholestane moiety bearing an ethyl group at the carbon atom C24.",
      'parent' => 258,
    ),
    array(
      'tid' => 2032,
      'name' => "Isoselenocyanates",
      'description' => "Organic compounds containing the isoselenocyanate group, an isocyanate analogue with the general formula RN=C=Se.",
      'parent' => 2468,
    ),
    array(
      'tid' => 2033,
      'name' => "Carbonyl imides",
      'description' => "Organic compounds containing a carbonyl imide group (a carbon atom linked through a double bond to an oxygen atom, which is in turn linked to a nitrogen atom).",
      'parent' => 3701,
    ),
    array(
      'tid' => 2034,
      'name' => "Carbonyl oxides",
      'description' => "Organic compounds containing a carbonyl imide group (a carbon atom linked through a double bond to an oxygen atom, which is in turn linked to an oxygen atom).",
      'parent' => 3701,
    ),
    array(
      'tid' => 2035,
      'name' => "Organic thiosulfuric acids and derivatives",
      'description' => "Organic compounds containing the thiosulfuric acid functional group or a derivative thereof.",
      'parent' => 264,
    ),
    array(
      'tid' => 2036,
      'name' => "Azo imides",
      'description' => "N-Imides of azo compounds, analogous to azoxy compounds, having a delocalized structure.",
      'parent' => 3631,
    ),
    array(
      'tid' => 2037,
      'name' => "Azoxy compounds",
      'description' => "Organic compounds sharing a common functional group with the general structure RN=N+(O-)R.",
      'parent' => 3631,
    ),
    array(
      'tid' => 2038,
      'name' => "Formazans",
      'description' => "Compounds containing the formazan group with the formula R1(R2)NN=CHN=NR3 (R1,R2,R3=H, alkyl, or aryl).",
      'parent' => 112,
    ),
    array(
      'tid' => 2039,
      'name' => "Gorgostanes and derivatives",
      'description' => "Steroids containing a gorgostane moiety, which a skeleton characterized by the presence.",
      'parent' => 258,
    ),
    array(
      'tid' => 2040,
      'name' => "Selenols",
      'description' => "Organic compounds that contains the functional group with the connectivity R-Se-H.",
      'parent' => 2468,
    ),
    array(
      'tid' => 2041,
      'name' => "Selones",
      'description' => "Organic compounds that contains the functional group with the connectivity RC(=Se)R' (R,R' not H).",
      'parent' => 2468,
    ),
    array(
      'tid' => 2042,
      'name' => "Terphenyls",
      'description' => "Polycyclic aromatic compounds containing a terphenyl skeleton, which consists of a benzene ring substituted with two phenyl groups. Isomers of terphenyl include m-terphenyls (1,3-diphenylbenzenes),  o-terphenyls (1,2-diphenylbenzenes),  p-terphenyls (1,4-diphenylbenzenes).",
      'parent' => 2279,
    ),
    array(
      'tid' => 2043,
      'name' => "Acenaphthenes and derivatives",
      'description' => "Organic compounds containing a naphthalene ring with an ethylene bridge connecting positions 1 and 8.",
      'parent' => 23,
    ),
    array(
      'tid' => 2044,
      'name' => "Phenylnaphthalenes",
      'description' => "Compounds containing a phenylnaphthalene skeleton, which consists of a naphthalene bound to a phenyl group.",
      'parent' => 23,
    ),
    array(
      'tid' => 2045,
      'name' => "Bakkenolides",
      'description' => "Sesquiterpene lactones containing a spiro[indene-2,3'-oxolane]-2'-one backbone.",
      'parent' => 1543,
    ),
    array(
      'tid' => 2046,
      'name' => "Ambrosanolides and secoambrosanolides",
      'description' => "Sesquiterpene lactones from the Ambrosia family, with a backbone derivative of azuleno[6,5-b]furan-2-one (ambrosanolides) or azuleno[4,5-b]furan-2-one (secoambrosanolides).",
      'parent' => 1543,
    ),
    array(
      'tid' => 2047,
      'name' => "Eremophilanolides and secoeremophilanolides",
      'description' => "Compounds containing the eremophilanolide skeleton, which is structurally characterized by a naphtho[2,3-b]furan-2-one ring system or a derivative thereof.",
      'parent' => 1543,
    ),
    array(
      'tid' => 2048,
      'name' => "Cadinanolides",
      'description' => "Sesquiterpene lactones based on 2-dioxonaphtho[4a,4-b]furan.",
      'parent' => 1543,
    ),
    array(
      'tid' => 2049,
      'name' => "Terpene glycosides",
      'description' => "Prenol lipids containing a carbohydrate moiety glycosidically bound to a terpene backbone.",
      'parent' => 259,
    ),
    array(
      'tid' => 2050,
      'name' => "Tetrathianes",
      'description' => "Organic compounds containing a tetrathiane ring, which is a six-member saturated aliphatic ring made up of four sulfur atoms and two carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2051,
      'name' => "Agarofurans",
      'description' => "Organic compounds containing an agarofuran moiety( a three-ring system, with core fragment oxatricyclo[7.2.1.0^{1,6}]dodec-2-ene).",
      'parent' => 1550,
    ),
    array(
      'tid' => 2052,
      'name' => "Metalloheterocyclic compounds",
      'description' => "Heterocyclic compounds contain one metal ring atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 2053,
      'name' => "Silyl enol ethers",
      'description' => "Organic compounds containing an enolate bonded through its oxygen terminus to an organosilicon group.",
      'parent' => 3194,
    ),
    array(
      'tid' => 2054,
      'name' => "Isoquinolones and derivatives",
      'description' => "Aromatic polycyclic compounds containing a ketone bearing isoquinoline moiety.",
      'parent' => 2566,
    ),
    array(
      'tid' => 2055,
      'name' => "Dithiins",
      'description' => "Compounds comprising a dithiin ring, which is an unsaturated six-member heterocycle containing four carbon atoms, two sulfur atoms and two double bonds.",
      'parent' => 2,
    ),
    array(
      'tid' => 2056,
      'name' => "Furazans",
      'description' => "Compounds containing a furazan moiety, which consists of a five-membered aromatic ring with 1 oxygen and 2 nitrogen atoms at positions 2, 1, and 5, respectively.",
      'parent' => 1822,
    ),
    array(
      'tid' => 2057,
      'name' => "Furoxans",
      'description' => "Compounds containing a furoxan (1,2,5-oxadiazol-2-ium-2-olate) moiety.",
      'parent' => 2056,
    ),
    array(
      'tid' => 2058,
      'name' => "Oxathiins",
      'description' => "Compounds containing an oxathiin moiety, which consists of an unsaturated aliphatic six-member ring with one oxygen atom, a sulfur atom, and four carbon atoms. Isomers  of oxaphospholane include 1,2-oxathiin, 1,3-oxathiin,and 1,4-oxathiin.",
      'parent' => 2,
    ),
    array(
      'tid' => 2059,
      'name' => "Benzoxathiins",
      'description' => "Organic compounds containing a benzene fused to an oxathiin ring (a six-membered aliphatic ring with four carbon atoms, one oxygen atom, and one sulfur atom).",
      'parent' => 2,
    ),
    array(
      'tid' => 2060,
      'name' => "Phenoxathiins",
      'description' => "Polycyclic aromatic compounds containing a phenoxathiin moiety, which is a linear tricyclic system that consists of a two benzene rings joined by a 1,4-oxathiin ring.",
      'parent' => 2059,
    ),
    array(
      'tid' => 2061,
      'name' => "Diazaphospholanes",
      'description' => "Cyclic organic compounds containing a five-member aliphatic single-bonded ring, with a phosphorine atom and two nitrogen atoms at the ring positions 1, 2, and 3 respectively.",
      'parent' => 2,
    ),
    array(
      'tid' => 2062,
      'name' => "Diazaphospholines",
      'description' => "Cyclic organic compounds containing a five-member aliphatic unsaturated ring with only double bond, and with a phosphorine atom, two nitrogen atoms at the ring positions 1, 2, and 3 respectively.",
      'parent' => 2,
    ),
    array(
      'tid' => 2063,
      'name' => "Diazaphospholes",
      'description' => "Cyclic organic compounds containing a five-member aliphatic unsaturated ring with two double bonds, and with a phosphorine atom, two nitrogen atoms at the ring positions 1, 2, and 3 respectively.",
      'parent' => 2,
    ),
    array(
      'tid' => 2064,
      'name' => "Histrionicotoxins",
      'description' => "Frog toxins structurally characterized by the presence of a dodecahydropyrrolo[1,2-a]quinolin-1-yl}ethanol moiety or a 2,7-disubstituted 1-azaspiro[5.5]undecan-8-ol moiety.",
      'parent' => 279,
    ),
    array(
      'tid' => 2065,
      'name' => "Organic orthonitrates",
      'description' => "Organic compounds containing the orhthonitrate oxoanion, with the formula [NO4]3−.",
      'parent' => 463,
    ),
    array(
      'tid' => 2066,
      'name' => "Organic perbromates",
      'description' => "Organic compounds containing the perbromate oxoanion, with the formula  [BrO4]-.",
      'parent' => 463,
    ),
    array(
      'tid' => 2067,
      'name' => "Organic perchlorates",
      'description' => "Organic compounds containing the perchlorate oxoanion, with the formula  [ClO4]-.",
      'parent' => 463,
    ),
    array(
      'tid' => 2068,
      'name' => "Organic periodates",
      'description' => "Organic compounds containing the periodate oxoanion, with the formula  [IO4]-.",
      'parent' => 463,
    ),
    array(
      'tid' => 2069,
      'name' => "Organic permanganates",
      'description' => "Organic compounds containing the permanganate oxoanion, with the formula  [MnO4]-.",
      'parent' => 463,
    ),
    array(
      'tid' => 2070,
      'name' => "Organic pertechnetates",
      'description' => "Organic compounds containing the pertechnetate oxoanion, with the formula  [TcO4]-.",
      'parent' => 463,
    ),
    array(
      'tid' => 2071,
      'name' => "Organic phosphites",
      'description' => "Organic compounds containing the phosphite oxoanion, with the formula  [PO3]3-.",
      'parent' => 463,
    ),
    array(
      'tid' => 2072,
      'name' => "Organic selenates",
      'description' => "Organic compounds containing the selenate oxoanion, with the formula  [SeO4]2-.",
      'parent' => 463,
    ),
    array(
      'tid' => 2073,
      'name' => "Organic selenites",
      'description' => "Organic compounds containing the selenite oxoanion, with the formula  [SeO3]2-.",
      'parent' => 463,
    ),
    array(
      'tid' => 2074,
      'name' => "Sulfite esters",
      'description' => "Organic compounds containing an organic group attached to the sulfite oxoanion, with the formula  R[SO3]2-.",
      'parent' => 4456,
    ),
    array(
      'tid' => 2075,
      'name' => "M-quinomethanes",
      'description' => "Organic compounds containing a benzene ring conjugated to a methylidene group and a ketone at carbon atoms 1 and 3, respectively.",
      'parent' => 125,
    ),
    array(
      'tid' => 2076,
      'name' => "Organic peroxomonosulfates",
      'description' => "Organic compounds containing the peroxomonosulfate oxoanion, with the formula [SO5]2-.",
      'parent' => 463,
    ),
    array(
      'tid' => 2077,
      'name' => "Organic peroxodisulfates",
      'description' => "Organic compounds containing the peroxodisulfate oxoanion, with the formula [S2O8]2−.",
      'parent' => 463,
    ),
    array(
      'tid' => 2078,
      'name' => "Organic pyrosulfates",
      'description' => "Organic compounds containing the pyrosulfate oxoanion, with the structure OS([O-])(=O)OS(O)([O-])=O.",
      'parent' => 463,
    ),
    array(
      'tid' => 2079,
      'name' => "Organic tetrathionates",
      'description' => "Organic compounds containing the tetrathionate oxoanion, with the formula  [S4O6]2−.",
      'parent' => 463,
    ),
    array(
      'tid' => 2080,
      'name' => "Organic thiosulfates",
      'description' => "Organic compounds containing the thiosulfate oxoanion, with the formula [S2O3]2-, or its conjugate base.",
      'parent' => 463,
    ),
    array(
      'tid' => 2081,
      'name' => "Organic dithionites",
      'description' => "Organic compounds containing the dithionite oxoanion, with the formula [S2O4]2−.",
      'parent' => 463,
    ),
    array(
      'tid' => 2082,
      'name' => "Organic hyposulfites",
      'description' => "Organic compounds containing the hyposulfite oxoanion, with the formula [SO2]2-.",
      'parent' => 463,
    ),
    array(
      'tid' => 2083,
      'name' => "Isoxazolidines",
      'description' => "Organic heterocyclic compounds containing an isoxazolidine moiety, with a structure characterized by a five-member saturated aliphatic ring with one oxygen atom and one nitrogen atom at ring positions 1 and 2, respectively.",
      'parent' => 2491,
    ),
    array(
      'tid' => 2084,
      'name' => "Isoxazolidinones",
      'description' => "Organic heterocyclic compounds containing an isoxazolidine moiety, which consists of an isoxazolidine ring which bears a ketone.",
      'parent' => 2083,
    ),
    array(
      'tid' => 2085,
      'name' => "Pyrazinecarboxamides",
      'description' => "Compounds containing a pyrazine ring which bears a carboxamide.",
      'parent' => 2265,
    ),
    array(
      'tid' => 2086,
      'name' => "Sulfanylbenzoic acids and derivatives",
      'description' => "Benzoic acids (or derivatives) which bear a sulfanyl group (R-SH) attached to the benzene ring.",
      'parent' => 176,
    ),
    array(
      'tid' => 2087,
      'name' => "Indoloquinazolines",
      'description' => "Polycyclic aromatic compounds containing an indole fused to a quinazoline. Indole is a bicyclic  compound consisting of a six-membered benzene ring fused to a five-membered nitrogen-containing pyrrole ring. Quinazoline is a heterocyclic compound consisting of two fused six-membered simple aromatic rings, a benzene ring and a pyrimidine ring.",
      'parent' => 485,
    ),
    array(
      'tid' => 2088,
      'name' => "Acyloins",
      'description' => "Organic compounds containing an alpha hydroxy ketone. Acyloins are formally derived from reductive coupling of carboxylic acyl groups.",
      'parent' => 1831,
    ),
    array(
      'tid' => 2089,
      'name' => "Oxoprolines",
      'description' => "Compounds containing an oxoproline moiety, which consists of a pyrrolidine ring bearing a carboxylic acid group at the ring position 2, and a ketone group.",
      'parent' => 1158,
    ),
    array(
      'tid' => 2090,
      'name' => "Dithioles",
      'description' => "Compounds comprising a dithiole ring, which is an unsaturated five-member heterocycle containing three carbon atoms, two sulfur atoms and a double bond.",
      'parent' => 2,
    ),
    array(
      'tid' => 2091,
      'name' => "Dihydrothiophenes",
      'description' => "Compounds containing a dihydrothiophene moiety, which is a thiophene derivative with only one double bond.",
      'parent' => 2,
    ),
    array(
      'tid' => 2092,
      'name' => "Tocotrienols",
      'description' => "Vitamin E derivatives containing an unsaturated trimethyltrideca-3,7,11-trien-1-yl chain attached to the carbon C6 atom of a benzopyran ring system. The differ from tocopherols that contain a saturated trimethyltridecyl chain.",
      'parent' => 1546,
    ),
    array(
      'tid' => 2093,
      'name' => "N-sulfonyl-1,2,4-triazoles",
      'description' => "Cyclic compounds containing a sulfonyl group attached to an N atoms of a 1,2,4-triazole ring.",
      'parent' => 1120,
    ),
    array(
      'tid' => 2094,
      'name' => "Glucuronic acid derivatives",
      'description' => "Compounds containing a glucuronic acid moiety (or a derivative), which consists of a glucose moiety with the C6 carbon oxidized to a carboxylic acid.",
      'parent' => 215,
    ),
    array(
      'tid' => 2095,
      'name' => "Methanesulfonates",
      'description' => "Compounds containing a methanesulfonate moiety, which consists of a methane linked to the sulfur atom of a sulfonate group.",
      'parent' => 3136,
    ),
    array(
      'tid' => 2096,
      'name' => "Beta sultims",
      'description' => "Organic compounds containing a sulfonamide group in which the N=S double bond is part of a four member ring. Beta Sultims are tautomeric forms of sultams, where N-S bond is double and not single.",
      'parent' => 1387,
    ),
    array(
      'tid' => 2097,
      'name' => "Gamma sultims",
      'description' => "Organic compounds containing a sulfonamide group in which the N=S double bond is part of a five member ring. Gamma Sultims are tautomeric forms of gamma sultams, where N-S bond is double and not single.",
      'parent' => 1387,
    ),
    array(
      'tid' => 2098,
      'name' => "Delta sultims",
      'description' => "Organic compounds containing a sulfonamide group in which the N=S double bond is part of a six member ring. Sultims are tautomeric forms of sultams, where N-S bond is double and not single.",
      'parent' => 1387,
    ),
    array(
      'tid' => 2099,
      'name' => "Cyclohexylphenols",
      'description' => "Compounds containing a cyclohexane lined to a phenol group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 2100,
      'name' => "Benzodioxins",
      'description' => "Organic compounds containing a benzene ring fused to a dioxin ring. Dioxin a six-membered unsaturated ring of two oxygen atoms and four carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2101,
      'name' => "1-acyl-sn-glycerol-3-phosphoinositols",
      'description' => "Glycerophosphoinositols where the glycerol is acylated only at position O-1 with a fatty acid.",
      'parent' => 1355,
    ),
    array(
      'tid' => 2102,
      'name' => "Azarsinanes",
      'description' => "Organic compounds containing a six-member saturated aliphatic ring containing a nitrogen atom (at carbon 1), an arsenic atom (at carbon 4), and four carbon atoms.",
      'parent' => 2052,
    ),
    array(
      'tid' => 2103,
      'name' => "Benzarsazines and derivatives",
      'description' => "Polycyclic aromatic compounds containing a benzene ring fused to a 1,4-azarsine ring.",
      'parent' => 2052,
    ),
    array(
      'tid' => 2104,
      'name' => "Phenarsazines and derivatives",
      'description' => "Polycyclic aromatic compounds containing two benzene rings joined by a 1,4-azarsine (or a derivative thereof).",
      'parent' => 2103,
    ),
    array(
      'tid' => 2105,
      'name' => "Glycosyl compounds",
      'description' => "Carbohydrate derivatives in which a sugar group is bonded through its anomeric carbon to another group via a C-, S-,N-,O-, or Se- glycosidic bond.",
      'parent' => 11,
    ),
    array(
      'tid' => 2106,
      'name' => "Anthracyclines",
      'description' => "Polyketides containing a tetracenequinone ring structure with a sugar attached by glycosidic linkage.",
      'parent' => 261,
    ),
    array(
      'tid' => 2107,
      'name' => "Benzodioxinopyrroles",
      'description' => "Polycyclic aromatic compounds containing a pyrrole ring fused to the dioxin ring of a benzo-p-dioxin.",
      'parent' => 1379,
    ),
    array(
      'tid' => 2108,
      'name' => "Benzomorpholines",
      'description' => "Polycyclic aromatic compounds containing a benzene ring fused to a morpholine ring.",
      'parent' => 392,
    ),
    array(
      'tid' => 2109,
      'name' => "Dioxiranes",
      'description' => "Compounds containing a three-membered cyclic with two oxygen atoms and a carbon atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 2110,
      'name' => "Furoindazoles",
      'description' => "Polycyclic aromatic compounds containing a furan ring fused to the benzene ring of an indazole.",
      'parent' => 80,
    ),
    array(
      'tid' => 2111,
      'name' => "Pyranopyridines",
      'description' => "Polycyclic aromatic compounds containing a pyran ring fused to a pyridine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 2112,
      'name' => "Azaborines",
      'description' => "Organic compounds containing a six-member aromatic ring containing a nitrogen atom, an arsenic atom, and four carbon atoms.",
      'parent' => 2052,
    ),
    array(
      'tid' => 2113,
      'name' => "Azaborinines",
      'description' => "Organic compounds containing a six-member unsaturated aliphatic ring containing a nitrogen atom, an arsenic atom, and four carbon atoms.",
      'parent' => 2052,
    ),
    array(
      'tid' => 2114,
      'name' => "Naphthothiazoles",
      'description' => "Polycyclic aromatic compounds containing a thiazole fused to a naphthalene. Thiazole is a 5-membered aromatic ring containing three carbon, one oxygen, and one nitrogen atom. Naphthalene is a polycyclic aromatic hydrocarbon  made up of two fused benzene rings.",
      'parent' => 2,
    ),
    array(
      'tid' => 2115,
      'name' => "Stannines",
      'description' => "Compounds containing a benzene analogue in which one of the carbon atoms is replaced by a tin atom.",
      'parent' => 1524,
    ),
    array(
      'tid' => 2116,
      'name' => "Stannoles",
      'description' => "Compounds containing a five-member aromatic ring with one tin atom and four carbon atoms.",
      'parent' => 1524,
    ),
    array(
      'tid' => 2117,
      'name' => "Triazolopyridazines",
      'description' => "Polycyclic compounds containing a triazole fused to a pyridazine. Triazole is a five-membered ring consisting of two carbon atoms and three nitrogen atoms. Pyridazine is a six-membered aromatic ring with two adjacent nitrogen atoms, and for carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2118,
      'name' => "Oxazolopyridines",
      'description' => "Polycyclic compounds containing an oxazole ring fused to a pyridine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 2119,
      'name' => "Quassinoids",
      'description' => "A group of compounds chemically degraded from triterpenes. According to their basic skeleton, quassinoids are categorized into five distinct groups, C-18, C-19, C-20, C-22 and C-25 types. The C-20 quassinoids can be further classified into two types, tetracyclic and the pentacyclic. The tetracyclic variety does not have oxygenation at C-20, while the pentacyclic quassinoids possess additional oxygenation at C-20 that allows for the formation of an additional ring.",
      'parent' => 1283,
    ),
    array(
      'tid' => 2120,
      'name' => "2-acyl-sn-glycerol-3-phosphoinositols",
      'description' => "Glycerophosphoinositols where the glycerol is acylated only at position O-2 with a fatty acid.",
      'parent' => 1355,
    ),
    array(
      'tid' => 2121,
      'name' => "2',5'-cyclic pyrimidine nucleotides",
      'description' => "Pyrimidine nucleotides in which the oxygen atoms linked to the C2 and C5 carbon atoms of the ribose moiety are both bonded the same phosphorus atom of the phosphate group.",
      'parent' => 1492,
    ),
    array(
      'tid' => 2122,
      'name' => "O-quinomethanes",
      'description' => "Organic compounds containing a benzene ring conjugated to a methylidene group and a ketone at carbon atoms 1 and 2, respectively.",
      'parent' => 125,
    ),
    array(
      'tid' => 2123,
      'name' => "P-quinomethanes",
      'description' => "Organic compounds containing a benzene ring conjugated to a methylidene group and a ketone at carbon atoms 1 and 4, respectively.",
      'parent' => 125,
    ),
    array(
      'tid' => 2124,
      'name' => "Triazolothiazoles",
      'description' => "Polycyclic compounds containing a triazole ring fused to a thiazole ring. Triazole is a five-membered ring consisting of two carbon atoms and three nitrogen atoms. Thiazole is a 6-membered ring that contains both sulfur and nitrogen.",
      'parent' => 2,
    ),
    array(
      'tid' => 2125,
      'name' => "Alkyl glycosides",
      'description' => "Lipids containing a glycosyl moiety (one or several units) linked to the hydroxyl group of a fatty alcohol.",
      'parent' => 1766,
    ),
    array(
      'tid' => 2126,
      'name' => "P-terphenyls",
      'description' => "Terphenyls with a structure containing the 1,4-diphenylbenzene skeleton.",
      'parent' => 2042,
    ),
    array(
      'tid' => 2127,
      'name' => "Pyrazolopyrazoles",
      'description' => "Polycyclic aromatic compounds containing to pyrazole rings fused to each other. Pyrazole is 5-membered ring consisting of three carbon atoms and two adjacent nitrogen centers.",
      'parent' => 2,
    ),
    array(
      'tid' => 2128,
      'name' => "Pyrrolopyrazoles",
      'description' => "Polycyclic aromatic compounds containing a pyrrole fused to a pyrazole ring. Pyrrole is 5-membered ring consisting of four carbon atoms and one nitrogen atom. Pyrazole is a 5-membered ring consisting of three carbon atoms and two adjacent nitrogen centers.",
      'parent' => 2,
    ),
    array(
      'tid' => 2129,
      'name' => "Pyranopyrimidines",
      'description' => "Polycyclic aromatic compounds containing a pyran ring fused to a pyrimidine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 2130,
      'name' => "Monothioketals",
      'description' => "Compounds containing a monothioketal functional group with the general structure R2C(OR')(SR') with (R = any atom but H).",
      'parent' => 2131,
    ),
    array(
      'tid' => 2131,
      'name' => "Monothioacetals",
      'description' => "Compounds containing a monothioacetal functional group with the general structure R2C(OR')(SR').",
      'parent' => 1187,
    ),
    array(
      'tid' => 2132,
      'name' => "Dithioacetals",
      'description' => "Compounds containing a dithioacetal functional group with the general structure R2C(SR')2.",
      'parent' => 1187,
    ),
    array(
      'tid' => 2133,
      'name' => "Dithioketals",
      'description' => "Compounds containing a dithioketal functional group with the general structure R2C(SR')2 with R, R' = organyl.",
      'parent' => 2132,
    ),
    array(
      'tid' => 2134,
      'name' => "Purine deoxyribonucleotides",
      'description' => "Purine nucleotides where the purine moiety is linked to a ribose lacking a hydroxyl group at one or more positions.",
      'parent' => 1506,
    ),
    array(
      'tid' => 2135,
      'name' => "Purine deoxyribonucleoside monophosphates",
      'description' => "Purine ribonucleotides with one monophosphate group attached to one hydroxyl group of the ribose moiety, which lacks a hydroxyl group at one or more positions.",
      'parent' => 2134,
    ),
    array(
      'tid' => 2136,
      'name' => "Purine deoxyribonucleoside diphosphates",
      'description' => "Purine ribonucleotides with one diphosphate group attached to one hydroxyl group of the ribose moiety, which lacks a hydroxyl group at one or more positions.",
      'parent' => 2134,
    ),
    array(
      'tid' => 2137,
      'name' => "Purine deoxyribonucleoside triphosphates",
      'description' => "Purine ribonucleotides with one triphosphate group attached to one hydroxyl group of the ribose moiety, which lacks a hydroxyl group at one or more positions.",
      'parent' => 2134,
    ),
    array(
      'tid' => 2138,
      'name' => "Purine deoxyribonucleoside polyphosphates",
      'description' => "Purine ribonucleotides with one polyphosphate (with at least four repetitively linked phosphates) group attached to one hydroxyl group of the ribose moiety, which lacks a hydroxyl group at one or more positions.",
      'parent' => 2134,
    ),
    array(
      'tid' => 2139,
      'name' => "Purine 2'-deoxyribonucleoside diphosphates",
      'description' => "Purine nucleotides with diphosphate group  linked to the ribose moiety lacking a hydroxyl group at position 2.",
      'parent' => 2136,
    ),
    array(
      'tid' => 2140,
      'name' => "Purine 3'-deoxyribonucleoside diphosphates",
      'description' => "Purine nucleotides with diphosphate group  linked to the ribose moiety lacking a hydroxyl group at position 3.",
      'parent' => 2136,
    ),
    array(
      'tid' => 2141,
      'name' => "Purine 2'-deoxyribonucleoside monophosphates",
      'description' => "Purine nucleotides with monophosphate group  linked to the ribose moiety lacking a hydroxyl group at position 2.",
      'parent' => 2135,
    ),
    array(
      'tid' => 2142,
      'name' => "Purine 3'-deoxyribonucleoside monophosphates",
      'description' => "Purine nucleotides with monophosphate group  linked to the ribose moiety lacking a hydroxyl group at position 3.",
      'parent' => 2135,
    ),
    array(
      'tid' => 2143,
      'name' => "Purine 2'-deoxyribonucleoside polyphosphates",
      'description' => "Purine nucleotides with polyphosphate (with 4 or more phosphate) group  linked to the ribose moiety lacking a hydroxyl group at position 2.",
      'parent' => 2138,
    ),
    array(
      'tid' => 2144,
      'name' => "Purine 3'-deoxyribonucleoside polyphosphates",
      'description' => "Purine nucleotides with polyphosphate (with 4 or more phosphate) group  linked to the ribose moiety lacking a hydroxyl group at position 3.",
      'parent' => 2138,
    ),
    array(
      'tid' => 2145,
      'name' => "Purine 2'-deoxyribonucleoside triphosphates",
      'description' => "Purine nucleotides with triphosphate group  linked to the ribose moiety lacking a hydroxyl group at position 2.",
      'parent' => 2137,
    ),
    array(
      'tid' => 2146,
      'name' => "Purine 3'-deoxyribonucleoside triphosphates",
      'description' => "Purine nucleotides with triphosphate group  linked to the ribose moiety lacking a hydroxyl group at position 3.",
      'parent' => 2137,
    ),
    array(
      'tid' => 2147,
      'name' => "Pyrimidine ribonucleotides",
      'description' => "Nucleotides consisting of a pyrimidine base linked to a ribose to which at least phosphate group is attached.",
      'parent' => 1509,
    ),
    array(
      'tid' => 2148,
      'name' => "Pyrimidine deoxyribonucleotides",
      'description' => "Pyrimidine nucleotides where the purine moiety is linked to a ribose lacking a hydroxyl group at one or more positions.",
      'parent' => 1509,
    ),
    array(
      'tid' => 2149,
      'name' => "Pyrimidine deoxyribonucleoside bisphosphates",
      'description' => "Pyrimidine ribobucleotides with one phosphate group attached to each of two different hydroxyl groups of the ribose moiety, which lacks a hydroxyl group at one or more positions.",
      'parent' => 2148,
    ),
    array(
      'tid' => 2150,
      'name' => "Pyrimidine deoxyribonucleoside diphosphates",
      'description' => "Pyrimidine ribobucleotides with one diphosphate group attached to one hydroxyl group of the ribose moiety, which lacks a hydroxyl group at one or more positions.",
      'parent' => 2148,
    ),
    array(
      'tid' => 2151,
      'name' => "Pyrimidine deoxyribonucleoside monophosphates",
      'description' => "Pyrimidine ribobucleotides with one monophosphate group attached to one hydroxyl group of the ribose moiety, which lacks a hydroxyl group at one or more positions.",
      'parent' => 2148,
    ),
    array(
      'tid' => 2152,
      'name' => "Pyrimidine deoxyribonucleoside polyphosphates",
      'description' => "Pyrimidine ribobucleotides with one polyphosphate (with at least four repetitively linked phosphates) group attached to one hydroxyl group of the ribose moiety, which lacks a hydroxyl group at one or more positions.",
      'parent' => 2148,
    ),
    array(
      'tid' => 2153,
      'name' => "Pyrimidine deoxyribonucleoside triphosphates",
      'description' => "Pyrimidine ribobucleotides with one triphosphate group attached to one hydroxyl group of the ribose moiety, which lacks a hydroxyl group at one or more positions.",
      'parent' => 2148,
    ),
    array(
      'tid' => 2154,
      'name' => "Pyrimidine deoxyribonucleoside 2',5'-bisphosphates",
      'description' => "Pyrimidine ribobucleotides with one phosphate group attached to each of two different hydroxyl groups of the ribose moiety, which lacks a hydroxyl group at position 3.",
      'parent' => 2149,
    ),
    array(
      'tid' => 2155,
      'name' => "Pyrimidine deoxyribonucleoside 3',5'-bisphosphates",
      'description' => "Pyrimidine ribobucleotides with one phosphate group attached to each of two different hydroxyl groups of the ribose moiety, which lacks a hydroxyl group at position 2.",
      'parent' => 2149,
    ),
    array(
      'tid' => 2156,
      'name' => "Pyrimidine 2'-deoxyribonucleoside diphosphates",
      'description' => "Pyrimidine nucleotides with a diphosphate group  linked to the ribose moiety lacking a hydroxyl group at position 2.",
      'parent' => 2150,
    ),
    array(
      'tid' => 2157,
      'name' => "Pyrimidine 3'-deoxyribonucleoside diphosphates",
      'description' => "Pyrimidine nucleotides with diphosphate group  linked to the ribose moiety lacking a hydroxyl group at position 3.",
      'parent' => 2150,
    ),
    array(
      'tid' => 2158,
      'name' => "Pyrimidine 2'-deoxyribonucleoside monophosphates",
      'description' => "Pyrimidine nucleotides with a monophosphate group  linked to the ribose moiety lacking a hydroxyl group at position 2.",
      'parent' => 2151,
    ),
    array(
      'tid' => 2159,
      'name' => "Pyrimidine 3'-deoxyribonucleoside monophosphates",
      'description' => "Pyrimidine nucleotides with monophosphate group  linked to the ribose moiety lacking a hydroxyl group at position 3.",
      'parent' => 2151,
    ),
    array(
      'tid' => 2160,
      'name' => "Pyrimidine 2'-deoxyribonucleoside polyphosphates",
      'description' => "Pyrimidine nucleotides with a polyphosphate (with 4 or more phosphate) group  linked to the ribose moiety lacking a hydroxyl group at position 2.",
      'parent' => 2152,
    ),
    array(
      'tid' => 2161,
      'name' => "Pyrimidine 3'-deoxyribonucleoside polyphosphates",
      'description' => "Pyrimidine nucleotides with polyphosphate (with 4 or more phosphate) group  linked to the ribose moiety lacking a hydroxyl group at position 3.",
      'parent' => 2152,
    ),
    array(
      'tid' => 2162,
      'name' => "Pyrimidine 2'-deoxyribonucleoside triphosphates",
      'description' => "Pyrimidine nucleotides with a triphosphate group  linked to the ribose moiety lacking a hydroxyl group at position 2.",
      'parent' => 2153,
    ),
    array(
      'tid' => 2163,
      'name' => "Pyrimidine 3'-deoxyribonucleoside triphosphates",
      'description' => "Pyrimidine nucleotides with triphosphate group  linked to the ribose moiety lacking a hydroxyl group at position 3.",
      'parent' => 2153,
    ),
    array(
      'tid' => 2164,
      'name' => "10,11-secoergolines",
      'description' => "Ergoline derivatives, where carbon atoms C10 and C11 of the ergoline moiety are not linked to each other.",
      'parent' => 279,
    ),
    array(
      'tid' => 2165,
      'name' => "Pyrimidine 2',3'-dideoxyribonucleoside diphosphates",
      'description' => "Pyrimidine nucleotides with diphosphate group  linked to the ribose moiety lacking a hydroxyl group at positions 2 and 3.",
      'parent' => 2150,
    ),
    array(
      'tid' => 2166,
      'name' => "Pyrimidine 2',3'-dideoxyribonucleoside monophosphates",
      'description' => "Pyrimidine nucleotides with monophosphate group  linked to the ribose moiety lacking a hydroxyl group at positions 2 and 3.",
      'parent' => 2151,
    ),
    array(
      'tid' => 2167,
      'name' => "Pyrimidine 2',3'-dideoxyribonucleoside polyphosphates",
      'description' => "Pyrimidine nucleotides with polyphosphate (with 4 or more phosphate) group  linked to the ribose moiety lacking a hydroxyl group at positions 2 and 3.",
      'parent' => 2152,
    ),
    array(
      'tid' => 2168,
      'name' => "Pyrimidine 2',3'-dideoxyribonucleoside triphosphates",
      'description' => "Pyrimidine nucleotides with triphosphate group  linked to the ribose moiety lacking a hydroxyl group at positions 2 and 3.",
      'parent' => 2153,
    ),
    array(
      'tid' => 2169,
      'name' => "Purine 2',3'-dideoxyribonucleoside diphosphates",
      'description' => "Purine nucleotides with diphosphate group  linked to the ribose moiety lacking a hydroxyl group at positions 2 and 3.",
      'parent' => 2136,
    ),
    array(
      'tid' => 2170,
      'name' => "Purine 2',3'-dideoxyribonucleoside monophosphates",
      'description' => "Purine nucleotides with monophosphate group  linked to the ribose moiety lacking a hydroxyl group at positions 2 and 3.",
      'parent' => 2135,
    ),
    array(
      'tid' => 2171,
      'name' => "Purine 2',3'-dideoxyribonucleoside polyphosphates",
      'description' => "Purine nucleotides with polyphosphate (with 4 or more phosphate) group  linked to the ribose moiety lacking a hydroxyl group at positions 2 and 3.",
      'parent' => 2138,
    ),
    array(
      'tid' => 2172,
      'name' => "Purine 2',3'-dideoxyribonucleoside triphosphates",
      'description' => "Purine nucleotides with triphosphate group  linked to the ribose moiety lacking a hydroxyl group at positions 2 and 3.",
      'parent' => 2137,
    ),
    array(
      'tid' => 2173,
      'name' => "Purine deoxyribonucleoside bisphosphates",
      'description' => "Purine ribonucleotides with one phosphate group attached to each of two different hydroxyl groups of the ribose moiety, which lacks a hydroxyl group at one or more positions.",
      'parent' => 2134,
    ),
    array(
      'tid' => 2174,
      'name' => "Pyrazole ribonucleosides and ribonucleotides",
      'description' => "Nucleosides and nucleotides containing a pyrazole moiety is linked to a ribose (or ribose derivative).",
      'parent' => 289,
    ),
    array(
      'tid' => 2175,
      'name' => "Purine deoxyribonucleoside 3',5'-bisphosphates",
      'description' => "Purine ribobucleotides with one phosphate group attached to each of two different hydroxyl groups of the ribose moiety, which lacks a hydroxyl group at position 2.",
      'parent' => 2173,
    ),
    array(
      'tid' => 2176,
      'name' => "Purine deoxyribonucleoside 2',5'-bisphosphates",
      'description' => "Purine ribobucleotides with one phosphate group attached to each of two different hydroxyl groups of the ribose moiety, which lacks a hydroxyl group at position 3.",
      'parent' => 2173,
    ),
    array(
      'tid' => 2177,
      'name' => "Purine 2'-deoxyribonucleosides",
      'description' => "Compounds consisting of a purine linked to a ribose which lacks a hydroxyl group at position 2.",
      'parent' => 479,
    ),
    array(
      'tid' => 2178,
      'name' => "Purine 3'-deoxyribonucleosides",
      'description' => "Compounds consisting of a purine linked to a ribose which lacks a hydroxyl group at position 3.",
      'parent' => 479,
    ),
    array(
      'tid' => 2179,
      'name' => "Purine 2',3'-dideoxyribonucleosides",
      'description' => "Compounds consisting of a purine linked to a ribose which lacks a hydroxyl group at positions 2 and 3.",
      'parent' => 479,
    ),
    array(
      'tid' => 2180,
      'name' => "Pyrimidine 2'-deoxyribonucleosides",
      'description' => "Compounds consisting of a pyrimidine linked to a ribose which lacks a hydroxyl group at position 2.",
      'parent' => 480,
    ),
    array(
      'tid' => 2181,
      'name' => "Pyrimidine 3'-deoxyribonucleosides",
      'description' => "Compounds consisting of a pyrimidine linked to a ribose which lacks a hydroxyl group at position 3.",
      'parent' => 480,
    ),
    array(
      'tid' => 2182,
      'name' => "Pyrimidine 2',3'-dideoxyribonucleosides",
      'description' => "Compounds consisting of a pyrimidine linked to a ribose which lacks a hydroxyl group at positions 2 and 3.",
      'parent' => 480,
    ),
    array(
      'tid' => 2183,
      'name' => "Phenyltriazoles",
      'description' => "Organic aromatic compounds containing a phenyl group substituted with a triazole ring.",
      'parent' => 99,
    ),
    array(
      'tid' => 2184,
      'name' => "Piperazinesulfonamides",
      'description' => "Organic cyclic compounds containing a sulfonamide group attached to a piperazine ring.",
      'parent' => 189,
    ),
    array(
      'tid' => 2185,
      'name' => "Pyrazolopyrimidine ribonucleosides and ribonucleotides",
      'description' => "Nucleoside or nucleotide analogues containing a pyrazolopyrimidine moiety is N-linked to a ribose (or ribose derivative).  Nucleotides have a phosphate group linked to the C5 carbon of the ribose (or deoxyribose) moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 2186,
      'name' => "N-amidino-alpha amino acids",
      'description' => "Alpha amido acids carrying an amidine group attached to their N-terminal.",
      'parent' => 60,
    ),
    array(
      'tid' => 2187,
      'name' => "Primary ketimines",
      'description' => "Ketimines where the nitrogen of the ketimine group is linked to a hydrogen atom.",
      'parent' => 1673,
    ),
    array(
      'tid' => 2188,
      'name' => "Phthalide isoquinolines",
      'description' => "Organic compounds with a structure characterized by an isoquinoline moiety linked to phthalide.",
      'parent' => 279,
    ),
    array(
      'tid' => 2189,
      'name' => "1-phenethyltetrahydroisoquinolines",
      'description' => "Compounds containing a phenethyl group attached to the C4-atom of a tetrahydroisoquinoline moiety.",
      'parent' => 2955,
    ),
    array(
      'tid' => 2190,
      'name' => "Pachysanane triterpenoids",
      'description' => "Triterpenoids with a structure based on the pachysanane skeleton, a friedelane derivative which has the C-28 methyl group attached to C-16.",
      'parent' => 1553,
    ),
    array(
      'tid' => 2191,
      'name' => "Oligosaccharide phosphates",
      'description' => "Carbohydrates containing between 3 and 9 sugar units, one of which bear one or more phosphate groups.",
      'parent' => 198,
    ),
    array(
      'tid' => 2192,
      'name' => "6,7-secoergolines",
      'description' => "Compounds containing a tricyclic ergoline analog, where carbon atoms C6 and C7 are not linked to each other.",
      'parent' => 279,
    ),
    array(
      'tid' => 2193,
      'name' => "Ergopeptams",
      'description' => "Tripeptidic noncyclol ergot alkaloids. The structure of ergopeptams is similar to ergopeptines except that L-proline is exchanged by D-proline, and the tripeptide chain is a noncyclol lactam.",
      'parent' => 2680,
    ),
    array(
      'tid' => 2194,
      'name' => "Hydroxy bile acids, alcohols and derivatives",
      'description' => "Bile acids, alcohols or derivatives bearing at least hydroxyl group.",
      'parent' => 1445,
    ),
    array(
      'tid' => 2195,
      'name' => "Naphthylisoquinolines",
      'description' => "Polycyclic aromatic compounds containing a naphthalene moiety linked to an isoquinoline through a CC or CN single bond.",
      'parent' => 2566,
    ),
    array(
      'tid' => 2196,
      'name' => "Naphthylquinolines",
      'description' => "Polycyclic aromatic compounds containing a naphthene moiety linked to a quinoline through a CC or CN single bond.",
      'parent' => 2348,
    ),
    array(
      'tid' => 2197,
      'name' => "Oxazolopyrazines",
      'description' => "Polycyclic compounds containing an oxazole ring fused to a pyrazine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 2198,
      'name' => "Pentahydroxy bile acids, alcohols and derivatives",
      'description' => "Bile acids, alcohols or derivatives bearing five hydroxyl groups.",
      'parent' => 2194,
    ),
    array(
      'tid' => 2199,
      'name' => "Peptidosulfonamides",
      'description' => "Peptidomimetics containing the alpha-peptidosulfonamide, the beta-peptidosulfonamide, or the alpha,beta-peptidosulfonamide skeleton, which consists of two N-S linked sulfonylalkanamides:  1-amino-N-(methanesulfonylmethyl)methanesulfonamide (alpha-peptidosulfonamide), 1-amino-N-(ethanesulfonylmethyl)ethanesulfonamide (beta-peptidosulfonamide), and 1-amino-N-(methanesulfonylmethyl)ethanesulfonamide (alpha,beta-peptidosulfonamide).",
      'parent' => 1813,
    ),
    array(
      'tid' => 2200,
      'name' => "Phenylazetidines",
      'description' => "Polycyclic aromatic compounds containing a phenyl ring substituted with an azetidine ring.",
      'parent' => 102,
    ),
    array(
      'tid' => 2201,
      'name' => "Sophorolipids",
      'description' => "Glycolipids containing a sophorose moiety linked glycosidically to the hydroxyl group of a 17-hydroxy-C18 saturated fatty acid. The carboxyl group of the fatty acid can be linked to the 4'-hydroxyl of the second glucose to form a lactone.",
      'parent' => 1766,
    ),
    array(
      'tid' => 2202,
      'name' => "Hydropyrimidines",
      'description' => "Compounds containing a hydrogenated pyrimidine ring (i.e. containing less than the maximum number of double bonds.).",
      'parent' => 75,
    ),
    array(
      'tid' => 2203,
      'name' => "Glycosylamines",
      'description' => "Compounds consisting of an amine with a beta-N-glycosidic bond to a carbohydrate, thus forming a cyclic hemiaminal ether bond (alpha-amino ether).",
      'parent' => 2105,
    ),
    array(
      'tid' => 2204,
      'name' => "C-glycosyl compounds",
      'description' => "Glycoside in which a sugar group is bonded through one carbon to another group via a C-glycosidic bond.",
      'parent' => 2105,
    ),
    array(
      'tid' => 2205,
      'name' => "Thioglycosides",
      'description' => "Glycoside in which a sugar group is bonded through one carbon to another group via a S-glycosidic bond.",
      'parent' => 2105,
    ),
    array(
      'tid' => 2206,
      'name' => "Selenoglycosides",
      'description' => "Glycoside in which a sugar group is bonded through one carbon to another group via a Se-glycosidic bond.",
      'parent' => 2105,
    ),
    array(
      'tid' => 2207,
      'name' => "O-glycosyl compounds",
      'description' => "Glycoside in which a sugar group is bonded through one carbon to another group via a O-glycosidic bond.",
      'parent' => 2105,
    ),
    array(
      'tid' => 2208,
      'name' => "Purine ribonucleoside 2',5'-bisphosphates",
      'description' => "Purine ribobucleotides with one phosphate group attached to 2' and 5' hydroxyl groups of the ribose moiety.",
      'parent' => 26,
    ),
    array(
      'tid' => 2209,
      'name' => "Purine ribonucleoside 3',5'-bisphosphates",
      'description' => "Purine ribobucleotides with one phosphate group attached to 3' and 5' hydroxyl groups of the ribose moiety.",
      'parent' => 26,
    ),
    array(
      'tid' => 2210,
      'name' => "Sugar alcohols",
      'description' => "Hydrogenated forms of carbohydrate in which the carbonyl group (aldehyde or ketone, reducing sugar) has been reduced to a primary or secondary hydroxyl group.",
      'parent' => 11,
    ),
    array(
      'tid' => 2211,
      'name' => "Isoxazolines",
      'description' => "Compounds containing a five-member unsaturated aliphatic ring,  with an oxygen atom adjacent to a nitrogen atoms, and three carbon atoms.",
      'parent' => 2490,
    ),
    array(
      'tid' => 2212,
      'name' => "Pyridine carboxaldehydes",
      'description' => "Aromatic compounds containing a pyridine ring which bears a carboxaldehyde group.",
      'parent' => 89,
    ),
    array(
      'tid' => 2213,
      'name' => "Glycerophosphocholines",
      'description' => "Lipids containing a glycerol moiety carrying a phosphocholine at the 3-position.",
      'parent' => 256,
    ),
    array(
      'tid' => 2214,
      'name' => "Glycerophosphates",
      'description' => "Compounds containing a glycerol linked to a phosphate group.",
      'parent' => 256,
    ),
    array(
      'tid' => 2215,
      'name' => "Glycerophosphoethanolamines",
      'description' => "Glycerolipids characterized by an ethanolamine ester of glycerophosphoric acid. As is the case with diacylglycerols, glycerophosphoethanolamines can have many different combinations of fatty acids of varying lengths and saturation attached to the C-1 and C-2 atoms.",
      'parent' => 256,
    ),
    array(
      'tid' => 2216,
      'name' => "Glycerophosphoglycerols",
      'description' => "Glycerophosphoglycerols are lipids that contain two glycerol moieties that are linked to each other through the only phosphate group.",
      'parent' => 256,
    ),
    array(
      'tid' => 2217,
      'name' => "Glycerophosphoglycerophosphates",
      'description' => "Glycerophospholipids that contain two glycerophosphate skeleton linked to each other through one of the phosphate groups.",
      'parent' => 256,
    ),
    array(
      'tid' => 2218,
      'name' => "Glycerophosphoserines",
      'description' => "Lipids containing a glycerol moiety carrying a phosphoserine at the 3-position.",
      'parent' => 256,
    ),
    array(
      'tid' => 2219,
      'name' => "Glycerophosphoinositols",
      'description' => "Lipids containing a glycerol moiety carrying a phosphoinositol at the 3-position.",
      'parent' => 256,
    ),
    array(
      'tid' => 2220,
      'name' => "Glycerophosphoinositol phosphates",
      'description' => "Lipids containing a common glycerophosphate skeleton linked to at least one fatty acyl chain and an inositol-5-phosphate moiety.",
      'parent' => 256,
    ),
    array(
      'tid' => 2221,
      'name' => "Polyprenylphenols",
      'description' => "Compounds containing a polyisoprene chain attached to a phenol group.",
      'parent' => 259,
    ),
    array(
      'tid' => 2222,
      'name' => "Hydropyrimidine carboxylic acids and derivatives",
      'description' => "Compounds containing a hydrogenated pyrimidine ring which bears a carboxylic acid group.",
      'parent' => 2202,
    ),
    array(
      'tid' => 2223,
      'name' => "Butenolides",
      'description' => "Dihydrofurans with a carbonyl group at the C2 carbon atom.",
      'parent' => 1982,
    ),
    array(
      'tid' => 2224,
      'name' => "Hydropyridines",
      'description' => "Compounds containing a hydrogenated pyridine ring (i.e. containing less than the maximum number of double bonds.).",
      'parent' => 89,
    ),
    array(
      'tid' => 2225,
      'name' => "Dioxaborolanes",
      'description' => "Compounds containing a five-member saturated aliphatic heterocycle made up of two oxygen atoms, a boron atom, and three carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2226,
      'name' => "Dioxaboroles",
      'description' => "Compounds containing a five-member unsaturated aliphatic heterocycle made up of two oxygen atoms, a boron atom, and three carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2227,
      'name' => "Oxaborole derivatives",
      'description' => "Compounds containing a five-member aliphatic heterocycle made up of one oxygen atom, a boron atom, and three carbon atoms.",
      'parent' => 2052,
    ),
    array(
      'tid' => 2228,
      'name' => "Dialkylamines",
      'description' => "Organic compounds containing a dialkylamine group, characterized by two alkyl groups bonded to the amino nitrogen.",
      'parent' => 2451,
    ),
    array(
      'tid' => 2229,
      'name' => "Medium-chain aldehydes",
      'description' => "An aldehyde with a chain length containing between 6 and 12 carbon atoms.",
      'parent' => 124,
    ),
    array(
      'tid' => 2230,
      'name' => "Short-chain aldehydes",
      'description' => "An aldehyde with a chain length containing between 2 and 5 carbon atoms.",
      'parent' => 124,
    ),
    array(
      'tid' => 2231,
      'name' => "Ubiquinols",
      'description' => "Coenzyme Q derivatives containing a 5, 6-dimethoxy-3-methylbenzene-1,4-diol moiety to which an isoprenyl group is attached at ring position 2(or 6).",
      'parent' => 2801,
    ),
    array(
      'tid' => 2232,
      'name' => "Isoxazolinones",
      'description' => "Compounds containing an isoxazoline ring that bears a ketone group.",
      'parent' => 2211,
    ),
    array(
      'tid' => 2233,
      'name' => "Aldazines",
      'description' => "Azines of aldehydes containing a moiety with the formula RCH=NN=CHR.",
      'parent' => 2392,
    ),
    array(
      'tid' => 2234,
      'name' => "Aminotetrazines",
      'description' => "Compounds containing an amine group attached to a tetrazine. Tetrazine is a six-membered aromatic heterocycle made up of four nitrogen atoms and a two carbon atoms.",
      'parent' => 92,
    ),
    array(
      'tid' => 2235,
      'name' => "Ketazines",
      'description' => "Azines of ketones containing a moiety with the formula R2C=NN=CR2.",
      'parent' => 2392,
    ),
    array(
      'tid' => 2236,
      'name' => "Delta sultones",
      'description' => "Organic compounds containing a delta-sultone, an intramolecular cyclic ester of hydroxy sulfonic acid, with a SO ring bond, and four ring carbon atoms.",
      'parent' => 1889,
    ),
    array(
      'tid' => 2237,
      'name' => "Arylsulfonic acids and derivatives",
      'description' => "Organic compounds containing an aryl group attached to the sulfonic acid group (or a derivative thereof).",
      'parent' => 270,
    ),
    array(
      'tid' => 2238,
      'name' => "Quinolizine carboxylic acids and derivatives",
      'description' => "Compounds containing a carboxylic group attached to a quinolizine moiety.",
      'parent' => 222,
    ),
    array(
      'tid' => 2239,
      'name' => "Trialkylamines",
      'description' => "Organic compounds containing a trialkylamine group, characterized by exactly three alkyl groups bonded to the amino nitrogen.",
      'parent' => 2452,
    ),
    array(
      'tid' => 2240,
      'name' => "Thiopyranoquinolines",
      'description' => "Polycyclic compounds containing a thiopyran ring fused to a quinoline moiety. Quinoline or benzo[b]pyridine is a bicyclic compound that consists of benzene fused to a pyridine.",
      'parent' => 56,
    ),
    array(
      'tid' => 2241,
      'name' => "Aromatic amines",
      'description' => "Aromatic compounds containing an aryl group linked to an amine.",
      'parent' => 2279,
    ),
    array(
      'tid' => 2242,
      'name' => "Elemanolides",
      'description' => "Compounds structurally characterized by the presence of the elemane backbone containing a lactone ring.",
      'parent' => 1543,
    ),
    array(
      'tid' => 2243,
      'name' => "Phenylacetylindoles",
      'description' => "Compounds containing an indole moiety attached to phenylacetate derivative.",
      'parent' => 211,
    ),
    array(
      'tid' => 2244,
      'name' => "8,2'-cyclic pyrimidine nucleotides",
      'description' => "Pyrimidine nucleotides in which the atom linked to the C2 carbon atom of the ribose moiety is bonded the C8 carbon atom of the pyrimidine moiety.",
      'parent' => 1492,
    ),
    array(
      'tid' => 2245,
      'name' => "Abscisic acids and derivatives",
      'description' => "Terpene compounds containing the abscisic acid moiety, which is characterized by a  3-methylpenta-2,4-dienoic acid attached to the C1 carbon of a 4-oxocyclohex-2-ene moiety.",
      'parent' => 1550,
    ),
    array(
      'tid' => 2246,
      'name' => "Cinchona alkaloids",
      'description' => "Alkaloids structurally characterized by the presence of the cinchonan skeleton, which consists of a quinoline linked to an azabicyclo[2.2.2]octane moiety.",
      'parent' => 279,
    ),
    array(
      'tid' => 2247,
      'name' => "Naphthoylindoles",
      'description' => "Polycyclic compounds containing an indole moiety that is N-linked to the carboxamide group attached to naphthalene.",
      'parent' => 211,
    ),
    array(
      'tid' => 2248,
      'name' => "Pyrimidine ribonucleoside 2',5'-bisphosphates",
      'description' => "Pyrimidine ribobucleotides with one phosphate group attached to 2' and 5' hydroxyl groups of the ribose moiety.",
      'parent' => 1904,
    ),
    array(
      'tid' => 2249,
      'name' => "Pyrimidine ribonucleoside 3',5'-bisphosphates",
      'description' => "Pyrimidine ribobucleotides with one phosphate group attached to 3' and 5' hydroxyl groups of the ribose moiety.",
      'parent' => 1904,
    ),
    array(
      'tid' => 2250,
      'name' => "Cyclic glycodepsipeptides",
      'description' => "Peptidomimetic containing a glycodepisipeptide backbone that lies in a cyclic moiety.",
      'parent' => 1994,
    ),
    array(
      'tid' => 2251,
      'name' => "Thioaldehyde s-oxides",
      'description' => "Compounds having the general structure RC(=S=O)H.",
      'parent' => 1188,
    ),
    array(
      'tid' => 2252,
      'name' => "Quinoline-3-carboxamides",
      'description' => "Quinolines in which the quinoline ring system is substituted by one carboxamide group at the 3-position.",
      'parent' => 2553,
    ),
    array(
      'tid' => 2253,
      'name' => "Nicotinamides",
      'description' => "Heterocyclic aromatic compounds containing a pyridine ring substituted at position 3 by a carboxamide group.",
      'parent' => 1326,
    ),
    array(
      'tid' => 2254,
      'name' => "N-substituted nicotinamides",
      'description' => "Nicotnamides in which the pyridine ring is substituted at position 1.",
      'parent' => 2253,
    ),
    array(
      'tid' => 2255,
      'name' => "Glyceraldehyde-3-phosphates",
      'description' => "Compounds containing a glyceraldehyde substituted at position O3 by a phosphate group.",
      'parent' => 1541,
    ),
    array(
      'tid' => 2256,
      'name' => "Pyrrolidinecarboxamides",
      'description' => "Pyrrolidines in which the pyrrolidine rings is substituted at one or more positions by a carboxamide group. Pyrrolidine is a five-membered saturated aliphatic heterocycle with one nitrogen atom and four carbon atoms.",
      'parent' => 1903,
    ),
    array(
      'tid' => 2257,
      'name' => "Substituted pyrroles",
      'description' => "Heterocyclic compounds containing a pyrrole ring substituted at one or more positions.",
      'parent' => 90,
    ),
    array(
      'tid' => 2258,
      'name' => "N-substituted pyrroles",
      'description' => "Heterocyclic compounds containing a pyrrole ring substituted at position 1.",
      'parent' => 2257,
    ),
    array(
      'tid' => 2259,
      'name' => "Pentose phosphates",
      'description' => "Carbohydrate derivatives containing a pentose substituted by one or more phosphate groups.",
      'parent' => 1497,
    ),
    array(
      'tid' => 2260,
      'name' => "Hexose phosphates",
      'description' => "Carbohydrate derivatives containing a hexose substituted by one or more phosphate groups.",
      'parent' => 1498,
    ),
    array(
      'tid' => 2261,
      'name' => "Oxathioles",
      'description' => "Organic heterocyclic compounds containing a saturated five-membered ring with three carbon atoms, one oxygen atom, one sulfur atom, and one double bond.",
      'parent' => 2,
    ),
    array(
      'tid' => 2262,
      'name' => "Gluconolactones",
      'description' => "Polyhydroxy acids containing a gluconolactone molecule, which is characterized by a tetrahydropyran substituted by three hydroxyl groups, one ketone group, and one hydroxymethyl group.",
      'parent' => 1498,
    ),
    array(
      'tid' => 2263,
      'name' => "Pyranopterins and derivatives",
      'description' => "Pterin derivatives in which a pyran ring is fused either to the pyrimidine ring or the pyrazine ring of the pterin moiety.",
      'parent' => 110,
    ),
    array(
      'tid' => 2264,
      'name' => "Sulfoquinovosyldiacylglycerols",
      'description' => "Glycerolipids made up of a sulfonic acid linked to the C6 atom of glucose, which in turn is bound to the O3 atom of the a 1,2-diacylglycerol moiety.",
      'parent' => 3067,
    ),
    array(
      'tid' => 2265,
      'name' => "Pyrazine carboxylic acids and derivatives",
      'description' => "Heterocyclic compounds containing a pyrazine ring substituted by one or more carboxylic acid groups (or derivatives thereof).",
      'parent' => 67,
    ),
    array(
      'tid' => 2266,
      'name' => "Actinide selenophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenophosphate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 2267,
      'name' => "Alkali metal selenophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiophosphate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 2268,
      'name' => "Lanthanide selenophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenophosphate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 2269,
      'name' => "Metalloid selenophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenophosphate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 2270,
      'name' => "Non-metal selenophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenophosphate, and in which the heaviest atom not in an oxoanion is a non-metal element.",
      'parent' => 1442,
    ),
    array(
      'tid' => 2271,
      'name' => "Post-transition metal selenophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenophosphate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 2272,
      'name' => "Transition metal selenophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenophosphate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 2273,
      'name' => "Hydantoins",
      'description' => "Heterocyclic compounds containing an imidazolidine  substituted by ketone group at positions 2 and 4.",
      'parent' => 1150,
    ),
    array(
      'tid' => 2274,
      'name' => "Allantoins",
      'description' => "Heterocyclic compounds containing an imiazolidine ring substituted by a ketone group at positions 2 and 5, and an urea at position 4.",
      'parent' => 2273,
    ),
    array(
      'tid' => 2275,
      'name' => "Nitronaphthalenes",
      'description' => "Polycyclic aromatic compounds containing a naphthalene moiety substituted by one or more nitro groups.",
      'parent' => 23,
    ),
    array(
      'tid' => 2276,
      'name' => "N-acyl-alpha-hexosamines",
      'description' => "Carbohydrate derivatives containing a hexose moiety in which the oxygen atom is replaced by an n-acyl group.",
      'parent' => 3305,
    ),
    array(
      'tid' => 2277,
      'name' => "Alkaline earth metal selenophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is selenophosphate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 2278,
      'name' => "Shikimic acids and derivatves",
      'description' => "Cyclitols containing a cyclohexanecarboxylic acid substituted with three hydroxyl groups at positions 3, 4, and 5.",
      'parent' => 2509,
    ),
    array(
      'tid' => 2279,
      'name' => "Benzene and substituted derivatives",
      'description' => "Aromatic compounds containing one monocyclic ring system consisting of benzene.",
      'parent' => 2448,
    ),
    array(
      'tid' => 2280,
      'name' => "Indole-3-glycerol-3-phosphates",
      'description' => "Heterocyclic compounds containing an indole moiety substituted at position 3 by a glycerol-3-phosphate.",
      'parent' => 2214,
    ),
    array(
      'tid' => 2281,
      'name' => "N-acyl-alpha-hexosamine-6-phosphates",
      'description' => "N-acyl hexosamines in which the hexose is substituted by a phosphate group at position 6.",
      'parent' => 2276,
    ),
    array(
      'tid' => 2282,
      'name' => "Phenylhydantoins",
      'description' => "Heterocyclic aromatic compounds containing an imiazolidinedione moiety substituted by a phenyl group.",
      'parent' => 2273,
    ),
    array(
      'tid' => 2283,
      'name' => "Pterin carboxylates",
      'description' => "Heterocyclic aromatic compounds containing a pterin moiety, in which one ring is substituted by one or more carboxylic acid groups. Pterin is a heterocyclic compound composed of a pteridine ring system (made up of a pyrazine fused to a pyrimidine), with a keto group and an amino group at the 2- and 4- positions, respectively.",
      'parent' => 110,
    ),
    array(
      'tid' => 2284,
      'name' => "Pyrrolopyrimidinecarboxylic acids and derivatives",
      'description' => "Heterocyclic aromatic compounds containing a pyrrolopyrimidine moiety substituted by one or more carboxylic acid groups.",
      'parent' => 1799,
    ),
    array(
      'tid' => 2285,
      'name' => "Carboximidic acids and derivatives",
      'description' => "Compounds containing a carboximidic group, with the general formula R-C(=NR1)OR2.",
      'parent' => 264,
    ),
    array(
      'tid' => 2286,
      'name' => "Polyols",
      'description' => "Organic compounds containing more than one hydroxyl groups.",
      'parent' => 129,
    ),
    array(
      'tid' => 2287,
      'name' => "Pyrroline carboxylic acids and derivatives",
      'description' => "Heterocyclic compounds containing a pyrroline ring substituted by one or more carboxylic acid groups (or derivative thereof).",
      'parent' => 91,
    ),
    array(
      'tid' => 2288,
      'name' => "Thiomorpholines",
      'description' => "Heterocyclic compounds containing a thiomorpholine ring, which is a six-membered aliphatic ring containing one nitrogen atom and one sulfur atom at positions 1 and 4 respectively, and four carbon atoms.",
      'parent' => 1884,
    ),
    array(
      'tid' => 2289,
      'name' => "Thiomorpholine carboxylic acids and derivatives",
      'description' => "Heterocyclic compounds containing a thiomorpholine ring substituted by one or more carboxylic acid groups (or derivative thereof). Thiomorpholine a six-membered aliphatic ring containing one nitrogen atom and one sulfur atom at positions 1 and 4 respectively, and four carbon atoms.",
      'parent' => 2288,
    ),
    array(
      'tid' => 2290,
      'name' => "Non-metal dithiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is dithiophosphate, and in which the heaviest atom not in an oxoanion is a non-metal element.",
      'parent' => 435,
    ),
    array(
      'tid' => 2291,
      'name' => "Non-metal thiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiophosphate, and in which the heaviest atom not in an oxoanion is a non-metal element.",
      'parent' => 435,
    ),
    array(
      'tid' => 2292,
      'name' => "Actinide dithiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is dithiophosphate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 2293,
      'name' => "Actinide thiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiophosphate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 2294,
      'name' => "Alkali metal thiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiophosphate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 2295,
      'name' => "Alkali metal dithiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is dithiophosphate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 2296,
      'name' => "Alkaline earth metal thiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiophosphate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 2297,
      'name' => "Alkaline earth metal dithiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is dithiophosphate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 2298,
      'name' => "Lanthanide thiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiophosphate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 2299,
      'name' => "Lanthanide dithiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is dithiophosphate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 2300,
      'name' => "Metalloid thiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiophosphate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 2301,
      'name' => "Metalloid dithiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is dithiophosphate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 2302,
      'name' => "Post-transition metal thiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiophosphate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 2303,
      'name' => "Post-transition metal dithiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is dithiophosphate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 2304,
      'name' => "Transition metal thiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is thiophosphate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 2305,
      'name' => "Transition metal dithiophosphates",
      'description' => "Inorganic compounds in which the largest oxoanion is dithiophosphate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 2306,
      'name' => "Pyrrolopyrimidine nucleosides and nucleotides",
      'description' => "Nucleoside derivatives containing a ribose derivative which is n-glycosylated to a pyrrolopyrimidine. Also called deazapurine nucleosides, they are analogs of purine nucleosides with the N atom of the purine being replaced by a C atom at position 7.",
      'parent' => 289,
    ),
    array(
      'tid' => 2307,
      'name' => "Morpholine carboxylic acids and derivatives",
      'description' => "Heterocyclic compounds containing a morpholine ring substituted by one or more carboxylic acid groups (or derivative thereof).",
      'parent' => 392,
    ),
    array(
      'tid' => 2308,
      'name' => "Phenylpyrimidines",
      'description' => "Polycyclic aromatic compounds containing a benzene ring linked to a pyrimidine ring through a CC or CN bond.  Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions.",
      'parent' => 75,
    ),
    array(
      'tid' => 2309,
      'name' => "Alpha amino acid amides",
      'description' => "Amide derivatives of alpha amino acids.",
      'parent' => 60,
    ),
    array(
      'tid' => 2310,
      'name' => "Substituted imidazoles",
      'description' => "Heterocyclic compounds containing an imidazole ring substituted at one or more positions.",
      'parent' => 78,
    ),
    array(
      'tid' => 2311,
      'name' => "N-substituted imidazoles",
      'description' => "Heterocyclic compounds containing an imidazole ring substituted at position 1.",
      'parent' => 2310,
    ),
    array(
      'tid' => 2312,
      'name' => "Piperidinecarboxamides",
      'description' => "Compounds containing a piperidine ring substituted with a carboxamide functional group.",
      'parent' => 1974,
    ),
    array(
      'tid' => 2313,
      'name' => "Thienodiazepines",
      'description' => "Heteropolycyclic containing a thiophene ring fused to a diazepine ring. Thiophene is 5-membered ring consisting of four carbon and one sulfur atoms. Diazepine is a 7-membered ring consisting of five carbon and two nitrogen atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2314,
      'name' => "Quinazolinamines",
      'description' => "Heterocyclic aromatic compounds containing a quianazoline moiety substituted by one or more amine groups.",
      'parent' => 485,
    ),
    array(
      'tid' => 2315,
      'name' => "Piperazine carboxylic acids and derivatives",
      'description' => "Heterocyclic compounds containing a piperazine ring substituted by one or more carboxylic acid groups (or derivatives thereof).",
      'parent' => 189,
    ),
    array(
      'tid' => 2316,
      'name' => "Piperazine carboxamides",
      'description' => "Heterocyclic compounds containing a piperazine ring substituted by one or more carboxamide group.",
      'parent' => 2315,
    ),
    array(
      'tid' => 2317,
      'name' => "Phenylpyridines",
      'description' => "Polycyclic aromatic compounds containing a benzene ring linked to a pyridine ring through a CC or CN bond.",
      'parent' => 89,
    ),
    array(
      'tid' => 2318,
      'name' => "Carbacephems",
      'description' => "A new class of beta-lactam antibiotics similar in structure to the cephalosporins. They differ from cephalosporins, however, in the substitution of a sulfur atom in the dihydrothiazine ring with a methylene group to form a tetrahydropyridine ring.",
      'parent' => 162,
    ),
    array(
      'tid' => 2319,
      'name' => "Phenol esters",
      'description' => "Aromatic compounds containing a benzene ring substituted by a hydroxyl group and an ester group.",
      'parent' => 2448,
    ),
    array(
      'tid' => 2320,
      'name' => "Halophenols",
      'description' => "Aromatic compounds containing benzene substituted by a hydroxyl group and a halogen atom.",
      'parent' => 134,
    ),
    array(
      'tid' => 2321,
      'name' => "Cycloartanols and derivatives",
      'description' => "Steroids containing a cycloartanol moiety.",
      'parent' => 258,
    ),
    array(
      'tid' => 2322,
      'name' => "Triazolodiazepines",
      'description' => "Heterocyclic aromatic compounds containing a triazole ring fused to a diazepine ring. Triazole is a five-membered ring consisting of two carbon atoms and three nitrogen atoms. Diazepine is a 7-membered ring consisting of five carbon and two nitrogen atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2323,
      'name' => "Benzothiadiazoles",
      'description' => "Heterocyclic aromatic compounds containing a benzene ring fused to a thiadiazole ring. Thiadiazole is a five-membered aromatic heterocycle made up of one sulfur atom and two nitrogen atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2324,
      'name' => "Triazole carboxylic acids and derivatives",
      'description' => "Heterocyclic compounds containing a triazole ring substituted by at least one carboxylic acid group (or a derivative thereof).",
      'parent' => 99,
    ),
    array(
      'tid' => 2325,
      'name' => "Triazole carboxamides",
      'description' => "Heterocyclic compounds containing a triazole ring substituted by at least one carboxamide group.",
      'parent' => 2324,
    ),
    array(
      'tid' => 2326,
      'name' => "Thiadiazole sulfonamides",
      'description' => "Heterocyclic compounds containing a thiazole ring substituted by at least one sulfonamide group.",
      'parent' => 93,
    ),
    array(
      'tid' => 2327,
      'name' => "Phenylimidazoles",
      'description' => "Polycyclic aromatic compounds containing a benzene ring linked to an imidazole ring through a CC or CN bond.",
      'parent' => 2310,
    ),
    array(
      'tid' => 2328,
      'name' => "Isoxazolidinediones",
      'description' => "Compounds containing an isoxazolidine ring substituted by two ketone groups.",
      'parent' => 2084,
    ),
    array(
      'tid' => 2329,
      'name' => "Aminothiazoles",
      'description' => "Compounds containing a thiazole ring substituted by one or more amine groups.",
      'parent' => 95,
    ),
    array(
      'tid' => 2330,
      'name' => "Isoxazolopyridines",
      'description' => "Aromatic compounds containing an isoxazole ring fused to a pyridine ring. Isoxazole is five-membered ring with three carbon atoms, and an oxygen atom next to a nitrogen atom. Pyridine is a 6-membered ring consisting of five carbon atoms and one nitrogen center.",
      'parent' => 2,
    ),
    array(
      'tid' => 2331,
      'name' => "Isoxazolopyrazines",
      'description' => "Aromatic compounds containing an isoxazole ring fused to a pyrazine ring. Isoxazole is five-membered ring with three carbon atoms, and an oxygen atom next to a nitrogen atom. Pyrazine is a 6-membered ring consisting of six carbon atoms and two nitrogen centers at ring positions 1 and 4.",
      'parent' => 2,
    ),
    array(
      'tid' => 2332,
      'name' => "Benzisoxazoles",
      'description' => "Aromatic compounds containing a benzene ring fused to an isoxazole ring. Isoxazole is five-membered ring with three carbon atoms, and an oxygen atom next to a nitrogen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 2333,
      'name' => "Benzisoxazolones",
      'description' => "Aromatic compounds containing a benzene ring fused to an isoxazolone moiety.",
      'parent' => 2332,
    ),
    array(
      'tid' => 2334,
      'name' => "Phenylpyrroles",
      'description' => "Polycyclic aromatic compounds containing a benzene ring linked to a pyrrole ring through a CC or CN bond.",
      'parent' => 2257,
    ),
    array(
      'tid' => 2335,
      'name' => "Phenylpyrrolines",
      'description' => "Polycyclic aromatic compounds containing a benzene ring linked to a pyrroline ring through a CC or CN bond.",
      'parent' => 91,
    ),
    array(
      'tid' => 2336,
      'name' => "Phenylpyrrolidines",
      'description' => "Polycyclic aromatic compounds containing a benzene ring linked to a pyrrolidine ring through a CC or CN bond. Pyrrolidine is a five-membered saturated aliphatic heterocycle with one nitrogen atom and four carbon atoms.",
      'parent' => 218,
    ),
    array(
      'tid' => 2337,
      'name' => "Imidazolethiones",
      'description' => "Aromatic compounds containing an imidazole ring which bears a thioketone group.",
      'parent' => 79,
    ),
    array(
      'tid' => 2338,
      'name' => "Cycloheptathiophenes",
      'description' => "Polycyclic compounds containing a thiophene ring fused to a 7 member carbocyclic moiety. Thiophene is 5-membered ring consisting of four carbon atoms and one sulfur atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 2339,
      'name' => "Chromenopyridines",
      'description' => "Aromatic heterocyclic compounds structurally characterized by a pyridine ring fused to a chromene moiety.",
      'parent' => 3410,
    ),
    array(
      'tid' => 2340,
      'name' => "Azasteroids and derivatives",
      'description' => "Steroid derivatives in which one carbon atom in the steroidal skeleton has been substituted with a nitrogen atom.",
      'parent' => 258,
    ),
    array(
      'tid' => 2341,
      'name' => "Phenol ethers",
      'description' => "Aromatic compounds containing an ether group substituted with a benzene ring.",
      'parent' => 2448,
    ),
    array(
      'tid' => 2342,
      'name' => "Triazole ribonucleosides and ribonucleotides",
      'description' => "Nucleoside derivatives containing a ribose (or deoxyribose) moiety which is N-glycosylated to a triazole.  Nucleotides have a phosphate group linked to the C5 carbon of the ribose (or deoxyribose) moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 2343,
      'name' => "Dialkylglycerophosphoglycerophosphates",
      'description' => "Glycerophosphoglycerophosphates that carry two aliphatic chains (alkyl group) attached to the glycerol moiety.",
      'parent' => 2217,
    ),
    array(
      'tid' => 2344,
      'name' => "Methoxybenzoic acids and derivatives",
      'description' => "Benzoic acids in which a hydrogen atom of the benzene ring is replaced by a methoxy group.",
      'parent' => 176,
    ),
    array(
      'tid' => 2345,
      'name' => "O-methoxybenzoic acids and derivatives",
      'description' => "Benzoic acids in which the hydrogen atom at position 2 of the benzene ring is replaced by a methoxy group.",
      'parent' => 2344,
    ),
    array(
      'tid' => 2346,
      'name' => "P-methoxybenzoic acids and derivatives",
      'description' => "Benzoic acids in which the hydrogen atom at position 4 of the benzene ring is replaced by a methoxy group.",
      'parent' => 2344,
    ),
    array(
      'tid' => 2347,
      'name' => "M-methoxybenzoic acids and derivatives",
      'description' => "Benzoic acids  in which the hydrogen atom at position 3 of the benzene ring is replaced by a methoxy group.",
      'parent' => 2344,
    ),
    array(
      'tid' => 2348,
      'name' => "Phenylquinolines",
      'description' => "Heterocyclic compounds containing a quinoline moiety substituted with a phenyl group.",
      'parent' => 1253,
    ),
    array(
      'tid' => 2349,
      'name' => "Naphthalenecarboxamides",
      'description' => "Compounds containing a naphthalene moiety, which bears a carboxylic acid amide group at one or more positions. Naphthalene is a bicyclic compound that is made up of two fused benzene rings.",
      'parent' => 1871,
    ),
    array(
      'tid' => 2350,
      'name' => "Pyrazole carboxylic acids and derivatives",
      'description' => "Heterocyclic compounds containing a pyrazole ring in which a hydrogen atom is replaced by a carboxylic acid group.",
      'parent' => 87,
    ),
    array(
      'tid' => 2351,
      'name' => "Benzocycloheptapyridines",
      'description' => "Aromatic compounds containing a benzene ring and a pyridine ring fused to a seven membered carbocycle.",
      'parent' => 2,
    ),
    array(
      'tid' => 2352,
      'name' => "Thioenol ethers",
      'description' => "Compounds containing the enol ether functional group, with the formula R3SCR2=CR1.",
      'parent' => 1202,
    ),
    array(
      'tid' => 2353,
      'name' => "Thioenols",
      'description' => "Compounds containing the enol functional group, with the structure HS(R)C=CR'. Thioenols interconvert with thioketones that have an alpha-hydrogen.",
      'parent' => 4,
    ),
    array(
      'tid' => 2354,
      'name' => "Enol esters",
      'description' => "Ester derivatives of enols. They have the general formula RC=COC(=O)R' where R, R' = H or organyl group.",
      'parent' => 1238,
    ),
    array(
      'tid' => 2355,
      'name' => "Benzoisochromanequinones",
      'description' => "Benzo derivatives of isochromanequinones. Isochromanequinones are structurally characterized by a quinone fused to an isochromane, and forming a naphtho[2,3-c]pyran-6,9-dione skeleton.",
      'parent' => 1649,
    ),
    array(
      'tid' => 2356,
      'name' => "Diketopiperazines",
      'description' => "Organic compounds containing a piperazine ring in which the two nitrogen atoms are part of amide linkages.",
      'parent' => 1995,
    ),
    array(
      'tid' => 2357,
      'name' => "Aminopiperidines",
      'description' => "Compounds containing a piperidine that carries an amino group.",
      'parent' => 195,
    ),
    array(
      'tid' => 2358,
      'name' => "Triterpene saponins",
      'description' => "Glycosylated derivatives of triterpene sapogenins. The sapogenin moiety backbone is usually based on the oleanane, ursane, taraxastane, bauerane,  lanostane, lupeol, lupane, dammarane, cycloartane, friedelane, hopane, 9b,19-cyclo-lanostane, cycloartane, or cycloartanol skeleton.",
      'parent' => 1580,
    ),
    array(
      'tid' => 2359,
      'name' => "Thiophenol ethers",
      'description' => "Thioether derivatives of thiophenols. Thiophenol is a phenol derivative obtained by replacing the oxygen atom from the hydroxyl group (attached to the benzene) by a sulfur atom.",
      'parent' => 2448,
    ),
    array(
      'tid' => 2360,
      'name' => "Thiophenol esters",
      'description' => "Thioester derivatives of thiophenols. Thiophenol is a phenol derivative obtained by replacing the oxygen atom from the hydroxyl group (attached to the benzene) by a sulfur atom.",
      'parent' => 2448,
    ),
    array(
      'tid' => 2361,
      'name' => "Thiobenzoic acids and derivatives",
      'description' => "Organic compounds containing thiobenzoic acid or a derivative thereof.",
      'parent' => 2279,
    ),
    array(
      'tid' => 2362,
      'name' => "Thienamycins",
      'description' => "Beta-lactam antibiotics that differ from penicillins in having the thiazolidine sulfur atom replaced by carbon, the sulfur then becoming the first atom in the side chain.",
      'parent' => 167,
    ),
    array(
      'tid' => 2363,
      'name' => "Phenylacetamides",
      'description' => "Amide derivatives of phenylacetic acids.",
      'parent' => 2279,
    ),
    array(
      'tid' => 2364,
      'name' => "Steroidal saponins",
      'description' => "Saponins in which the aglycone moiety is a steroid. The steroidal aglycone is usually a spirostane, furostane, spirosolane, solanidane, or curcubitacin derivative.",
      'parent' => 1013,
    ),
    array(
      'tid' => 2365,
      'name' => "Cyanogenic glycosides",
      'description' => "Glycosides in which the aglycone moiety contains a cyanide group.",
      'parent' => 2105,
    ),
    array(
      'tid' => 2366,
      'name' => "Non-metal phosphonates",
      'description' => "Inorganic non-metallic compounds containing a phosphonate as its largest oxoanion.",
      'parent' => 435,
    ),
    array(
      'tid' => 2367,
      'name' => "Actinide phosphonates",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphonate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 2368,
      'name' => "Alkali metal phosphonates",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphonate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 2369,
      'name' => "Alkaline earth metal phosphonates",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphonate, and in which the heaviest atom not in an oxoanion is an alkaline earth metal.",
      'parent' => 446,
    ),
    array(
      'tid' => 2370,
      'name' => "Lanthanide phosphonates",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphonate, and in which the heaviest atom not in an oxoanion is a lanthanide.",
      'parent' => 447,
    ),
    array(
      'tid' => 2371,
      'name' => "Metalloid phosphonates",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphonate, and in which the heaviest atom not in an oxoanion is a metalloid.",
      'parent' => 449,
    ),
    array(
      'tid' => 2372,
      'name' => "Post-transition metal phosphonates",
      'description' => "Inorganic compounds in which the largest oxoanion is phosphonate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 2373,
      'name' => "Transition metal phosphonates",
      'description' => "Inorganic compounds in which the largest oxoanion phosphonate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 2374,
      'name' => "Furanoquinolines",
      'description' => "Compounds containing a furan ring fused to a quinoline.",
      'parent' => 1253,
    ),
    array(
      'tid' => 2375,
      'name' => "Secondary ketimines",
      'description' => "Ketimines where the nitrogen of the ketimine group is linked to an alkyl or aryl group.",
      'parent' => 1673,
    ),
    array(
      'tid' => 2376,
      'name' => "Nitrite esters",
      'description' => "Ester derivatives of nitro compounds.",
      'parent' => 1152,
    ),
    array(
      'tid' => 2377,
      'name' => "Piperazinopiperidines",
      'description' => "Organic aromatic compounds containing a piperazine ring fused to a piperidine.",
      'parent' => 2,
    ),
    array(
      'tid' => 2378,
      'name' => "Pyrroloquinoxalines",
      'description' => "Organic heterocyclic compounds containing a pyrrole ring fused to a quinoxaline ring system.",
      'parent' => 486,
    ),
    array(
      'tid' => 2379,
      'name' => "Triazoloquinazolines",
      'description' => "Organic heterocyclic compounds containing a thiazole ring fused to a quinazoline ring system.",
      'parent' => 485,
    ),
    array(
      'tid' => 2380,
      'name' => "Limonoids",
      'description' => "Highly oxygenated, modified terpenoids with a prototypical structure either containing or derived from a precursor with a 4,4,8-trimethyl-17-furanylsteroid skeleton. All naturally occurring citrus limonoids contain a furan ring attached to the D-ring, at C-17, as well as oxygen containing functional groups at C-3, C-4, C-7, C-16 and C-17.",
      'parent' => 1553,
    ),
    array(
      'tid' => 2381,
      'name' => "17-furanylsteroids and derivatives",
      'description' => "Steroidal compounds having a furanyl group linked to the steroid backbone at the C17 position.",
      'parent' => 258,
    ),
    array(
      'tid' => 2382,
      'name' => "Oxasteroids and derivatives",
      'description' => "Steroid derivatives where a carbon atom of the steroid is replaced by an oxygen atom.",
      'parent' => 258,
    ),
    array(
      'tid' => 2383,
      'name' => "Thiasteroids and derivatives",
      'description' => "Steroid derivatives in which one carbon atom in the steroidal skeleton has been substituted with a sulfur atom.",
      'parent' => 258,
    ),
    array(
      'tid' => 2384,
      'name' => "Benzoquinones",
      'description' => "Organic compounds containing a benzene ring that carries two ketone group at the 1- and 4-positions (cyclohexa-2,5-diene-1,4-dione).",
      'parent' => 2495,
    ),
    array(
      'tid' => 2385,
      'name' => "O-quinones",
      'description' => "Quinones where the two C=O groups are attached at the 1- and 2-positions, respectively.",
      'parent' => 2495,
    ),
    array(
      'tid' => 2386,
      'name' => "M-quinones",
      'description' => "Quinones where the two C=O groups are attached at the 1- and 3-positions, respectively.",
      'parent' => 2495,
    ),
    array(
      'tid' => 2387,
      'name' => "P-quinones",
      'description' => "Quinones where the two C=O groups are attached at the 1- and 4-positions, respectively.",
      'parent' => 2495,
    ),
    array(
      'tid' => 2388,
      'name' => "O-iminoquinones",
      'description' => "O-quinones that carry an imine group.",
      'parent' => 2851,
    ),
    array(
      'tid' => 2389,
      'name' => "Diazinanes",
      'description' => "Organic compounds containing diazinane, a six-membered saturated heterocycle containing four carbon atoms and two nitrogen atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2390,
      'name' => "P-iminoquinones",
      'description' => "P-quinones that carry an imine group.",
      'parent' => 2851,
    ),
    array(
      'tid' => 2391,
      'name' => "Glycerol ethers",
      'description' => "Lipids containing an ether derivative of glycerol.",
      'parent' => 175,
    ),
    array(
      'tid' => 2392,
      'name' => "Azines",
      'description' => "Hydrazine derivatives in which the hydrazine group is conjugated to two aldehydes (forming aldazines) or ketones (forming ketazines).",
      'parent' => 112,
    ),
    array(
      'tid' => 2393,
      'name' => "Azomethines",
      'description' => "Compounds having the general structure RN=CR2 (where R is not a hydrogen atom).",
      'parent' => 278,
    ),
    array(
      'tid' => 2394,
      'name' => "Shiff bases",
      'description' => "Aldimines where the nitrogen atom of the aldimine group is linked to an alkyl or aryl group.",
      'parent' => 1267,
    ),
    array(
      'tid' => 2395,
      'name' => "Primary aldimines",
      'description' => "Aldimines where the nitrogen atom of the aldimine group is linked to a hydrogen atom.",
      'parent' => 1267,
    ),
    array(
      'tid' => 2396,
      'name' => "Azomethine imides",
      'description' => "1,3-dipolar N-imides of azomethines. They have the general formula R1C(R2)=[N+](R3)[N-]R4 or  R1[C-](R2)[N+](R3)=[N-]R4, where R1-R4 = organyl group.",
      'parent' => 3631,
    ),
    array(
      'tid' => 2397,
      'name' => "Nitrones",
      'description' => "N-oxides of imines, with the general structure R1C(R2)=[N+](R3)[O-] (R3 is not an Hydrogen atom).",
      'parent' => 3631,
    ),
    array(
      'tid' => 2398,
      'name' => "Azomethine ylides",
      'description' => "1,3-Dipolar  Compounds having the general structure [C-][N+]=C(R)(R').",
      'parent' => 3631,
    ),
    array(
      'tid' => 2399,
      'name' => "Azonic acids and derivatives",
      'description' => "Organic acids with the general formula R[N+](OR')(OR'')O- (R = organyl; R',R\" = any atom).",
      'parent' => 278,
    ),
    array(
      'tid' => 2400,
      'name' => "Adianane, fernane, filicane, and neohopane triterpenoids",
      'description' => "Triterpenoids with a structure based either on the adianane, fernane, filicane, or neohopane skeleton. These are obtained by rearrangement of the moretane skeleton.",
      'parent' => 1553,
    ),
    array(
      'tid' => 2401,
      'name' => "Thiophthalic anhydrides",
      'description' => "Organic heterocyclic aromatic compounds that contain a 1,3-dihydro-2-benzothiophene-1,3-dione moiety.",
      'parent' => 2,
    ),
    array(
      'tid' => 2402,
      'name' => "N-acyl-alpha amino acids",
      'description' => "Compounds containing an alpha amino acid which bears an acyl group at its terminal nitrogen atom.",
      'parent' => 1189,
    ),
    array(
      'tid' => 2403,
      'name' => "N-carbamoyl-alpha amino acids",
      'description' => "Compounds containing an alpha amino acid which bears an carbamoyl group at its terminal nitrogen atom.",
      'parent' => 1224,
    ),
    array(
      'tid' => 2404,
      'name' => "Alpha amino acids",
      'description' => "Amino acids in which the amino group is attached to the carbon atom immediately adjacent to the carboxylate group (alpha carbon).",
      'parent' => 60,
    ),
    array(
      'tid' => 2405,
      'name' => "Imidazole carboxylic acids",
      'description' => "Substituted imidazoles in which the imidazole ring bears a carboxylic acid group.",
      'parent' => 1226,
    ),
    array(
      'tid' => 2406,
      'name' => "Indolecarboxylic acids",
      'description' => "Compounds containing a carboxylic acid group linked to an indole.",
      'parent' => 2013,
    ),
    array(
      'tid' => 2407,
      'name' => "Morpholine carboxylic acids",
      'description' => "Heterocyclic compounds containing a morpholine ring substituted by one or more carboxylic acid groups.",
      'parent' => 2307,
    ),
    array(
      'tid' => 2408,
      'name' => "Thiomorpholine carboxylic acids",
      'description' => "Heterocyclic compounds containing a thiomorpholine ring substituted by one or more carboxylic acid groups. Thiomorpholine a six-membered aliphatic ring containing one nitrogen atom and one sulfur atom at positions 1 and 4 respectively, and four carbon atoms.",
      'parent' => 2289,
    ),
    array(
      'tid' => 2409,
      'name' => "Oxirane carboxylic acids",
      'description' => "Compounds containing an oxirane ring bearing a carboxylic acid group.",
      'parent' => 1864,
    ),
    array(
      'tid' => 2410,
      'name' => "Piperazine carboxylic acids",
      'description' => "Heterocyclic compounds containing a piperazine ring substituted by one or more carboxylic acid groups.",
      'parent' => 2315,
    ),
    array(
      'tid' => 2411,
      'name' => "Piperidinecarboxylic acids",
      'description' => "Compounds containing a piperidine ring which bears a carboxylic acid group.",
      'parent' => 1974,
    ),
    array(
      'tid' => 2412,
      'name' => "Pyran carboxylic acids",
      'description' => "Compounds containing a pyran ring which bears a carboxylic acid group.",
      'parent' => 1991,
    ),
    array(
      'tid' => 2413,
      'name' => "Pyrazine carboxylic acids",
      'description' => "Heterocyclic compounds containing a pyrazine ring substituted by one or more carboxylic acid groups.",
      'parent' => 2265,
    ),
    array(
      'tid' => 2414,
      'name' => "Pyridinecarboxylic acids",
      'description' => "Compounds containing a pyridine ring bearing a carboxylic acid group.",
      'parent' => 1322,
    ),
    array(
      'tid' => 2415,
      'name' => "Pyrimidinecarboxylic acids",
      'description' => "Pyrimidines with a structure containing a carboxyl group attached to the pyrimidine ring.",
      'parent' => 1319,
    ),
    array(
      'tid' => 2416,
      'name' => "Pyrrolidine carboxylic acids",
      'description' => "Compounds containing a pyrrolidine ring which bears a carboxylic acid. Pyrrolidine is a five-membered saturated aliphatic heterocycle with one nitrogen atom and four carbon atoms.",
      'parent' => 1903,
    ),
    array(
      'tid' => 2417,
      'name' => "Pyrroline carboxylic acids",
      'description' => "Heterocyclic compounds containing a pyrroline ring substituted by one or more carboxylic acid groups.",
      'parent' => 2287,
    ),
    array(
      'tid' => 2418,
      'name' => "Thiazolecarboxylic acids",
      'description' => "Heterocyclic compounds containing a thiazole ring which bears a carboxylic acid group.",
      'parent' => 2007,
    ),
    array(
      'tid' => 2419,
      'name' => "Thiophene carboxylic acids",
      'description' => "Compounds containing a thiophene ring which bears a carboxylic acid group.",
      'parent' => 2017,
    ),
    array(
      'tid' => 2420,
      'name' => "Triazole carboxylic acids",
      'description' => "Heterocyclic compounds containing a triazole ring substituted by at least one carboxylic acid group.",
      'parent' => 2324,
    ),
    array(
      'tid' => 2421,
      'name' => "Naphthalenecarboxylic acids",
      'description' => "Compounds containing a naphthalene moiety, which bears a carboxylic acid group one or more positions. Naphthalene is a bicyclic compound that is made up of two fused benzene ring.",
      'parent' => 1871,
    ),
    array(
      'tid' => 2422,
      'name' => "Azetidinecarboxylic acids",
      'description' => "Organic compounds containing a carboxylic acid group attached to an azetidine ring.",
      'parent' => 1876,
    ),
    array(
      'tid' => 2423,
      'name' => "Aziridinecarboxylic acids",
      'description' => "Organic compounds containing a carboxylic acid group attached to an aziridine ring.",
      'parent' => 1877,
    ),
    array(
      'tid' => 2424,
      'name' => "Anthracenecarboxylic acids",
      'description' => "Organic compounds containing a carboxylic acid group attached to an anthracene ring system.",
      'parent' => 1911,
    ),
    array(
      'tid' => 2425,
      'name' => "Tellurols",
      'description' => "Analogues of alcohols and phenols where the oxygen is replaced by a tellurium atom.",
      'parent' => 2469,
    ),
    array(
      'tid' => 2426,
      'name' => "Tellones",
      'description' => "Organotellurium compounds with the general formula RC(=Te)R' (R,R\" = organyl).",
      'parent' => 2469,
    ),
    array(
      'tid' => 2427,
      'name' => "Carboselenoic acids and derivatives",
      'description' => "Organic compounds containing at least one carboselenoyl group, with the formula RC(=O)Se (or a derivative thereof).",
      'parent' => 264,
    ),
    array(
      'tid' => 2428,
      'name' => "Selenazoles",
      'description' => "Compounds containing a five-membered aromatic ring with a the carbon atom replaced by a selenium atom (at position 1) and a nitrogen atom (at position 2 or 3).",
      'parent' => 2,
    ),
    array(
      'tid' => 2429,
      'name' => "Selenoethers",
      'description' => "Organic compounds containing a selenoether group, with the general formula RseR' ( where R, R' are not H atoms).",
      'parent' => 2468,
    ),
    array(
      'tid' => 2430,
      'name' => "Selenoesters",
      'description' => "Analogues of esters where an oxygen atom is replaced by a selenium atom. They generally have the formula RC(=O)SeR' or RC(=Se)OR'.",
      'parent' => 2468,
    ),
    array(
      'tid' => 2431,
      'name' => "Telluroethers",
      'description' => "Organic compounds containing a telluroether group, with the general formula RTeR' ( where R, R' are not H atoms).",
      'parent' => 2469,
    ),
    array(
      'tid' => 2432,
      'name' => "Alpha-bromoaldehydes",
      'description' => "Aldehydes with the general formula C(Br)C(=O)H, with in which the aldehydic C=O function is conjugated to a C-Br group.",
      'parent' => 124,
    ),
    array(
      'tid' => 2433,
      'name' => "Alpha,beta-unsaturated aldehydes",
      'description' => "Aldehydes of general formula R(1)R(2)C=CR(3)-CH=O or RC#C-CH=O in which the aldehydic C=O function is conjugated to an unsaturated C-C bond at the alpha,beta position.",
      'parent' => 3131,
    ),
    array(
      'tid' => 2434,
      'name' => "Alpha-hydrogen aldehydes",
      'description' => "Aldehydes with the general formula HC(H)(R)C(=O)H, where R is an organyl group.",
      'parent' => 124,
    ),
    array(
      'tid' => 2435,
      'name' => "Beta-hydroxy aldehydes",
      'description' => "Organic compounds containing an aldehyde substituted with a hydroxy group on the second carbon atom.",
      'parent' => 124,
    ),
    array(
      'tid' => 2436,
      'name' => "Enals",
      'description' => "An alpha,beta-unsaturated aldehyde of general formula RC=C-CH=O in which the aldehydic C=O function is conjugated to a C=C triple bond at the alpha,beta position.",
      'parent' => 2433,
    ),
    array(
      'tid' => 2437,
      'name' => "Ynals",
      'description' => "An alpha,beta-unsaturated aldehyde of general formula RC#C-CH=O in which the aldehydic C=O function is conjugated to a C#C triple bond at the alpha,beta position.",
      'parent' => 2433,
    ),
    array(
      'tid' => 2438,
      'name' => "Terminal alkynes",
      'description' => "Alkynes featuring a carbon substituent on one acetylenic carbon, and a hydrogen on the other carbon.",
      'parent' => 1301,
    ),
    array(
      'tid' => 2439,
      'name' => "Internal alkynes",
      'description' => "Alkynes featuring carbon substituents on each acetylenic carbon.",
      'parent' => 1301,
    ),
    array(
      'tid' => 2440,
      'name' => "Artemisinins",
      'description' => "Sesquiterpenoids originally isolated from the herb Artemisia annua. Their structure is based on artemisinin, a tetracyclic compound that contains a 1,2-dioxepane fused to an octahydrobenzopyran moiety. The internal peroxide bridge is believed to be a key to the mode of action of artemisinins.",
      'parent' => 1550,
    ),
    array(
      'tid' => 2441,
      'name' => "Naphthols and derivatives",
      'description' => "Naphthalene derivatives carrying one or more hydroxyl (-OH) groups at any ring position.",
      'parent' => 23,
    ),
    array(
      'tid' => 2442,
      'name' => "Nitrosopiperidines",
      'description' => "Piperidines with a nitroso functional group attached to the piperidine ring.",
      'parent' => 195,
    ),
    array(
      'tid' => 2443,
      'name' => "Nitrosothiols",
      'description' => "nitroso compounds containing the nitrosothiol group, with the general formula RS=N=O.",
      'parent' => 4779,
    ),
    array(
      'tid' => 2444,
      'name' => "N-methylnitrosoureas",
      'description' => "Organonitrogen compounds with the general formula H3CN(N=O)R(N)=O (R = any atom).",
      'parent' => 1229,
    ),
    array(
      'tid' => 2445,
      'name' => "Peroxycarboxylic acids and derivatives",
      'description' => "Organic acids with the general formula OOC(R)=O (R = H, organyl group).",
      'parent' => 265,
    ),
    array(
      'tid' => 2446,
      'name' => "Peroxycarboxylic acids",
      'description' => "Organic acids with the general formula [H]OOC(R)=O (R = H, organyl group).",
      'parent' => 2445,
    ),
    array(
      'tid' => 2447,
      'name' => "Piperidinylpiperazines",
      'description' => "Heteropolycyclic compounds containing a piperidine ring and a piperazine ring linked together by a single bond that is not part of a ring.",
      'parent' => 189,
    ),
    array(
      'tid' => 2448,
      'name' => "Benzenoids",
      'description' => "Aromatic compounds containing one or more benzene rings.",
      'parent' => 0,
    ),
    array(
      'tid' => 2449,
      'name' => "Amines",
      'description' => "Compounds formally derived from ammonia by replacing one, two or three hydrogen atoms by hydrocarbyl groups, and having the general structures RNH2 (primary amines), R2NH (secondary amines), R3N (tertiary amines).",
      'parent' => 278,
    ),
    array(
      'tid' => 2450,
      'name' => "Primary amines",
      'description' => "Amines having the nitrogen atom linked to exactly one hydrocarbyl group.",
      'parent' => 2449,
    ),
    array(
      'tid' => 2451,
      'name' => "Secondary amines",
      'description' => "Amines having the nitrogen atom linked to exactly two hydrocarbyl groups.",
      'parent' => 2449,
    ),
    array(
      'tid' => 2452,
      'name' => "Tertiary amines",
      'description' => "Amines having the nitrogen atom linked to exactly three hydrocarbyl groups.",
      'parent' => 2449,
    ),
    array(
      'tid' => 2453,
      'name' => "Primary aromatic amines",
      'description' => "Primary amines where the only hydrocarbyl substituent of the amine group is aromatic. Primary amines have the general formula RNH2 (R=aryl).",
      'parent' => 2450,
    ),
    array(
      'tid' => 2454,
      'name' => "Tertiary alkylarylamines",
      'description' => "Tertiary amines where the nitrogen atom is linked to at least one alkyl group and at least one aryl group.",
      'parent' => 2452,
    ),
    array(
      'tid' => 2455,
      'name' => "Diarylamines",
      'description' => "Secondary amines where the two hydrocarbyl substituents of the amine group are aryl groups.",
      'parent' => 2451,
    ),
    array(
      'tid' => 2456,
      'name' => "Germacrane sesquiterpenoids",
      'description' => "Sesquiterpenoids having the germacrane skeleton, with a structure characterized by a cyclodecane ring substituted with an isopropyl and two methyl groups.",
      'parent' => 1550,
    ),
    array(
      'tid' => 2457,
      'name' => "Triarylamines",
      'description' => "Organic compounds containing a trialkylamine group, characterized by exactly three aryl groups bonded to the amino nitrogen.",
      'parent' => 2452,
    ),
    array(
      'tid' => 2458,
      'name' => "Secondary alkylarylamines",
      'description' => "Secondary alkylarylamines with the general formula HN(R)R' (R = alkyl, R' = aryl).",
      'parent' => 2451,
    ),
    array(
      'tid' => 2459,
      'name' => "Nitramines",
      'description' => "Organyl derivatives of nitramide with the general formula RNHO2 (R = organyl group).",
      'parent' => 1152,
    ),
    array(
      'tid' => 2460,
      'name' => "Alkanolamines",
      'description' => "Organic compounds that carry a hydroxy and an amino functional groups on an alkane backbone.",
      'parent' => 2449,
    ),
    array(
      'tid' => 2461,
      'name' => "Nitrile imides",
      'description' => "Organic compounds with the general structure RC#[N+][N-]R, R[C+]=N=[N-]R, or R[C-]=[N+]=NR.",
      'parent' => 3633,
    ),
    array(
      'tid' => 2462,
      'name' => "Imidothioic acids and derivatives",
      'description' => "Sulfur derivatives of imidic acid (a derivatives thereof) containing the functional group -RC(=N)S, obtained by replacing the oxygen atom by a sulfur atom.",
      'parent' => 264,
    ),
    array(
      'tid' => 2463,
      'name' => "Diarylethers",
      'description' => "Organic compounds containing the dialkyl ether functional group, with the formula ROR', where R and R' are aryl groups.",
      'parent' => 254,
    ),
    array(
      'tid' => 2464,
      'name' => "Hydrazidines",
      'description' => "Hydrazine derivatives with the general formula RC(NHNH2)2=NNH2.",
      'parent' => 112,
    ),
    array(
      'tid' => 2465,
      'name' => "Ynols",
      'description' => "Organooxygen compounds with the general formula R#CO (R = organyl).",
      'parent' => 323,
    ),
    array(
      'tid' => 2466,
      'name' => "Oxazaphosphinanes",
      'description' => "Organic heterocyclic compounds containing an oxazaphosphinane ring, which consists of three carbon atoms, one nitrogen atom, and one phosphorus atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 2467,
      'name' => "1,2-diols",
      'description' => "Polyols containing an alcohol group at two adjacent positions.",
      'parent' => 2286,
    ),
    array(
      'tid' => 2468,
      'name' => "Organoselenium compounds",
      'description' => "Organic compounds containing a carbon-selenium bond.",
      'parent' => 1370,
    ),
    array(
      'tid' => 2469,
      'name' => "Organotellurium compounds",
      'description' => "Compounds containing bond between a carbon atom and a tellurium atom.",
      'parent' => 1370,
    ),
    array(
      'tid' => 2470,
      'name' => "Selenocyanates",
      'description' => "Organic compounds with the general formula RSeC#N.",
      'parent' => 2468,
    ),
    array(
      'tid' => 2471,
      'name' => "Selenenyl halides",
      'description' => "Organoselenium compounds with the general formula RSeX (R = organyl, X = halogen atom).",
      'parent' => 2468,
    ),
    array(
      'tid' => 2472,
      'name' => "Diselenides",
      'description' => "Organoselenium compounds with the general structure R-Se-Se-R' (R,R' = H or organic moiety).",
      'parent' => 2468,
    ),
    array(
      'tid' => 2473,
      'name' => "Selenoxides",
      'description' => "Organoselenium compounds with the general formula RSe(=O)R' (R,R'= organyl).",
      'parent' => 2468,
    ),
    array(
      'tid' => 2474,
      'name' => "Perselenic acids",
      'description' => "Compounds containing a P-hydrocarbyl derivative of perselenic acid.",
      'parent' => 2475,
    ),
    array(
      'tid' => 2475,
      'name' => "Perselenic acids and derivatives",
      'description' => "Compounds containing a P-hydrocarbyl derivative of perselenic acid (or a derivative thereof).",
      'parent' => 264,
    ),
    array(
      'tid' => 2476,
      'name' => "Seleniranes",
      'description' => "Organoselenium compounds containing a three-member ring consisting of two carbon atoms and one selenium atom.",
      'parent' => 2468,
    ),
    array(
      'tid' => 2477,
      'name' => "Telluraldehydes",
      'description' => "Organotellurium compounds with the general formula RC(=Te)H (R =  organyl).",
      'parent' => 2469,
    ),
    array(
      'tid' => 2478,
      'name' => "Ditellurides",
      'description' => "Organotellurium compounds with the general structure R-Te-Te-R' (R,R' = H or organic moiety).",
      'parent' => 2469,
    ),
    array(
      'tid' => 2479,
      'name' => "Tellurones",
      'description' => "Organotellurium compounds with the general formula R[Te](R')(=O)=O (R,R' = organyl).",
      'parent' => 2469,
    ),
    array(
      'tid' => 2480,
      'name' => "Telluric acids and derivatives",
      'description' => "Organic acids containing a telluric acid group or a derivative thereof.",
      'parent' => 264,
    ),
    array(
      'tid' => 2481,
      'name' => "Telluric acids",
      'description' => "Organic acids containing a telluric acid group.",
      'parent' => 2480,
    ),
    array(
      'tid' => 2482,
      'name' => "Telluroxides",
      'description' => "Organotellurium compounds R[Te](R')=O (R,R' = organyl).",
      'parent' => 2469,
    ),
    array(
      'tid' => 2483,
      'name' => "Dicarboxdiimides",
      'description' => "Hydrazine derivatives in which each of the two nitrogen atoms is the central atom of a dicarboximide group.",
      'parent' => 112,
    ),
    array(
      'tid' => 2484,
      'name' => "Carboximidic acids",
      'description' => "Organic acids with the general formula RC(=N)-OH (R=H, organic group).",
      'parent' => 2285,
    ),
    array(
      'tid' => 2485,
      'name' => "Thiols",
      'description' => "Organic compounds containing a functional group with the structure RSH (R = organyl).",
      'parent' => 4,
    ),
    array(
      'tid' => 2486,
      'name' => "Dioxathiolanes",
      'description' => "Organic heterocyclic compounds containing a dioxathiolane, with a structure consisting of a five-membered saturated ring with one sulfur atom, two oxygen atoms, and two carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2487,
      'name' => "Organic nitric acids",
      'description' => "Compounds containing an organonitric acid group.",
      'parent' => 488,
    ),
    array(
      'tid' => 2488,
      'name' => "Oligophosphenes",
      'description' => "Organophosphorus compounds with the general formula RP=P-PR' (R=alkyl, aryl).",
      'parent' => 400,
    ),
    array(
      'tid' => 2489,
      'name' => "Diphosphenes",
      'description' => "Organophosphorus compounds with the general formula RP=PR'(R,R'= alkyl, aryl).",
      'parent' => 400,
    ),
    array(
      'tid' => 2490,
      'name' => "Azolines",
      'description' => "Azole derivatives obtained by conversion of one double bond of the azole ring to a single bond.",
      'parent' => 2,
    ),
    array(
      'tid' => 2491,
      'name' => "Azolidines",
      'description' => "Azole derivatives obtained by conversion of both double bonds of the azole ring to single bonds, yielding a saturated ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 2492,
      'name' => "O-benzoquinones",
      'description' => "Benzoquinones where the two C=O groups are attached at the 1- and 2-positions, respectively.",
      'parent' => 2384,
    ),
    array(
      'tid' => 2493,
      'name' => "M-benzoquinones",
      'description' => "Benzoquinones where the two C=O groups are attached at the 1- and 3-position, respectively.",
      'parent' => 2384,
    ),
    array(
      'tid' => 2494,
      'name' => "P-benzoquinones",
      'description' => "Benzoquinones where the two C=O groups are attached at the 1- and 4-positions, respectively.",
      'parent' => 2384,
    ),
    array(
      'tid' => 2495,
      'name' => "Quinones",
      'description' => "Compounds having a fully conjugated cyclic dione structure, such as that of benzoquinones, derived from aromatic compounds by conversion of an even number of number of -CH= groups into -C(=O)- groups with any necessary rearrangement of double bonds (polycyclic and heterocyclic analogues are included).",
      'parent' => 3487,
    ),
    array(
      'tid' => 2496,
      'name' => "Isoindolines",
      'description' => "Heterocyclic compounds containing a 2,3-dihydro-1H-iso-indole moiety.",
      'parent' => 1819,
    ),
    array(
      'tid' => 2497,
      'name' => "Indoles",
      'description' => "Compounds containing an indole moiety, which consists of pyrrole ring fused to benzene  to form 2,3-benzopyrrole.",
      'parent' => 211,
    ),
    array(
      'tid' => 2498,
      'name' => "Isothiochromenes",
      'description' => "Organic heterocyclic compounds containing an isothiochromene moiety.",
      'parent' => 2,
    ),
    array(
      'tid' => 2499,
      'name' => "Thiochromenes",
      'description' => "Organosulfur compounds that are analogues to chromene, with the difference that a sulfur atom replaces the oxygen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 2500,
      'name' => "Alkanes",
      'description' => "Acyclic branched or unbranched hydrocarbons having the general formula CnH2n+2 , and therefore consisting entirely of hydrogen atoms and saturated carbon atoms.",
      'parent' => 4474,
    ),
    array(
      'tid' => 2501,
      'name' => "Alkenes",
      'description' => "Acyclic branched or unbranched hydrocarbons having one carbon-carbon double bond and the general formula CnH2n.",
      'parent' => 2839,
    ),
    array(
      'tid' => 2502,
      'name' => "Cembranolides",
      'description' => "Diterpenoids with a structure based on a cembrane skeleton fused to a lactone ring (5- or 6-membered).",
      'parent' => 1538,
    ),
    array(
      'tid' => 2503,
      'name' => "Hydroxycinnamic acids",
      'description' => "Compounds containing an cinnamic acid where the benzene ring is hydroxylated.",
      'parent' => 1391,
    ),
    array(
      'tid' => 2504,
      'name' => "Cinnamic acids",
      'description' => "Organic aromatic compounds containing a benzene and a carboxylic acid group forming 3-phenylprop-2-enoic acid.",
      'parent' => 476,
    ),
    array(
      'tid' => 2505,
      'name' => "Coumaric acids",
      'description' => "Aromatic compounds containing a cinnamic acid moiety hydroxylated at the C2 (ortho-), C3 (meta-), or C4 (para-) carbon atom of the benzene ring.",
      'parent' => 59,
    ),
    array(
      'tid' => 2506,
      'name' => "Isoflavonoids",
      'description' => "Natural products derived from 3-phenylchromen-4-one.",
      'parent' => 261,
    ),
    array(
      'tid' => 2507,
      'name' => "Homoisoflavonoids",
      'description' => "Naturally occurring oxygen heterocycles with a structure based on a 16-carbon skeleton including a chromanone, chromone or chromane system with a benzyl group at position C-3.",
      'parent' => 261,
    ),
    array(
      'tid' => 2508,
      'name' => "Homoisoflavans",
      'description' => "Homoisoflavonoids with a structure based on the chromane system. Chromone is a bicyclic compound consisting of a 3,4-dihydro-1-benzopyran.",
      'parent' => 2507,
    ),
    array(
      'tid' => 2509,
      'name' => "Cyclitols and derivatives",
      'description' => "Compounds containing a cycloalkane moiety with one hydroxyl group on each of three or more ring atoms. These of also include derivatives where the hydrogen atom of one or more of the hydroxyl groups is replaced with another atom.",
      'parent' => 1292,
    ),
    array(
      'tid' => 2510,
      'name' => "Aminocyclitols and derivatives",
      'description' => "Cyclitols, or derivatives thereof with at least one hydroxyl group replace by an amino group. These of also include derivatives where the hydrogen atom of one or more of the hydroxyl groups is replaced with another atom.",
      'parent' => 2509,
    ),
    array(
      'tid' => 2511,
      'name' => "Inositol phosphates",
      'description' => "Compounds containing a phosphate group attached to an inositol (or cyclohexanehexol) moiety.",
      'parent' => 2509,
    ),
    array(
      'tid' => 2512,
      'name' => "Quinic acids and derivatives",
      'description' => "Compounds containing a quinic acid moiety (or a derivative thereof), which is a cyclitol made up of a cyclohexane ring that bears four hydroxyl groups at positions 1,3.4, and 5, as well as a carboxylic acid at position 1.",
      'parent' => 2509,
    ),
    array(
      'tid' => 2513,
      'name' => "O-galloylquinic acids and derivatives",
      'description' => "Compounds containing a galloic acid moiety, linked to one hydroxyl group of a quinic acid moiety.",
      'parent' => 2512,
    ),
    array(
      'tid' => 2514,
      'name' => "Salicylic acids",
      'description' => "Ortho-hydroxylated benzoic acids.",
      'parent' => 487,
    ),
    array(
      'tid' => 2515,
      'name' => "Salicylamides",
      'description' => "Carboxamide derivatives of salicylic acid. Salicylic acid is the ortho-hydroxylated derivative of benzoic acid.",
      'parent' => 487,
    ),
    array(
      'tid' => 2516,
      'name' => "N-piperazineacetamides",
      'description' => "Heterocyclic compounds containing a piperazine ring, which N-substituted with an acetamide group.",
      'parent' => 189,
    ),
    array(
      'tid' => 2517,
      'name' => "Chamigranes",
      'description' => "Sesquiterpenoids characterized by a 1,1,5,9-tetramethylspiro[5,5]undecane skeleton, formally obtained by linking the C1-C6 and C6-C11 of farnesane together. They are predominantly isolated from algae.",
      'parent' => 1550,
    ),
    array(
      'tid' => 2518,
      'name' => "Annonaceous acetogenins",
      'description' => "Waxy derivatives of fatty acids (usually C32 or C34), containing a terminal carboxylic acid combined with a 2-propanol unit at the C-2 position to form a methyl- substituted alpha,beta-unsaturated-gamma-lactone. One of their interesting structural features is a single, adjacent, or nonadjacent tetrahydrofuran (THF) or tetrahydropyran (THP) system with one or two flanking hydroxyl group(s) at the center of a long hydrocarbon chain.",
      'parent' => 1334,
    ),
    array(
      'tid' => 2519,
      'name' => "Acylphloroglucinols and derivatives",
      'description' => "Phloroglucinol derivatives characterized by the presence of a COR group.",
      'parent' => 382,
    ),
    array(
      'tid' => 2520,
      'name' => "P-toluquinols and derivatives",
      'description' => "Toluenes with two hydroxyl group attached to the benzene ring in a para-relationship. The hydrogen atom of either hydroxyl group can be substituted by another atom.",
      'parent' => 134,
    ),
    array(
      'tid' => 2521,
      'name' => "P-toluquinols",
      'description' => "Toluene with two hydroxyl group attached to the benzene ring in a para-relationship.",
      'parent' => 2520,
    ),
    array(
      'tid' => 2522,
      'name' => "P-toluquinones",
      'description' => "Toluene with two ketone group attached to the benzene ring in a para-relationship.",
      'parent' => 2494,
    ),
    array(
      'tid' => 2523,
      'name' => "Isoflavanquinones",
      'description' => "Isoflavans where the phenyl group carries two C=O groups at position 1 and 4, respectively.",
      'parent' => 2506,
    ),
    array(
      'tid' => 2524,
      'name' => "Cyclopropanecarboxylic acids and derivatives",
      'description' => "Organic compounds containing a carboxyl group (or a derivative thereof) attached to a cyclopropane ring.",
      'parent' => 265,
    ),
    array(
      'tid' => 2525,
      'name' => "Cyclopropanecarboxylic acids",
      'description' => "Organic compounds containing a carboxyl group attached to a cyclopropane ring.",
      'parent' => 2524,
    ),
    array(
      'tid' => 2526,
      'name' => "1-aminocyclopropane-1-carboxylic acids and derivatives",
      'description' => "Organic compounds containing both a carboxyl group (or a derivative thereof) and an amino group at position C1 of a cyclopropane ring.",
      'parent' => 2524,
    ),
    array(
      'tid' => 2527,
      'name' => "1-aminocyclopropane-1-carboxylic acids",
      'description' => "Organic compounds containing both a carboxyl group and an amino group at position C1 of a cyclopropane ring.",
      'parent' => 2526,
    ),
    array(
      'tid' => 2528,
      'name' => "Halohydrins",
      'description' => "Alcohols substituted by a halogen atom at a saturated carbon atom otherwise bearing only hydrogen or hydrocarbyl groups (usually used to mean beta-halo alcohols).",
      'parent' => 267,
    ),
    array(
      'tid' => 2529,
      'name' => "Carbonylimidazoles",
      'description' => "Substituted imidazoles in which the imidazole ring bears a carbonyl group.",
      'parent' => 2310,
    ),
    array(
      'tid' => 2530,
      'name' => "Epoxypiperidines",
      'description' => "Heteropolycyclic compounds containing an oxirane fused to a piperidine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 2531,
      'name' => "Thiosulfonimidic o-acids",
      'description' => "Organic compounds with the general formula HOS(R)(=N)(=S) (R =  alkyl, aryl).",
      'parent' => 264,
    ),
    array(
      'tid' => 2532,
      'name' => "Thiosulfonimidic s-acids",
      'description' => "Organic compounds with the general formula HSS(R)(=N)(=O) (R =  alkyl, aryl).",
      'parent' => 264,
    ),
    array(
      'tid' => 2533,
      'name' => "Trithiosulfonic acids",
      'description' => "Organic compounds with the general formula HSS(R)(=S)(=S) (R =  alkyl, aryl).",
      'parent' => 264,
    ),
    array(
      'tid' => 2534,
      'name' => "Sulfinohydroximic acids",
      'description' => "Organic compounds with the general formula HON=S(R)OH.",
      'parent' => 264,
    ),
    array(
      'tid' => 2535,
      'name' => "Sulfinohydrazonic acids",
      'description' => "Organic acids with the general formula RS(=NN)OH.",
      'parent' => 264,
    ),
    array(
      'tid' => 2536,
      'name' => "Phenoxides",
      'description' => "Salts or analogous metal derivatives of phenols.",
      'parent' => 2279,
    ),
    array(
      'tid' => 2537,
      'name' => "Isothiocyanate acids",
      'description' => "Acidic derivatives of isothiocyanates with the general formula RC(=O)N=C=S.",
      'parent' => 1234,
    ),
    array(
      'tid' => 2538,
      'name' => "Nitronic acids",
      'description' => "Organic compounds containing the nitronate functional group with the general formula RC=N+(O)OH or RCN+(=O)OH.",
      'parent' => 264,
    ),
    array(
      'tid' => 2539,
      'name' => "Hemiketals",
      'description' => "Hemiacetals having the structure R2C(OH)OR' ( R' not H ), derived from ketones by formal addition of an alcohol to the carbonyl group.",
      'parent' => 1092,
    ),
    array(
      'tid' => 2540,
      'name' => "Dihydroxyphosphanes",
      'description' => "Organic compounds with the general formula RP(OH)OH.",
      'parent' => 400,
    ),
    array(
      'tid' => 2541,
      'name' => "Carbodithioic acids",
      'description' => "Organic acids with the general formula RC(=S)SH (R = organyl).",
      'parent' => 264,
    ),
    array(
      'tid' => 2542,
      'name' => "Benzylethers",
      'description' => "Aromatic ethers with the general formula ROCR' (R = alkyl, aryl; R'=benzene).",
      'parent' => 2279,
    ),
    array(
      'tid' => 2543,
      'name' => "Dithiosulfonic O-acids",
      'description' => "Organic acids with the general formula RS(=S)(=S)OH.",
      'parent' => 264,
    ),
    array(
      'tid' => 2544,
      'name' => "Dithiosulfonic S-acids",
      'description' => "Organic acids with the general formula RS(=O)(=S)SH.",
      'parent' => 264,
    ),
    array(
      'tid' => 2545,
      'name' => "Coumarinolignans",
      'description' => "Lignans with a structure characterized by the presence of a 1,4-dioxane bridge substituted by a phenyl group, and fused to a coumarin.",
      'parent' => 1392,
    ),
    array(
      'tid' => 2546,
      'name' => "Diazetidines",
      'description' => "Organic compounds containing the diazetidine ring, a saturated four-membered ring with two nitrogen atoms and 2 carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2547,
      'name' => "Phenylimidazolidines",
      'description' => "Polycyclic compounds containing an imidazoline substituted by a phenyl group.",
      'parent' => 250,
    ),
    array(
      'tid' => 2548,
      'name' => "Tanshinones, isotanshinones, and derivatives",
      'description' => "A group of abietane-type norditerpenoid quinones.",
      'parent' => 1551,
    ),
    array(
      'tid' => 2549,
      'name' => "Tanshinlactones and derivatives",
      'description' => "Oxasteroids with a structure containing an C-17 steroid skeleton, with two oxygen atoms replacing carbon atoms, and one C=O group. They all have one nitrogen atom at the 15-position. Some tanshinlactones have the second oxygen atom at the 11-position and a C=O group at the 12-position. Others have the second oxygen atom at the 12-position and a C=O group at the 11-position.",
      'parent' => 2382,
    ),
    array(
      'tid' => 2550,
      'name' => "Isocopalane and spongiane diterpenoids",
      'description' => "Diterpenoids with a structure based on the isocopalane  (Tetradecahydro-1,1,4a,7,8,8a-hexamethylphenanthrene) or the 15,16-epoxyisocopalane skeleton.",
      'parent' => 1551,
    ),
    array(
      'tid' => 2551,
      'name' => "Phenylpropanoic acids",
      'description' => "Compounds with a structure containing a benzene ring conjugated to a propanoic acid.",
      'parent' => 261,
    ),
    array(
      'tid' => 2552,
      'name' => "Quinoline carboxylic acids",
      'description' => "Quinolines in which the quinoline ring system is substituted by a carboxyl group at one or more positions.",
      'parent' => 1253,
    ),
    array(
      'tid' => 2553,
      'name' => "Quinoline carboxamides",
      'description' => "Quinolines in which the quinoline ring system is substituted by one or more carboxamide groups.",
      'parent' => 1253,
    ),
    array(
      'tid' => 2554,
      'name' => "Pyrrole carboxylic acids and derivatives",
      'description' => "Heterocyclic compounds containing a pyrrole ring bearing a carboxyl group (or a derivative thereof).",
      'parent' => 90,
    ),
    array(
      'tid' => 2555,
      'name' => "Pyrrole carboxylic acids",
      'description' => "Heterocyclic compounds containing a pyrrole ring bearing a carboxyl group.",
      'parent' => 2554,
    ),
    array(
      'tid' => 2556,
      'name' => "Pyrrole carboxamides",
      'description' => "Heterocyclic compounds containing a pyrrole ring bearing a carboxamide.",
      'parent' => 2554,
    ),
    array(
      'tid' => 2557,
      'name' => "Pyrrole 2-carboxylic acids",
      'description' => "Pyrrole carboxylic acids where the carboxyl group is attached at position C2.",
      'parent' => 2555,
    ),
    array(
      'tid' => 2558,
      'name' => "N-substituted phenoxazines",
      'description' => "Phenoxyazines where the nitrogen atom is linked to an atom other than the hydrogen atom.",
      'parent' => 1855,
    ),
    array(
      'tid' => 2559,
      'name' => "Sulfosalicylic acids and derivatives",
      'description' => "Salicylic acids (or derivatives thereof) with a sulfate group attached to the benzene ring.",
      'parent' => 487,
    ),
    array(
      'tid' => 2560,
      'name' => "Sulfosalicyclic acids",
      'description' => "Salicylic acids with a sulfate group attached to the benzene ring.",
      'parent' => 2559,
    ),
    array(
      'tid' => 2561,
      'name' => "Thiatriazoles",
      'description' => "Heteroaromatic compounds containing a thiatriazole ring, which is a five-membered aromatic ring with one sulfur atom, three nitrogen atom, and a carbon atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 2562,
      'name' => "Aminothiadiazoles",
      'description' => "Thiadiazoles with an amino group attached to the thiadiazole ring.",
      'parent' => 93,
    ),
    array(
      'tid' => 2563,
      'name' => "Methoxypyrazines",
      'description' => "Pyrazines containing a methoxyl group attached to the pyrazine ring.",
      'parent' => 67,
    ),
    array(
      'tid' => 2564,
      'name' => "Dichlorobenzenes",
      'description' => "Compounds containing a benzene with exactly two chlorine atoms attached to it.",
      'parent' => 1099,
    ),
    array(
      'tid' => 2565,
      'name' => "Benzoic acids",
      'description' => "Organic Compounds containing a benzene ring which bears at least one carboxyl group.",
      'parent' => 176,
    ),
    array(
      'tid' => 2566,
      'name' => "Isoquinolines and derivatives",
      'description' => "Aromatic polycyclic compounds containing an isoquinoline moiety, which consists of a benzene ring fused to a pyridine ring and forming benzo[c]pyridine.",
      'parent' => 2,
    ),
    array(
      'tid' => 2567,
      'name' => "Isoquinoline quinones",
      'description' => "Isoquinoline derivative with a structure containing a 5,8-dihydroisoquinoline-5,8-dione skeleton.",
      'parent' => 2566,
    ),
    array(
      'tid' => 2568,
      'name' => "Angular furanocoumarins",
      'description' => "Furanocoumarins, with a structure characterized by a furan ring angularly fused to a coumarin.",
      'parent' => 358,
    ),
    array(
      'tid' => 2569,
      'name' => "Linear furanocoumarins",
      'description' => "Furanocoumarins, with a structure characterized by a furan ring linearly fused to a coumarin.",
      'parent' => 358,
    ),
    array(
      'tid' => 2570,
      'name' => "Quinoline quinones",
      'description' => "Quinoline derivative with a structure containing a 5,8-dihydroisoquinoline-5,8-dione skeleton.",
      'parent' => 1253,
    ),
    array(
      'tid' => 2571,
      'name' => "Phenanthraquinones",
      'description' => "Phenanthrene derivatives containing two ketone groups at position C9 and C10, respectively.",
      'parent' => 25,
    ),
    array(
      'tid' => 2572,
      'name' => "Naphthothiophenes",
      'description' => "Compounds containing a naphthalene (or a derivative) fused to thiophene.",
      'parent' => 23,
    ),
    array(
      'tid' => 2573,
      'name' => "Thienobenzoxepines",
      'description' => "Compounds containing a benzoxepine fused to a thiophene ring. Thiophene is 5-membered ring consisting of four carbon atoms and one sulfur atom.",
      'parent' => 1910,
    ),
    array(
      'tid' => 2574,
      'name' => "Phenyloxazolidines",
      'description' => "Heterocyclic compounds containing an oxazolidine ring conjugated by a phenyl group.",
      'parent' => 108,
    ),
    array(
      'tid' => 2575,
      'name' => "Phenylisoxazolidines",
      'description' => "Heterocyclic compounds containing an isoxazolidine conjugated by a phenyl group.",
      'parent' => 2083,
    ),
    array(
      'tid' => 2576,
      'name' => "1,2-oxazinanes",
      'description' => "Compounds containing an oxazinane ring with the nitrogen atom and the oxygen atom at positions 1  and 2, respectively.",
      'parent' => 107,
    ),
    array(
      'tid' => 2577,
      'name' => "Phenylthiomorpholines",
      'description' => "Compounds containing a thiomorpholine ring conjugated to a phenyl group. Thiomorpholine a six-membered aliphatic ring containing one nitrogen atom and one sulfur atom at positions 1 and 4 respectively, and four carbon atoms.",
      'parent' => 2288,
    ),
    array(
      'tid' => 2578,
      'name' => "Oxathiazolidines",
      'description' => "Heterocyclic compounds containing an oxathiazolidine, a saturated five-membered ring having two carbon atoms, one oxygen atom, one nitrogen atom, and one sulfur atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 2579,
      'name' => "Phenylthiazetidines",
      'description' => "Compounds containing a thiazetidine ring conjugated to a phenyl group.",
      'parent' => 1881,
    ),
    array(
      'tid' => 2580,
      'name' => "Isoflavonequinones",
      'description' => "Isoflavones where the phenyl group carries two C=O groups at position 1 and 4, respectively.",
      'parent' => 494,
    ),
    array(
      'tid' => 2581,
      'name' => "Neoflavans",
      'description' => "Neoflavonoids with a structure based on a 3,4-dihydro-4-aryl-2H-1-benzopyran skeleton.",
      'parent' => 1614,
    ),
    array(
      'tid' => 2582,
      'name' => "Neoflavenes",
      'description' => "Neoflavonoids with a structure based on a 4-phenylchromene skeleton.",
      'parent' => 1614,
    ),
    array(
      'tid' => 2583,
      'name' => "Dalbergiquinols",
      'description' => "Neoflavonoids with a structure based on a 3,3-diarylprop-1-ene skeleton.",
      'parent' => 1614,
    ),
    array(
      'tid' => 2584,
      'name' => "Phenylbenzofurans",
      'description' => "Organic aromatic compounds that contain a phenyl group attached to a benzofuran moiety. Benzofuran is a bicyclic compound containing a benzene fused to a furan.",
      'parent' => 301,
    ),
    array(
      'tid' => 2585,
      'name' => "O-methylated flavonoids",
      'description' => "Flavonoids with methoxy groups conjugated to the flavonoid backbone.",
      'parent' => 334,
    ),
    array(
      'tid' => 2586,
      'name' => "O-methylated isoflavonoids",
      'description' => "Isoflavonoids with methoxy groups conjugated to the isoflavonoid backbone. Isoflavonoids are natural products derived from 3-phenylchromen-4-one.",
      'parent' => 2506,
    ),
    array(
      'tid' => 2587,
      'name' => "2-O-methylated flavonoids",
      'description' => "Flavonoids with methoxy groups attached to the C2 atom of the flavonoid backbone.",
      'parent' => 2585,
    ),
    array(
      'tid' => 2588,
      'name' => "3-O-methylated flavonoids",
      'description' => "Flavonoids with methoxy groups attached to the C3 atom of the flavonoid backbone.",
      'parent' => 2585,
    ),
    array(
      'tid' => 2589,
      'name' => "4-O-methylated flavonoids",
      'description' => "Flavonoids with methoxy groups attached to the C4 atom of the flavonoid backbone.",
      'parent' => 2585,
    ),
    array(
      'tid' => 2590,
      'name' => "5-O-methylated flavonoids",
      'description' => "Flavonoids with methoxy groups attached to the C5 atom of the flavonoid backbone.",
      'parent' => 2585,
    ),
    array(
      'tid' => 2591,
      'name' => "6-O-methylated flavonoids",
      'description' => "Flavonoids with methoxy groups attached to the C6 atom of the flavonoid backbone.",
      'parent' => 2585,
    ),
    array(
      'tid' => 2592,
      'name' => "7-O-methylated flavonoids",
      'description' => "Flavonoids with methoxy groups attached to the C7 atom of the flavonoid backbone.",
      'parent' => 2585,
    ),
    array(
      'tid' => 2593,
      'name' => "8-O-methylated flavonoids",
      'description' => "Flavonoids with methoxy groups attached to the C8 atom of the flavonoid backbone.",
      'parent' => 2585,
    ),
    array(
      'tid' => 2594,
      'name' => "2'-O-methylated flavonoids",
      'description' => "Flavonoids with methoxy groups attached to the C2' atom of the flavonoid backbone.",
      'parent' => 2585,
    ),
    array(
      'tid' => 2595,
      'name' => "3'-O-methylated flavonoids",
      'description' => "Flavonoids with methoxy groups attached to the C3' atom of the flavonoid backbone.",
      'parent' => 2585,
    ),
    array(
      'tid' => 2596,
      'name' => "4'-O-methylated flavonoids",
      'description' => "Flavonoids with methoxy groups attached to the C4' atom of the flavonoid backbone.",
      'parent' => 2585,
    ),
    array(
      'tid' => 2597,
      'name' => "2-O-methylated isoflavonoids",
      'description' => "Isoflavonoids with methoxy groups attached to the C2 atom of the isoflavonoid backbone. Isoflavonoids are natural products derived from 3-phenylchromen-4-one.",
      'parent' => 2586,
    ),
    array(
      'tid' => 2598,
      'name' => "3-O-methylated isoflavonoids",
      'description' => "Isoflavonoids with methoxy groups attached to the C3 atom of the isoflavonoid backbone. Isoflavonoids are natural products derived from 3-phenylchromen-4-one.",
      'parent' => 2586,
    ),
    array(
      'tid' => 2599,
      'name' => "4-O-methylated isoflavonoids",
      'description' => "Isoflavonoids with methoxy groups attached to the C4 atom of the isoflavonoid backbone. Isoflavonoids are natural products derived from 3-phenylchromen-4-one.",
      'parent' => 2586,
    ),
    array(
      'tid' => 2600,
      'name' => "5-O-methylated isoflavonoids",
      'description' => "Isoflavonoids with methoxy groups attached to the C5 atom of the isoflavonoid backbone. Isoflavonoids are natural products derived from 3-phenylchromen-4-one.",
      'parent' => 2586,
    ),
    array(
      'tid' => 2601,
      'name' => "6-O-methylated isoflavonoids",
      'description' => "Isoflavonoids with methoxy groups attached to the C6 atom of the isoflavonoid backbone. Isoflavonoids are natural products derived from 3-phenylchromen-4-one.",
      'parent' => 2586,
    ),
    array(
      'tid' => 2602,
      'name' => "7-O-methylated isoflavonoids",
      'description' => "Isoflavonoids with methoxy groups attached to the C7 atom of the isoflavonoid backbone. Isoflavonoids are natural products derived from 3-phenylchromen-4-one.",
      'parent' => 2586,
    ),
    array(
      'tid' => 2603,
      'name' => "8-O-methylated isoflavonoids",
      'description' => "Isoflavonoids with methoxy groups attached to the C8 atom of the isoflavonoid backbone. Isoflavonoids are natural products derived from 3-phenylchromen-4-one.",
      'parent' => 2586,
    ),
    array(
      'tid' => 2604,
      'name' => "2'-O-methylated isoflavonoids",
      'description' => "Isoflavonoids with methoxy groups attached to the C2' atom of the isoflavonoid backbone. Isoflavonoids are natural products derived from 3-phenylchromen-4-one.",
      'parent' => 2586,
    ),
    array(
      'tid' => 2605,
      'name' => "3'-O-methylated isoflavonoids",
      'description' => "Isoflavonoids with methoxy groups attached to the C3' atom of the isoflavonoid backbone. Isoflavonoids are natural products derived from 3-phenylchromen-4-one.",
      'parent' => 2586,
    ),
    array(
      'tid' => 2606,
      'name' => "4'-O-methylated isoflavonoids",
      'description' => "Isoflavonoids with methoxy groups attached to the C4' atom of the isoflavonoid backbone. Isoflavonoids are natural products derived from 3-phenylchromen-4-one.",
      'parent' => 2586,
    ),
    array(
      'tid' => 2607,
      'name' => "Bromohydrins",
      'description' => "Alcohols substituted by a bromine atom at a saturated carbon atom otherwise bearing only hydrogen or hydrocarbyl groups.",
      'parent' => 2528,
    ),
    array(
      'tid' => 2608,
      'name' => "Chlorohydrins",
      'description' => "Alcohols substituted by a chlorine atom at a saturated carbon atom otherwise bearing only hydrogen or hydrocarbyl groups.",
      'parent' => 2528,
    ),
    array(
      'tid' => 2609,
      'name' => "Fluorohydrins",
      'description' => "Alcohols substituted by a fluorine atom at a saturated carbon atom otherwise bearing only hydrogen or hydrocarbyl groups.",
      'parent' => 2528,
    ),
    array(
      'tid' => 2610,
      'name' => "Iodohydrins",
      'description' => "Alcohols substituted by a iodine atom at a saturated carbon atom otherwise bearing only hydrogen or hydrocarbyl groups.",
      'parent' => 2528,
    ),
    array(
      'tid' => 2611,
      'name' => "Dichlorobenzoic acids",
      'description' => "Benzoic acids having two chlorine atoms attached to the carboxylated benzene ring.",
      'parent' => 2565,
    ),
    array(
      'tid' => 2612,
      'name' => "Alpha-methyldeoxybenzoin flavonoids",
      'description' => "Flavonoids with a structure based on a 1,2-diphenyl-2-propan-2-one.",
      'parent' => 261,
    ),
    array(
      'tid' => 2613,
      'name' => "2-phenylbenzofurans",
      'description' => "Phenylbenzofurans where the benzofuran moiety is conjugated at the 2-position to a phenyl group.",
      'parent' => 2584,
    ),
    array(
      'tid' => 2614,
      'name' => "Furanoflavonoids and dihydrofuranoflavonoids",
      'description' => "Flavonoids possessing a furan (or dihydrofuran) ring fused to the benzopyran moiety of the flavonoid skeleton.",
      'parent' => 334,
    ),
    array(
      'tid' => 2615,
      'name' => "Angular furanoflavonoids and dihydrofuranoflavonoids",
      'description' => "Flavonoids possessing a furan (or a dihydrofuran) ring angularly fused to the benzopyran moiety of the flavonoid skeleton.",
      'parent' => 2614,
    ),
    array(
      'tid' => 2616,
      'name' => "Linear furanoflavonoids and dihydrofuranoflavonoids",
      'description' => "Flavonoids possessing a furan (or a dihydrofuran) ring linearly fused to the benzopyran moiety of the flavonoid skeleton.",
      'parent' => 2614,
    ),
    array(
      'tid' => 2617,
      'name' => "Furanoisoflavonoids",
      'description' => "Isoflavonoids possessing a furan ring fused to the phenyl group of the isoflavonoid skeleton.",
      'parent' => 2506,
    ),
    array(
      'tid' => 2618,
      'name' => "Tetrahydrofolic acids and derivatives",
      'description' => "Heterocyclic compounds based on the 5,6,7,8-tetrahydropteroic acid skeleton conjugated with at least one L-glutamic acid unit (or a derivative thereof) .",
      'parent' => 3042,
    ),
    array(
      'tid' => 2619,
      'name' => "Dihydrofolic acids and derivatives",
      'description' => "Heterocyclic compounds based on the 5,6-dihydropteroic acid/7,8-dihydropteroic acid skeleton conjugated with one or more L-glutamic acid units (or derivative thereof).",
      'parent' => 3041,
    ),
    array(
      'tid' => 2620,
      'name' => "N-benzylalanines",
      'description' => "N-benzyl derivatives of alanine.",
      'parent' => 2402,
    ),
    array(
      'tid' => 2621,
      'name' => "N-benzoylpiperidines",
      'description' => "Heterocyclic Compounds containing a piperidine ring conjugated to a benzyl group through one nitrogen ring atom.",
      'parent' => 335,
    ),
    array(
      'tid' => 2622,
      'name' => "N-benzylpiperidines",
      'description' => "Heterocyclic Compounds containing a piperidine ring conjugated to a benzyl group through one nitrogen ring atom.",
      'parent' => 3087,
    ),
    array(
      'tid' => 2623,
      'name' => "Thiohydroquinones",
      'description' => "Organic compounds similar to hydroquinones wit the difference that one hydroxyl group is replaced by a thiol group.",
      'parent' => 134,
    ),
    array(
      'tid' => 2624,
      'name' => "Aminohydroquinones",
      'description' => "Organic compounds containing an amine group attached to a hydroquinone.",
      'parent' => 136,
    ),
    array(
      'tid' => 2626,
      'name' => "Phenylsulfates",
      'description' => "Compounds containing a sulfuric acid group conjugated to a phenyl group.",
      'parent' => 4258,
    ),
    array(
      'tid' => 2627,
      'name' => "Imidazopiperidines",
      'description' => "Heterocyclic compounds containing an imidazole ring fused to a piperidine ring. Imidazole is 5-membered ring consisting of three carbon atoms, and two nitrogen centers at the 1- and 3-positions. Piperidine is a five-membered heterocycle containing five carbon atoms and one nitrogen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 2628,
      'name' => "Trisubstituted imidazoles",
      'description' => "Imidazoles in which the imidazole ring is substituted at exactly three different positions.",
      'parent' => 2310,
    ),
    array(
      'tid' => 2629,
      'name' => "1,2,4-trisubstituted imidazoles",
      'description' => "Imidazoles in which the imidazole ring is substituted at positions 1, 2, and 3.",
      'parent' => 2628,
    ),
    array(
      'tid' => 2630,
      'name' => "1,2,5-trisubstituted imidazoles",
      'description' => "Imidazoles in which the imidazole ring is substituted at positions 1, 2, and 5.",
      'parent' => 2628,
    ),
    array(
      'tid' => 2631,
      'name' => "2,4,5-trisubstituted imidazoles",
      'description' => "Imidazoles in which the imidazole ring is substituted at positions 2, 4, and 5.",
      'parent' => 2628,
    ),
    array(
      'tid' => 2632,
      'name' => "Tetrasubstituted imidazoles",
      'description' => "Imidazoles in which the imidazole ring is substituted at exactly four different positions.",
      'parent' => 2310,
    ),
    array(
      'tid' => 2633,
      'name' => "1,2,4,5-tetrasubstituted imidazoles",
      'description' => "Imidazoles in which the imidazole ring is substituted at for positions 1,2,4, and 5.",
      'parent' => 2632,
    ),
    array(
      'tid' => 2634,
      'name' => "2,4-disubstituted thiazoles",
      'description' => "Compounds containing a thiazole ring substituted at the positions 2 and 3.",
      'parent' => 95,
    ),
    array(
      'tid' => 2635,
      'name' => "2,5-disubstituted thiazoles",
      'description' => "Compounds containing a thiazole ring substituted at positions 2 and 5 only.",
      'parent' => 95,
    ),
    array(
      'tid' => 2636,
      'name' => "4,5-disubstituted thiazoles",
      'description' => "Compounds containing a thiazole ring substituted at positions 4 and 5 only.",
      'parent' => 95,
    ),
    array(
      'tid' => 2637,
      'name' => "2,4,5-trisubstituted thiazoles",
      'description' => "Compounds containing a thiazole ring substituted at positions 2, 4 and 5 only.",
      'parent' => 95,
    ),
    array(
      'tid' => 2638,
      'name' => "2,4-disubstituted oxazoles",
      'description' => "Compounds containing an oxazole ring substituted at positions 2 and 4 only. Oxazole is a five-membered aromatic heterocycle with one  oxygen, one nitrogen, and three carbon atoms. Isomers include 1,2-oxazole and 1,3-oxazole.",
      'parent' => 83,
    ),
    array(
      'tid' => 2639,
      'name' => "2,5-disubstituted oxazoles",
      'description' => "Compounds containing an oxazole ring substituted at positions 2 and 5 only. Oxazole is a five-membered aromatic heterocycle with one  oxygen, one nitrogen, and three carbon atoms. Isomers include 1,2-oxazole and 1,3-oxazole.",
      'parent' => 83,
    ),
    array(
      'tid' => 2640,
      'name' => "4,5-disubstituted oxazoles",
      'description' => "Compounds containing an oxazole ring substituted at positions 4 and 5 only. Oxazole is a five-membered aromatic heterocycle with one  oxygen, one nitrogen, and three carbon atoms. Isomers include 1,2-oxazole and 1,3-oxazole.",
      'parent' => 83,
    ),
    array(
      'tid' => 2641,
      'name' => "2,4,5-trisubstituted oxazoles",
      'description' => "Compounds containing an oxazole ring substituted at positions 2, 4 and 5 only. Oxazole is a five-membered aromatic heterocycle with one  oxygen, one nitrogen, and three carbon atoms. Isomers include 1,2-oxazole and 1,3-oxazole.",
      'parent' => 83,
    ),
    array(
      'tid' => 2642,
      'name' => "3,4-dihydrocoumarins",
      'description' => "3,4-dihydrogenated coumarins. Coumarin is a bicyclic compound that a 1-benzopyran carrying an oxo group at the 2-position.",
      'parent' => 261,
    ),
    array(
      'tid' => 2643,
      'name' => "6,7-dihydroxycoumarins",
      'description' => "Coumarins bearing two hydroxyl groups at positions 6 and 7 of the coumarin skeleton, respectively.",
      'parent' => 2908,
    ),
    array(
      'tid' => 2644,
      'name' => "7,8-dihydroxycoumarins",
      'description' => "Coumarins bearing two hydroxyl groups at the C7- and C8-positions of the coumarin skeleton, respectively.",
      'parent' => 2908,
    ),
    array(
      'tid' => 2645,
      'name' => "Halogenated steroids",
      'description' => "Compounds containing an steroid backbone, with at least one hydrogen substituted by a halogen atom.",
      'parent' => 258,
    ),
    array(
      'tid' => 2646,
      'name' => "Cyclohexanones",
      'description' => "Compounds containing a cylohexenone moiety, which is a six-membered saturated aliphatic ring that carries a ketone.",
      'parent' => 3487,
    ),
    array(
      'tid' => 2647,
      'name' => "Cyclohexanols",
      'description' => "Compounds containing an alcohol group attached to a cyclohexane ring.",
      'parent' => 1661,
    ),
    array(
      'tid' => 2648,
      'name' => "Tetrahydrofurans",
      'description' => "Heterocyclic compounds containing a saturated, aliphatic, five-membered ring where a carbon is replaced by an oxygen.",
      'parent' => 2,
    ),
    array(
      'tid' => 2649,
      'name' => "Oxathiaphospholanes",
      'description' => "Heterocyclic compounds containing an oxathiophospholane ring, which is a saturated, five-membered ring with one oxygen atom, one sulfur atom, one phosphorus atom and two carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2650,
      'name' => "Diarylheptanoids",
      'description' => "Phenylpropanoids with a structure containing two  aromatic rings joined by a seven carbons (a 1,7-diphenylheptane skeleton) and may have various substituents.",
      'parent' => 261,
    ),
    array(
      'tid' => 2651,
      'name' => "Linear diarylheptanoids",
      'description' => "Diarylheptanoids with an open heptane chain. The two aromatic rings are linked only by the heptane chain.",
      'parent' => 2650,
    ),
    array(
      'tid' => 2652,
      'name' => "Cyclic diarylheptanoids",
      'description' => "Diarylheptanoids where the two aromatic rings of the skeleton are joined by a CC bond or an ether group, in addition to the heptane chain.",
      'parent' => 2650,
    ),
    array(
      'tid' => 2653,
      'name' => "Phenalenes",
      'description' => "Aromatic hydrocarbons containing a cyclohexene ring fused to both benzenes of a naphthalene ring system, so as to form a triad.",
      'parent' => 2448,
    ),
    array(
      'tid' => 2654,
      'name' => "Phenalenones",
      'description' => "Compounds containing a phenalene ring system, which carries a keto group.",
      'parent' => 2653,
    ),
    array(
      'tid' => 2655,
      'name' => "Phenalanes",
      'description' => "Aromatic hydrocarbons containing a cyclohexene ring fused to both benzenes of a naphthalene ring system, so as to form a triad.",
      'parent' => 2448,
    ),
    array(
      'tid' => 2656,
      'name' => "Loline alkaloids and derivatives",
      'description' => "Alkaloids with a structure characterized by  a saturated pyrrolizidine ring, a primary amine at the C-1 carbon, and an internal ether bridge joining two distant ring (C-2 and C-7) carbons. Different substituents at the C-1 amine, such as methyl, formyl, and acetyl groups, yield various loline species.",
      'parent' => 279,
    ),
    array(
      'tid' => 2657,
      'name' => "Cularin alkaloids and derivatives",
      'description' => "Derivatives of benzylisoquinolines in which a phenolic oxygen is incorporated into a seven-membered ring.",
      'parent' => 279,
    ),
    array(
      'tid' => 2658,
      'name' => "Rhoeadine alkaloids",
      'description' => "Alkaloids with a structure based on rhoeadine. They usually contain a benzazepine system fused with a six-membered hemiacetal or acetal.",
      'parent' => 279,
    ),
    array(
      'tid' => 2659,
      'name' => "Emetine alkaloids",
      'description' => "Alkaloids with a structure characterized by the presence of both an isoquinoline and a benzoquinolizidine nuclei.",
      'parent' => 279,
    ),
    array(
      'tid' => 2660,
      'name' => "Proaporphines",
      'description' => "Benzylisoquinoline derivatives characterized by the presence of a spirocyclohexane ring that can occur in various oxidation levels, from cyclohexadienone to cyclohexanol.",
      'parent' => 279,
    ),
    array(
      'tid' => 2661,
      'name' => "Homoaporphines",
      'description' => "Alkaloids derived from phenethylisoquinoline precursors by direct intramolecular oxidative coupling. They incorporate a nucleus A and are always pentaoxygenated at C- 1, -2, - 10, - 11, and - 12. The nitrogen function in ring B is usually N-methylated, but it may also be secondary.",
      'parent' => 279,
    ),
    array(
      'tid' => 2662,
      'name' => "Homoproaporphines",
      'description' => "Analogues of proaporphines with the difference that the spirocyclohexenol ring is joined to a cyclohexane instead of a cyclopentane.",
      'parent' => 279,
    ),
    array(
      'tid' => 2663,
      'name' => "Aristolactams",
      'description' => "Phenanthrenic compounds containing a five-membered lactam ring and a 1,3-dioxolane ring fused to the phenanthrene ring system.",
      'parent' => 279,
    ),
    array(
      'tid' => 2664,
      'name' => "Aristolochic acids and derivatives",
      'description' => "Organic heterocyclic compounds with a structure characterized by a nitrophenanthro[3,4-d][1,3]dioxole ring system substituted at position 5, 6, and 8 by a carboxyl group (or a derivative thereof), a nitro group, and a methoxy group, respectively.",
      'parent' => 25,
    ),
    array(
      'tid' => 2665,
      'name' => "Benzophenanthridine alkaloids",
      'description' => "Polycyclic alkaloids with a structure based on the benzo[c]phenanthridine skeleton. They derived from tetrahydroprotoberberine precursors by oxidation of the C6-N bond followed by cyclization of C6 on to position 13.",
      'parent' => 279,
    ),
    array(
      'tid' => 2666,
      'name' => "Hexahydrobenzophenanthridine alkaloids",
      'description' => "Alkaloids containing a hexahydrobenzophenanthridine skeleton, which is a tetracyclic compound containing a benzene fused to a hexahydrophenanthridine moiety.",
      'parent' => 2665,
    ),
    array(
      'tid' => 2667,
      'name' => "Dihydrobenzophenanthridine alkaloids",
      'description' => "Alkaloids containing a dihydrobenzophenanthridine skeleton, which is a tetracyclic compound containing a benzene fused to a dihydrophenanthridine moiety.",
      'parent' => 2665,
    ),
    array(
      'tid' => 2668,
      'name' => "N-demethylbenzophenanthridine alkaloids",
      'description' => "Alkaloids containing a N-demethylbenzophenanthridine skeleton, which consists of a benzene ring fused to one benzene moiety of the tricyclic phenanthiridine system. These compounds do not carry a methyl group at the N-atom of the phenanthridine moiety, in contrast to other benzophenanthridine alkaloids.",
      'parent' => 2665,
    ),
    array(
      'tid' => 2669,
      'name' => "Quaternary benzophenanthridine alkaloids",
      'description' => "Alkaloids containing a quaternary N-demethylbenzophenanthridine skeleton, where the nitrogen atom of the phenanthridine moiety is part of four bonds.",
      'parent' => 2665,
    ),
    array(
      'tid' => 2670,
      'name' => "Secobenzophenanthridine alkaloids",
      'description' => "Alkaloids containing a secobenzophenanthridine skeleton.",
      'parent' => 2665,
    ),
    array(
      'tid' => 2671,
      'name' => "Eburnan-type alkaloids",
      'description' => "Alkaloids with a structure based on the eburnan skeleton, that arises from rearrangement of the aspidospermidine ring system, involving migration of C-21 from C-7 to C-2, fission of the 2,16-bond, and attachment of C-16 to N-1.",
      'parent' => 279,
    ),
    array(
      'tid' => 2672,
      'name' => "Plumeran-type alkaloids",
      'description' => "Alkaloids with a structure based on the plumeran skeleton. Plumeran is a pentacyclic compound that consists of a pyrrolidine  ring shed to the quinoline moiety of pyrido[3,2-c]carbazole ring system.",
      'parent' => 279,
    ),
    array(
      'tid' => 2673,
      'name' => "Benzylamines",
      'description' => "Organic compounds containing benzylamine, which consists of a benzene group attached to an amine group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 2674,
      'name' => "Cyclohexylamines",
      'description' => "Organic compounds containing a cyclohexylamine moiety, which consist of a cyclohexane ring attached to an amine group.",
      'parent' => 278,
    ),
    array(
      'tid' => 2675,
      'name' => "Thiirenes",
      'description' => "Compounds containing a thriirene ring, an unsaturated three-membered ring made up of two carbon atoms and a sulfur atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 2676,
      'name' => "Peroxols",
      'description' => "Monosubstituted derivatives of hydrogen peroxide, with the general formula ROOH, where R is an organic group.",
      'parent' => 323,
    ),
    array(
      'tid' => 2677,
      'name' => "Indenoazepines",
      'description' => "Heterocyclic aromatic compounds with a structure based on an indene ring system fused to an azepine ring.",
      'parent' => 21,
    ),
    array(
      'tid' => 2678,
      'name' => "Lycoctonine alkaloids",
      'description' => "Alkaloids with a structure based on the hexacyclic lycoctonine skeleton, which contains a quinolizidine moiety, an azepane ring. Lycoctonine alkaloids are also characterized by the presence of an oxygenated group at the C7 carbon.",
      'parent' => 1551,
    ),
    array(
      'tid' => 2679,
      'name' => "Ergoline and derivatives",
      'description' => "Compounds containing an ergoline moiety, which is structurally characterized by he presence of a 4,6,6a,7,8,9,10,10a-octahydroindolo[4,3-fg] quinoline.",
      'parent' => 279,
    ),
    array(
      'tid' => 2680,
      'name' => "Lysergic acids and derivatives",
      'description' => "Alkaloids with a structure based on the lysergic acid skeleton.",
      'parent' => 2679,
    ),
    array(
      'tid' => 2681,
      'name' => "Oxaergolines",
      'description' => "Alkaloids with a structure based on the oxaergoline skeleton, an analog of ergoline obtained by substituted one of the pyridine C atom by an oxygen atom.",
      'parent' => 279,
    ),
    array(
      'tid' => 2682,
      'name' => "Coumaroyl glycosides",
      'description' => "Compounds containing coumaric acid esterified with a glycosyl group.",
      'parent' => 3003,
    ),
    array(
      'tid' => 2683,
      'name' => "M-coumaroyl glycosides",
      'description' => "Glycosides of m-coumaric acids. M-coumaric acids are aromatic compounds containing a cinnamic acid moiety hydroxylated at the C3 carbon atom of the benzene ring.",
      'parent' => 2682,
    ),
    array(
      'tid' => 2684,
      'name' => "O-coumaroyl glycosides",
      'description' => "Glycosides of o-coumaric acids. O-coumaric acids are aromatic compounds containing a cinnamic acid moiety hydroxylated at the C2 carbon atom of the benzene ring.",
      'parent' => 2682,
    ),
    array(
      'tid' => 2685,
      'name' => "P-coumaroyl glycosides",
      'description' => "Glycosides of p-coumaric acids. P-coumaric acids are aromatic compounds containing a cinnamic acid moiety hydroxylated at the C4 carbon atom of the benzene ring.",
      'parent' => 2682,
    ),
    array(
      'tid' => 2686,
      'name' => "2-hydroxyisoflavanones",
      'description' => "An isoflavonoid that bears a hydroxyl group at position 2.",
      'parent' => 1827,
    ),
    array(
      'tid' => 2687,
      'name' => "4'-O-methylisoflavones",
      'description' => "Isoflavones with methoxy groups attached to the C4' atom of the isoflavone backbone.",
      'parent' => 2606,
    ),
    array(
      'tid' => 2688,
      'name' => "1-acyl-sn-glycerol-2,3-cyclic-phosphates",
      'description' => "Monoacylglycerophosphates consisting of a sn-glycerol 2,3-cyclic phosphate that carries an acyl group at the 1-position.",
      'parent' => 1683,
    ),
    array(
      'tid' => 2689,
      'name' => "7-O-methylisoflavones",
      'description' => "Isoflavones with methoxy groups attached to the C7 atom of the isoflavone backbone.",
      'parent' => 2602,
    ),
    array(
      'tid' => 2690,
      'name' => "3'-O-methylisoflavones",
      'description' => "Flavones with methoxy groups attached to the C2' atom of the isoflavone backbone.",
      'parent' => 2605,
    ),
    array(
      'tid' => 2691,
      'name' => "Diazirines",
      'description' => "Heterocyclic compounds containing a diazirine ring, which is a three-membered unsaturated cycle with one carbon atom, and two nitrogen atoms joined by a double bond.",
      'parent' => 2,
    ),
    array(
      'tid' => 2692,
      'name' => "Triazirines",
      'description' => "Heterocyclic compounds containing a triazirine ring, which is a three-membered unsaturated cycle with three nitrogen atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2693,
      'name' => "Triazinanes",
      'description' => "Compounds containing a triazinane ring, which is a six-membered saturated heterocycle with  three nitrogen ring atoms and three ring carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2694,
      'name' => "Molybdopterins",
      'description' => "Cofactors or analogs thereof, with a structure based on a furan ring fused to a pterin. In addition, the pyran ring features two thiolates, which serve as ligands in molybdo- and tungstoenzymes. In some cases, the alkyl phosphate group is replaced by an alkyl diphosphate nucleotide.",
      'parent' => 110,
    ),
    array(
      'tid' => 2695,
      'name' => "Diphenylpyrroles",
      'description' => "Aromatic heterocyclic compounds with a structure based on a pyrrole ring linked to exactly two phenyl groups.",
      'parent' => 2334,
    ),
    array(
      'tid' => 2696,
      'name' => "Chlorocatechols",
      'description' => "Catechols having one or more chlorine atoms attached to the benzene ring.",
      'parent' => 135,
    ),
    array(
      'tid' => 2697,
      'name' => "4-chlorocatechols",
      'description' => "Chlorocatechols with the chlorine atom attached at position C4 of the benzene ring.",
      'parent' => 2696,
    ),
    array(
      'tid' => 2698,
      'name' => "3-chlorocatechols",
      'description' => "Chlorocatechols with the chlorine atom attached at position C3 of the benzene ring.",
      'parent' => 2696,
    ),
    array(
      'tid' => 2699,
      'name' => "Benzodioxanes",
      'description' => "Heterocyclic compounds containing a benzene ring fused to a dioxane ring. Dioxane a six-member saturated ring of two oxygen atoms and four carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2700,
      'name' => "Benzo-1,2-dioxanes",
      'description' => "Heterocyclic compounds containing a benzene ring fused to a 1,2-dioxane ring.",
      'parent' => 2699,
    ),
    array(
      'tid' => 2701,
      'name' => "Benzo-1,3-dioxanes",
      'description' => "Heterocyclic compounds containing a benzene ring fused to a 1,3-dioxane ring.",
      'parent' => 2699,
    ),
    array(
      'tid' => 2702,
      'name' => "Benzo-1,4-dioxanes",
      'description' => "Heterocyclic compounds containing a benzene ring fused to a 1,4-dioxane ring.",
      'parent' => 2699,
    ),
    array(
      'tid' => 2703,
      'name' => "Benzo-2,3-dioxanes",
      'description' => "Heterocyclic compounds containing a benzene ring fused to a 2,3-dioxane ring.",
      'parent' => 2699,
    ),
    array(
      'tid' => 2704,
      'name' => "Phenylbenzodioxanes",
      'description' => "Benzodioxanes having a phenyl group attached to the dioxane moiety.",
      'parent' => 2699,
    ),
    array(
      'tid' => 2705,
      'name' => "Phenylbenzo-1,3-dioxanes",
      'description' => "Benzo-1,3-dioxanes having a phenyl group attached to the 1,3-dioxane moiety.",
      'parent' => 2704,
    ),
    array(
      'tid' => 2706,
      'name' => "Phenylbenzo-2,3-dioxanes",
      'description' => "Benzo-1,3-dioxanes having a phenyl group attached to the 2,3-dioxane moiety.",
      'parent' => 2704,
    ),
    array(
      'tid' => 2707,
      'name' => "Phenylbenzo-1,4-dioxanes",
      'description' => "Benzo-1,3-dioxanes having a phenyl group attached to the 1,4-dioxane moiety.",
      'parent' => 2704,
    ),
    array(
      'tid' => 2708,
      'name' => "Anthocyanidin 3-O-p-coumaroyl glycosides",
      'description' => "Anthocyanidin 3-O-glycosides where the carbohydrate moiety is esterified with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 3678,
    ),
    array(
      'tid' => 2709,
      'name' => "Anthocyanidin 3p-O-p-coumaroyl glycosides",
      'description' => "Anthocyanidin 3p-O-glycosides where the carbohydrate moiety is esterified with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 3681,
    ),
    array(
      'tid' => 2710,
      'name' => "Anthocyanidin 5-O-p-coumaroyl glycosides",
      'description' => "Anthocyanidin 5-O-glycosides where the carbohydrate moiety is esterified with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 3679,
    ),
    array(
      'tid' => 2711,
      'name' => "Anthocyanidin 3-O-6-p-coumaroyl glycosides",
      'description' => "Anthocyanidin 3-O-glycosides where the carbohydrate moiety is esterified at the C6 position with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 2708,
    ),
    array(
      'tid' => 2712,
      'name' => "Anthocyanidin 3-O-2-p-coumaroyl glycosides",
      'description' => "Anthocyanidin 3-O-glycosides where the carbohydrate moiety is esterified at the C2 position with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 2708,
    ),
    array(
      'tid' => 2713,
      'name' => "Anthocyanidin 3p-O-6-p-coumaroyl glycosides",
      'description' => "Anthocyanidin 3p-O-glycosides where the carbohydrate moiety is esterified at the C6 position with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 2709,
    ),
    array(
      'tid' => 2714,
      'name' => "Anthocyanidin 3p-O-2-p-coumaroyl glycosides",
      'description' => "Anthocyanidin 3p-O-glycosides where the carbohydrate moiety is esterified at the C2 position with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 2709,
    ),
    array(
      'tid' => 2715,
      'name' => "Anthocyanidin 5-O-6-p-coumaroyl glycosides",
      'description' => "Anthocyanidin 5-O-glycosides where the carbohydrate moiety is esterified at the C6 position with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 2710,
    ),
    array(
      'tid' => 2716,
      'name' => "Anthocyanidin 5-O-2-p-coumaroyl glycosides",
      'description' => "Anthocyanidin 5-O-glycosides where the carbohydrate moiety is esterified at the C2 position with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 2710,
    ),
    array(
      'tid' => 2717,
      'name' => "Polyphenyl ethers",
      'description' => "Polymers of unsubstituted phenoxy groups linked through ether bonds.",
      'parent' => 2279,
    ),
    array(
      'tid' => 2718,
      'name' => "Polyphenyl thioethers",
      'description' => "Polymers of unsubstituted phenoxy groups linked through thioether bonds.",
      'parent' => 2279,
    ),
    array(
      'tid' => 2719,
      'name' => "Lupin alkaloids",
      'description' => "Alkaloids extracted from the lupinus species. They usually possess a bi-, tri-, or tetracyclic skeleton consisting of one or more quinolizidine moieties.",
      'parent' => 279,
    ),
    array(
      'tid' => 2720,
      'name' => "Matrine alkaloids",
      'description' => "Lupin alkaloids with a structure based on the matrine skeleton, a four-ring skeleton that based on a saturated dipyrido[2,1-f:3',2',1'-ij][1,6]naphthyridin-10-one skeleton.",
      'parent' => 2719,
    ),
    array(
      'tid' => 2721,
      'name' => "Lupinine-type alkaloids",
      'description' => "Lupin alkaloids with a structure based on the lupinine skeleton, which is a bicyclic compound consisting of a quinolizidine.",
      'parent' => 2719,
    ),
    array(
      'tid' => 2722,
      'name' => "Cytisine and derivatives",
      'description' => "Lupin alkaloids with a structure based on the cytisine skeleton, which is a tetracyclic ketone containing fused pyridine and piperidine rings that form pyrido[1,2a][1,5]diazocin-8-one.",
      'parent' => 2719,
    ),
    array(
      'tid' => 2723,
      'name' => "Anagyrine-type alkaloids",
      'description' => "Lupin alkaloids with a structure based on the anagyrine skeleton. Anagyrine is a tetracyclic ketone containing a quinolizidine, and two pyridine rings fused together to form dipyrido[1,2-a:1',2'-e][1,5]diazocin-4-one.",
      'parent' => 2719,
    ),
    array(
      'tid' => 2724,
      'name' => "Steroidal alkaloids",
      'description' => "Alkaloids characterized by the presence of one or more alkylamino substituents attached to a steroidal skeleton. These are azasteroids in which a nitrogen atom forms an integral part of the steroid nucleus or may be present in the side chain.",
      'parent' => 258,
    ),
    array(
      'tid' => 2725,
      'name' => "Solanocapsine-type alkaloids",
      'description' => "Steroidal alkaloids with a structure that is characterized by a docosahydronaphth[2,1:4',5']indene ring system fused to a pyrano[3,2-b]pyridine moiety.",
      'parent' => 2724,
    ),
    array(
      'tid' => 2726,
      'name' => "Buxus alkaloids",
      'description' => "Alkaloids with a triterpenoid-steroid pregnane type structure with C-4 methyl groups, a 9beta,10beta-cycloartenol system, and a degraded C-20 side chain. Structurally, they are  derivatives of either a 9beta,10beta-cyclo-4,4,14alpha-trimethyl-5alpha-pregnane or a 9(10->19)abeo 4,4,14alpha-trimethyl-5alpha-pregnane system.",
      'parent' => 2724,
    ),
    array(
      'tid' => 2727,
      'name' => "Samamine-type alkaloids",
      'description' => "Alkaloids with a structure that is based on the samamine skeleton, a tetracyclic compound consisting of and azepane ring fuse a saturated cyclopenta[a]naphthalene derivative.",
      'parent' => 2724,
    ),
    array(
      'tid' => 2728,
      'name' => "Jerveratrum-type alkaloids",
      'description' => "Steroidal alkaloids with a structure that is based on the jervane ring system. Jerveratrum alkaloids have alkamines with 1-3 oxygen atoms, and occur as such or as monoglycosides.",
      'parent' => 2724,
    ),
    array(
      'tid' => 2729,
      'name' => "Cerveratrum-type alkaloids",
      'description' => "Steroidal alkaloids containing the cevane (23-methyl-4- azahexacyclo[12.11.0.0^{2,11}.0^{4,9}.0^{15,24}.0^{18,23}]pentacosane) moiety, which is a six ring system. Cerveratrum alkaloids have 7-9 oxygen atoms and occur as free alkamines or esters of simple aliphatic or aromatic acids.",
      'parent' => 2724,
    ),
    array(
      'tid' => 2730,
      'name' => "Pregnane-type alkaloids",
      'description' => "Alkaloids with a structure based on the pregnane skeleton, which is characterized by the presence of monomethylamino or dimethylamino substituents either at C-3 and/or at the C-20 position in basic steroidal skeleton.",
      'parent' => 2724,
    ),
    array(
      'tid' => 2731,
      'name' => "Conanine-type alkaloids",
      'description' => "Alkaloids with a structure based on the conanine skeleton.",
      'parent' => 2724,
    ),
    array(
      'tid' => 2732,
      'name' => "22,26-epiminocholestanes",
      'description' => "Steroid alkaloids obtained by reduction of spirosolane through opening of the E-ring.",
      'parent' => 2724,
    ),
    array(
      'tid' => 2733,
      'name' => "22,23-secosolanidanes and derivatives",
      'description' => "Cholestane derivatives that contain the 22,23-secosolanidane moiety. 22,23-secosolanidane arises from the conversion of the  cholestane side-chain into a piperidine ring that is N-substituted with a 2-methylpropyl group.",
      'parent' => 2724,
    ),
    array(
      'tid' => 2734,
      'name' => "Samandarines",
      'description' => "Samamime-type alkaloids in which the A-ring of the steroidal backbone is an oxazolidine.",
      'parent' => 2727,
    ),
    array(
      'tid' => 2735,
      'name' => "3-oxo-22,26-epiminocholestanes",
      'description' => "22,26-epiminocholestane derivatives carrying C=O group at the 3-position.",
      'parent' => 2732,
    ),
    array(
      'tid' => 2736,
      'name' => "3-amino-22,26-epiminocholestanes",
      'description' => "22,26-epicholestane derivatives carrying an amino group at the 3-position.",
      'parent' => 2732,
    ),
    array(
      'tid' => 2737,
      'name' => "3-aminospirostanes",
      'description' => "Spirostane derivatives carrying an amino group at the 3-position. Spirostanes are 16b,22:22,26-diepoxycholestanes, or 22,26-epoxyfurostans. The sixth ring so formed is known as ring F.",
      'parent' => 2724,
    ),
    array(
      'tid' => 2738,
      'name' => "Atisane diterpenoids",
      'description' => "Diterpenoids with a structure based on the atisane skeleton, which is a tetracyclic compound containing the [2,2,2]bicyc1ic ring system with the C15-C16 bridge attached at C12.",
      'parent' => 3401,
    ),
    array(
      'tid' => 2739,
      'name' => "Atisine-type diterpenoid alkaloids",
      'description' => "Alkaloid diterpenoids with a structure based on the pentacyclic atisine skeleton.",
      'parent' => 2738,
    ),
    array(
      'tid' => 2740,
      'name' => "Benzodifurans",
      'description' => "Organic heterocyclic compounds containing a to furan rings fused to a central benzene ring. They can be grouped in angular and linear benzodifurans.",
      'parent' => 301,
    ),
    array(
      'tid' => 2741,
      'name' => "Angular benzodifurans",
      'description' => "Benzodifurans containing angularly fused benzene and furan rings.",
      'parent' => 2740,
    ),
    array(
      'tid' => 2742,
      'name' => "Linear benzodifurans",
      'description' => "Benzodifurans containing linearly fused benzene and furan rings.",
      'parent' => 2740,
    ),
    array(
      'tid' => 2743,
      'name' => "Protopine alkaloids",
      'description' => "Alkaloids with a structure based on a tricyclic protopine formed by oxidative ring fission of protoberberine N-metho salts.",
      'parent' => 279,
    ),
    array(
      'tid' => 2744,
      'name' => "Vobasan alkaloids",
      'description' => "Alkaloids containing the vobasan skeleton.",
      'parent' => 279,
    ),
    array(
      'tid' => 2745,
      'name' => "Lysergic acids",
      'description' => "Derivatives of lysergic acid are amides in which the amidic moiety is formed by a small peptide or an alkylamide.",
      'parent' => 2680,
    ),
    array(
      'tid' => 2746,
      'name' => "Lysergamides",
      'description' => "Amides of Lysergic acids.",
      'parent' => 2680,
    ),
    array(
      'tid' => 2747,
      'name' => "Clavines and derivatives",
      'description' => "Hydroxy and dehydro derivatives of 6,8-dimethylergolenes and the corresponding ergolines.",
      'parent' => 2679,
    ),
    array(
      'tid' => 2748,
      'name' => "Ibogan-type alkaloids",
      'description' => "Indole alkaloids with a structure based on the ibogamine skeleton or a derivative thereof. Ibogamine is a pentacyclic heterocyclic compound consisting of an indole fused to an azepane-containing tricyclic moiety ring. Iboga alkaloids arise from the cyclization of a secodine-type precursor through the formation of a 16,21 bond.",
      'parent' => 279,
    ),
    array(
      'tid' => 2749,
      'name' => "Strychnos alkaloids",
      'description' => "Alkaloids having a core structure based on the strychnan, stemmadenine (seco-curan), or the akuammicine (curan) skeleton.",
      'parent' => 279,
    ),
    array(
      'tid' => 2750,
      'name' => "Corynanthean-type alkaloids",
      'description' => "Alkaloids with a structure based on the corynanthean nucleus, which is a tetracycle characterized by an indole fused to a quinolizidine. Additionally, the quinolizidine ring system is substituted to a 2-methylpropyl group and one ethyl group.",
      'parent' => 279,
    ),
    array(
      'tid' => 2751,
      'name' => "Vallesiachotaman alkaloids",
      'description' => "Alkaloids with a structure based on the vallesiachotaman skeleton. Vallesiachotaman is a tetracyclic compound that has a indolo[2,3-a]quinolizine core substituted by two methyl groups at the 3-, and 12-positions as well as a 2-methylbutane group at the 2-position.",
      'parent' => 279,
    ),
    array(
      'tid' => 2752,
      'name' => "Vincosan alkaloids",
      'description' => "Alkaloids containing the vincosan skeleton, a tetracyclic ring system containing a carboline and a tetrahydropyran ring.",
      'parent' => 279,
    ),
    array(
      'tid' => 2753,
      'name' => "Pyridoxine-5'-phosphates",
      'description' => "Pyridoxines that carry a phosphate group at the 5-position.",
      'parent' => 1948,
    ),
    array(
      'tid' => 2754,
      'name' => "Cinnamyl alcohols",
      'description' => "Aromatic alcohols containing a 3-phenylprop-2-en-1-ol moiety.",
      'parent' => 261,
    ),
    array(
      'tid' => 2755,
      'name' => "Aspidospermatan-type alkaloids",
      'description' => "Tryptophan-derived alkaloids that are derived from the fusion of tryptamine and a terpene unit (generally either 9 or 10 carbons). Aspidospermine and aspidospermidine (along with tabersonine) are the archetypical members of the Aspidosperma alkaloids.",
      'parent' => 279,
    ),
    array(
      'tid' => 2756,
      'name' => "Vinca alkaloids",
      'description' => "Alkaloids with a dimeric chemical structure composed of an indole nucleus (catharanthine), and a dihydroindole nucleus (vindoline), joined together.",
      'parent' => 279,
    ),
    array(
      'tid' => 2757,
      'name' => "Quebrachamine alkaloids",
      'description' => "Alkaloids with a structure based on the quebrachamine skeleton, a tetracyclic compound that is derived by fission of the 7,21 bond of the aspidospermidine skeleton. Some quebrachamine alkaloids lack the C-16 methoxycarbonyl group.",
      'parent' => 279,
    ),
    array(
      'tid' => 2758,
      'name' => "Rhazinilam alkaloids",
      'description' => "Alkaloids with a structure based on the rhazinilam skeleton, a tetracyclic compound with a complex tetracyclic carbon skeleton containing pyrrole ring embedded in its indolizine core.",
      'parent' => 279,
    ),
    array(
      'tid' => 2759,
      'name' => "Tacaman alkaloids",
      'description' => "Alkaloids containing the pentacyclic tacaman skeleton, which consists of a pyrido[1,2-a]indole fused to a quinolizine. Tacaman alkaloids are obtained from a precursor to a pseudoaspidospermidine (type II skeleton) derivative, by the formation of new bonds at C-20/C-3 and C-140/C-17.",
      'parent' => 279,
    ),
    array(
      'tid' => 2760,
      'name' => "Amidoximes",
      'description' => "Amidines, in which the imino nitrogen is substituted by a hydroxy group.",
      'parent' => 7,
    ),
    array(
      'tid' => 2761,
      'name' => "3-sulfobenzoic acids",
      'description' => "Sulfobenzoic acid carrying the sulfonyl group at the 3-position of the benzene group.",
      'parent' => 34,
    ),
    array(
      'tid' => 2762,
      'name' => "4-sulfobenzoic acids",
      'description' => "Sulfobenzoic acid carrying the sulfonyl group at the 4-position of the benzene group.",
      'parent' => 34,
    ),
    array(
      'tid' => 2763,
      'name' => "Iodophenols",
      'description' => "Halophenols carrying a iodine on the benzene ring.",
      'parent' => 2320,
    ),
    array(
      'tid' => 2764,
      'name' => "Bromophenols",
      'description' => "Halophenols carrying a bromine on the benzene ring.",
      'parent' => 2320,
    ),
    array(
      'tid' => 2765,
      'name' => "Fluorophenols",
      'description' => "Halophenols carrying a fluorine on the benzene ring.",
      'parent' => 2320,
    ),
    array(
      'tid' => 2766,
      'name' => "Chlorophenols",
      'description' => "Halophenols carrying a chlorine on the benzene ring.",
      'parent' => 2320,
    ),
    array(
      'tid' => 2767,
      'name' => "M-bromophenols",
      'description' => "Bromophenols carrying a iodine at the C3 position of the benzene ring.",
      'parent' => 2764,
    ),
    array(
      'tid' => 2768,
      'name' => "O-bromophenols",
      'description' => "Bromophenols carrying a iodine at the C2 position of the benzene ring.",
      'parent' => 2764,
    ),
    array(
      'tid' => 2769,
      'name' => "P-bromophenols",
      'description' => "Bromophenols carrying a iodine at the C4 position of the benzene ring.",
      'parent' => 2764,
    ),
    array(
      'tid' => 2770,
      'name' => "M-chlorophenols",
      'description' => "Chlorophenols carrying a iodine at the C3 position of the benzene ring.",
      'parent' => 2766,
    ),
    array(
      'tid' => 2771,
      'name' => "O-chlorophenols",
      'description' => "Chlorophenols carrying a iodine at the C2 position of the benzene ring.",
      'parent' => 2766,
    ),
    array(
      'tid' => 2772,
      'name' => "P-chlorophenols",
      'description' => "Chlorophenols carrying a iodine at the C4 position of the benzene ring.",
      'parent' => 2766,
    ),
    array(
      'tid' => 2773,
      'name' => "M-fluorophenols",
      'description' => "Fluorophenols carrying a iodine at the C3 position of the benzene ring.",
      'parent' => 2765,
    ),
    array(
      'tid' => 2774,
      'name' => "O-fluorophenols",
      'description' => "Fluorophenols carrying a iodine at the C2 position of the benzene ring.",
      'parent' => 2765,
    ),
    array(
      'tid' => 2775,
      'name' => "P-fluorophenols",
      'description' => "Fluorophenols carrying a iodine at the C4 position of the benzene ring.",
      'parent' => 2765,
    ),
    array(
      'tid' => 2776,
      'name' => "M-iodophenols",
      'description' => "Iodophenols carrying a iodine at the C3 position of the benzene ring.",
      'parent' => 2763,
    ),
    array(
      'tid' => 2777,
      'name' => "O-iodophenols",
      'description' => "Iodophenols carrying a iodine at the C2 position of the benzene ring.",
      'parent' => 2763,
    ),
    array(
      'tid' => 2778,
      'name' => "P-iodophenols",
      'description' => "Iodophenols carrying a iodine at the C4 position of the benzene ring.",
      'parent' => 2763,
    ),
    array(
      'tid' => 2779,
      'name' => "4-nitroquinoline N-oxides",
      'description' => "Nitroquinoline derivative bearing a nitro group at ring position 4 and N-oxide group at ring position 1.",
      'parent' => 1155,
    ),
    array(
      'tid' => 2780,
      'name' => "Erythrinanes",
      'description' => "Erythrina alkaloids possessing either a 6-5-6-6-membered indoloisoquinoline core or a derivative thereof.",
      'parent' => 1782,
    ),
    array(
      'tid' => 2781,
      'name' => "Homoerythrinane alkaloids",
      'description' => "Erythrina alkaloids predominantly possessing a 6-5-7-6-membered indolobenzazepine skeleton or a derivative thereof.",
      'parent' => 1782,
    ),
    array(
      'tid' => 2782,
      'name' => "Pyridodiazepines",
      'description' => "Heterocyclic compounds containing a pyridine fused to a diazepine ring. Pyridine is 6-membered ring consisting of five carbon atoms and a nitrogen atom. Diazepine is a 7-membered ring consisting of five carbon atoms and two nitrogen centers.",
      'parent' => 2,
    ),
    array(
      'tid' => 2783,
      'name' => "Akuammilan and related alkaloids",
      'description' => "Alkaloids with a structure based on either the akuammilan skeleton. The ring system in this group is formed from a precursor of the corynantheine type by bond formation between C-16 and C-7. Variations in this subgroup include, among others, alkaloids derived by C-3 to N-4 bond fission, as well as alkaloids in which the N-4 to C-5 bond in the Akuammiline skeleton has been severed.",
      'parent' => 279,
    ),
    array(
      'tid' => 2784,
      'name' => "Sulfanylbenzoic acids",
      'description' => "Benzoic acids which bear a sulfanyl group (R-SH) attached to the benzene ring.",
      'parent' => 2086,
    ),
    array(
      'tid' => 2785,
      'name' => "Thiosalicylic acids",
      'description' => "Compounds containing a benzene ring which bears a carboxyl group and a sulfhydryl functional group a positions 1 and 2, respectively.",
      'parent' => 77,
    ),
    array(
      'tid' => 2786,
      'name' => "M-sulfanylbenzoic acids and derivatives",
      'description' => "Benzoic acids (or derivatives) which bear a sulfanyl group (R-SH) attached to the benzene ring at positions 1 and 3, respectively.",
      'parent' => 2086,
    ),
    array(
      'tid' => 2787,
      'name' => "P-sulfanylbenzoic acids and derivatives",
      'description' => "Benzoic acids (or derivatives) which bear a sulfanyl group (R-SH) attached to the benzene ring at positions 1 and 4, respectively.",
      'parent' => 2086,
    ),
    array(
      'tid' => 2788,
      'name' => "M-sulfanylbenzoic acids",
      'description' => "Benzoic acids which bear a sulfanyl group (R-SH) attached to the benzene ring at positions 1 and 3, respectively.",
      'parent' => 2786,
    ),
    array(
      'tid' => 2789,
      'name' => "P-sulfanylbenzoic acids",
      'description' => "Benzoic acids which bear a sulfanyl group (R-SH) attached to the benzene ring at positions 1 and 4, respectively.",
      'parent' => 2787,
    ),
    array(
      'tid' => 2790,
      'name' => "1,3-oxazinanes",
      'description' => "Compounds contain an oxazinane ring with the nitrogen atom and the oxygen atom at positions 1  and 3, respectively.",
      'parent' => 107,
    ),
    array(
      'tid' => 2791,
      'name' => "Acutumine and related alkaloids",
      'description' => "Alkaloids with a structure based on the tricyclic acutumine skeleton, which contains an indoline moiety and two cyclopentene rings.",
      'parent' => 279,
    ),
    array(
      'tid' => 2792,
      'name' => "Hasubanan alkaloids",
      'description' => "Alkaloids with a structure based on the hasubanan skeleton, a tetracyclic propellane.",
      'parent' => 279,
    ),
    array(
      'tid' => 2793,
      'name' => "Pavine alkaloids",
      'description' => "Alkaloids with a structure based on the pavine skeleton.",
      'parent' => 279,
    ),
    array(
      'tid' => 2794,
      'name' => "Isopavine alkaloids",
      'description' => "Alkaloids with a structure based on the isopavine skeleton.",
      'parent' => 279,
    ),
    array(
      'tid' => 2795,
      'name' => "Organoboron compounds",
      'description' => "Organic compounds containing a carbon-boron bond.",
      'parent' => 1370,
    ),
    array(
      'tid' => 2796,
      'name' => "1,2,3-triazinanes",
      'description' => "Triazinanes having three nitrogen ring atoms at the 1-, 2-, and 3- positions.",
      'parent' => 2693,
    ),
    array(
      'tid' => 2797,
      'name' => "1,2,4-triazinanes",
      'description' => "Triazinanes having three nitrogen ring atoms at the 1-, 2-, and 4- positions.",
      'parent' => 2693,
    ),
    array(
      'tid' => 2798,
      'name' => "1,3,5-triazinanes",
      'description' => "Triazinanes having three nitrogen ring atoms at the 1-, 3-, and 5- positions.",
      'parent' => 2693,
    ),
    array(
      'tid' => 2799,
      'name' => "Organic trisulfides",
      'description' => "Organosulfur compounds with the general formula RSSSR' (R,R'=alkyl, aryl).",
      'parent' => 4,
    ),
    array(
      'tid' => 2800,
      'name' => "Organic disulfides",
      'description' => "Organosulfur compounds with the general formula RSSR' (R,R' = alkyl, aryl).",
      'parent' => 4,
    ),
    array(
      'tid' => 2801,
      'name' => "Prenylated hydroquinones",
      'description' => "Quinones with a structure characterized by the hydroquinone ring substituted by an prenyl side-chain.",
      'parent' => 1534,
    ),
    array(
      'tid' => 2802,
      'name' => "Prenylquinones",
      'description' => "Quinones with a structure characterized by the quinone ring substituted by an prenyl side-chain.",
      'parent' => 1534,
    ),
    array(
      'tid' => 2803,
      'name' => "Thianthrenes",
      'description' => "Organic compounds containing a thianthrene moiety. Thianthrene is a tricyclic ring system that consists of two benzene rings fused to each other through a 1,4-dithiin ring.",
      'parent' => 2807,
    ),
    array(
      'tid' => 2804,
      'name' => "Benzodithiins",
      'description' => "Organic heterocyclic compounds containing a benzene ring fused to a dithiin ring. Dithiin is an unsaturated six-member heterocycle containing four carbon atoms, two sulfur atoms and two double bonds.",
      'parent' => 2,
    ),
    array(
      'tid' => 2805,
      'name' => "1,2-benzodithiins",
      'description' => "Organic heterocyclic compounds containing a benzene ring fused to a 1,2-dithiin ring.",
      'parent' => 2804,
    ),
    array(
      'tid' => 2806,
      'name' => "1,3-benzodithiins",
      'description' => "Organic heterocyclic compounds containing a benzene ring fused to a 1,3-dithiin ring.",
      'parent' => 2804,
    ),
    array(
      'tid' => 2807,
      'name' => "1,4-benzodithiins",
      'description' => "Organic heterocyclic compounds containing a benzene ring fused to a 1,4-dithiin ring.",
      'parent' => 2804,
    ),
    array(
      'tid' => 2808,
      'name' => "2,3-benzodithiins",
      'description' => "Organic heterocyclic compounds containing a benzene ring fused to a 2,3-dithiin ring.",
      'parent' => 2804,
    ),
    array(
      'tid' => 2809,
      'name' => "N-methylpyrroles",
      'description' => "Organic heterocyclic compounds containing a N-methylated pyrrole.",
      'parent' => 2258,
    ),
    array(
      'tid' => 2810,
      'name' => "Cinnamic acid amides",
      'description' => "Amides of cinnamic acids. Cinnamic acid is an aromatic compound containing a benzene and a carboxylic acid group forming 3-phenylprop-2-enoic acid.",
      'parent' => 476,
    ),
    array(
      'tid' => 2811,
      'name' => "Phenylpropanes",
      'description' => "Organic compounds containing a phenylpropane moiety.",
      'parent' => 2279,
    ),
    array(
      'tid' => 2812,
      'name' => "Acyl glucuronides",
      'description' => "Carbohydrate derivatives containing glucuronic acid linked to another substance through an ester bond attached at position C-1, C-2, C-3, or C-4 of the glucuronic acid moiety. The C-1 acyl glucuronide is usually the initial isomer, However, the acyl group can rearrange from its initial position on the C-1 hydroxyl group of the glucuronic acid moiety to the C-2 and, subsequently, the C-3 and the C-4 hydroxyl group. Formation of the C-3 from the C-2 isomer, and the C-4 from the C-3 isomer is possible, whereas the C-1 isomer cannot result from the other regioisomers via acyl migration.",
      'parent' => 374,
    ),
    array(
      'tid' => 2813,
      'name' => "O-glucuronides",
      'description' => "Glucuronides in which the aglycone is linked to the carbohydrate unit through an O-glycosidic bond.",
      'parent' => 374,
    ),
    array(
      'tid' => 2814,
      'name' => "N-glucuronides",
      'description' => "Glucuronides in which the aglycone is linked to the carbohydrate unit through a N-glycosidic bond.",
      'parent' => 374,
    ),
    array(
      'tid' => 2815,
      'name' => "C-glucuronides",
      'description' => "Glucuronides in which the aglycone is linked to the carbohydrate unit through a C-glycosidic bond.",
      'parent' => 374,
    ),
    array(
      'tid' => 2816,
      'name' => "S-glucuronides",
      'description' => "Carbohydrate derivatives containing glucuronic acid linked to another substance through a S-glycosidic bond.",
      'parent' => 374,
    ),
    array(
      'tid' => 2817,
      'name' => "Dibenzopyrans",
      'description' => "Organic heterocyclic compounds with a structure containing a dibenzopyran moiety, made up of two benzene rings fused to a central pyran ring.",
      'parent' => 3410,
    ),
    array(
      'tid' => 2818,
      'name' => "Dibenzothiophenes",
      'description' => "Organic heterocyclic compounds with a structure containing a dibenzothiophene moiety, made up of two benzene rings fused to a central thiophene ring.",
      'parent' => 312,
    ),
    array(
      'tid' => 2819,
      'name' => "Isoflav-3-enes",
      'description' => "Flavonoids with a structure based on the 3-phenylchromene skeleton, with a double bond between the C3 and C4 carbon atoms of the chromene moiety.",
      'parent' => 2506,
    ),
    array(
      'tid' => 2820,
      'name' => "Isoflav-3-enones",
      'description' => "Flavonoids with a structure based on an isoflav-3-ene skeleton bearing an oxo-group at position C2.",
      'parent' => 2819,
    ),
    array(
      'tid' => 2821,
      'name' => "Isoflavone epoxides",
      'description' => "Isoflavones where the atoms C-2 and C-3 are both linked to the same oxygen atom to form an epoxide ring.",
      'parent' => 494,
    ),
    array(
      'tid' => 2822,
      'name' => "Leontidine-type alkaloids",
      'description' => "Lupin alkaloids with a structure based on the leontidine skeleton, a tetracyclic compound containing fused piperidine, pyridine, and pyrrolidine rings.",
      'parent' => 2719,
    ),
    array(
      'tid' => 2823,
      'name' => "Aloperine and related alkaloids",
      'description' => "Lupin Alkaloids with a structure based on the aloperine skeleton. Aloperine is a tetracyclic compound made up of a quinolizidine and a decahydroquinoline joined to  form 3,15-diazatetracycloheptadecane.",
      'parent' => 2719,
    ),
    array(
      'tid' => 2824,
      'name' => "9b-azaphenalenes",
      'description' => "Alkaloids with a structure based on the perhydro-9b-azaphenalene skeleton. Perhydro-9b-azaphenalene is a tricyclic compound consisting of quinolizidine that share its only nitrogen atom with a piperidine. In some 9b-azaphenalenes, the resulting tricyclic backbone can be unsaturated.",
      'parent' => 279,
    ),
    array(
      'tid' => 2825,
      'name' => "Ormosia-type alkaloids",
      'description' => "Aloperine alkaloids with a structure based on the ormosanine skeleton.",
      'parent' => 2823,
    ),
    array(
      'tid' => 2826,
      'name' => "Pyrido[2,3,4-kl]acridones",
      'description' => "Compounds containing a pyrido[2,3,4-kl]acridine carrying a C=O group.",
      'parent' => 1810,
    ),
    array(
      'tid' => 2827,
      'name' => "Pyrido[2,3,4-kl]acridines",
      'description' => "Organic heterocyclic compounds with a structure based on the pyrido[2,3,4-kl]acridine skeleton.",
      'parent' => 1763,
    ),
    array(
      'tid' => 2828,
      'name' => "Pyrrolo[2,3,4-kl]acridines",
      'description' => "Organic heterocyclic compounds with a structure based on the Pyrrolo[2,3,4-kl]acridine skeleton.",
      'parent' => 1762,
    ),
    array(
      'tid' => 2829,
      'name' => "Pyrrolo[4,3,2-de]quinolines",
      'description' => "Organic heterocyclic compounds with a structure based on the Pyrrolo[4,3,2-de]quinoline skeleton.",
      'parent' => 1734,
    ),
    array(
      'tid' => 2830,
      'name' => "5-hydroxypsoralens",
      'description' => "Psoralens containing a hydroxyl group attached at the C5 position of the psoralen group.",
      'parent' => 202,
    ),
    array(
      'tid' => 2831,
      'name' => "8-hydroxypsoralens",
      'description' => "Psoralens containing a hydroxyl group attached at the C8 position of the psoralen group.",
      'parent' => 202,
    ),
    array(
      'tid' => 2832,
      'name' => "5-methoxypsoralens",
      'description' => "Psoralens containing a methoxy group attached at the C5 position of the psoralen group.",
      'parent' => 202,
    ),
    array(
      'tid' => 2833,
      'name' => "8-methoxypsoralens",
      'description' => "Psoralens containing a methoxy group attached at the C8 position of the psoralen group.",
      'parent' => 202,
    ),
    array(
      'tid' => 2834,
      'name' => "Thiochromanes",
      'description' => "Organic heterocyclic compounds containing a thiochromane moiety.",
      'parent' => 2,
    ),
    array(
      'tid' => 2835,
      'name' => "Isothiochromanes",
      'description' => "Organic heterocyclic compounds containing an isothiochromane moiety.",
      'parent' => 2,
    ),
    array(
      'tid' => 2836,
      'name' => "Pyrazolidinones",
      'description' => "Organic heterocyclic compounds containing a pyrazolidinone moiety.",
      'parent' => 217,
    ),
    array(
      'tid' => 2837,
      'name' => "Hydrocarbons",
      'description' => "Organic compounds made up only of carbon and hydrogen atoms.",
      'parent' => 0,
    ),
    array(
      'tid' => 2838,
      'name' => "Olefins",
      'description' => "Acyclic and cyclic hydrocarbons having one or more carbon-carbon double bonds, apart from the formal ones in aromatic compounds. The class of olefins subsumes alkenes and cycloalkenes and the corresponding polyenes.",
      'parent' => 4475,
    ),
    array(
      'tid' => 2839,
      'name' => "Acyclic olefins",
      'description' => "Olefins that do not contain a ring in their structure.",
      'parent' => 2838,
    ),
    array(
      'tid' => 2840,
      'name' => "Cyclic olefins",
      'description' => "Olefins that contain at least one ring in their structure.",
      'parent' => 2838,
    ),
    array(
      'tid' => 2841,
      'name' => "Alkatrienes",
      'description' => "Acyclic hydrocarbons that contain exactly three carbon-to-carbon double bonds.",
      'parent' => 2839,
    ),
    array(
      'tid' => 2842,
      'name' => "Alkatetraenes",
      'description' => "Acyclic hydrocarbons that contain exactly four carbon-to-carbon double bonds.",
      'parent' => 2839,
    ),
    array(
      'tid' => 2843,
      'name' => "Acetylenes",
      'description' => "Acyclic (branched or unbranched) and cyclic (with or without side chain) hydrocarbons having one or more carbon to carbon triple bonds.",
      'parent' => 4475,
    ),
    array(
      'tid' => 2844,
      'name' => "Alkadiynes",
      'description' => "Acyclic branched or unbranched hydrocarbons having two triple bonds, with the general formula CnH2n-6.",
      'parent' => 2847,
    ),
    array(
      'tid' => 2845,
      'name' => "Alkatriynes",
      'description' => "Acyclic branched or unbranched hydrocarbons having three triple bonds, with the general formula CnH2n-10.",
      'parent' => 2847,
    ),
    array(
      'tid' => 2846,
      'name' => "Cyclic acetylenes",
      'description' => "Cyclic hydrocarbons containing one or more acetylene groups.",
      'parent' => 2843,
    ),
    array(
      'tid' => 2847,
      'name' => "Acyclic acetylenes",
      'description' => "Acyclic hydrocarbons containing one or more acetylene groups.",
      'parent' => 2843,
    ),
    array(
      'tid' => 2848,
      'name' => "Monocyclic acetylenes",
      'description' => "Monocyclic hydrocarbons containing one or more acetylene groups.",
      'parent' => 2846,
    ),
    array(
      'tid' => 2849,
      'name' => "Polycyclic acetylenes",
      'description' => "Polycyclic hydrocarbons containing one or more acetylene groups.",
      'parent' => 2846,
    ),
    array(
      'tid' => 2850,
      'name' => "Cycloalkynes",
      'description' => "Unsaturated monocyclic hydrocarbons having one endocyclic triple bond.",
      'parent' => 2848,
    ),
    array(
      'tid' => 2851,
      'name' => "Iminoquinones",
      'description' => "Quinones that carry an imine group.",
      'parent' => 2495,
    ),
    array(
      'tid' => 2852,
      'name' => "Cytochalasins",
      'description' => "Cytochalasans in which the hydrogenated isoindolone bears a benzyl group.",
      'parent' => 1821,
    ),
    array(
      'tid' => 2853,
      'name' => "Aziridinones",
      'description' => "Compounds with a structure containing an aziridines ring bearing one carbonyl group. They are cyclic amides of acetic acid.",
      'parent' => 103,
    ),
    array(
      'tid' => 2854,
      'name' => "Lactims",
      'description' => "Cyclic amides of carboximidic acids. Lactams are tautomers of lactams, having an endocyclic carbon-nitrogen double bond.",
      'parent' => 2,
    ),
    array(
      'tid' => 2855,
      'name' => "Phosphorus mustard compounds",
      'description' => "Compounds having two beta-haloalkyl groups bound to a phosphorus atom.",
      'parent' => 400,
    ),
    array(
      'tid' => 2856,
      'name' => "1,1-diols",
      'description' => "Alcohols in which two hydroxy groups are bonded to the same atom.",
      'parent' => 2286,
    ),
    array(
      'tid' => 2857,
      'name' => "Organic phosphoric acid monoamides",
      'description' => "Organophosphorus compounds with the general formula RNP(O)(O)=O (R=alkyl, aryl).",
      'parent' => 1204,
    ),
    array(
      'tid' => 2858,
      'name' => "Isofamides",
      'description' => "Oxazaphospholanes containing the isofamide skeleton. Isofamide is a heterocyclic compound made up of a 1,3,2-oxazaphospholane, where the phosphorus atom is part of a phosphodiamide group, and the oxazaphospholane is substituted by two haloalkyl chains.",
      'parent' => 2466,
    ),
    array(
      'tid' => 2859,
      'name' => "Azlactones",
      'description' => "Oxazol-5(4H)-ones I, compounds derived by cyclization of N-acyl alpha-amino carboxylic acids, RC(=O)NHCR2C(=O)OH, through formal loss of the elements of water.",
      'parent' => 84,
    ),
    array(
      'tid' => 2860,
      'name' => "Sulfonylamines",
      'description' => "Compounds having the general structure RN=S(=O)2.",
      'parent' => 278,
    ),
    array(
      'tid' => 2861,
      'name' => "Vinyl fluorides",
      'description' => "Vinyl halides in which a fluorine atom is bonded to an sp2-hybridised carbon atom.",
      'parent' => 2868,
    ),
    array(
      'tid' => 2862,
      'name' => "Vinyl iodides",
      'description' => "Vinyl halides in which a iodine atom is bonded to an sp2-hybridised carbon atom.",
      'parent' => 2868,
    ),
    array(
      'tid' => 2863,
      'name' => "Vinyl chlorides",
      'description' => "Vinyl halides in which a chlorine atom is bonded to an sp2-hybridised carbon atom.",
      'parent' => 2868,
    ),
    array(
      'tid' => 2864,
      'name' => "Vinyl bromides",
      'description' => "Vinyl halides in which a bromine atom is bonded to an sp2-hybridised carbon atom.",
      'parent' => 2868,
    ),
    array(
      'tid' => 2865,
      'name' => "Acyl halides",
      'description' => "Organic compounds with the general structure RC(=O)X, where X is a halogen atom.",
      'parent' => 267,
    ),
    array(
      'tid' => 2866,
      'name' => "Aryl halides",
      'description' => "Organic compounds containing an aromatic ring (or ring system) carrying a C-X bond.",
      'parent' => 267,
    ),
    array(
      'tid' => 2867,
      'name' => "Alkyl halides",
      'description' => "Organic compounds containing a linear aliphatic chain (or ring system) carrying a C-X bond, where X is a halogen atom.",
      'parent' => 267,
    ),
    array(
      'tid' => 2868,
      'name' => "Vinyl halides",
      'description' => "Organic compounds in which the halogen atom is bonded to an sp2-hybridised carbon atom of a carbon-carbon double bond (C=C).",
      'parent' => 267,
    ),
    array(
      'tid' => 2869,
      'name' => "Organic sulfuryl halides",
      'description' => "Organic compounds containing the sulfuryl halide group.",
      'parent' => 267,
    ),
    array(
      'tid' => 2870,
      'name' => "Imidoyl halides",
      'description' => "Organic compounds containing the imidoyl halide functional group, with the general structure R(X)C=NR' (R, R'=H, alkyl, aryl; X = halogen).",
      'parent' => 267,
    ),
    array(
      'tid' => 2871,
      'name' => "Grayanoids",
      'description' => "Diterpenoids containing a skeleton based on or derived from the ent-kaurane moiety. Grayanoids usually possess either one of the grayanane, the 2,4-seco-grayanane, the 9,10-seco-grayanane, the 1,5-seco-grayanane, the kalmane, or the leucothane skeleton. Some derivatives also include the 1,5-seco-kalmane skeleton.",
      'parent' => 1551,
    ),
    array(
      'tid' => 2872,
      'name' => "Elemane sesquiterpenoids",
      'description' => "Sesquiterpenoids with a structure based on the elemane skeleton. Elemane is a monocyclic compound consisting of a cyclohexane ring substituted with a methyl group, an ethyl group, and two 1-methylethyl groups at the 1-, 1-, 2-, and 4-position, respectively.",
      'parent' => 1550,
    ),
    array(
      'tid' => 2873,
      'name' => "Pseudoguaianes",
      'description' => "Sesquiterpenoids with a structure based on the pseudoguaiane skeleton, which arises by the migration of the a methyl group of the bicyclic guaiane skeleton from the C4 to the C5 position.",
      'parent' => 1550,
    ),
    array(
      'tid' => 2874,
      'name' => "Guaianes",
      'description' => "Sesquiterpenoids with a structure based on the guaiane skeleton. Guaiane is a bicyclic compound consisting of a decahydroazulene moiety, substituted with two methyl groups and a 1-methylethyl group at the 1-, 4-, and 7-position, respectively.",
      'parent' => 1550,
    ),
    array(
      'tid' => 2875,
      'name' => "Tigliane and ingenane diterpenoids",
      'description' => "Diterpenoids containing the tigliane or ingenane carbon skeleton. The tigliane skeleton is a tetracyclic ring that consists of the 4/7/6/3 ring junction. It is derived from casbane by 6,10- and 5,14-cyclizations and is a framework of phorbol. The ingenane skeleton is derived by rearrangement of tigliane.",
      'parent' => 1551,
    ),
    array(
      'tid' => 2876,
      'name' => "Cyathane diterpenoids",
      'description' => "Fungal diterpenoid metabolites with a structure containing the cyathane skeleton (Tetradecahydro-3a,5a,8-trimethyl-1-(1-methylethyl)-cyclohept[e]indene).",
      'parent' => 1551,
    ),
    array(
      'tid' => 2877,
      'name' => "Jatrophane and cyclojatrophane diterpenoids",
      'description' => "Diterpenoids with a structure based on the jatrophane or the 9,13-jatrophane skeleton. Jatrophane can be derived from casbane by 6,10-cyclization and opening of the cyclopropane. Cyclojatrophane diterpenoids are based on the 9,13-cyclization of the jatrophane skeleton yields the 9,13-cyclojatrophane skeleton.",
      'parent' => 1551,
    ),
    array(
      'tid' => 2878,
      'name' => "Leucothol and grayanotoxane diterpenoids",
      'description' => "Diterpenoids with a structure based either on the leucothol or the grayanotoxane skeleton.",
      'parent' => 2871,
    ),
    array(
      'tid' => 2879,
      'name' => "Xeniaphyllane and xenicane diterpenoids",
      'description' => "Diterpenoids with a structure based either on the xeniaphyllane or the xenicane skeleton.",
      'parent' => 1551,
    ),
    array(
      'tid' => 2880,
      'name' => "Sphaerane diterpenoids",
      'description' => "Diterpenoids containing a sphaerane skeleton or tetradecahydro-5,8a,10a-trimethyl-1-(1-methylethyl)-phenanthrene.",
      'parent' => 1551,
    ),
    array(
      'tid' => 2881,
      'name' => "Cheilanthane sesterterpenoids",
      'description' => "Sesterterpnoids with a structure based on the cheilanthane backbone. Cheilanthane is a tricyclic compound consisting of a tetradecahydrophenanthrene ring system that carries two methyl groups at the 1-position, one methyl group at the 4a-,7-, and 8a-positions, as well as a 3-methylpentyl group at the 8-position.",
      'parent' => 1552,
    ),
    array(
      'tid' => 2882,
      'name' => "Ophiobolane sesterterpenoids",
      'description' => "Sesterterpnoids with a structure based on the ophiobolane backbone. Ophiobolane is a tricyclic compound consisting of two cyclopentane rings joined by a cyclooctane ring, and carries a methyl group at the 1-, 4-, and 8-position, as well as a 6-methylheptane group at the 12-position.",
      'parent' => 1552,
    ),
    array(
      'tid' => 2883,
      'name' => "Scalarane sesterterpenoids",
      'description' => "Sesterterpenoids with a structure based on the scalarane backbone. Scalarane is a tetracyclic compound, which is similar the homoandrostane with five methyl groups at the 4-, 4-, 8-, 17-, 17a-positions.",
      'parent' => 1552,
    ),
    array(
      'tid' => 2884,
      'name' => "Lupane triterpenoids",
      'description' => "Triterpenoids with a structure based on the lupane skeleton. They arise from the formation of a five membered ring E from the baccharane precursor.",
      'parent' => 1553,
    ),
    array(
      'tid' => 2885,
      'name' => "Tirucallane and euphane triterpenoids",
      'description' => "Triterpenoids with a structure based either on the tirucallane or the euphane skeleton. They are obtained by backbone rearrangement of a dammarane-based precursor.",
      'parent' => 1553,
    ),
    array(
      'tid' => 2886,
      'name' => "Taraxastane, ursane, and bauerane triterpenoids",
      'description' => "Triterpenoids with a structure based on either the taraxastane, ursane, or bauerane skeleton. These are obtained by methyl migration in ring E of the oleanane backbone.",
      'parent' => 1553,
    ),
    array(
      'tid' => 2887,
      'name' => "Taraxerane, multiflorane, glutinane and friedelane triterpenoids",
      'description' => "Triterpenoids with a structure based either on the taraxerane, the multiflorane, the glutinane, or the friedelane skeleton. These compounds arise upon rearrangement of the oleanane skeleton.",
      'parent' => 1553,
    ),
    array(
      'tid' => 2888,
      'name' => "Dammarane triterpenoids",
      'description' => "Triterpenoids with a structure based on the dammarane skeleton.",
      'parent' => 1553,
    ),
    array(
      'tid' => 2889,
      'name' => "Protostane and fusidane triterpenoids",
      'description' => "Triterpenoids with a structure based either on the protostane or the fusidane skeleton.",
      'parent' => 1553,
    ),
    array(
      'tid' => 2890,
      'name' => "Briarane diterpenoids",
      'description' => "Marine diterpenoids with a structure based on the briarane (3,8-cyclocembrane) skeleton.",
      'parent' => 1551,
    ),
    array(
      'tid' => 2891,
      'name' => "Actinide metavanadates",
      'description' => "Inorganic compounds in which the largest oxoanion is metavanadate, and in which the heaviest atom not in an oxoanion is an actinide.",
      'parent' => 448,
    ),
    array(
      'tid' => 2892,
      'name' => "Quinonimines",
      'description' => "Imines derived from quinones by replacement of one or both oxygens by =NR.",
      'parent' => 278,
    ),
    array(
      'tid' => 2893,
      'name' => "M-quinonimines",
      'description' => "Quinonimines in which the imine groups are in a meta-relationship.",
      'parent' => 2892,
    ),
    array(
      'tid' => 2894,
      'name' => "O-quinonimines",
      'description' => "Quinonimines in which the imine groups are in a ortho-relationship.",
      'parent' => 2892,
    ),
    array(
      'tid' => 2895,
      'name' => "P-quinonimines",
      'description' => "Quinonimines in which the imine groups are in a para-relationship.",
      'parent' => 2892,
    ),
    array(
      'tid' => 2896,
      'name' => "Isoflavonoid C-glycosides",
      'description' => "C-glycosylated derivatives of isoflavonoids, which are natural products derived from 3-phenylchromen-4-one.",
      'parent' => 2506,
    ),
    array(
      'tid' => 2897,
      'name' => "Neoflavonoid 5-O-glycosides",
      'description' => "5-O-glycosylated neoflavonoids. Neoflavonoids are compounds with a structure based on the 4-phenylchromene backbone.",
      'parent' => 1614,
    ),
    array(
      'tid' => 2898,
      'name' => "Homoisoflavanones",
      'description' => "Homoisoflavonoids with a structure based on the chromanone system. Chromanone is a bicyclic compound consisting of a 3,4-dihydro-1-benzopyran, which bears a ketone group at the 4-position.",
      'parent' => 2508,
    ),
    array(
      'tid' => 2899,
      'name' => "Sulfinohydrazonoperoxoic acids",
      'description' => "Organic acids with the general formula RS(=NN)OOH.",
      'parent' => 264,
    ),
    array(
      'tid' => 2900,
      'name' => "1,2-diaryl-2-propen-1-ols",
      'description' => "Flavonoids with a structure based on the 1,2-diaryl-2-propen-1-ol skeleton.",
      'parent' => 261,
    ),
    array(
      'tid' => 2901,
      'name' => "Isoflav-2-enes",
      'description' => "Flavonoids with a structure based on the 3-phenylchromene skeleton, with a double bond between the C2 and C3 carbon atoms of the chromene moiety.",
      'parent' => 2506,
    ),
    array(
      'tid' => 2902,
      'name' => "Milbemycins",
      'description' => "A group of macrolides with a structure containing a 16-membered lactone ring fused to a 1,7-dioxaspiroundecane ring system and to either a benzofuran (or hydrogenated derivative thereof). In some cases (e.g. Milbemycin E), the tetrahydrofuranyl ring is missing. Milbemycins can be o-glycosylated at C13 to form Avermectins. Milbemycins are produced by Streptomyces species.",
      'parent' => 147,
    ),
    array(
      'tid' => 2903,
      'name' => "Perylenequinones",
      'description' => "Heterocyclic compounds characterized by  two 8-hydroxy-1,4-dihydronaphthalen-1-one moieties joined together one or two CC-bonds.",
      'parent' => 2448,
    ),
    array(
      'tid' => 2904,
      'name' => "Holostanes",
      'description' => "Steroids with a structure characterized by a lanostane moiety possessing a 18,20-lactone ring.",
      'parent' => 258,
    ),
    array(
      'tid' => 2905,
      'name' => "1,2-dithiole-3-thiones",
      'description' => "Organic heterocyclic compounds containing a 1,2-dithiole ring that bears a C=S group.",
      'parent' => 3624,
    ),
    array(
      'tid' => 2906,
      'name' => "Phorbol esters",
      'description' => "Tigliane diterpenoids which are esters of phorbol.",
      'parent' => 2875,
    ),
    array(
      'tid' => 2907,
      'name' => "4-hydroxycoumarins",
      'description' => "Coumarins that contain one or more hydroxyl groups attached to C4-position the coumarin skeleton.",
      'parent' => 2908,
    ),
    array(
      'tid' => 2908,
      'name' => "Hydroxycoumarins",
      'description' => "Coumarins that contain one or more hydroxyl groups attached to the coumarin skeleton.",
      'parent' => 145,
    ),
    array(
      'tid' => 2909,
      'name' => "7-hydroxycoumarins",
      'description' => "Coumarins that contain one or more hydroxyl groups attached to the C7 position the coumarin skeleton.",
      'parent' => 2908,
    ),
    array(
      'tid' => 2910,
      'name' => "Borinanes",
      'description' => "Organic heterocyclic compounds containing a saturated aliphatic six-membered ring consisting of five carbon atoms and one boron atom.",
      'parent' => 2052,
    ),
    array(
      'tid' => 2911,
      'name' => "Polypodane, malabaricane and podiodane triterpenoids",
      'description' => "Triterpenoids with a structure based either on the polypodane, the malabaricane, or the podiodane skeleton.",
      'parent' => 1553,
    ),
    array(
      'tid' => 2912,
      'name' => "Alpha-hydroxy ketones",
      'description' => "Organic compounds containing a carboxylic acid, and an amine group attached to the alpha carbon atom, relative to the C=O group.",
      'parent' => 118,
    ),
    array(
      'tid' => 2913,
      'name' => "Beta-hydroxy ketones",
      'description' => "Ketones containing a hydroxyl group attached to the beta-carbon atom, relative to the C=O group.",
      'parent' => 118,
    ),
    array(
      'tid' => 2914,
      'name' => "3-hydroxyflavonoids",
      'description' => "Flavonoids that bear one hydroxyl group at the C-3 position of the flavonoid skeleton.",
      'parent' => 2991,
    ),
    array(
      'tid' => 2915,
      'name' => "3'-hydroxyflavonoids",
      'description' => "Flavonoids that bear one hydroxyl group at the C-3' position of the flavonoid skeleton.",
      'parent' => 2991,
    ),
    array(
      'tid' => 2916,
      'name' => "Eunicellane and asbestinane diterpenoids",
      'description' => "Diterpenoids with a structure based on either the eunicellane (5,14-cyclocembrane) or the asbestinane skeleton.",
      'parent' => 1551,
    ),
    array(
      'tid' => 2917,
      'name' => "Arborinane and stictane triterpenoids",
      'description' => "Triterpenoids with a structure based on the arborinane or stictane skeleton.",
      'parent' => 1553,
    ),
    array(
      'tid' => 2918,
      'name' => "Serratane and onocerane triterpenoids",
      'description' => "Triterpenoids with a structure based either on the serratane or the onocerane skeleton.",
      'parent' => 1553,
    ),
    array(
      'tid' => 2919,
      'name' => "Phenyltropanes",
      'description' => "Compounds containing a phenyl group linked to a tropane moiety. Tropane is an organonitrogenous  [3.2.1] bicyclic organic compound.",
      'parent' => 492,
    ),
    array(
      'tid' => 2920,
      'name' => "Diazepanes",
      'description' => "Compounds containing a diazepane rings, which is a saturated seven-membered ring with 2 nitrogen atoms and five carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2921,
      'name' => "1,2-diazepanes",
      'description' => "Diazepanes having the two nitrogen atoms at position 1 and 2 of the diazepane ring.",
      'parent' => 2920,
    ),
    array(
      'tid' => 2922,
      'name' => "1,3-diazepanes",
      'description' => "Diazepanes having the two nitrogen atoms at position 1 and 3 of the diazepane ring.",
      'parent' => 2920,
    ),
    array(
      'tid' => 2923,
      'name' => "1,4-diazepanes",
      'description' => "Diazepanes having the two nitrogen atoms at position 1 and 4 of the diazepane ring.",
      'parent' => 2920,
    ),
    array(
      'tid' => 2924,
      'name' => "1,2,4-oxadiazoles",
      'description' => "Compounds containing an oxadiazole ring with the oxygen and the two nitrogen atoms at positions 1, 2, and 4, respectively.",
      'parent' => 1822,
    ),
    array(
      'tid' => 2925,
      'name' => "1,3,4-oxadiazoles",
      'description' => "Compounds containing an oxadiazole ring with the oxygen and the two nitrogen atoms at positions 1, 3, and 4, respectively.",
      'parent' => 1822,
    ),
    array(
      'tid' => 2926,
      'name' => "Ortho esters",
      'description' => "Compounds having the general structure RC(OR')3 ( R' not H), or the structure C(OR')4 ( R' not H).",
      'parent' => 323,
    ),
    array(
      'tid' => 2927,
      'name' => "Ortho amides",
      'description' => "Hypothetical  Compounds having the general structure RC(NH2)3, and N-substituted derivatives thereof.",
      'parent' => 278,
    ),
    array(
      'tid' => 2928,
      'name' => "Ortho acids",
      'description' => "Ortho acid derivatives of carboxylic acids, with the general formula RC(OH)3.",
      'parent' => 323,
    ),
    array(
      'tid' => 2929,
      'name' => "Sulfimides",
      'description' => "Organic derivatives of sulfimide, with the general formula RN=S(R=organic group).",
      'parent' => 4,
    ),
    array(
      'tid' => 2930,
      'name' => "Mutilane diterpenoids",
      'description' => "Diterpenoids with a structure based on the mutilane skeleton.",
      'parent' => 1551,
    ),
    array(
      'tid' => 2931,
      'name' => "Aphidicolane and stemodane diterpenoids",
      'description' => "Diterpenoids with a structure based on the aphidicolane or the stemodane  skeleton.",
      'parent' => 1551,
    ),
    array(
      'tid' => 2932,
      'name' => "1,3-isoquinolinediones",
      'description' => "Isoquinoline derivatives carrying one C=O group at positions 1, and 3 respectively.",
      'parent' => 2566,
    ),
    array(
      'tid' => 2933,
      'name' => "1,4-isoquinolinediones",
      'description' => "Isoquinoline derivatives carrying a C=O group at positions 1 and 4, respectively.",
      'parent' => 2566,
    ),
    array(
      'tid' => 2934,
      'name' => "Flavonoid O-glucuronides",
      'description' => "Phenolic compounds containing a flavonoid moiety which is O-glycosidically linked to glucuronic acid.",
      'parent' => 1583,
    ),
    array(
      'tid' => 2935,
      'name' => "Neoflavonoid 7-O-glycosides",
      'description' => "7-O-glycosylated neoflavonoids. Neoflavonoids are compounds with a structure based on the 4-phenylchromene backbone.",
      'parent' => 1614,
    ),
    array(
      'tid' => 2936,
      'name' => "Cycloheptafurans",
      'description' => "Organic heterocyclic compounds containing a cycloheptane derivative fused to a furan. Furan is a five-membered aromatic ring with four carbon atoms and one oxygen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 2937,
      'name' => "Cycloheptapyrans",
      'description' => "Organic heterocyclic compounds containing a cycloheptane derivative fused to a pyran. Pyran a six-membered heterocyclic, non-aromatic ring, made up of five carbon atoms and one oxygen atom and containing two double bonds.",
      'parent' => 2,
    ),
    array(
      'tid' => 2938,
      'name' => "Cyclopentanols",
      'description' => "Compounds containing a cyclopentane ring that carries an alcohol group.",
      'parent' => 1661,
    ),
    array(
      'tid' => 2939,
      'name' => "Dioxepines",
      'description' => "Compounds containing a dioxepane ring, which is a seven-membered aliphatic unsaturated ring with two oxygen atoms and five carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2940,
      'name' => "1,2-dioxepines",
      'description' => "Dioxepines with the two ring oxygen atoms at position 1 and 2, respectively.",
      'parent' => 2939,
    ),
    array(
      'tid' => 2941,
      'name' => "1,3-dioxepines",
      'description' => "Dioxepines with the two ring oxygen atoms at position 1 and 3, respectively.",
      'parent' => 2939,
    ),
    array(
      'tid' => 2942,
      'name' => "1,4-dioxepines",
      'description' => "Dioxepines with the two ring oxygen atoms at position 1 and 4, respectively.",
      'parent' => 2939,
    ),
    array(
      'tid' => 2943,
      'name' => "Dioxepanes",
      'description' => "Compounds containing a dioxepane ring, which is a seven-membered aliphatic saturated ring with two oxygen atoms and five carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 2944,
      'name' => "1,2-dioxepanes",
      'description' => "Dioxepanes with the two ring oxygen atoms at position 1 and 2, respectively.",
      'parent' => 2943,
    ),
    array(
      'tid' => 2945,
      'name' => "1,3-dioxepanes",
      'description' => "Dioxepanes with the two ring oxygen atoms at position 1 and 3, respectively.",
      'parent' => 2943,
    ),
    array(
      'tid' => 2946,
      'name' => "1,4-dioxepanes",
      'description' => "Dioxepanes with the two ring oxygen atoms at position 1 and 4, respectively.",
      'parent' => 2943,
    ),
    array(
      'tid' => 2947,
      'name' => "Guanidinobenzoic acids",
      'description' => "Aromatic compounds containing a guanidine group linked to the benzene ring of a benzoic acid.",
      'parent' => 1779,
    ),
    array(
      'tid' => 2948,
      'name' => "Aminobenzoic acids",
      'description' => "Benzoic acids containing an amine group attached to the benzene moiety.",
      'parent' => 281,
    ),
    array(
      'tid' => 2949,
      'name' => "Long-chain fatty acids",
      'description' => "Fatty acids with an aliphatic tail that contains between 13 and 21 carbon atoms.",
      'parent' => 262,
    ),
    array(
      'tid' => 2950,
      'name' => "Very long-chain fatty acids",
      'description' => "Fatty acids with an aliphatic tail that contains at least 22 carbon atoms.",
      'parent' => 262,
    ),
    array(
      'tid' => 2951,
      'name' => "Long-chain fatty alcohols",
      'description' => "Fatty alcohols that have an aliphatic tail of 13 to 21 carbon atoms.",
      'parent' => 1334,
    ),
    array(
      'tid' => 2952,
      'name' => "Long-chain fatty aldehydes",
      'description' => "Fatty aldehydes carrying a long aliphatic chain, with 13 to 21 carbon atoms.",
      'parent' => 298,
    ),
    array(
      'tid' => 2953,
      'name' => "Piperidinesulfonamides",
      'description' => "Organic compounds containing a sulfonamide group linked to a piperidine ring.",
      'parent' => 195,
    ),
    array(
      'tid' => 2954,
      'name' => "Tetrahydrofolic acids",
      'description' => "Heterocyclic compounds based on the 5,6,7,8-tetrahydropteroic acid skeleton conjugated with at least one L-glutamic acid unit.",
      'parent' => 2618,
    ),
    array(
      'tid' => 2955,
      'name' => "Tetrahydroisoquinolines",
      'description' => "Tetrahydrogenated isoquinoline derivatives.",
      'parent' => 2,
    ),
    array(
      'tid' => 2956,
      'name' => "1-phenyltetrahydroisoquinolines",
      'description' => "Compounds containing a phenyl group attached to the C1-atom of a tetrahydroisoquinoline moiety.",
      'parent' => 2955,
    ),
    array(
      'tid' => 2957,
      'name' => "4-phenyltetrahydroisoquinolines",
      'description' => "Compounds containing a phenyl group attached to the C4-atom of a tetrahydroisoquinoline moiety.",
      'parent' => 2955,
    ),
    array(
      'tid' => 2958,
      'name' => "Dihydroisoquinolines",
      'description' => "Isoquinoline derivatives where exactly two carbon atoms joined by an aromatic bond are linked with a hydrogen atom each, resulting in a CC single bond.",
      'parent' => 2,
    ),
    array(
      'tid' => 2959,
      'name' => "Sulfonohydrazides",
      'description' => "Organic compounds with the general formula RS(=O)(=O)NHNH2.",
      'parent' => 270,
    ),
    array(
      'tid' => 2960,
      'name' => "3-hydroxyacyl CoAs",
      'description' => "Organic compounds containing a 3-hydroxyl acylated coenzyme A derivative.",
      'parent' => 1090,
    ),
    array(
      'tid' => 2961,
      'name' => "N-acylsphingosines",
      'description' => "Sphingolipids containing a N-acylated sphingosine.",
      'parent' => 1418,
    ),
    array(
      'tid' => 2962,
      'name' => "N-acylsphinganines",
      'description' => "Sphingolipids containing a N-acylated sphinganine.",
      'parent' => 1418,
    ),
    array(
      'tid' => 2963,
      'name' => "Phytoceramides",
      'description' => "N-acylated 4-hydroxysphinganine.",
      'parent' => 1418,
    ),
    array(
      'tid' => 2964,
      'name' => "N-formyl-alpha amino acids",
      'description' => "Compounds containing an alpha amino acid which bears a formyl group at its terminal nitrogen atom.",
      'parent' => 2965,
    ),
    array(
      'tid' => 2965,
      'name' => "N-formyl-alpha amino acids and derivatives",
      'description' => "Compounds containing an alpha amino acid (or a derivative thereof) which bears a formyl group at its terminal nitrogen atom.",
      'parent' => 60,
    ),
    array(
      'tid' => 2966,
      'name' => "Tetracarboxylic acids and derivatives",
      'description' => "Carboxylic acids containing exactly four carboxyl groups.",
      'parent' => 265,
    ),
    array(
      'tid' => 2967,
      'name' => "Hexacarboxylic acids and derivatives",
      'description' => "Carboxylic acids containing exactly six carboxyl groups.",
      'parent' => 265,
    ),
    array(
      'tid' => 2968,
      'name' => "3-hydroxy delta-1-steroids",
      'description' => "3-hydroxy steroids containing a double bond between positions 1 and 2.",
      'parent' => 3027,
    ),
    array(
      'tid' => 2969,
      'name' => "3-hydroxy delta-1,4-steroids",
      'description' => "3-hydroxy steroids containing a double bond between positions 1 and 2, as well as positions 4 and 5.",
      'parent' => 3027,
    ),
    array(
      'tid' => 2970,
      'name' => "3-hydroxy delta-4-steroids",
      'description' => "3-hydroxy steroids containing a double bond between positions 4 and 5.",
      'parent' => 3027,
    ),
    array(
      'tid' => 2971,
      'name' => "3-hydroxy delta-5-steroids",
      'description' => "3-hydroxy steroids containing a double bond between positions 5 and 6.",
      'parent' => 3027,
    ),
    array(
      'tid' => 2972,
      'name' => "3-oxo delta-1-steroids",
      'description' => "3-oxo steroids containing a double bond between positions 1 and 2.",
      'parent' => 3026,
    ),
    array(
      'tid' => 2973,
      'name' => "3-oxo delta-1,4-steroids",
      'description' => "3-oxo steroids containing a double bond between positions 1 and 2, as well as positions 4 and 5.",
      'parent' => 3026,
    ),
    array(
      'tid' => 2974,
      'name' => "3-oxo delta-4-steroids",
      'description' => "3-oxo steroids containing a double bond between positions  3 and 4.",
      'parent' => 3026,
    ),
    array(
      'tid' => 2975,
      'name' => "3-oxo delta-5-steroids",
      'description' => "3-oxo steroids containing a double bond between positions 4 and 5.",
      'parent' => 3026,
    ),
    array(
      'tid' => 2976,
      'name' => "Delta-1-steroids",
      'description' => "Steroids containing a double bond between positions 1 and 2.",
      'parent' => 258,
    ),
    array(
      'tid' => 2977,
      'name' => "Delta-1,4-steroids",
      'description' => "Steroids containing a double bond between positions 1 and 2, as well as positions 4 and 5.",
      'parent' => 258,
    ),
    array(
      'tid' => 2978,
      'name' => "Delta-4-steroids",
      'description' => "Steroids containing a double bond between positions 4 and 5.",
      'parent' => 258,
    ),
    array(
      'tid' => 2979,
      'name' => "Delta-5-steroids",
      'description' => "Steroids containing a double bond between positions 5 and 6.",
      'parent' => 258,
    ),
    array(
      'tid' => 2980,
      'name' => "N-phenylthioureas",
      'description' => "Compounds containing a N-phenylthiourea moiety, which is structurally characterized by a phenyl group linked to one nitrogen atom of a thiourea group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 2981,
      'name' => "N-acyl-phenylthioureas",
      'description' => "Thiourea derivatives where one nitrogen atom of the urea group is linked to a phenyl group and the other is acylated.",
      'parent' => 2980,
    ),
    array(
      'tid' => 2982,
      'name' => "N-acyl-phenylureas",
      'description' => "Urea derivatives where one nitrogen atom of the urea group is linked to a phenyl group and the other is acylated.",
      'parent' => 1935,
    ),
    array(
      'tid' => 2983,
      'name' => "Acylguanidines",
      'description' => "N-acylated derivatives of guanidines.",
      'parent' => 375,
    ),
    array(
      'tid' => 2984,
      'name' => "Delta-7-steroids",
      'description' => "Steroids containing a double bond between positions 7 and 8.",
      'parent' => 258,
    ),
    array(
      'tid' => 2985,
      'name' => "3-hydroxy delta-7-steroids",
      'description' => "3-hydroxy steroids containing a double bond between positions 7 and 8.",
      'parent' => 3027,
    ),
    array(
      'tid' => 2986,
      'name' => "3-oxo delta-7-steroids",
      'description' => "3-oxo steroids containing a double bond between positions 6 and 7.",
      'parent' => 3026,
    ),
    array(
      'tid' => 2987,
      'name' => "6-aminopurines",
      'description' => "Purines that carry an amino group at position 6. Purine is a bicyclic aromatic compound made up of a pyrimidine ring fused to an imidazole ring.",
      'parent' => 245,
    ),
    array(
      'tid' => 2988,
      'name' => "4-hydroxyflavonoids",
      'description' => "Flavonoids that bear one hydroxyl group at the C-4 position of the flavonoid skeleton.",
      'parent' => 2991,
    ),
    array(
      'tid' => 2989,
      'name' => "4'-hydroxyflavonoids",
      'description' => "Flavonoids that bear one hydroxyl group at the C-4' position of the flavonoid skeleton.",
      'parent' => 2991,
    ),
    array(
      'tid' => 2990,
      'name' => "6-hydroxyflavonoids",
      'description' => "Flavonoids that bear one hydroxyl group at the C-6 position of the flavonoid skeleton.",
      'parent' => 2991,
    ),
    array(
      'tid' => 2991,
      'name' => "Hydroxyflavonoids",
      'description' => "Flavonoids in which one or more hydroxyl groups are attached to the flavonoid skeleton.",
      'parent' => 334,
    ),
    array(
      'tid' => 2992,
      'name' => "5-hydroxyflavonoids",
      'description' => "Flavonoids that bear one hydroxyl group at the C-5 position of the flavonoid skeleton.",
      'parent' => 2991,
    ),
    array(
      'tid' => 2993,
      'name' => "7-hydroxyflavonoids",
      'description' => "Flavonoids that bear one hydroxyl group at the C-7 position of the flavonoid skeleton.",
      'parent' => 2991,
    ),
    array(
      'tid' => 2994,
      'name' => "8-hydroxyflavonoids",
      'description' => "Flavonoids that bear one hydroxyl group at the C-8 position of the flavonoid skeleton.",
      'parent' => 2991,
    ),
    array(
      'tid' => 2995,
      'name' => "Pentacarboxylic acids and derivatives",
      'description' => "Carboxylic acids containing exactly five carboxyl groups.",
      'parent' => 265,
    ),
    array(
      'tid' => 2996,
      'name' => "Anthocyanidin-3-O-glycosides",
      'description' => "Phenolic compounds containing one anthocyanidin moiety which is O-glycosidically linked to a carbohydrate moiety at the C3-position.",
      'parent' => 1361,
    ),
    array(
      'tid' => 2997,
      'name' => "Anthocyanidin-5-O-glycosides",
      'description' => "Phenolic compounds containing one anthocyanidin moiety which is O-glycosidically linked to a carbohydrate moiety at the C5-position.",
      'parent' => 1361,
    ),
    array(
      'tid' => 2998,
      'name' => "C19-gibberellins",
      'description' => "Gibberellins containing 19 carbon atoms, with the COOH group in position 7. In nearly all C19-gibberellins, the carboxyl group at C-4 forms a lactone  ring at C-10, a configuration which arises in connection with the loss of the extra C-20 atom.",
      'parent' => 1767,
    ),
    array(
      'tid' => 2999,
      'name' => "C20-gibberellins",
      'description' => "Gibberellins with carboxy groups in positions 7 and 18 and some also in 20, while others have an aldehyde group in the latter position.",
      'parent' => 1767,
    ),
    array(
      'tid' => 3000,
      'name' => "Alpha-halocarboxylic acids",
      'description' => "Carboxylic acids containing a halogen atom bonded to the alpha carbon atom.",
      'parent' => 1548,
    ),
    array(
      'tid' => 3001,
      'name' => "Alpha-halocarboxylic acid derivatives",
      'description' => "Carboxylic acid derivatives containing a halogen atom bonded to the alpha carbon atom.",
      'parent' => 1548,
    ),
    array(
      'tid' => 3002,
      'name' => "Hydroxycinnamic acid esters",
      'description' => "Ester derivatives of hydroxycinnamic acids.",
      'parent' => 1391,
    ),
    array(
      'tid' => 3003,
      'name' => "Hydroxycinnamic acid glycosides",
      'description' => "Glycosylated hydoxycinnamic acids derivatives.",
      'parent' => 3002,
    ),
    array(
      'tid' => 3004,
      'name' => "Chlorogenic acids and derivatives",
      'description' => "Esters hydroxycinnamic acid with quinic acid (3-O, 4-O, or 4-O) or tartaric acid. The cinnamic acid moiety is hydroxylated at positions 3, 4, or both.",
      'parent' => 3002,
    ),
    array(
      'tid' => 3005,
      'name' => "Sulfated flavonoids",
      'description' => "Flavonoids that are sulfated at one or more positions.",
      'parent' => 334,
    ),
    array(
      'tid' => 3006,
      'name' => "Monohydroxyflavonoids",
      'description' => "Flavonoids that bear one hydroxyl group on the flavonoid skeleton.",
      'parent' => 2991,
    ),
    array(
      'tid' => 3007,
      'name' => "Phenanthrols",
      'description' => "Compounds containing a phenanthrene (or its hydrogenated derivative) to which a hydroxyl group is attached.",
      'parent' => 25,
    ),
    array(
      'tid' => 3008,
      'name' => "Aminosalicylic acids and derivatives",
      'description' => "Salicylic acids or derivatives carrying an amino group on the benzene ring.",
      'parent' => 487,
    ),
    array(
      'tid' => 3009,
      'name' => "Aminosalicylic acids",
      'description' => "Salicylic acids carrying an amino group on the benzene ring.",
      'parent' => 3008,
    ),
    array(
      'tid' => 3010,
      'name' => "3-aminosalicylic acids",
      'description' => "Aminosalicylic acids carrying an amino group at the C-3 atom of the benzene ring.",
      'parent' => 3037,
    ),
    array(
      'tid' => 3011,
      'name' => "4-aminosalicylic acids",
      'description' => "Aminosalicylic acids carrying an amino group at the C-4 atom of the benzene ring.",
      'parent' => 3038,
    ),
    array(
      'tid' => 3012,
      'name' => "Flavan-3-ols",
      'description' => "Flavans that bear and hydroxyl group at position 3 (B ring), but not at position 4.",
      'parent' => 337,
    ),
    array(
      'tid' => 3013,
      'name' => "Flavan-4-ols",
      'description' => "Flavans that bear and hydroxyl group at position 4 (B ring), but not at the 3-position.",
      'parent' => 337,
    ),
    array(
      'tid' => 3014,
      'name' => "Organophosphinic acids and derivatives",
      'description' => "P-hydrocarbyl derivatives of phosphinic acid.",
      'parent' => 400,
    ),
    array(
      'tid' => 3015,
      'name' => "Phosphinic acid esters",
      'description' => "Compounds containing a phosphinic acid ester group.",
      'parent' => 3014,
    ),
    array(
      'tid' => 3016,
      'name' => "Tropoloisoquinolines",
      'description' => "Organic compounds that contain a tropolone ring fused to an isoquinoline ring to form an azuleno[1,2,3-ij]isoquinoline skeleton.",
      'parent' => 279,
    ),
    array(
      'tid' => 3017,
      'name' => "Benzacridines",
      'description' => "Organic heterocyclic compounds with a structure characterized by a benzene ring fused to an acridine ring system.",
      'parent' => 274,
    ),
    array(
      'tid' => 3018,
      'name' => "Isoaporphines",
      'description' => "Alkaloids with a structure that contains the isoaporphine skeleton. Isoaporphine is an isomer of aporphine, with the difference that the N atom of the quinoline moiety is at the 1-position instead of the 6-position. This compounds also include oxoisoaporphines, which bear an oxo group at the 7-position. Oxoisoaporphines are believed to arise from aporphines via a spirodienone rearrangement.",
      'parent' => 279,
    ),
    array(
      'tid' => 3019,
      'name' => "1-azaoxoaporphines",
      'description' => "Analogues of Aporphines, where a nitrogen atom replaces the carbon atom at position 1, and a keto group at C7.",
      'parent' => 279,
    ),
    array(
      'tid' => 3020,
      'name' => "Azahomoaporphines",
      'description' => "Analogues of homoaporphines where a nitrogen atom replaces one carbon atom of the cyclopheptane ring.",
      'parent' => 279,
    ),
    array(
      'tid' => 3021,
      'name' => "Hydroxy-7-aporphines",
      'description' => "Aporphines containing a hydroxyl group at the 7-position.",
      'parent' => 381,
    ),
    array(
      'tid' => 3022,
      'name' => "Methyl-7-aporphines",
      'description' => "Aporphines containing a methyl group at the 7-position.",
      'parent' => 381,
    ),
    array(
      'tid' => 3023,
      'name' => "N-acylpyrrolidines",
      'description' => "N-Acylated Pyrrolidine derivatives. Pyrrolidine is a five-membered saturated aliphatic heterocycle with one nitrogen atom and four carbon atoms.",
      'parent' => 218,
    ),
    array(
      'tid' => 3024,
      'name' => "Gamma-glutamyl amino acids",
      'description' => "Dipeptides consisting of any C-terminal amino acid having a gamma-glutamyl residue attached at the N alpha-position.",
      'parent' => 348,
    ),
    array(
      'tid' => 3025,
      'name' => "Gamma-glutamyl peptides",
      'description' => "Oligo- and polypeptides consisting of any C-terminal alpha peptide having a gamma-glutamyl residue attached at the N alpha-position.",
      'parent' => 348,
    ),
    array(
      'tid' => 3026,
      'name' => "3-oxosteroids",
      'description' => "Steroid derivatives carrying a C=O group at the 3-position of the steroid skeleton.",
      'parent' => 1194,
    ),
    array(
      'tid' => 3027,
      'name' => "3-hydroxysteroids",
      'description' => "Steroids carrying a hydroxyl group at the 3-position of the steroid backbone.",
      'parent' => 1295,
    ),
    array(
      'tid' => 3028,
      'name' => "Polyprenylbenzene-1,2-diols",
      'description' => "Compounds containing a polyisoprene chain attached to a catechol group.",
      'parent' => 2221,
    ),
    array(
      'tid' => 3029,
      'name' => "Polychlorinated dibenzofurans",
      'description' => "Organic compounds containing two or more chlorine atoms attached to a dibenzofuran moiety.",
      'parent' => 1378,
    ),
    array(
      'tid' => 3030,
      'name' => "Polychlorinated biphenyls",
      'description' => "Organic compounds containing at least two chlorine atoms attached to either benzene ring of the biphenyl moiety.",
      'parent' => 500,
    ),
    array(
      'tid' => 3031,
      'name' => "Pyrrolidine-2-ones",
      'description' => "Pyrrolidines which bear a C=O group at position 2 of the pyrrolidine ring.",
      'parent' => 1158,
    ),
    array(
      'tid' => 3032,
      'name' => "Pyrrolidine-3-ones",
      'description' => "Pyrrolidines which bear a C=O group at position 3 of the pyrrolidine ring.",
      'parent' => 1158,
    ),
    array(
      'tid' => 3033,
      'name' => "Dicarboximides",
      'description' => "Carboxylic acid amides in which the two acyl groups linked to the central nitrogen atoms are carboacyl groups.",
      'parent' => 1657,
    ),
    array(
      'tid' => 3034,
      'name' => "C-nitroso compounds",
      'description' => "Nitroso compounds with he general formula RN=O, where R is an organic group.",
      'parent' => 4776,
    ),
    array(
      'tid' => 3037,
      'name' => "3-aminosalicyclic acids and derivatives",
      'description' => "Aminosalicylic acids or derivatives carrying an amino group at the C-3 atom of the benzene ring.",
      'parent' => 3008,
    ),
    array(
      'tid' => 3038,
      'name' => "4-aminosalicyclic acids and derivatives",
      'description' => "Aminosalicylic acids or derivatives carrying an amino group at the C-4 atom of the benzene ring.",
      'parent' => 3008,
    ),
    array(
      'tid' => 3039,
      'name' => "Folic acids",
      'description' => "Heterocyclic compounds based on the 4-[(pteridin-6-ylmethyl)amino]benzoic acid skeleton conjugated with one or more L-glutamate units.",
      'parent' => 255,
    ),
    array(
      'tid' => 3040,
      'name' => "Pteroic acids",
      'description' => "Compounds that are composed of a pterin with a 4-aminobenzoic acid at the 6 position on the pteridine ring.",
      'parent' => 1228,
    ),
    array(
      'tid' => 3041,
      'name' => "Dihydropteroic acids and derivatives",
      'description' => "Dihydrogenated pteroic acids or derivatives thereof.",
      'parent' => 110,
    ),
    array(
      'tid' => 3042,
      'name' => "Tetrahydropteroic acids and derivatives",
      'description' => "Heterocyclic compounds based on the 5,6,7,8-tetrahydropteroic acid skeleton (or derivative thereof).",
      'parent' => 110,
    ),
    array(
      'tid' => 3043,
      'name' => "7,8-dihydrofolic acids",
      'description' => "Heterocyclic compounds based on the 7,8-dihydropteroic acid skeleton conjugated with one or more L-glutamic acid units.",
      'parent' => 3044,
    ),
    array(
      'tid' => 3044,
      'name' => "7,8-dihydrofolic acids and derivatives",
      'description' => "Heterocyclic compounds based on the 7,8-dihydropteroic acid skeleton conjugated with one or more L-glutamic acid units (or derivative thereof).",
      'parent' => 2619,
    ),
    array(
      'tid' => 3045,
      'name' => "Tetrahydropteroic acids",
      'description' => "Heterocyclic compounds based on the 5,6,7,8-tetrahydropteroic acid skeleton(or a derivative thereof) .",
      'parent' => 3042,
    ),
    array(
      'tid' => 3046,
      'name' => "7,8-dihydropteroic acids",
      'description' => "7,8-dihydrogenated pteroic acids.",
      'parent' => 3047,
    ),
    array(
      'tid' => 3047,
      'name' => "7,8-dihydropteroic acids and derivatives",
      'description' => "7,8-dihydrogenated pteroic acids or derivatives thereof.",
      'parent' => 3041,
    ),
    array(
      'tid' => 3048,
      'name' => "N-acylneuraminic acids",
      'description' => "Neuraminic acids carrying an N-acyl substituent.",
      'parent' => 3049,
    ),
    array(
      'tid' => 3049,
      'name' => "N-acylneuraminic acids and derivatives",
      'description' => "Neuraminic acids (or derivatives thereof) carrying an N-acyl substituent.",
      'parent' => 1258,
    ),
    array(
      'tid' => 3050,
      'name' => "Neuraminic acids",
      'description' => "Carbohydrate derivatives containing a neuraminic acid moiety.",
      'parent' => 1258,
    ),
    array(
      'tid' => 3051,
      'name' => "N-acylglutathiones",
      'description' => "Any glutathione derivative with a N-acyl substituent.",
      'parent' => 348,
    ),
    array(
      'tid' => 3052,
      'name' => "S-acylglutathiones",
      'description' => "Any glutathione derivative with a S-acyl substituent.",
      'parent' => 348,
    ),
    array(
      'tid' => 3053,
      'name' => "25-azasteroids and derivatives",
      'description' => "Azasteroids where the carbon atom at position 25 is replaced by a nitrogen atom.",
      'parent' => 2340,
    ),
    array(
      'tid' => 3054,
      'name' => "8-azasteroids and derivatives",
      'description' => "Azasteroids where the carbon atom at position 8 is replaced by a nitrogen atom.",
      'parent' => 2340,
    ),
    array(
      'tid' => 3055,
      'name' => "6-azasteroids and derivatives",
      'description' => "Azasteroids where the carbon atom at position 6 is replaced by a nitrogen atom.",
      'parent' => 2340,
    ),
    array(
      'tid' => 3056,
      'name' => "4-azasteroids and derivatives",
      'description' => "Azasteroids where the carbon atom at position 4 is replaced by a nitrogen atom.",
      'parent' => 2340,
    ),
    array(
      'tid' => 3057,
      'name' => "p-Bromobenzenesulfonates",
      'description' => "Benzenesulfonic acids (or derivative thereof) carrying a bromine at the para- position.",
      'parent' => 32,
    ),
    array(
      'tid' => 3058,
      'name' => "20-oxosteroids",
      'description' => "Steroid derivatives carrying a C=O group at the 20-position of the steroid skeleton.",
      'parent' => 1194,
    ),
    array(
      'tid' => 3059,
      'name' => "11-oxosteroids",
      'description' => "Steroid derivatives carrying a C=O group at the 11-position of the steroid skeleton.",
      'parent' => 1194,
    ),
    array(
      'tid' => 3060,
      'name' => "16-oxosteroids",
      'description' => "Steroid derivatives carrying a C=O group at the 16-position of the steroid skeleton.",
      'parent' => 1194,
    ),
    array(
      'tid' => 3061,
      'name' => "C24-propyl sterols and derivatives",
      'description' => "Sterols that carry a hydroxyl group at the 3-position, and a propyl group at the 24-position of the steroid backbone.",
      'parent' => 258,
    ),
    array(
      'tid' => 3062,
      'name' => "Sulfoquinovosylmonoacylglycerols",
      'description' => "Glycerolipids made up of a sulfonic acid linked to the C6 atom of glucose, which in turn is bound to the O3 atom of the a monoacylglycerol moiety.",
      'parent' => 1773,
    ),
    array(
      'tid' => 3063,
      'name' => "Sulfoquinovosyl 1-monoacylglycerols",
      'description' => "Sulfoquinovosylmonoacylglycerols where the glycerol moiety is 1-O acylated.",
      'parent' => 3062,
    ),
    array(
      'tid' => 3064,
      'name' => "Sulfoquinovosyl 2-monoacylglycerols",
      'description' => "Sulfoquinovosylmonoacylglycerols where the glycerol moiety is 2-O acylated.",
      'parent' => 3062,
    ),
    array(
      'tid' => 3065,
      'name' => "Indan-1-spirocyclohexanes",
      'description' => "Organic aromatic compounds containing a cyclohexane moiety linked to the 1-position of an indane moiety in a spiro configuration.",
      'parent' => 27,
    ),
    array(
      'tid' => 3066,
      'name' => "Carbapenams",
      'description' => "Beta-lactams with a saturated carbapenem skeleton.",
      'parent' => 162,
    ),
    array(
      'tid' => 3067,
      'name' => "Glycosyldiacylglycerols",
      'description' => "Diacylglycerols that carry a saccharide moiety linked to the glycerol.",
      'parent' => 3822,
    ),
    array(
      'tid' => 3068,
      'name' => "Monosubstituted amine oxides and derivatives",
      'description' => "Amine oxides where the N atom is monosubstituted with one organic group.",
      'parent' => 496,
    ),
    array(
      'tid' => 3069,
      'name' => "Disubstituted amine oxides and derivatives",
      'description' => "Amine oxides where the N atom is disubstituted with two organic groups.",
      'parent' => 496,
    ),
    array(
      'tid' => 3070,
      'name' => "Trisubstituted amine oxides and derivatives",
      'description' => "Amine oxides where the N atom is trisubstituted with three organic groups.",
      'parent' => 496,
    ),
    array(
      'tid' => 3071,
      'name' => "1,8-naphthalic anhydrides",
      'description' => "Organic aromatic compounds that contain a naphthalene carrying two carboxyl groups at the 1- and 8-positions. In naphthalene anhydrides, the two carboxyl groups at the 1- and 8-positions share one oxygen atom.",
      'parent' => 1871,
    ),
    array(
      'tid' => 3072,
      'name' => "1-carboxy-2-haloaromatic compounds",
      'description' => "Aromatic compounds containing 1 carboxyl group and a C-X (X = halogen) group at adjacent positions of an aromatic ring.",
      'parent' => 1205,
    ),
    array(
      'tid' => 3073,
      'name' => "Aromatic alcohols",
      'description' => "Compounds containing an alcohol group attached to an aromatic carbon.",
      'parent' => 129,
    ),
    array(
      'tid' => 3074,
      'name' => "Arylsufonic acids",
      'description' => "Organic compounds containing an aryl group attached to the sulfonic acid group (or a derivative thereof).",
      'parent' => 2237,
    ),
    array(
      'tid' => 3075,
      'name' => "1-sulfo,2-unsubstituted aromatic compounds",
      'description' => "An arylsulfonic acid carrying the sulfonic acid group at the 1-position, and no substitute at the 2-position of the aromatic ring.",
      'parent' => 3074,
    ),
    array(
      'tid' => 3076,
      'name' => "Thioamide-S-oxides",
      'description' => "Organic compounds with the general formula RC(N)=[S+][O-] (R =  organyl).",
      'parent' => 510,
    ),
    array(
      'tid' => 3077,
      'name' => "Thioamide-S,S-dioxides",
      'description' => "Organic compounds with the general formula RC(N)=[S+]([O-])(=O) (R =  organyl).",
      'parent' => 510,
    ),
    array(
      'tid' => 3078,
      'name' => "Aldoximes",
      'description' => "Organic compounds with the general formula RC(H)=NOH (R = organyl).",
      'parent' => 411,
    ),
    array(
      'tid' => 3079,
      'name' => "Ketoximes",
      'description' => "Organic compounds with the general formula RC(R')=NOH (R,R' = organyl).",
      'parent' => 411,
    ),
    array(
      'tid' => 3080,
      'name' => "N-aliphatic s-triazines",
      'description' => "N-aliphatic amine derivatives of 1,3,5-triazines. 1,3,5-triazines are aromatic compounds having three nitrogen ring atoms at the 1-, 3-, and 5- positions.",
      'parent' => 1693,
    ),
    array(
      'tid' => 3081,
      'name' => "Acylsulfonic acids and derivatives",
      'description' => "Acylated products of sulfonic acids (or derivatives).",
      'parent' => 270,
    ),
    array(
      'tid' => 3082,
      'name' => "Acylsulfonic acids",
      'description' => "Acylated derivatives of sulfonic acids.",
      'parent' => 3081,
    ),
    array(
      'tid' => 3083,
      'name' => "2-polyprenyl-6-methoxyphenols",
      'description' => "Compounds containing a polyisoprene chain attached at the 2-position of a 6-methoxyphenol group.",
      'parent' => 2221,
    ),
    array(
      'tid' => 3084,
      'name' => "Chlorohydroquinones",
      'description' => "Organic compounds containing a chlorine atom attached to a hydroquinone.",
      'parent' => 136,
    ),
    array(
      'tid' => 3085,
      'name' => "Peroxybenzoic acids and derivatives",
      'description' => "Organic compounds with a structure containing a benzoic acid or a derivative thereof.",
      'parent' => 176,
    ),
    array(
      'tid' => 3086,
      'name' => "Medium-chain fatty acids",
      'description' => "Fatty acids with an aliphatic tail that contains between 4 and 12 carbon atoms.",
      'parent' => 262,
    ),
    array(
      'tid' => 3087,
      'name' => "Benzylpiperidines",
      'description' => "Heterocyclic compounds containing a piperidine ring conjugated to a benzyl group.",
      'parent' => 195,
    ),
    array(
      'tid' => 3088,
      'name' => "2-benzylpiperidines",
      'description' => "Organic compounds containing a benzyl group attached to the 2-position of a piperidine.",
      'parent' => 3087,
    ),
    array(
      'tid' => 3089,
      'name' => "3-benzylpiperidines",
      'description' => "Organic compounds containing a benzyl group attached to the 3-position of a piperidine.",
      'parent' => 3087,
    ),
    array(
      'tid' => 3090,
      'name' => "4-benzylpiperidines",
      'description' => "Organic compounds containing a benzyl group attached to the 4-position of a piperidine.",
      'parent' => 3087,
    ),
    array(
      'tid' => 3091,
      'name' => "N-acylimines",
      'description' => "N-acyl derivatives of imines. Imines are compounds containing an imine functional group, with the general structure RN=CR2 (R = H, hydrocarbyl).",
      'parent' => 117,
    ),
    array(
      'tid' => 3092,
      'name' => "Oxaziridines",
      'description' => "Organic heterocyclic compounds containing oxaziridine, a three-membered ring containing an oxygen atom, a carbon atom, and a nitrogen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 3093,
      'name' => "N-sulfonyloxaziridines",
      'description' => "N-sulfonyl derivatives of oxaziridines, which are compounds containing a three-membered ring made up of an oxygen atom, a carbon atom, and a nitrogen atom.",
      'parent' => 3092,
    ),
    array(
      'tid' => 3094,
      'name' => "Thiadiazinanes",
      'description' => "Organic heterocyclic compounds containing a six-membered saturated heterocycle with two nitrogen, one sulfur, and three carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 3095,
      'name' => "21-hydroxysteroids",
      'description' => "Steroids carrying a hydroxyl group at the 21-position of the steroid backbone.",
      'parent' => 1295,
    ),
    array(
      'tid' => 3096,
      'name' => "Halobenzoic acids and derivatives",
      'description' => "Benzoic acids or derivatives carrying a halogen atom on the benzene ring.",
      'parent' => 176,
    ),
    array(
      'tid' => 3097,
      'name' => "Halobenzoic acids",
      'description' => "Benzoic acids carrying a halogen atom on the benzene ring.",
      'parent' => 3096,
    ),
    array(
      'tid' => 3098,
      'name' => "2-halobenzoic acids and derivatives",
      'description' => "Benzoic acids or derivatives carrying a halogen atom at the 2-position of the benzene ring.",
      'parent' => 3096,
    ),
    array(
      'tid' => 3099,
      'name' => "3-halobenzoic acids and derivatives",
      'description' => "Benzoic acids or derivatives carrying a halogen atom at the 3-position of the benzene ring.",
      'parent' => 3096,
    ),
    array(
      'tid' => 3100,
      'name' => "4-halobenzoic acids and derivatives",
      'description' => "Benzoic acids or derivatives carrying a halogen atom at the 4-position of the benzene ring.",
      'parent' => 3096,
    ),
    array(
      'tid' => 3101,
      'name' => "2-halobenzoic acids",
      'description' => "Benzoic acids carrying a halogen atom at the 2-position of the benzene ring.",
      'parent' => 3098,
    ),
    array(
      'tid' => 3102,
      'name' => "3-halobenzoic acids",
      'description' => "Benzoic acids carrying a halogen atom at the 3-position of the benzene ring.",
      'parent' => 3099,
    ),
    array(
      'tid' => 3103,
      'name' => "4-halobenzoic acids",
      'description' => "Benzoic acids carrying a halogen atom at the 4-position of the benzene ring.",
      'parent' => 3100,
    ),
    array(
      'tid' => 3104,
      'name' => "Geminal diols",
      'description' => "Organic compounds carrying two hydroxyl functional groups (-OH) on the same carbon atom.",
      'parent' => 2286,
    ),
    array(
      'tid' => 3105,
      'name' => "O-sulfanylbenzoic acids and derivatives",
      'description' => "Benzoic acids (or derivatives) which bear a sulfanyl group (R-SH) attached to the benzene ring at positions 1 and 2, respectively.",
      'parent' => 2086,
    ),
    array(
      'tid' => 3106,
      'name' => "O-sulfanylbenzoic acids",
      'description' => "Benzoic acids which bear a sulfanyl group (R-SH) attached to the benzene ring at positions 1 and 2, respectively.",
      'parent' => 3105,
    ),
    array(
      'tid' => 3107,
      'name' => "Carbothioic S-acids",
      'description' => "Organic acids with the general formula RCS-OH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3108,
      'name' => "Carbothioic O-acids",
      'description' => "Organic acids with the general formula RCO-SH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3109,
      'name' => "Flavaglines",
      'description' => "Heterocyclic compounds with a structure characterized by a cyclopenta[b]benzofuran skeleton.",
      'parent' => 301,
    ),
    array(
      'tid' => 3110,
      'name' => "Hydroxylamine O-sulfonic acids",
      'description' => "Sulfonic acids with the general formula R-N-OS(O)(=O)=O. They can be synthesized through reaction of hydroxylamine and chlorosulfonic acids.",
      'parent' => 264,
    ),
    array(
      'tid' => 3111,
      'name' => "Hydrazinesulfinic acids",
      'description' => "Sulfinic acids with the general formula R-N-NS(=O)=O.",
      'parent' => 264,
    ),
    array(
      'tid' => 3112,
      'name' => "Sulfonohydrazonic acids",
      'description' => "Organic acids with the general formula RS(O)(=NNH2)-OH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3113,
      'name' => "Sulfonimidic acids",
      'description' => "Organic acids with the general formula RS(O)(=NH)-OH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3114,
      'name' => "Sulfonodihydrazonic acids",
      'description' => "Organic acids with the general formula RS(NNH2)2-OH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3115,
      'name' => "Tellurinohydrazonic acids",
      'description' => "Organic acids with the general formula RTe(OH)NN (R=organyl).",
      'parent' => 264,
    ),
    array(
      'tid' => 3116,
      'name' => "Selenodiimidic acids",
      'description' => "Organic acids with the general formula R[Se](OH)(=N)=NR' (R = any atom but N).",
      'parent' => 264,
    ),
    array(
      'tid' => 3117,
      'name' => "Selenimidic acids",
      'description' => "Organic acids with the general formula R[Se](OH)NR' (R = any atom but N).",
      'parent' => 264,
    ),
    array(
      'tid' => 3118,
      'name' => "Sulfonohydrazonimidic acids",
      'description' => "Organic acids with the general formula RCO-SH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3119,
      'name' => "Seleninyl compounds",
      'description' => "Organic compounds with the general formula RSe(=O)R' (R =  organyl).",
      'parent' => 2468,
    ),
    array(
      'tid' => 3120,
      'name' => "Selenonyl compounds",
      'description' => "Organoselenium compounds with the general formula RSe(=O)(=O)R'",
      'parent' => 2468,
    ),
    array(
      'tid' => 3121,
      'name' => "Telluronyl compounds",
      'description' => "Orgnotellurium compounds with the general formula R[Te](R')(=O)=O (R =  organyl, R' not O-atom).",
      'parent' => 2469,
    ),
    array(
      'tid' => 3122,
      'name' => "Tellurinyl compounds",
      'description' => "Organotellurium compounds with the general formula RTe(=O)R' (R = organyl).",
      'parent' => 2469,
    ),
    array(
      'tid' => 3123,
      'name' => "Selenocarbonyl compounds",
      'description' => "Organoselenium compounds with the general formula RC(=Se)R' (R= organyl, R' = H, organyl).",
      'parent' => 2468,
    ),
    array(
      'tid' => 3124,
      'name' => "Tellurocarbonyl compounds",
      'description' => "Organotellurium compounds with the general formula RC(=Te)R' (R= organyl, R' = H, organyl).",
      'parent' => 2469,
    ),
    array(
      'tid' => 3125,
      'name' => "Imidocarbonyl compounds",
      'description' => "Organic compounds with the general formula N=C(R)R' (R=organyl, R' = H or organyl).",
      'parent' => 278,
    ),
    array(
      'tid' => 3126,
      'name' => "Carboselenoic acids",
      'description' => "Organic compounds containing at least one carboselenoyl group, with the formula RC(=O)SeH.",
      'parent' => 2427,
    ),
    array(
      'tid' => 3127,
      'name' => "Carboselenoamides",
      'description' => "Organic acid amide with the general formula RC(Se)NH2 (R=H, organic group).",
      'parent' => 2427,
    ),
    array(
      'tid' => 3128,
      'name' => "Carbotelluroic acids and derivatives",
      'description' => "Organic acids or derivatives thereof with the general formula RC(OH)=Te or RC(Te)OH (R =  organyl).",
      'parent' => 264,
    ),
    array(
      'tid' => 3129,
      'name' => "Carbotelluroamides",
      'description' => "Organic acid amide with the general formula RC(Te)NH2 (R=H, organic group).",
      'parent' => 3128,
    ),
    array(
      'tid' => 3130,
      'name' => "Sulfinyl compounds",
      'description' => "Organic compounds containing a sulfinyl group with the general formula RS(=O)R' (R = organyl, R' = any atom but O).",
      'parent' => 4,
    ),
    array(
      'tid' => 3131,
      'name' => "Alpha,beta-unsaturated carbonyl compounds",
      'description' => "Carbonyl compounds with the general structure R#CC(=O)R' or R=CC(=O)R', where R=organyl, R'=H, N, O, organyl group or halide group.",
      'parent' => 1831,
    ),
    array(
      'tid' => 3132,
      'name' => "Hydrazinecarboxylic acids and derivatives",
      'description' => "Organonitrogen compounds with the general formula RN(H)N(H)C(=O)OR' (R = organyl, R = any).",
      'parent' => 265,
    ),
    array(
      'tid' => 3133,
      'name' => "Hydrazinecarboxylic acids",
      'description' => "Organonitrogen compounds with the general formula RN(H)N(H)C(=O)OH (R = organyl).",
      'parent' => 3132,
    ),
    array(
      'tid' => 3134,
      'name' => "Hydrazinecarboxamides",
      'description' => "Organonitrogen compounds with the general formula RN(H)N(H)C(=O)N (R = organyl).",
      'parent' => 3132,
    ),
    array(
      'tid' => 3135,
      'name' => "Organic thioperoxides",
      'description' => "Organosulfur compounds with the general formula RSOR' (R,R' = organyl).",
      'parent' => 4,
    ),
    array(
      'tid' => 3136,
      'name' => "Alkanesulfonic acids and derivatives",
      'description' => "Organic acids containing an alkane chain linked to a sulfonic acid group. They have the general structure RS(=O)2-OR' (R = alkyl, R' = any atom).",
      'parent' => 270,
    ),
    array(
      'tid' => 3137,
      'name' => "Aminosulfonyl compounds",
      'description' => "Organosulfur compounds with the general formula RS(=O)(=O)N(R')R''  (R = organyl, R'-R\" = any atom but N).",
      'parent' => 1157,
    ),
    array(
      'tid' => 3138,
      'name' => "Hydrazinosulfonyl compounds",
      'description' => "Hydrazine derivatives with the general formula RS(=O)(=O)N(H)N (R = organyl).",
      'parent' => 1157,
    ),
    array(
      'tid' => 3139,
      'name' => "Aminosulfonodithioyl compounds",
      'description' => "Organosulfur compounds with the general formula RS(=S)(=S)N(R')R\" (R = organyl; R',R'' = any atom but N).",
      'parent' => 4,
    ),
    array(
      'tid' => 3140,
      'name' => "Trialkoxysilanes",
      'description' => "Organosilicon compounds with the general formula RO[Si](R')(OR'')OR''' (R-R''' = aliphatic organyl group).",
      'parent' => 3265,
    ),
    array(
      'tid' => 3141,
      'name' => "S-hydrazinosulfonimidoyl compounds",
      'description' => "Organosulfur compounds with the general formula N=S(R)(=O)N(N)R' (R=organyl, R' = any atom but N).",
      'parent' => 4,
    ),
    array(
      'tid' => 3142,
      'name' => "S-aminosulfonimidothioyl compounds",
      'description' => "Organosulfur compounds with the general formula N=S(R)(=S)N(R')R\" (R=organyl; R',R\" = any atom but N).",
      'parent' => 4,
    ),
    array(
      'tid' => 3143,
      'name' => "Aminosulfinyl compounds",
      'description' => "Organic sulfinyl compounds with the general formula RS(=O)N(R')R\" (R=organyl; R'-R\" = any atom but N).",
      'parent' => 3130,
    ),
    array(
      'tid' => 3144,
      'name' => "Sulfonohydrazonothioic o-acids",
      'description' => "Organic acids with the general formula RS(S)(=NH2)-OH  (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3145,
      'name' => "Sulfonohydrazonothioic s-acids",
      'description' => "Organic acids with the general formula RS(O)(=NNH2)-SH  (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3146,
      'name' => "Sulfonimidodithioic acids",
      'description' => "Organic acids with the general formula RS(S)(=NH)-SH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3147,
      'name' => "Sulfonimidoselenoic acids",
      'description' => "Organic acids with the general formula SeS(R)=NR'(R=organyl, R' = any atom but N).",
      'parent' => 264,
    ),
    array(
      'tid' => 3148,
      'name' => "Sulfonohydrazonamides",
      'description' => "Organic acids with the general formula RS(O)(=NNH2)-NH2 (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3149,
      'name' => "Hydrazineselenoamides",
      'description' => "Organoselenium compounds with the general formula N(R)NC(=Se)N(R')R'' (R = organyl; R',R'' = H or organyl).",
      'parent' => 264,
    ),
    array(
      'tid' => 3150,
      'name' => "Sulfonodiimidoperoxoic acids",
      'description' => "Organic acids with the general formula RS(=NH)2-OOH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3151,
      'name' => "Sulfonodiimidic acids",
      'description' => "Organic acids with the general formula RS(=NH)2-OH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3152,
      'name' => "Carboximidamides",
      'description' => "Organonitrogen compounds with the general formula RN=CN(R')(R''), (R,R',R'' = H or organyl group).",
      'parent' => 278,
    ),
    array(
      'tid' => 3153,
      'name' => "Carboximidohydrazides",
      'description' => "Organonitrogen compounds with the general formula HN(H)N(H)C(H)=NR' (R' = H or organyl).",
      'parent' => 278,
    ),
    array(
      'tid' => 3154,
      'name' => "Sulfonimidamides",
      'description' => "Organic compounds with the general formula RS(=O)=NR' (R = organyl, R' = any atom but N).",
      'parent' => 4,
    ),
    array(
      'tid' => 3155,
      'name' => "Sulfonodiimidamides",
      'description' => "Organosulfur compounds with the general formula HN=S(R)(=NH)N(R')R\" (R = organyl; R',R\" = any atom but N).",
      'parent' => 4,
    ),
    array(
      'tid' => 3156,
      'name' => "Sulfinoimidoperoxoic acids",
      'description' => "Organic acids with the general formula RS(=N)-OOH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3157,
      'name' => "OS-thioperoxols",
      'description' => "Thioperoxols with the general formula R-OSH (R = organyl group).",
      'parent' => 3159,
    ),
    array(
      'tid' => 3158,
      'name' => "SO-thioperoxols",
      'description' => "Thioperoxols with the general formula R-SOH (R = organyl group).",
      'parent' => 3159,
    ),
    array(
      'tid' => 3159,
      'name' => "Thioperoxols",
      'description' => "Organosulfur compounds with the general formula R-OSH or R-SOH (R = organyl group).",
      'parent' => 4,
    ),
    array(
      'tid' => 3160,
      'name' => "Telluronohydrazides",
      'description' => "Organotellurium compounds with the general formula R-TeO2-NHNH2.",
      'parent' => 3121,
    ),
    array(
      'tid' => 3161,
      'name' => "Tellurinohydrazides",
      'description' => "Organotellurium compounds with the general formula RTe(O)-NHNH2.",
      'parent' => 3122,
    ),
    array(
      'tid' => 3162,
      'name' => "Seleninohydrazides",
      'description' => "Organoselenium compounds with the general formula RSeO2NHNH2.",
      'parent' => 3119,
    ),
    array(
      'tid' => 3163,
      'name' => "Selenonohydrazides",
      'description' => "Organoselenium compounds with the general formula RSeO2-NHNH2 (R = organyl).",
      'parent' => 3120,
    ),
    array(
      'tid' => 3164,
      'name' => "Carboperoxoic acids",
      'description' => "Organic acids with the general formula RCO-OOH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3165,
      'name' => "Carboperoxoselenoic acids",
      'description' => "Organic acids with the general formula RCSe-OOH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3166,
      'name' => "Carboperoxothioic OO-acids",
      'description' => "Organic acids with the general formula RCS-OOH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3167,
      'name' => "Carboselenothioic S-acids",
      'description' => "Organic acids with the general formula RCSe-SH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3168,
      'name' => "Carboselenothioic Se-acids",
      'description' => "Organic acids with the general formula RCS-SeH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3169,
      'name' => "Carbodiselenoic acids",
      'description' => "Organic acids with the general formula RCSe-SeH (R=H, organic group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3170,
      'name' => "Long-chain 1-monoacylglycerols",
      'description' => "1-monoacylglycerols carrying a long-chain fatty acid at the 1-position.",
      'parent' => 1597,
    ),
    array(
      'tid' => 3171,
      'name' => "Very long-chain 1-monoacylglycerols",
      'description' => "1-monoacylglycerols carrying a very long-chain fatty acid at the 1-position.",
      'parent' => 1597,
    ),
    array(
      'tid' => 3172,
      'name' => "Long-chain 2-monoacylglycerols",
      'description' => "2-monoacylglycerols carrying a long-chain fatty acid at the 2-position.",
      'parent' => 1603,
    ),
    array(
      'tid' => 3173,
      'name' => "Very long-chain 2-monoacylglycerols",
      'description' => "2-monoacylglycerols carrying a very long-chain fatty acid at the 2-position.",
      'parent' => 1603,
    ),
    array(
      'tid' => 3174,
      'name' => "Very long-chain fatty aldehydes",
      'description' => "Fatty aldehydes carrying a long aliphatic chain, with at least 22 carbon atoms.",
      'parent' => 298,
    ),
    array(
      'tid' => 3175,
      'name' => "Very long-chain fatty acyl CoAs",
      'description' => "Acyl CoAs where the group acylated to the coenzyme A moiety is a very long aliphatic chain of 22 carbon atoms or more.",
      'parent' => 1090,
    ),
    array(
      'tid' => 3176,
      'name' => "Long-chain 3-oxoacyl CoAs",
      'description' => "Organic compounds containing a coenzyme A derivative, which is  3-oxo acylated long aliphatic chain of 13 to 21 carbon atoms.",
      'parent' => 1328,
    ),
    array(
      'tid' => 3177,
      'name' => "Very-long-chain 3-oxoacyl CoAs",
      'description' => "Organic compounds containing a coenzyme A derivative, which is  3-oxo acylated long aliphatic chain of 22 carbon atoms or more.",
      'parent' => 1328,
    ),
    array(
      'tid' => 3178,
      'name' => "Long-chain 3-hydroxyacyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to a long acyl chain.",
      'parent' => 2960,
    ),
    array(
      'tid' => 3179,
      'name' => "Very long-chain 3-hydroxyacyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to a very long acyl chain.",
      'parent' => 2960,
    ),
    array(
      'tid' => 3180,
      'name' => "Enoyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to an acyl chain.",
      'parent' => 3327,
    ),
    array(
      'tid' => 3181,
      'name' => "2-enoyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to a 2-enoyl chain.",
      'parent' => 3180,
    ),
    array(
      'tid' => 3182,
      'name' => "3-enoyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to a 3-enoyl chain.",
      'parent' => 3180,
    ),
    array(
      'tid' => 3183,
      'name' => "Long-chain enoyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to a long-chain enoyl chain.",
      'parent' => 3180,
    ),
    array(
      'tid' => 3184,
      'name' => "Long-chain 2-enoyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to a long-chain 2-enoyl chain of 13 to 21 carbon atoms.",
      'parent' => 3183,
    ),
    array(
      'tid' => 3185,
      'name' => "Long-chain 3-enoyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to a long-chain 3-enoyl chain of 13 to 21 carbon atoms.",
      'parent' => 3183,
    ),
    array(
      'tid' => 3186,
      'name' => "N-acyl-phosphatidylethanolamines",
      'description' => "Phosphatidylethanolamines with a N-acylated ethanolamine moiety.",
      'parent' => 3187,
    ),
    array(
      'tid' => 3187,
      'name' => "Glycero-3-phospho-N-acyl-ethanolamines",
      'description' => "Glycerophosphoethanolamines with a n-acylated ethanolamine moiety.",
      'parent' => 2215,
    ),
    array(
      'tid' => 3188,
      'name' => "Acyl homoserines",
      'description' => "N-acylated homoserine derivatives.",
      'parent' => 331,
    ),
    array(
      'tid' => 3189,
      'name' => "3-Oxo-acyl homoserines",
      'description' => "Homoserines carrying a N-acyl chain with a C=O at the 3-position.",
      'parent' => 3188,
    ),
    array(
      'tid' => 3190,
      'name' => "Coumarino-alpha-pyrones",
      'description' => "Organic compounds with a structure characterized by the presence of a pyrano[3,2-c]chromene that carries two ketone groups at the 2- and 5-positions.",
      'parent' => 145,
    ),
    array(
      'tid' => 3191,
      'name' => "Coumarino-gamma-pyrones",
      'description' => "Organic compounds with a structure characterized by the presence of a pyrano[3,2-c]chromene that carries two ketone groups at the 4- and 5-positions.",
      'parent' => 145,
    ),
    array(
      'tid' => 3192,
      'name' => "Ammonium ylides",
      'description' => "Organonitrogen compounds with the general formula  R3N+-C-R2.",
      'parent' => 2449,
    ),
    array(
      'tid' => 3193,
      'name' => "Nitrile ylides",
      'description' => "1,3-Dipolar  Compounds having the general structure RC#[N+][C-], R[C-]=[N+]=C, R[C+]=N[C-].",
      'parent' => 3633,
    ),
    array(
      'tid' => 3194,
      'name' => "Organosilicon compounds",
      'description' => "Organic compounds containing a C[Si] bond.",
      'parent' => 1370,
    ),
    array(
      'tid' => 3195,
      'name' => "Alkylsilanes",
      'description' => "Aliphatic organosilicon compounds.",
      'parent' => 3194,
    ),
    array(
      'tid' => 3196,
      'name' => "Alkylarylsilanes",
      'description' => "Organosilicon compounds with the general formula R[Si]R' (R = alkyl, R' = aryl).",
      'parent' => 3194,
    ),
    array(
      'tid' => 3197,
      'name' => "Alpha-diazo esters",
      'description' => "Organonitrogen compounds with the general formula ROC(=O)C=[N+]=[N-] (R = organyl).",
      'parent' => 1668,
    ),
    array(
      'tid' => 3198,
      'name' => "Alpha-diazo ketones",
      'description' => "Organonitrogen compounds with the general formula RC(=O)C=[N+]=[N-] (R = organyl).",
      'parent' => 1668,
    ),
    array(
      'tid' => 3199,
      'name' => "Sulfonyl azides",
      'description' => "Organosulfur compounds with the general formula RS(=O)(=O)N=[N+][N-] (R = organyl).",
      'parent' => 1157,
    ),
    array(
      'tid' => 3200,
      'name' => "Silyl ethers",
      'description' => "Organic compounds containing a silicon atom covalently bonded to an alkoxy group. They have the general formula R1R2R3Si-O-R4 (R4 = aryl, alkyl).",
      'parent' => 3194,
    ),
    array(
      'tid' => 3201,
      'name' => "Silanols",
      'description' => "Organosilicon compounds with the general formula R[Si]OH (R = organyl group).",
      'parent' => 3194,
    ),
    array(
      'tid' => 3202,
      'name' => "Urazoles",
      'description' => "Organonitrogen compounds containing a 1,3,4-triazolidine ring carrying two C=O groups at positions 2 and 5.",
      'parent' => 1327,
    ),
    array(
      'tid' => 3203,
      'name' => "Maleimides",
      'description' => "Compounds containing a 2,5-pyrroledione moiety.",
      'parent' => 1158,
    ),
    array(
      'tid' => 3204,
      'name' => "2,3-dihydro-4-pyridones",
      'description' => "Organic compounds containing a 2,3-dihydrogenated derivative of 4-pyridone.",
      'parent' => 2224,
    ),
    array(
      'tid' => 3205,
      'name' => "Disiloxanes",
      'description' => "Organosilicon compounds with the general formula H[Si](R)(R')O[Si](H)(R'')R'''  (R= organyl, R'-R'''= H or organyl).",
      'parent' => 4446,
    ),
    array(
      'tid' => 3206,
      'name' => "Medium-chain fatty acyl CoAs",
      'description' => "Acyl CoAs where the group acylated to the coenzyme A moiety is a medium aliphatic chain of 6 to 12 carbon atoms.",
      'parent' => 1090,
    ),
    array(
      'tid' => 3207,
      'name' => "Medium-chain 2-enoyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to a medium-chain 2-enoyl chain of 5 to 12 carbon atoms.",
      'parent' => 3180,
    ),
    array(
      'tid' => 3208,
      'name' => "2,3,4-saturated fatty acyl CoAs",
      'description' => "Acyl-CoAs carrying a 2,3,4-saturated fatty acyl chain.",
      'parent' => 1090,
    ),
    array(
      'tid' => 3209,
      'name' => "Carbo-azosulfones",
      'description' => "Organosulfur compounds with the general formula RS(R')(=N)=O (R,R' = alkyl groups).",
      'parent' => 1157,
    ),
    array(
      'tid' => 3210,
      'name' => "5-monosubstituted hydantoins",
      'description' => "Organic compounds containing a hydantoin moiety substituted at exactly one position.",
      'parent' => 2273,
    ),
    array(
      'tid' => 3211,
      'name' => "N-acyl-aliphatic-alpha amino acids",
      'description' => "Alpha amino acids carrying a N-acylated aliphatic chain.",
      'parent' => 2402,
    ),
    array(
      'tid' => 3212,
      'name' => "N-acyl-aromatic-alpha amino acids",
      'description' => "Alpha amino acids carrying a N-acylated aromatic chain.",
      'parent' => 2402,
    ),
    array(
      'tid' => 3213,
      'name' => "Aryl-aldehydes",
      'description' => "Compounds containing an aldehyde group directly attached to an aromatic ring.",
      'parent' => 124,
    ),
    array(
      'tid' => 3214,
      'name' => "2-phenylindoles",
      'description' => "Indoles substituted at the 2-position with a phenyl group.",
      'parent' => 2497,
    ),
    array(
      'tid' => 3215,
      'name' => "Thiophene sulfoxides",
      'description' => "Organosulfur compounds containing a thiophene ring carrying a S=O bond (in some cases, a [S+][O-]).",
      'parent' => 97,
    ),
    array(
      'tid' => 3216,
      'name' => "3-aroylthiophenes",
      'description' => "Thiophenes which are substituted by an aroyl group at the 3-position.",
      'parent' => 97,
    ),
    array(
      'tid' => 3217,
      'name' => "2-amino-3-aroylthiophenes",
      'description' => "3-aroylthiophenes which are substituted by an amino group at the 2-position.",
      'parent' => 3216,
    ),
    array(
      'tid' => 3218,
      'name' => "3-aroylfurans",
      'description' => "Compounds containing a furan moiety which is acylated at the 3-position with an aromatic moiety.",
      'parent' => 76,
    ),
    array(
      'tid' => 3219,
      'name' => "Borinic acid derivatives",
      'description' => "Compounds comprising any derivative of the boronic acid functional group, with the general structure RB(OR'')R' (R,R'=organyl; R''=H atom or Organyl group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3220,
      'name' => "Borinic acid esters",
      'description' => "Compounds comprising the boronic acid ester functional group RB(R')OR'' (R,R',R''=organyl; X= any O,N,Hal residue).",
      'parent' => 3219,
    ),
    array(
      'tid' => 3221,
      'name' => "Borinic acids",
      'description' => "Compounds comprising any derivative of the boronic acid functional group, with the general structure RB(R')OH (R,R'=organyl).",
      'parent' => 3219,
    ),
    array(
      'tid' => 3222,
      'name' => "Organoboroxines",
      'description' => "Organic compounds containing a boroxine ring B-substituted with an organyl group.",
      'parent' => 2,
    ),
    array(
      'tid' => 3223,
      'name' => "Acetohydroxamic acids",
      'description' => "Organic compounds that contain a hydroxamic acid group carrying a methyl group attached to its carbon center.",
      'parent' => 376,
    ),
    array(
      'tid' => 3224,
      'name' => "(R)-3-hydroxyacyl CoAs",
      'description' => "Organic compounds containing a (R)-3-hydroxyl acylated coenzyme A derivative.",
      'parent' => 2960,
    ),
    array(
      'tid' => 3225,
      'name' => "(S)-3-hydroxyacyl CoAs",
      'description' => "Organic compounds containing a (S)-3-hydroxyl acylated coenzyme A derivative.",
      'parent' => 2960,
    ),
    array(
      'tid' => 3226,
      'name' => "3-beta-hydroxy delta-5-steroids",
      'description' => "3beta-hydroxy steroids containing a double bond between positions 5 and 6.",
      'parent' => 2971,
    ),
    array(
      'tid' => 3227,
      'name' => "11-beta-hydroxysteroids",
      'description' => "Hydroxysteroids carrying a beta-hydroxyl group at the 11-position.",
      'parent' => 3228,
    ),
    array(
      'tid' => 3228,
      'name' => "11-hydroxysteroids",
      'description' => "Steroids carrying a hydroxyl group at the 11-position of the steroid backbone.",
      'parent' => 1295,
    ),
    array(
      'tid' => 3229,
      'name' => "16-hydroxysteroids",
      'description' => "Steroids carrying a hydroxyl group at the 16-position of the steroid backbone.",
      'parent' => 1295,
    ),
    array(
      'tid' => 3230,
      'name' => "16-alpha-hydroxysteroids",
      'description' => "Hydroxysteroids carrying a alpha-hydroxyl group at the 16-position.",
      'parent' => 3229,
    ),
    array(
      'tid' => 3231,
      'name' => "16-beta-hydroxysteroids",
      'description' => "Hydroxysteroids carrying a beta-hydroxyl group at the 16-position.",
      'parent' => 3229,
    ),
    array(
      'tid' => 3232,
      'name' => "3-alpha-hydroxysteroids",
      'description' => "Steroids carrying a alpha-hydroxyl group at the 3-position of the steroid backbone.",
      'parent' => 3027,
    ),
    array(
      'tid' => 3233,
      'name' => "3-beta-hydroxysteroids",
      'description' => "Steroids carrying a beta-hydroxyl group at the 3-position of the steroid backbone.",
      'parent' => 3027,
    ),
    array(
      'tid' => 3234,
      'name' => "11-alpha-hydroxysteroids",
      'description' => "Hydroxysteroids carrying a alpha-hydroxyl group at the 11-position.",
      'parent' => 3228,
    ),
    array(
      'tid' => 3235,
      'name' => "Delta-11-acyl CoAs",
      'description' => "Acyl-CoAs carrying an unsaturated delta(11)-fatty acid.",
      'parent' => 1090,
    ),
    array(
      'tid' => 3236,
      'name' => "17-hydroxysteroids",
      'description' => "Steroids carrying a hydroxyl group at the 17-position of the steroid backbone.",
      'parent' => 1295,
    ),
    array(
      'tid' => 3237,
      'name' => "17-beta-hydroxysteroids",
      'description' => "Hydroxysteroids carrying a beta-hydroxyl group at the 17-position.",
      'parent' => 3236,
    ),
    array(
      'tid' => 3238,
      'name' => "7-hydroxysteroids",
      'description' => "Steroids carrying a hydroxyl group at the 7-position of the steroid backbone.",
      'parent' => 1295,
    ),
    array(
      'tid' => 3239,
      'name' => "7-alpha-hydroxysteroids",
      'description' => "Steroids carrying a alpha-hydroxyl group at the 7-position of the steroid backbone.",
      'parent' => 3238,
    ),
    array(
      'tid' => 3240,
      'name' => "7-beta-hydroxysteroids",
      'description' => "Steroids carrying a beta-hydroxyl group at the 7-position of the steroid backbone.",
      'parent' => 3238,
    ),
    array(
      'tid' => 3241,
      'name' => "12-hydroxysteroids",
      'description' => "Steroids carrying a hydroxyl group at the 12-position of the steroid backbone.",
      'parent' => 1295,
    ),
    array(
      'tid' => 3242,
      'name' => "12-alpha-hydroxysteroids",
      'description' => "Hydroxysteroids carrying a alpha-hydroxyl group at the 12-position.",
      'parent' => 3241,
    ),
    array(
      'tid' => 3243,
      'name' => "12-beta-hydroxysteroids",
      'description' => "Hydroxysteroids carrying a beta-hydroxyl group at the 12-position.",
      'parent' => 3241,
    ),
    array(
      'tid' => 3244,
      'name' => "7-oxosteroids",
      'description' => "Steroid derivatives carrying a C=O group at the 7-position of the steroid skeleton.",
      'parent' => 1194,
    ),
    array(
      'tid' => 3245,
      'name' => "3-oxo-5-alpha-steroids",
      'description' => "5-alpha-steroids carrying a C=O group at the 3-position of the steroid skeleton.",
      'parent' => 3026,
    ),
    array(
      'tid' => 3246,
      'name' => "1-alpha,2-epoxy-3-oxo-5-alpha-steroids",
      'description' => "3-oxo-5-alpha-steroids sharing  the carbon atoms C1 and C2 wit an epoxide ring to form a 1-alpha,2-epoxy moiety.",
      'parent' => 3247,
    ),
    array(
      'tid' => 3247,
      'name' => "1,2-epoxy-3-oxosteroids",
      'description' => "3-oxosteroids sharing the carbon atoms C1 and C2 with an epoxide ring.",
      'parent' => 3026,
    ),
    array(
      'tid' => 3248,
      'name' => "3-beta-hydroxy-6-oxo-5-alpha-steroids",
      'description' => "5-alpha steroids that carry a hydroxyl group at the 3-position and an oxo group at the 6-position.",
      'parent' => 3249,
    ),
    array(
      'tid' => 3249,
      'name' => "6-oxosteroids",
      'description' => "Steroid derivatives carrying a C=O group at the 6-position of the steroid skeleton.",
      'parent' => 1194,
    ),
    array(
      'tid' => 3250,
      'name' => "5,6-epoxysteroids",
      'description' => "Steroid derivatives sharing two carbon atoms  at the 5- and 6- positions with an epoxide ring.",
      'parent' => 258,
    ),
    array(
      'tid' => 3251,
      'name' => "3-beta-hydroxy-delta-7-steroids",
      'description' => "Delta-7-steroids carrying a 3-beta-hydroxyl group at the 3-position.",
      'parent' => 2985,
    ),
    array(
      'tid' => 3252,
      'name' => "3-oxo-4-azasteroids",
      'description' => "Steroids with a structure characterized a C=O group at the 3-position and a nitrogen atom replacing the carbon atom at the 4-position.",
      'parent' => 3026,
    ),
    array(
      'tid' => 3253,
      'name' => "17-azasteroids and derivatives",
      'description' => "Azasteroids where the carbon atom at the25 position is replaced by a nitrogen atom.",
      'parent' => 2340,
    ),
    array(
      'tid' => 3254,
      'name' => "(2R)-hydroxy acids and derivatives",
      'description' => "2R-enantiomers of alpha hydroxy acids and derivatives thereof.",
      'parent' => 1359,
    ),
    array(
      'tid' => 3255,
      'name' => "(2R)-hydroxy acids",
      'description' => "2R-enantiomers of alpha hydroxy acids.",
      'parent' => 3254,
    ),
    array(
      'tid' => 3256,
      'name' => "3-oxo-5-beta-steroids",
      'description' => "5-beta-steroids carrying a C=O group at the 3-position of the steroid skeleton.",
      'parent' => 3026,
    ),
    array(
      'tid' => 3257,
      'name' => "GalNAcb1-4Galb1-4Glc- (Ganglio series)",
      'description' => "Neutral glycosphingolipids in which the root sequence is GalNAcb1-4Galb1-4Glc.",
      'parent' => 1419,
    ),
    array(
      'tid' => 3258,
      'name' => "Glycosphingolipids",
      'description' => "Sphingolipids containing a saccharide moiety glycosidically attached to the sphingoid base. Although saccharide moieties are mostly O-glycosidically linked to the ceramide moiety, other sphingolipids with glycosidic bonds of other types (e.g. S-,C-, or N-type) has been reported.",
      'parent' => 257,
    ),
    array(
      'tid' => 3259,
      'name' => "1,2-diacyl-3-O-beta-D-galactosyl-sn-glycerols",
      'description' => "Glycosyldiacylglycerols carrying a beta-D-galactose at the 3-position of the glycerol moiety.",
      'parent' => 3067,
    ),
    array(
      'tid' => 3260,
      'name' => "Sulfenyl compounds",
      'description' => "Organosulfur compounds a sulfenyl group with the general formula RS (R = organyl).",
      'parent' => 4,
    ),
    array(
      'tid' => 3261,
      'name' => "Sulfenyl halides",
      'description' => "Organosulfur compounds with the general formula RSX (R = organyl, X = halogen atom).",
      'parent' => 3260,
    ),
    array(
      'tid' => 3262,
      'name' => "Sulfinyl halides",
      'description' => "Organosulfur compounds with the general formula RS(=O)X (R = organyl, X = halogen atom).",
      'parent' => 3130,
    ),
    array(
      'tid' => 3263,
      'name' => "Monoalkylglycerols",
      'description' => "Glycerolipids containing exactly one aliphatic chain linked to the glycerol moiety. This chain is the only one linked to the glycerol.",
      'parent' => 3808,
    ),
    array(
      'tid' => 3264,
      'name' => "Glycerol vinyl ethers",
      'description' => "Lipids containing a vinyl ether derivative of glycerol.",
      'parent' => 175,
    ),
    array(
      'tid' => 3265,
      'name' => "Alkoxysilanes",
      'description' => "Organosilicon compounds with the general formula RO[Si](OR')(R'')(R''') (R,R' = organyl; R'',R''' = any atom).",
      'parent' => 3194,
    ),
    array(
      'tid' => 3266,
      'name' => "Monoalkylsilanols",
      'description' => "Organosilicon compounds containing exactly one alkyl group attached to the silicon atom of a silanol group. They have the general formula R[Si](H)(H)OH.",
      'parent' => 3201,
    ),
    array(
      'tid' => 3267,
      'name' => "Dialkylsilanols",
      'description' => "Organosilicon compounds with the general formula HO[Si](R)(R')H where R and R' are alkyl groups.",
      'parent' => 3201,
    ),
    array(
      'tid' => 3268,
      'name' => "Trialkylsilanols",
      'description' => "Organosilicon compounds with the general formula HO[Si](R)(R')R'' where R, R' and R'' are alkyl groups.",
      'parent' => 3201,
    ),
    array(
      'tid' => 3269,
      'name' => "Monoalkylsilanediols",
      'description' => "Organosilicon compounds with the general formula HO[Si](R)(H)OH where R is an alkyl groups.",
      'parent' => 3201,
    ),
    array(
      'tid' => 3270,
      'name' => "Monoalkylsilanetriols",
      'description' => "Organosilicon compounds with the general formula HO[Si](R)(OH)OH where R is an alkyl groups.",
      'parent' => 3201,
    ),
    array(
      'tid' => 3271,
      'name' => "Dialkylsilanediols",
      'description' => "Organosilicon compounds with the general formula HO[Si](R)(R')OH where R and R' are alkyl groups.",
      'parent' => 3201,
    ),
    array(
      'tid' => 3272,
      'name' => "Isocyanide dichlorides",
      'description' => "Organonitrogen compounds derived from isocyanide, with the general formula RN=C(Cl)Cl (R = organyl).",
      'parent' => 278,
    ),
    array(
      'tid' => 3273,
      'name' => "Alkylhalosilanes",
      'description' => "Organosilicon compounds with the general formula R(Si(R')(R\"))nX (R =  aliphatic chain, R'-R\" =H, C, or halogen atom, X = halogen atom).",
      'parent' => 3194,
    ),
    array(
      'tid' => 3274,
      'name' => "Idoso compounds",
      'description' => "Organoiodide compounds with the general formula RI=O (R = organyl group).",
      'parent' => 1518,
    ),
    array(
      'tid' => 3275,
      'name' => "Idoxy compounds",
      'description' => "Organoiodide compounds with the general formula RI(OH)OH (R = organyl group).",
      'parent' => 1518,
    ),
    array(
      'tid' => 3276,
      'name' => "Tosyl compounds",
      'description' => "Organosulfur compounds containing a tosyl group, with the general formula CH3C6H4S(O2)R (R =  any atom).",
      'parent' => 1091,
    ),
    array(
      'tid' => 3277,
      'name' => "p-Nitrobenzenesulfonates",
      'description' => "Benzenesulfonic acids (or derivative thereof) carrying a nitro group at the para- position.",
      'parent' => 32,
    ),
    array(
      'tid' => 3278,
      'name' => "p-Methylbenzenesulfonates",
      'description' => "Benzenesulfonic acids (or derivative thereof) carrying a methyl group at the para- position.",
      'parent' => 32,
    ),
    array(
      'tid' => 3279,
      'name' => "Ynolates",
      'description' => "Organooxygen compounds with the general formula R=C=O (R = organyl).",
      'parent' => 323,
    ),
    array(
      'tid' => 3280,
      'name' => "N-hydroxyguanidines",
      'description' => "Compounds containing a guanidine group in which one of the hydrogens attached to the nitrogen at position 1 is substituted by a hydroxyl group.",
      'parent' => 375,
    ),
    array(
      'tid' => 3281,
      'name' => "N-nitrosated N-hydroxyguanidines",
      'description' => "Compounds containing a guanidine group in which one of the hydrogens attached to the nitrogen at position 1 is substituted by a hydroxyl group, while the other hydrogen is substituted by a nitroso group.",
      'parent' => 3280,
    ),
    array(
      'tid' => 3282,
      'name' => "N-arylamides",
      'description' => "Organic compounds that contain a carboxamide group that is N-linked to a aryl group. They have the generic structure RC(=O)N(R')H, R = organyl group and R'= aryl group.",
      'parent' => 278,
    ),
    array(
      'tid' => 3283,
      'name' => "N-aryl-N-hydroxylamides",
      'description' => "Organic aromatic compounds containing a benzene ring N-linked to a N-hydroxylamide group. They have the generic structure [H]ON(R)C(R')=O, where R= aryl group, R'= organyl group.",
      'parent' => 376,
    ),
    array(
      'tid' => 3284,
      'name' => "Thiosulfonic acids",
      'description' => "Organic compounds containing a thiosulfonic acid, with the general formula [H]SS(R)(=O)=O, R=organyl group.",
      'parent' => 4,
    ),
    array(
      'tid' => 3285,
      'name' => "Alkali metal metavanadates",
      'description' => "Inorganic compounds in which the largest oxoanion is metavanadate, and in which the heaviest atom not in an oxoanion is an alkali metal.",
      'parent' => 445,
    ),
    array(
      'tid' => 3286,
      'name' => "Acetohydroximates",
      'description' => "Organic compounds that contain a hydroximic acid group carrying a methyl group attached to its carbon center.",
      'parent' => 376,
    ),
    array(
      'tid' => 3287,
      'name' => "1-(1Z-alkenyl)-glycero-3-phosphates",
      'description' => "Compounds containing a 1-alkenyl group attached to the O1- position of the glycero-3-phosphate moiety.",
      'parent' => 1254,
    ),
    array(
      'tid' => 3288,
      'name' => "2-(1Z-alkenyl)-glycero-3-phosphates",
      'description' => "Compounds containing a 1-alkenyl group attached to the O2- position of the glycero-3-phosphate moiety.",
      'parent' => 1254,
    ),
    array(
      'tid' => 3289,
      'name' => "Miscellaneous metavanadates",
      'description' => "Inorganic compounds in which the largest metallic oxoanion is metavanadate, to which either no atom or a non metal atom is bonded.",
      'parent' => 1470,
    ),
    array(
      'tid' => 3290,
      'name' => "Non-metal orthovanadates",
      'description' => "Inorganic non-metallic compounds containing a orthovanadate as its largest oxoanion.",
      'parent' => 1442,
    ),
    array(
      'tid' => 3291,
      'name' => "Non-metal metavanadates",
      'description' => "Inorganic non-metallic compounds containing a metavanadate as its largest oxoanion.",
      'parent' => 1442,
    ),
    array(
      'tid' => 3292,
      'name' => "Post-transition metal metavanadates",
      'description' => "Inorganic compounds in which the largest oxoanion is metavanadate, and in which the heaviest atom not in an oxoanion is a post-transition metal.",
      'parent' => 451,
    ),
    array(
      'tid' => 3293,
      'name' => "Transition metal metavanadates",
      'description' => "Inorganic compounds in which the largest oxoanion is metavanadate, and in which the heaviest atom not in an oxoanion is a transition metal.",
      'parent' => 450,
    ),
    array(
      'tid' => 3294,
      'name' => "Organic metavanadates",
      'description' => "Organic compounds containing the metavanadate oxoanion, with the formula [VO4]3-.",
      'parent' => 463,
    ),
    array(
      'tid' => 3295,
      'name' => "N-alkylated hydrazones",
      'description' => "Organonitrogen compounds containing a hydrazone group that is substituted with an alkyl group. They have the generic structure RNN=C(R')R\" (R= alkyl group; R',R\"= H or organyl group).",
      'parent' => 116,
    ),
    array(
      'tid' => 3296,
      'name' => "N-alkyl sulfonyl hydrazones",
      'description' => "Organonitrogen compounds containing a hydrazone derivative with the generic structure R1C(R2)=NN(R4)S(R3)(=O)=O where R4 = alkyl group and R1-R3 = H or organyl group.",
      'parent' => 116,
    ),
    array(
      'tid' => 3297,
      'name' => "Organic Polymers",
      'description' => "Organic compounds, generally large molecules or macromolecules, which are composed of many repeating units.",
      'parent' => 0,
    ),
    array(
      'tid' => 3298,
      'name' => "Polypeptides",
      'description' => "Peptides containing ten or more amino acid residues.",
      'parent' => 3297,
    ),
    array(
      'tid' => 3299,
      'name' => "Polystyrenes",
      'description' => "Organic polymers that a made up of several consecutive units of the styrene monomer.",
      'parent' => 3297,
    ),
    array(
      'tid' => 3300,
      'name' => "Polyureas",
      'description' => "Organic polymers made up of 10 or more repeating urea units (R-CO(NH2)2-)n.",
      'parent' => 3297,
    ),
    array(
      'tid' => 3301,
      'name' => "Polynucleotides",
      'description' => "Organic polymers made up of a sequence of at least 13 purine or pyrimidine nucleotide residues linked to one another from the 5' -end to the 3'-end through a phosphate group.",
      'parent' => 3297,
    ),
    array(
      'tid' => 3302,
      'name' => "Polycarbamates",
      'description' => "Organic polymers made up of 10 or more repeating carbamate units (R-OCONH-)n.",
      'parent' => 3297,
    ),
    array(
      'tid' => 3303,
      'name' => "Amino oligosaccharides",
      'description' => "Oligosaccharides in which one or more sugar units bears at least one amine group.",
      'parent' => 3305,
    ),
    array(
      'tid' => 3304,
      'name' => "Acylamino oligosaccharides",
      'description' => "Oligosaccharides in which one or more sugar units bears at least one acylamine group.",
      'parent' => 3303,
    ),
    array(
      'tid' => 3305,
      'name' => "Aminosaccharides",
      'description' => "Saccharides containing a sugar unit that bears an amino group.",
      'parent' => 11,
    ),
    array(
      'tid' => 3306,
      'name' => "Monosaccharide sulfates",
      'description' => "Monosaccharides that contain a sulfate group linked to the sugar moiety.",
      'parent' => 1540,
    ),
    array(
      'tid' => 3307,
      'name' => "Disaccharide sulfates",
      'description' => "Disaccharides carrying  one or more sulfate group on a sugar unit.",
      'parent' => 1542,
    ),
    array(
      'tid' => 3308,
      'name' => "Oligosaccharide sulfates",
      'description' => "Carbohydrates containing between 3 and 9 sugar units, one of which bear one or more sulfate groups.",
      'parent' => 198,
    ),
    array(
      'tid' => 3309,
      'name' => "Polysaccharide sulfates",
      'description' => "Carbohydrates containing more than 10 sugar units, one of which bear one or more sulfate groups.",
      'parent' => 1539,
    ),
    array(
      'tid' => 3310,
      'name' => "Naphthalene sulfonates",
      'description' => "Organic aromatic compounds that contain a naphthalene moiety that carries a sulfonic acid group at one or more positions. Naphthalene is a bicyclic compound that is made up of two fused benzene ring.",
      'parent' => 3597,
    ),
    array(
      'tid' => 3311,
      'name' => "Alkanesulfonic acids",
      'description' => "Organic acids containing an alkane chain linked to a sulfonic acid group. They have the general structure RS(=O)2-OH (R = alkyl).",
      'parent' => 3136,
    ),
    array(
      'tid' => 3312,
      'name' => "1,1-diunsubstituted alkanesulfonic acids",
      'description' => "Alkanesufonic acids that carry two substituents at the 1-position.",
      'parent' => 3313,
    ),
    array(
      'tid' => 3313,
      'name' => "1,1-diunsubstituted alkanesulfonic acids and derivatives",
      'description' => "Alkanesufonic acids or derivatives that carry two substituents at the 1-position.",
      'parent' => 3136,
    ),
    array(
      'tid' => 3314,
      'name' => "Phenyl-1,2,4-triazoles",
      'description' => "Organic compounds containing a 1,2,4-triazole substituted by a phenyl group.",
      'parent' => 2183,
    ),
    array(
      'tid' => 3315,
      'name' => "Phenyl-1,2,3-triazoles",
      'description' => "Organic compounds containing a 1,2,3-triazole substituted by a phenyl group.",
      'parent' => 2183,
    ),
    array(
      'tid' => 3317,
      'name' => "Pyridyltriazoles",
      'description' => "Organic compounds containing a pyridine ring attached to a triazole ring.",
      'parent' => 89,
    ),
    array(
      'tid' => 3318,
      'name' => "Pyridyl-1,2,3-triazoles",
      'description' => "Organic compounds containing a pyridine ring attached to a 1,2,3-triazole ring.",
      'parent' => 3317,
    ),
    array(
      'tid' => 3319,
      'name' => "Pyridyl-1,2,4-triazoles",
      'description' => "Organic compounds containing a pyridine ring attached to a 1,2,4-triazole ring.",
      'parent' => 3317,
    ),
    array(
      'tid' => 3321,
      'name' => "1,2-diacylglycero-3-phosphosulfocholines",
      'description' => "Glycerophosphosulfocholines in which the two free -OH are attached to one fatty acid each through an ester linkage.",
      'parent' => 3853,
    ),
    array(
      'tid' => 3322,
      'name' => "Wax monoesters",
      'description' => "Waxes bearing an ester group at exactly one position.",
      'parent' => 1723,
    ),
    array(
      'tid' => 3323,
      'name' => "Type 1 wax diesters",
      'description' => "Waxes based on  beta-hydroxy acids (usually C8 to C16) esterified with s fatty acid (usually C6 to C16) at the beta-hydroxy position and with  a fatty alcohol (usually C16 to C20) at the carboxyl group.",
      'parent' => 3325,
    ),
    array(
      'tid' => 3324,
      'name' => "Type 2 wax diesters",
      'description' => "Waxes based on alkane-1,2-diols (usually C12-C23) esterified with C10-C20 acids at the two hydroxyl groups.",
      'parent' => 3325,
    ),
    array(
      'tid' => 3325,
      'name' => "Wax diesters",
      'description' => "Waxes bearing an ester group at exactly two positions.",
      'parent' => 1723,
    ),
    array(
      'tid' => 3326,
      'name' => "4,5-dioxoaporphines",
      'description' => "Alkaloids that contains the tetracyclic aporphine skeleton with two C=O groups at the 4- and 5-positions.",
      'parent' => 381,
    ),
    array(
      'tid' => 3327,
      'name' => "Fatty acyl thioesters",
      'description' => "Thioester derivatives of a fatty acid with the general formula RC(=O)SR', where R is the fatty acyl chain.",
      'parent' => 3909,
    ),
    array(
      'tid' => 3328,
      'name' => "2,3-dienoyl  fatty acyl thioesters",
      'description' => "Thioesters of a 2,3-dienoyl fatty acid with the general formula RC(=O)SR', where R is the fatty acyl chain.",
      'parent' => 3327,
    ),
    array(
      'tid' => 3329,
      'name' => "3,4-dienoyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to a 3,4-enoyl chain.",
      'parent' => 3180,
    ),
    array(
      'tid' => 3330,
      'name' => "2,4-dienoyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to a 2,4-enoyl chain.",
      'parent' => 3180,
    ),
    array(
      'tid' => 3331,
      'name' => "2,5-dienoyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to a 2,5-enoyl chain.",
      'parent' => 3180,
    ),
    array(
      'tid' => 3332,
      'name' => "6,6a-secoaporphines",
      'description' => "Alkaloids with a structure that contains an aminoethylphenanthrene moiety.",
      'parent' => 279,
    ),
    array(
      'tid' => 3333,
      'name' => "Cyclic glycosylpeptides and derivatives",
      'description' => "Compounds containing a carbohydrate moiety glycosidically linked to a cyclic peptide.",
      'parent' => 1996,
    ),
    array(
      'tid' => 3334,
      'name' => "Glycosylpeptides and derivatives",
      'description' => "Compounds containing a carbohydrate glycosidically linked to a peptide.",
      'parent' => 1699,
    ),
    array(
      'tid' => 3335,
      'name' => "Glyco-alpha-amino acids",
      'description' => "Saccharides attached to a single alpha-amino acid by any kind of covalent bond.",
      'parent' => 60,
    ),
    array(
      'tid' => 3336,
      'name' => "Glycosyl-alpha-amino acids",
      'description' => "Saccharides attached to a single alpha-amino acid by glycosidic bond.",
      'parent' => 3335,
    ),
    array(
      'tid' => 3337,
      'name' => "Organoarsonous acids",
      'description' => "As-hydrocarbyl compounds with the general formula RAs(OH)2, where R is an organic group.",
      'parent' => 264,
    ),
    array(
      'tid' => 3338,
      'name' => "Polyethylene glycols",
      'description' => "Oligomers or polymers of ethylene oxide, with the general formula (C2H4O)n (with n>=3).",
      'parent' => 1167,
    ),
    array(
      'tid' => 3339,
      'name' => "2-amino-3-benzoylthiophenes",
      'description' => "Compounds containing a thiophene ring which is substituted at the 2-position by an amine and at the 3-position by a benzoyl group.",
      'parent' => 3217,
    ),
    array(
      'tid' => 3340,
      'name' => "2-amino-3-aroyl-4,5-alkylthiophenes",
      'description' => "3-aroylthiophenes which are substituted at the 2-position by an amine group and the 4-, and 5-position by an alkyl group.",
      'parent' => 3217,
    ),
    array(
      'tid' => 3341,
      'name' => "1-acyl-3-O-beta-D-galactosyl-sn-glycerols",
      'description' => "Glycosylmonoacylglycerols carrying a beta-D-galactose at the 3-position of the glycerol moiety and a fatty acyl at the O-1 position of the glycerol moiety.",
      'parent' => 1773,
    ),
    array(
      'tid' => 3342,
      'name' => "1,2-diacyl-3-O-beta-D-digalactosyl-sn-glycerols",
      'description' => "Glycosylmonoacylglycerols carrying a beta-D-digalactose at the 3-position of the glycerol moiety and a fatty acyl at the O-1 and O-2 positions of the glycerol moiety.",
      'parent' => 3344,
    ),
    array(
      'tid' => 3343,
      'name' => "1-acyl-3-O-beta-D-digalactosyl-sn-glycerols",
      'description' => "Glycosylmonoacylglycerols carrying a beta-D-digalactose at the 3-position of the glycerol moiety and a fatty acyl at the O-1 position of the glycerol moiety.",
      'parent' => 3344,
    ),
    array(
      'tid' => 3344,
      'name' => "3-O-beta-D-digalactosyl-sn-glycerols",
      'description' => "Glycosylglycerols carrying a beta-D-digalactose at the 3-position of the glycerol moiety.",
      'parent' => 637,
    ),
    array(
      'tid' => 3345,
      'name' => "3-O-beta-D-monogalactosyl-sn-glycerols",
      'description' => "Glycosylglycerols carrying a beta-D-galactose at the 3-position of the glycerol moiety.",
      'parent' => 637,
    ),
    array(
      'tid' => 3346,
      'name' => "Phosphatidylinositol dimannosides",
      'description' => "Glycerophospholipids with a structure characterized by the presence of a glycerophosphoinositol carrying acyl groups at the C1 and C2 terminal carbon atoms, as well as two mannoside units glycosidically linked to the 2- and 6-positions of the inositol ring.",
      'parent' => 1344,
    ),
    array(
      'tid' => 3347,
      'name' => "Phosphatidylinositol monomannosides",
      'description' => "Glycerophospholipids with a structure characterized by the presence of a glycerophosphoinositol carrying acyl groups at the C1 and C2 terminal carbon atoms, as well as exactly one mannoside unit glycosidically linked to the 2-position of the inositol ring.",
      'parent' => 1344,
    ),
    array(
      'tid' => 3348,
      'name' => "3-thia fatty acids",
      'description' => "Thia fatty acids with the general structure RC(S)CC(=O)OH.",
      'parent' => 1423,
    ),
    array(
      'tid' => 3349,
      'name' => "4-thia fatty acids",
      'description' => "Thia fatty acids with the general structure RC(S)CCC(=O)OH.",
      'parent' => 1423,
    ),
    array(
      'tid' => 3350,
      'name' => "N-hydroxyl-alpha-amino acids",
      'description' => "Alpha amino acids that carry a hydroxyl group at the N-terminal.",
      'parent' => 60,
    ),
    array(
      'tid' => 3351,
      'name' => "1,2,3-oxadiazoles",
      'description' => "Compounds containing an oxadiazole ring with the oxygen and the two nitrogen atoms at positions 1, 2, and 3, respectively.",
      'parent' => 1822,
    ),
    array(
      'tid' => 3352,
      'name' => "Thienopyridazines",
      'description' => "Organic aromatic compounds containing a thiophene ring fused to a pyridazine ring. A thiophene is a five-member aromatic ring with one sulfur and four carbon atoms, while a pyridazine is a six-membered aromatic ring with two adjacent nitrogen atoms and four carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 3353,
      'name' => "Thieno[3,4-c]pyridazines",
      'description' => "Organic heterocyclic compounds consisting of a thieno[3,4-c]pyridazine moiety. Thieno[3,4-c]pyridazine is a bicyclic compound made up of a thiophene ring fused to a pyridazine ring so that the sulfur atom and the two nitrogen atoms are at the 1-, 5-, and 6-position, respectively.",
      'parent' => 3352,
    ),
    array(
      'tid' => 3354,
      'name' => "Thieno[3,4-d]pyridazines",
      'description' => "Organic heterocyclic compounds consisting of a thieno[3,4-d]pyridazine moiety. Thieno[3,4-d]pyridazine is a bicyclic compound made up of a thiophene ring fused to a pyridazine ring so that the sulfur atom and the two nitrogen atoms are at the 1-, 4-, and 5-position, respectively.",
      'parent' => 3352,
    ),
    array(
      'tid' => 3355,
      'name' => "2-aminothieno[3,4-c]pyridazines",
      'description' => "Organic compounds containing a thieno[3,4-c]pyridazine that carries an amino group at the 2-position. Thieno[3,4-c]pyridazine is a bicyclic compound made up of a thiophene ring fused to a pyridazine ring so that the sulfur atom and the two nitrogen atoms are at the 1-, 5-, and 6-position, respectively.",
      'parent' => 3353,
    ),
    array(
      'tid' => 3356,
      'name' => "2-aminothieno[3,4-d]pyridazines",
      'description' => "Organic compounds containing a thieno[3,4-d]pyridazine that carries an amino group at the 2-position. Thieno[3,4-d]pyridazine is a bicyclic compound made up of a thiophene ring fused to a pyridazine ring so that the sulfur atom and the two nitrogen atoms are at the 1-, 4-, and 5-position, respectively.",
      'parent' => 3354,
    ),
    array(
      'tid' => 3357,
      'name' => "N-alkylpiperazines",
      'description' => "Organic compounds containing a piperazine ring where the nitrogen ring atom carries an alkyl group.",
      'parent' => 189,
    ),
    array(
      'tid' => 3358,
      'name' => "N-methylpiperazines",
      'description' => "Organic compounds containing a piperazine ring where the nitrogen ring atom carries a methyl group.",
      'parent' => 3357,
    ),
    array(
      'tid' => 3359,
      'name' => "N-arylpiperazines",
      'description' => "Organic compounds containing a piperazine ring where the nitrogen ring atom carries an aryl group.",
      'parent' => 189,
    ),
    array(
      'tid' => 3360,
      'name' => "30-hydroxysteroids",
      'description' => "Steroids carrying a hydroxyl group at the 30-position of the steroid backbone.",
      'parent' => 1295,
    ),
    array(
      'tid' => 3361,
      'name' => "Pyrazinium compounds",
      'description' => "Organic aromatic compounds containing a pyriazinium ring.",
      'parent' => 1346,
    ),
    array(
      'tid' => 3362,
      'name' => "1-aminopyrazinium compounds",
      'description' => "Organic compounds containing a pyrazinium ring that carries an amine group at the 1-position.",
      'parent' => 3361,
    ),
    array(
      'tid' => 3363,
      'name' => "2-aminopyrazinium compounds",
      'description' => "Organic compounds containing a pyrazinium ring that carries an amine group at the 2-position.",
      'parent' => 3361,
    ),
    array(
      'tid' => 3364,
      'name' => "Steroid acids",
      'description' => "Compounds containing a carboxyl group attached to a steroid backbone.",
      'parent' => 258,
    ),
    array(
      'tid' => 3365,
      'name' => "Mono-rhamnolipids",
      'description' => "Rhamnolipids containing exactly one rhamnose sugar ring.",
      'parent' => 1765,
    ),
    array(
      'tid' => 3366,
      'name' => "Di-rhamnolipids",
      'description' => "Rhamnolipids containing two rhamnose rings.",
      'parent' => 1765,
    ),
    array(
      'tid' => 3367,
      'name' => "3-carboxy-20-oxosteroids",
      'description' => "Steroid compounds that carry a carboxyl group and a C=O group at the C3- and C20-positions of the steroid backbone, respectively.",
      'parent' => 3368,
    ),
    array(
      'tid' => 3368,
      'name' => "3-carboxy steroids",
      'description' => "Steroid compounds that carry a carboxyl group at the C3-atom of the steroid backbone.",
      'parent' => 3364,
    ),
    array(
      'tid' => 3369,
      'name' => "17-carboxy steroids",
      'description' => "Steroid compounds that carry a carboxyl group at the C17-atom of the steroid backbone.",
      'parent' => 3364,
    ),
    array(
      'tid' => 3370,
      'name' => "Azobenzenes",
      'description' => "Organonitrogen aromatic compounds that contain a central azo group, where each nitrogen atom is conjugated to a benzene ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 3371,
      'name' => "Isodiazenes",
      'description' => "Organonitrogen compounds with the formula RN(R')N or R[N+](R')N-, where R and R' are organic groups.",
      'parent' => 278,
    ),
    array(
      'tid' => 3372,
      'name' => "1,2-dithiolanes",
      'description' => "Organic compounds containing a 1,2-dithiolane ring. 1,2-dithiolane moiety is a 5-membered  saturated aliphatic ring with three carbon atoms, and two sulfur atoms at the 1- and 2- ring positions.",
      'parent' => 484,
    ),
    array(
      'tid' => 3373,
      'name' => "1,3-dithiolanes",
      'description' => "Organic compounds containing a 1,3-dithiolane ring. 1,3-dithiolane moiety is a 5-membered saturated aliphatic ring with three carbon atoms, and two sulfur atoms at the 1- and 3- ring positions.",
      'parent' => 484,
    ),
    array(
      'tid' => 3374,
      'name' => "1,2-dithiolane-3-carboxylic acids",
      'description' => "Organic compounds containing a 1,2-dithiolane ring that bears a carboxylic acid group at the 3-position.",
      'parent' => 3379,
    ),
    array(
      'tid' => 3375,
      'name' => "1,2-dithiolane-4-carboxylic acids",
      'description' => "Organic compounds containing a 1,2-dithiolane ring that bears a carboxylic acid group at the 4-position.",
      'parent' => 3379,
    ),
    array(
      'tid' => 3376,
      'name' => "1,3-dithiolane-2-carboxylic acids",
      'description' => "Organic compounds containing a 1,3-dithiolane ring that bears a carboxylic acid group at the 2-position.",
      'parent' => 3380,
    ),
    array(
      'tid' => 3377,
      'name' => "1,3-dithiolane-4-carboxylic acids",
      'description' => "Organic compounds containing a 1,2-dithiolane ring that bears a carboxylic acid group at the 4-position.",
      'parent' => 3380,
    ),
    array(
      'tid' => 3378,
      'name' => "Dithiolanecarboxylic acids",
      'description' => "Organic heterocyclic compounds containing a dithiolane ring that bears one or more carboxylic acids.",
      'parent' => 484,
    ),
    array(
      'tid' => 3379,
      'name' => "1,2-dithiolanecarboxylic acids",
      'description' => "Organic compounds containing a 1,2-dithiolane ring that bears one or more carboxylic acid groups. The 1,2-dithiolane moiety is a 5-membered ring with three carbon atoms, and two sulfur atoms at the 1- and 2- ring positions.",
      'parent' => 3378,
    ),
    array(
      'tid' => 3380,
      'name' => "1,3-dithiolanecarboxylic acids",
      'description' => "Organic compounds containing a 1,3-dithiolane ring that bears one or more carboxylic acid groups. The 1,3-dithiolane moiety is a 5-membered ring with three carbon atoms, and two sulfur atoms at the 1- and 3- ring positions.",
      'parent' => 3378,
    ),
    array(
      'tid' => 3381,
      'name' => "alpha-Mercaptocarboxylic acids",
      'description' => "Carboxylic acids that bear a thiol group at the C-2 position. Alpha-mercaptocarboxylic acids have the general formula RC(S)C(=O)O, where R = H, organyl group.",
      'parent' => 1205,
    ),
    array(
      'tid' => 3382,
      'name' => "Thiophosphate monoesters",
      'description' => "Organic compounds containing the thiophosphoric acid functional group or a derivative thereof, with the general structure ROP(OR')(OR'')=S, where exactly one R-group is an organyl group.",
      'parent' => 1572,
    ),
    array(
      'tid' => 3383,
      'name' => "Thiophosphate diesters",
      'description' => "Organic compounds containing the thiophosphoric acid functional group or a derivative thereof, with the general structure ROP(OR')(OR'')=S, where exactly two R-groups are organyl groups.",
      'parent' => 1572,
    ),
    array(
      'tid' => 3384,
      'name' => "Thiophosphate triesters",
      'description' => "Organic compounds containing the thiophosphoric acid functional group or a derivative thereof, with the general structure ROP(OR')(OR'')=S, where exactly three R-groups are organyl groups.",
      'parent' => 1572,
    ),
    array(
      'tid' => 3385,
      'name' => "Organic dithiophosphoric acids and derivatives",
      'description' => "Organic compounds that contain dithiophosphoric acid or a derivative thereof, with the general formula ROP(S)(=S)OR', (R,R'=H, or organyl group).",
      'parent' => 264,
    ),
    array(
      'tid' => 3387,
      'name' => "Dithiophosphate S-esters",
      'description' => "S-ester derivatives of dithiophosphates, with the general structure RSP(O)(O)=S (R = organyl group).",
      'parent' => 3385,
    ),
    array(
      'tid' => 3388,
      'name' => "1'-(acyl-sn-glycero-3-phospho),3'-(acyl-sn-glycero-3-phospho)-sn-glycerols",
      'description' => "Glycerophospholipids in which the O1 and O3 oxygen atoms of the central glycerol moiety are each linked to one 1-monoacylglyerol chain.",
      'parent' => 3389,
    ),
    array(
      'tid' => 3389,
      'name' => "Glycerophosphoglycerophosphoglycerols",
      'description' => "Glycerophospholipids that contain three glycerol moieties sequentially linked to each other with a phosphate group. They include cardiolipins.",
      'parent' => 256,
    ),
    array(
      'tid' => 3390,
      'name' => "Ceramide-1-phosphates",
      'description' => "Sphingoid analogue of phosphatidic acid formed from ceramide by adding a phosphate group at its 1-position.",
      'parent' => 1427,
    ),
    array(
      'tid' => 3391,
      'name' => "Phosphonosphingolipids",
      'description' => "Sphingolipids with a structure based on a sphingoid base that is attached to a phosphonate head group. They differ from Phosphosphingolipids which have a phosphate head group.",
      'parent' => 257,
    ),
    array(
      'tid' => 3392,
      'name' => "Phosphosphingolipids",
      'description' => "Sphingolipids with a structure based on a sphingoid base that is attached to a phosphate head group. They differ from phosphonospingolipids which have a phosphonate head group.",
      'parent' => 257,
    ),
    array(
      'tid' => 3393,
      'name' => "(2'->5')-dinucleotides",
      'description' => "Dinucleotides where the two bases are connected via a (2'->5')-phosphodiester linkage.",
      'parent' => 289,
    ),
    array(
      'tid' => 3394,
      'name' => "(3'->5')-dinucleotides",
      'description' => "Dinucleotides where the two bases are connected via a (3'->5')-phosphodiester linkage.",
      'parent' => 3796,
    ),
    array(
      'tid' => 3395,
      'name' => "5'-phospho-(2'->5')-dinucleotides",
      'description' => "(2'->5')-dinucleotides in which one of the based bears a phosphate group (or a phosphate chain) at the 5'-position.",
      'parent' => 3393,
    ),
    array(
      'tid' => 3396,
      'name' => "5'-phospho-(3'->5')-dinucleotides",
      'description' => "(3'->5')-dinucleotides in which one of the based bears a phosphate group (or a phosphate chain) at the 5'-position.",
      'parent' => 3394,
    ),
    array(
      'tid' => 3397,
      'name' => "Sphenolobane diterpenoids",
      'description' => "Diterpenoids with a structure characterized by a sphenolobane skeleton. They possess a trans-fused hydroazulenoid skeleton as a common structural motif, but differ in configuration at C(9), where a prenyl group is attached. Sphenolobane is also considered an 'extended' daucane skeleton, with a carbon side chain appended onto the cyclopentane ring.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3398,
      'name' => "Amphilectane, neoamphilectane, cycloamphilectane, and adociane diterpenoids",
      'description' => "Diterpenoids with a structure based on the amphilectane or a seco-,neo-, or cyclo- derivative thereof. Amphilectane is a tricyclic structure made up of three cyclohexane fused together, with a methyl group at the C11-, C7-, and C3- positions. Additionally, it carries a 2-methylpropyl group at the C1-position. Amphilectanes are presumably derived from serrulatanes. Cycloamphilectanes represent a further cyclisation.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3399,
      'name' => "Cyclohexane sesterterpenes",
      'description' => "Sesterterpenoids with a structure containing a cyclohexane linked to an isoprenyl chain. They arise by cyclisation of the acyclic sesterterpene skeleton between carbons 14 and 19.",
      'parent' => 1552,
    ),
    array(
      'tid' => 3400,
      'name' => "Stemarane diterpenoids",
      'description' => "Diterpenoids with a structure characterized by a stemarane skeleton. Some characteristics include the bicyclic system C/D that is constituted by a bicyclo[3.2.1]octane fused to the bicyclic A/B system in a different fashion with respect to other tetracyclic diterpenes possessing the bicyclo[3.2.1]octane system. Moreover, the two contiguous quaternary carbon atoms,  C(9) and C(10), are present, the former being a spirocyclic atom. Oxygenation can happen at positions C(2), C(7), C(13), C(17), C(18), and C(19).",
      'parent' => 3401,
    ),
    array(
      'tid' => 3401,
      'name' => "Villanovane, atisane, trachylobane or helvifulvane diterpenoids",
      'description' => "Diterpenoids with a structure based on the villanovane, atisane, trachylobane or helvifulvane skeleton. The astisane and atisane skeletons arise from the rearrangement of the beyerane cation intermediate. The trachylobane and helvifulvane skeletons are formed by rearrangement of the beyerane cation intermediate followed by cyclisation.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3402,
      'name' => "Monomethylphosphatidylethanolamines",
      'description' => "Lipids with a structure containing a glycerol moiety linked at its  terminal C3 atom to a N-methylphosphoethanolamine group, and at its C1 and C2 terminal atoms by an acyl group.",
      'parent' => 1393,
    ),
    array(
      'tid' => 3403,
      'name' => "Dimethylphosphatidylethanolamines",
      'description' => "Lipids with a structure containing a glycerol moiety linked at its  terminal C3 atom to a N,N-dimethylphosphoethanolamine group, and at its C1 and C2 terminal atoms by an acyl group.",
      'parent' => 1393,
    ),
    array(
      'tid' => 3404,
      'name' => "Phosphatidylethanols",
      'description' => "Glycerophospholipids where the central glycerol is acylated at the 1- and 2-positions by two acyl chains, and is linked at the 3-position to a phosphoethanol.  They are phospholipids formed only in the presence of ethanol via the action of phospholipase D.",
      'parent' => 256,
    ),
    array(
      'tid' => 3405,
      'name' => "2-arylbenzofuran flavonoids",
      'description' => "Phenylpropanoids containing the 2-phenylbenzofuran moiety.",
      'parent' => 261,
    ),
    array(
      'tid' => 3406,
      'name' => "3-arylcoumarin flavonoids",
      'description' => "Isoflavonoids that bear a ketone group at the C2-position.",
      'parent' => 2506,
    ),
    array(
      'tid' => 3407,
      'name' => "Peltogynoid flavonoids",
      'description' => "Flavonoid compounds with a structure based on the isochromeno[4,3-b]-chromene skeleton. This skeleton results from the fusion of an isochromene to a chromene ring system.",
      'parent' => 334,
    ),
    array(
      'tid' => 3408,
      'name' => "Isobenzofurans",
      'description' => "Organic aromatic compounds containing an isobenzofuran moiety.",
      'parent' => 2,
    ),
    array(
      'tid' => 3409,
      'name' => "Isobenzofuranones",
      'description' => "Compounds containing a 2-benzofuran moiety that carries an oxo group at the 1 position.",
      'parent' => 4191,
    ),
    array(
      'tid' => 3410,
      'name' => "1-benzopyrans",
      'description' => "Organic aromatic compounds that 1-benzopyran, a bicyclic compound made up of a benzene ring fused to a pyran, so that the oxygen atom is at the 1-position.",
      'parent' => 123,
    ),
    array(
      'tid' => 3411,
      'name' => "2-benzopyrans",
      'description' => "Organic aromatic compounds that 1-benzopyran, a bicyclic compound made up of a benzene ring fused to a pyran, so that the oxygen atom is at the 2-position.",
      'parent' => 123,
    ),
    array(
      'tid' => 3412,
      'name' => "Benzothiopyrans",
      'description' => "Organic heterocyclic compounds containing a benzene ring fused to a pyran ring. Pyran a six-membered heterocyclic, non-aromatic ring, made up of five carbon atoms and one oxygen atom and containing two double bonds.",
      'parent' => 2,
    ),
    array(
      'tid' => 3413,
      'name' => "1-benzothiopyrans",
      'description' => "Organic aromatic compounds that 1-benzothiopyran, a bicyclic compound made up of a benzene ring fused to a thiopyran, so that the sulfur atom is at the 1-position.",
      'parent' => 3412,
    ),
    array(
      'tid' => 3414,
      'name' => "2-benzothiopyrans",
      'description' => "Organic aromatic compounds that 1-benzothiopyran, a bicyclic compound made up of a benzene ring fused to a thiopyran, so that the sulfur atom is at the 2-position.",
      'parent' => 3412,
    ),
    array(
      'tid' => 3415,
      'name' => "Angucyclines",
      'description' => "Polyketides with a structure based on then benz[a]anthracene skeleton, with the particularity that the central ring of the anthracene moiety is a para-quinone.",
      'parent' => 261,
    ),
    array(
      'tid' => 3416,
      'name' => "Methyl esters",
      'description' => "Organic compounds containing a carboxyl group that is esterified with a methyl group. They have the general structure RC(=O)OR', where R=H or organyl group and R'=methyl group.",
      'parent' => 1238,
    ),
    array(
      'tid' => 3417,
      'name' => "Fatty acid methyl esters",
      'description' => "Compounds containing a fatty acid that is esterified with a methyl group. They have the general structure RC(=O)OR', where R=fatty aliphatic tail or organyl group and R'=methyl group.",
      'parent' => 324,
    ),
    array(
      'tid' => 3418,
      'name' => "Dihydrobenzofuran and benzofuran lignans",
      'description' => "Neolignans in which the two C6-C3 units are linked together by a bond other than Cbeta-Cbeta'. They usually consist of a 1-benzofuran or 2,3-dihydro-1-benzofuran, which is substituted a the 2-, 3-, and 5-positions with a phenyl group, a methyl group, and a propyl group, respectively.",
      'parent' => 1392,
    ),
    array(
      'tid' => 3419,
      'name' => "Cyclobutane lignans",
      'description' => "Lignans with a structure characterized by to phenylpropanoid units coupled together through the C7-C7' and C8-C8' bonds, forming a cyclobutane ring with the C7, C7', C8', and C8 atoms.",
      'parent' => 1392,
    ),
    array(
      'tid' => 3420,
      'name' => "Alpha-acyloxy ketones",
      'description' => "Ketones that have an acyloxy substituent alpha to the carbonyl group. They have the general structure R4C(=O)OC(R2)(R3)C(R1)=O (R1=organyl, R4=H or organyl; R2,R3 = any atom).",
      'parent' => 3677,
    ),
    array(
      'tid' => 3421,
      'name' => "7,8'-epoxylignans",
      'description' => "Lignans that contain either isomer of the 7,8'-epoxylignan skeleton. The first isomer consists of a tetrahydrofuran that carries a phenyl group at the 2- and the 4-positions, as well as one a methyl group at the 3- and 5-positions. The second isomer consists of a tetrahydrofuran that carries a benzyl group, a phenyl group, and a methyl group at the 2-, 4-, 5-position, respectively.",
      'parent' => 1604,
    ),
    array(
      'tid' => 3422,
      'name' => "7,9'-epoxylignans",
      'description' => "Lignans that contain the 7,9'-epoxylignan skeleton, which consists of a tetrahydrofuran that carries a phenyl group, a methyl group, and a benzyl group at the 2-, 3-, 4-position, respectively.",
      'parent' => 1604,
    ),
    array(
      'tid' => 3423,
      'name' => "7,7'-epoxylignans",
      'description' => "Lignans with a structure based on a 2,5-diaryl-3, 4-dimethyltetrahydrofuran skeleton.",
      'parent' => 1604,
    ),
    array(
      'tid' => 3424,
      'name' => "9,9'-epoxylignans",
      'description' => "Lignans with a structure based on the 9,9'-epoxylignan skeleton, which consists of a tetrahydrofuran that carries two benzyl groups at the 3- and 4-positions. Additionally they are oxygenated at the 2-position to form dibenzylbutyrolactones (oxo group) or a dibenzylbutyrolactols (hydroxyl group).",
      'parent' => 1604,
    ),
    array(
      'tid' => 3425,
      'name' => "Aryltetralin lignans",
      'description' => "Lignans with a structure based on the 1-phenyltetralin skeleton.",
      'parent' => 1392,
    ),
    array(
      'tid' => 3426,
      'name' => "9,9p-dihydroxyaryltetralin lignans",
      'description' => "Lignans with a structure based on the 1-phenyltetralin skeleton carrying a hydroxyl group at the 9- and the 9'- position.",
      'parent' => 3425,
    ),
    array(
      'tid' => 3427,
      'name' => "Stemona alkaloids",
      'description' => "Alkaloids are characterized by a pyrrolo[1,2- a]azepine nucleus usually linked with two carbon chains mostly forming terminal lactone rings. They can be clasified in different subgroups, based on the different carbon chains attached to C-9 of the pyrroloazepine nucleus.",
      'parent' => 279,
    ),
    array(
      'tid' => 3428,
      'name' => "Croomine-type alkaloids",
      'description' => "Stemona alkaloids with a structure containing a pyrrolo[1,2-a]azepine group, where the azepine moiety forms a spiro system with oxolane-5-one to give spiro[oxolane-2,9'-pyrrolo[1,2-a]azepine]-5-one. Moreover, another 5-oxooxolane moiety attached to the pyrrole ring.",
      'parent' => 3916,
    ),
    array(
      'tid' => 3429,
      'name' => "Stichoneurine-type alkaloids",
      'description' => "Stemona alkaloids with a structure that typically contains a 3-methyloxolan-2-one and a 5-propyloxolan-2-one moieties that are attached to the characteristic pyrrolo[1,2-a]azepine skeleton at the C3 and C9 position, respectively.",
      'parent' => 3914,
    ),
    array(
      'tid' => 3430,
      'name' => "Protostemonine-type alkaloids",
      'description' => "Stemona alkaloids with a structure containing a pyrrolo[1,2-a]azepine skeleton (S1) , one 5-oxooxolane moiety (S2), and one a 5-(oxolan-2-yl)oxolan-2-one moiety (S3). The S2 moiety is linked to the C3 atom of the pyrrole ring in the S1 moiety. Additionally, the azepine ring of S1 is fused to one oxolane ring of the S3 moiety.",
      'parent' => 3914,
    ),
    array(
      'tid' => 3431,
      'name' => "Vallesaman alkaloids",
      'description' => "Alkaloids with a structure that is based on the vallesaman skeleton, a tetracyclic compound that contains a piperidine ring fused to an indole.",
      'parent' => 279,
    ),
    array(
      'tid' => 3432,
      'name' => "Thiocarbamic acid bromides",
      'description' => "Organic compounds containing a functional group with the general structure BrC(=S)N(R1)R2 (R1, R2=H, alkyl, aryl).",
      'parent' => 1191,
    ),
    array(
      'tid' => 3433,
      'name' => "Thiocarbamic acid iodides",
      'description' => "Organic compounds containing a functional group with the general structure IC(=S)N(R1)R2 (R1, R2=H, alkyl, aryl).",
      'parent' => 1191,
    ),
    array(
      'tid' => 3434,
      'name' => "Thiocarbamic acid fluorides",
      'description' => "Organic compounds containing a functional group with the general structure FC(=S)N(R1)R2 (R1, R2=H, alkyl, aryl).",
      'parent' => 1191,
    ),
    array(
      'tid' => 3435,
      'name' => "Thiocarbamic acid chlorides",
      'description' => "Organic compounds containing a functional group with the general structure ClC(=S)N(R1)R2 (R1, R2=H, alkyl, aryl).",
      'parent' => 1191,
    ),
    array(
      'tid' => 3436,
      'name' => "Dithiocarboxylic acids and derivatives",
      'description' => "Organic compounds containing a dithiocarboxylic acid with the general formula RC(=S)SR' (R = organyl group, R' = H or organyl group).",
      'parent' => 1198,
    ),
    array(
      'tid' => 3437,
      'name' => "Dithiocarboxylic acids",
      'description' => "Organic compounds with the general formula RC(=S)SH.",
      'parent' => 3436,
    ),
    array(
      'tid' => 3438,
      'name' => "Dithiocarboxylic acid amides",
      'description' => "Organic compounds with the general formula RC(=S)SN(R')R'', (R = organyl group; R', R'' = H, organyl group.",
      'parent' => 3436,
    ),
    array(
      'tid' => 3439,
      'name' => "Dithiocarboxylic acid esters",
      'description' => "Organic compounds with the general formula RC(=S)SR', where R and R' are organyl groups.",
      'parent' => 3436,
    ),
    array(
      'tid' => 3440,
      'name' => "S-alkyl-CoAs",
      'description' => "Alkyl sulfides consisting of coenzyme A that carries an S-alkyl substituent.",
      'parent' => 12,
    ),
    array(
      'tid' => 3441,
      'name' => "S-alkyl-L-cysteines",
      'description' => "Cysteine derivatives that carry an alkyl chain attached to the sulfanyl group.",
      'parent' => 4146,
    ),
    array(
      'tid' => 3442,
      'name' => "S-alkyl-L-cysteine S-oxides",
      'description' => "Cysteine derivatives that carry an alkyl chain attached to a sulfinyl group that arose from oxygenation of the sulfanyl group.",
      'parent' => 3441,
    ),
    array(
      'tid' => 3443,
      'name' => "S-alkyl thiosulfates",
      'description' => "Organosulfur compounds that contain a alkyl chain that is attached to the sulfur atom of thiosulfuric acid (or its conjugated base).",
      'parent' => 2035,
    ),
    array(
      'tid' => 3444,
      'name' => "Glycerone and derivatives",
      'description' => "Organic compounds containing the glycerone moiety or a derivative (ether or ester) thereof.",
      'parent' => 118,
    ),
    array(
      'tid' => 3445,
      'name' => "O-alkylglycerones",
      'description' => "Organic compounds containing a glycerone that carries an acyl substituent at the 1-position or the 2-position.",
      'parent' => 3444,
    ),
    array(
      'tid' => 3446,
      'name' => "Glycerone phosphates",
      'description' => "Organic compounds containing a glycerone moiety that carries a phosphate group at the O-1 or O-2 position.",
      'parent' => 3444,
    ),
    array(
      'tid' => 3447,
      'name' => "O-alkylglycerone phosphates",
      'description' => "Glycerone-3-phosphates carrying an alkyl substituent at the 1-position.",
      'parent' => 3446,
    ),
    array(
      'tid' => 3448,
      'name' => "O-acylglycerone-phosphates",
      'description' => "Glycerone-3-phosphates carrying an acyl substituent at the 1-position.",
      'parent' => 3446,
    ),
    array(
      'tid' => 3449,
      'name' => "N-alkylpyrrolidines",
      'description' => "Compounds containing a pyrrolidine moiety that is substituted at the N1-position with an alkyl group. Pyrrolidine is a five-membered saturated aliphatic heterocycle with one nitrogen atom and four carbon atoms.",
      'parent' => 218,
    ),
    array(
      'tid' => 3450,
      'name' => "Acyl-L-homoserine lactones",
      'description' => "L-isomers of N-acyl-homoserine-lactones.",
      'parent' => 1102,
    ),
    array(
      'tid' => 3451,
      'name' => "Acyl L-homoserines",
      'description' => "L-isomers of Acyl homoserines.",
      'parent' => 3188,
    ),
    array(
      'tid' => 3452,
      'name' => "Acyl D-homoserines",
      'description' => "D-isomers of Acyl homoserines.",
      'parent' => 3188,
    ),
    array(
      'tid' => 3453,
      'name' => "6-thiopurines",
      'description' => "Compounds containing a purine that carries a thiol group at the 6-position. Purine is a bicyclic aromatic compound made up of a pyrimidine ring fused to an imidazole ring.",
      'parent' => 245,
    ),
    array(
      'tid' => 3454,
      'name' => "6-alkylaminopurines",
      'description' => "Compounds that contain an alkylamine group attached at the 6-position of a purine. Purine is a bicyclic aromatic compound made up of a pyrimidine ring fused to an imidazole ring.",
      'parent' => 2987,
    ),
    array(
      'tid' => 3455,
      'name' => "Sulfuric acid esters",
      'description' => "Organic compounds containing a sulfate group that carries one or two O-ester groups.",
      'parent' => 403,
    ),
    array(
      'tid' => 3456,
      'name' => "Alkyl sulfates",
      'description' => "Organic compounds containing a sulfate group that carries an alkyl group through an ether group.",
      'parent' => 403,
    ),
    array(
      'tid' => 3457,
      'name' => "Alkyl phosphates",
      'description' => "Organic compounds containing a phosphate group that is linked to one or more alkyl chains.",
      'parent' => 408,
    ),
    array(
      'tid' => 3458,
      'name' => "Monoalkyl phosphates",
      'description' => "Organic compounds containing a phosphate group that is linked to exactly one alkyl chain.",
      'parent' => 3457,
    ),
    array(
      'tid' => 3459,
      'name' => "Dialkyl phosphates",
      'description' => "Organic compounds containing a phosphate group that is linked to exactly two alkyl chain.",
      'parent' => 3457,
    ),
    array(
      'tid' => 3460,
      'name' => "Trialkyl phosphates",
      'description' => "Organic compounds containing a phosphate group that is linked to exactly three alkyl chains.",
      'parent' => 3457,
    ),
    array(
      'tid' => 3461,
      'name' => "Alkanesulfinic acids and derivatives",
      'description' => "Organosulfur compounds containing an aliphatic group attached to a sulfinic acid group (or a derivative thereof), with the general formula RSO2R' (R= alkyl, R'=any atom).",
      'parent' => 269,
    ),
    array(
      'tid' => 3462,
      'name' => "Alkanesulfinic acids",
      'description' => "Organosulfur compounds containing an aliphatic group attached to a sulfinic acid group (or a derivative thereof), with the general formula RSO2R' (R= alkyl, R'=H).",
      'parent' => 3461,
    ),
    array(
      'tid' => 3463,
      'name' => "Thiolane-2-thiones",
      'description' => "Organic heterocyclic compounds containing a thiolane ring that carries a thione group at the 2-position. Thiolane is a five-membered saturated aliphatic ring made up of one sulfur atom and four carbon atoms.",
      'parent' => 233,
    ),
    array(
      'tid' => 3464,
      'name' => "Thiolane-3-thiones",
      'description' => "Organic heterocyclic compounds containing a thiolane ring that carries a thione group at the 3-position. Thiolane is a five-membered saturated aliphatic ring made up of one sulfur atom and four carbon atoms.",
      'parent' => 233,
    ),
    array(
      'tid' => 3465,
      'name' => "p-Dioxolo[2,3-g]coumarins",
      'description' => "Organic aromatic compounds that contain a p-dioxole ring that is linearly fused to the benzene ring of a coumarin.",
      'parent' => 145,
    ),
    array(
      'tid' => 3466,
      'name' => "p-Dioxolo[2,3-h]coumarins",
      'description' => "Organic aromatic compounds that contain a p-dioxole ring that is angularly fused to the benzene ring of a coumarin. In p-dioxolo[2,3-h]coumarins, the coumarin ring system shares its C7-C8 bond with the p-dioxole ring.",
      'parent' => 145,
    ),
    array(
      'tid' => 3467,
      'name' => "Linear 1,3-diarylpropanoids",
      'description' => "Organic compounds with a structure based on a C6-C3-C6 skeleton, where the two benzene rings are not linked together.",
      'parent' => 261,
    ),
    array(
      'tid' => 3468,
      'name' => "(5'->5')-dinucleotides",
      'description' => "Dinucleotides where the two bases are connected via a (5'->5')-phosphodiester linkage.",
      'parent' => 289,
    ),
    array(
      'tid' => 3469,
      'name' => "N-benzylbenzamides",
      'description' => "Compounds containing a benzamide moiety that is N-linked to a benzyl group.",
      'parent' => 178,
    ),
    array(
      'tid' => 3470,
      'name' => "Coumaronochromenes",
      'description' => "Isoflavonoids with a structure characterized by the presence of a benzopyran and a benzofuran, with the particularity that the pyran and the furan ring are fused to each other.",
      'parent' => 2506,
    ),
    array(
      'tid' => 3471,
      'name' => "Auronols",
      'description' => "Aurone flavonoids in which the pyran ring of the aurone skeleton carries a hydroxyl group at the 2-position.",
      'parent' => 1631,
    ),
    array(
      'tid' => 3472,
      'name' => "2'-Hydroxychalcones",
      'description' => "Organic compounds containing chalcone skeleton that carries a hydroxyl group at the 2'-position.",
      'parent' => 1630,
    ),
    array(
      'tid' => 3473,
      'name' => "2'-Hydroxy-dihydrochalcones",
      'description' => "Organic compounds containing dihydrochalcone skeleton that carries a hydroxyl group at the 2'-position.",
      'parent' => 1630,
    ),
    array(
      'tid' => 3474,
      'name' => "Retrochalcones",
      'description' => "A form of normal chalcones that are structurally distinguished by the lack of oxygen functionalities at the C2'- and C6'-positions.",
      'parent' => 1630,
    ),
    array(
      'tid' => 3475,
      'name' => "Retro-dihydrochalcones",
      'description' => "A form of normal dihydrochalcones that are structurally distinguished by the lack of oxygen functionalities at the C2'- and C6'-positions.",
      'parent' => 1630,
    ),
    array(
      'tid' => 3476,
      'name' => "2,3-Cyclopentanoindolines",
      'description' => "Organic aromatic compounds containing an indoline ring system that shares its C2-C3 bond with a cyclopentane ring.",
      'parent' => 1146,
    ),
    array(
      'tid' => 3477,
      'name' => "Azaphilones",
      'description' => "A structurally variable family of fungal polyketide metabolites possessing a highly oxygenated pyranoquinone bicyclic core, usually known as isochromene, and a quaternary carbon center.",
      'parent' => 2,
    ),
    array(
      'tid' => 3478,
      'name' => "C-cinnamoyl glycosides",
      'description' => "C-glycoside derivatives of cinnamic acid. Cinnamic acid is an aromatic compound containing a benzene and a carboxylic acid group forming 3-phenylprop-2-enoic acid.",
      'parent' => 3480,
    ),
    array(
      'tid' => 3479,
      'name' => "O-cinnamoyl glycosides",
      'description' => "O-glycoside derivatives of cinnamic acid. Cinnamic acid is an aromatic compound containing a benzene and a carboxylic acid group forming 3-phenylprop-2-enoic acid.",
      'parent' => 3480,
    ),
    array(
      'tid' => 3480,
      'name' => "Cinnamic acid esters",
      'description' => "Compound containing an ester derivative of cinnamic acid.",
      'parent' => 476,
    ),
    array(
      'tid' => 3481,
      'name' => "2,5-disubstituted thiophenes",
      'description' => "Organic compounds containing a thiophene that is disubstituted at the C-2,  and C5-positions.",
      'parent' => 97,
    ),
    array(
      'tid' => 3482,
      'name' => "2,3,5-trisubstituted thiophenes",
      'description' => "Organic compounds containing a thiophene that is trisubstituted at the C-2, C3- and C5-positions.",
      'parent' => 97,
    ),
    array(
      'tid' => 3483,
      'name' => "Benzoxanthenes",
      'description' => "Organic compounds containing a benzene ring fused to a xanthene ring system. Xanthene is a tricyclic compound made up of two benzene rings linearly fused to each other through a pyran ring.",
      'parent' => 200,
    ),
    array(
      'tid' => 3484,
      'name' => "Pyranocoumarins",
      'description' => "Organic compounds containing a pyran (or a hydrogenated derivative) fused to a coumarin moiety.",
      'parent' => 145,
    ),
    array(
      'tid' => 3485,
      'name' => "Angular pyranocoumarins",
      'description' => "Organic compounds containing a pyran (or a hydrogenated derivative) angularly fused to a coumarin moiety.",
      'parent' => 3484,
    ),
    array(
      'tid' => 3486,
      'name' => "Linear pyranocoumarins",
      'description' => "Organic compounds containing a pyran (or a hydrogenated derivative) linearly fused to a coumarin moiety.",
      'parent' => 3484,
    ),
    array(
      'tid' => 3487,
      'name' => "Cyclic ketones",
      'description' => "Organic compounds containing a ketone that is conjugated to a cyclic moiety.",
      'parent' => 118,
    ),
    array(
      'tid' => 3488,
      'name' => "2,4-diphenylfurans",
      'description' => "Organic heterocyclic compounds that contain a furan ring substituted with a phenyl group only the C2- and C4-positions.",
      'parent' => 3491,
    ),
    array(
      'tid' => 3489,
      'name' => "2,5-diphenylfurans",
      'description' => "Organic heterocyclic compounds that contain a furan ring substituted with a phenyl group only the C2- and C5-positions.",
      'parent' => 3491,
    ),
    array(
      'tid' => 3490,
      'name' => "3,4-diphenylfurans",
      'description' => "Organic heterocyclic compounds that contain a furan ring substituted with a phenyl group only the C3- and C4-positions.",
      'parent' => 3491,
    ),
    array(
      'tid' => 3491,
      'name' => "Diphenylfurans",
      'description' => "Organic heterocyclic compounds that contain a furan ring substituted with a phenyl group at exactly two positions.",
      'parent' => 76,
    ),
    array(
      'tid' => 3492,
      'name' => "4-carboxy steroids",
      'description' => "Steroid compounds that carry a carboxyl group at the C4-atom of the steroid backbone.",
      'parent' => 3364,
    ),
    array(
      'tid' => 3493,
      'name' => "Pyripyropenes",
      'description' => "Fungal compounds or derivative thereof that contain a pyridine attached to the external pyran ring of a decahydro-2H,11H-benzo[f]pyrano[4,3-b]chromene ring system.",
      'parent' => 3543,
    ),
    array(
      'tid' => 3494,
      'name' => "Rhamnofolane and daphnane diterpenoids",
      'description' => "Diterpenoids with a structure based on one the rhamnofolane or daphnane skeleton. The rhamnofolane and daphnane skeletons are closely related, being formally derived from casbane by two cyclizations (6,10 and 5,14) followed by cleavage of the 1,15 (daphnane) or 2,15 (rhamnofolane) cyclopropane bonds.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3495,
      'name' => "Stilbenolignans",
      'description' => "Non-conventional lignans that derived from stilbene. They are characterized by a p-dioxin ring substituted at one carbon atom by a C3C6 (phenylpropan) group and fused to one ring of the stilbene moiety.",
      'parent' => 1392,
    ),
    array(
      'tid' => 3496,
      'name' => "Cinnamylphenols",
      'description' => "Organic compounds containing the 1,3-diphenylpropene moiety with one benzene ring bearing one or more hydroxyl groups.",
      'parent' => 3467,
    ),
    array(
      'tid' => 3497,
      'name' => "Benzofuran-2-C-glycosides",
      'description' => "Benzofurans that a C-glycosylated at the 2-position. Benzofurans are organic compounds containing a benzene ring fused to a furan.",
      'parent' => 2204,
    ),
    array(
      'tid' => 3498,
      'name' => "Benzofuran-2-O-glycosides",
      'description' => "Benzofurans that a O-glycosylated at the 2-position. Benzofurans are organic compounds containing a benzene ring fused to a furan.",
      'parent' => 2207,
    ),
    array(
      'tid' => 3499,
      'name' => "Benzofuran-5-C-glycosides",
      'description' => "Benzofurans that a C-glycosylated at the 5-position. Benzofurans are organic compounds containing a benzene ring fused to a furan.",
      'parent' => 2204,
    ),
    array(
      'tid' => 3500,
      'name' => "Benzofuran-5-O-glycosides",
      'description' => "Benzofurans that a O-glycosylated at the 2-position. Benzofurans are organic compounds containing a benzene ring fused to a furan.",
      'parent' => 2207,
    ),
    array(
      'tid' => 3501,
      'name' => "3-prenylated flavones",
      'description' => "Flavones that features a C5-isoprenoid substituent at the 3-position.",
      'parent' => 1615,
    ),
    array(
      'tid' => 3502,
      'name' => "3'-prenylated flavones",
      'description' => "Flavones that features a C5-isoprenoid substituent at the 3'-position.",
      'parent' => 1615,
    ),
    array(
      'tid' => 3503,
      'name' => "6-prenylated flavones",
      'description' => "Flavones that features a C5-isoprenoid substituent at the 6-position.",
      'parent' => 1615,
    ),
    array(
      'tid' => 3504,
      'name' => "8-prenylated flavones",
      'description' => "Flavones that features a C5-isoprenoid substituent at the 8-position.",
      'parent' => 1615,
    ),
    array(
      'tid' => 3505,
      'name' => "3-prenylated flavanones",
      'description' => "Flavanones that features a C5-isoprenoid substituent at the 3-position.",
      'parent' => 3639,
    ),
    array(
      'tid' => 3506,
      'name' => "3'-prenylated flavanones",
      'description' => "Flavanones that features a C5-isoprenoid substituent at the 3'-position.",
      'parent' => 3643,
    ),
    array(
      'tid' => 3507,
      'name' => "6-prenylated flavanones",
      'description' => "Flavanones that features a C5-isoprenoid substituent at the 6-position.",
      'parent' => 3646,
    ),
    array(
      'tid' => 3508,
      'name' => "8-prenylated flavanones",
      'description' => "Flavanones that features a C5-isoprenoid substituent at the 8-position.",
      'parent' => 3642,
    ),
    array(
      'tid' => 3509,
      'name' => "3-prenylated chalcones",
      'description' => "Chalcones featuring a C5-isoprenoid unit at the 3-position.",
      'parent' => 1630,
    ),
    array(
      'tid' => 3510,
      'name' => "3'-prenylated chalcones",
      'description' => "Chalcones featuring a C5-isoprenoid unit at the 3'-position.",
      'parent' => 1630,
    ),
    array(
      'tid' => 3511,
      'name' => "4-prenylated 2-arybenzofurans",
      'description' => "2-arylbenzofuran flavonoids featuring a C5-isoprenoid unit at the 4-position.",
      'parent' => 3405,
    ),
    array(
      'tid' => 3512,
      'name' => "3'-prenylated isoflavones",
      'description' => "Isoflavones featuring a C5-isoprenoid unit at the 3'-position.",
      'parent' => 494,
    ),
    array(
      'tid' => 3513,
      'name' => "6-prenylated isoflavones",
      'description' => "Isoflavones featuring a C5-isoprenoid unit at the 6-position.",
      'parent' => 494,
    ),
    array(
      'tid' => 3514,
      'name' => "8-prenylated isoflavones",
      'description' => "Isoflavones featuring a C5-isoprenoid unit at the 8-position.",
      'parent' => 494,
    ),
    array(
      'tid' => 3515,
      'name' => "7-prenylated 2-arybenzofurans",
      'description' => "2-arylbenzofuran flavonoids featuring a C5-isoprenoid unit at the 7-position.",
      'parent' => 3405,
    ),
    array(
      'tid' => 3516,
      'name' => "4'-prenylated 2-arybenzofurans",
      'description' => "2-arylbenzofuran flavonoids featuring a C5-isoprenoid unit at the 4'-position.",
      'parent' => 3405,
    ),
    array(
      'tid' => 3517,
      'name' => "2-prenylated xanthones",
      'description' => "Organic compounds containing a C5-isoprenoid group linked to a xanthone moiety at the 2-position. Xanthone is a tricyclic compound made up of two benzene rings linearly fused to each other through a pyran ring that carries a ketone group.",
      'parent' => 204,
    ),
    array(
      'tid' => 3518,
      'name' => "4-prenylated xanthones",
      'description' => "Organic compounds containing a C5-isoprenoid group linked to a xanthone moiety at the 4-position. Xanthone is a tricyclic compound made up of two benzene rings linearly fused to each other through a pyran ring that carries a ketone group.",
      'parent' => 204,
    ),
    array(
      'tid' => 3519,
      'name' => "8-prenylated xanthones",
      'description' => "Organic compounds containing a C5-isoprenoid group linked to a xanthone moiety at the 8-position. Xanthone is a tricyclic compound made up of two benzene rings linearly fused to each other through a pyran ring that carries a ketone group.",
      'parent' => 204,
    ),
    array(
      'tid' => 3520,
      'name' => "Pyranoflavonoids",
      'description' => "Compounds containing a pyran ring fused to a 2-phenyl-1,4-benzopyran skeleton.",
      'parent' => 334,
    ),
    array(
      'tid' => 3521,
      'name' => "Pyranoxanthones",
      'description' => "Organic aromatic compounds containing a pyran or a hydrogenated derivative fused to a xanthone ring system.",
      'parent' => 204,
    ),
    array(
      'tid' => 3522,
      'name' => "2,2-dimethyl-1-benzopyrans",
      'description' => "Organic compounds containing a 1-benzopyran moiety that carries two methyl groups at the 2-position.",
      'parent' => 3410,
    ),
    array(
      'tid' => 3523,
      'name' => "Meta,para-diphenylether diarylheptanoids",
      'description' => "Cyclic diarylheptanoids where the two benzene rings are linked to each other by an ether group conjugated to the 3-position of one benzene ring and the 4-position of the other ring.",
      'parent' => 2652,
    ),
    array(
      'tid' => 3524,
      'name' => "Meta,meta-bridged biphenyls",
      'description' => "Cyclic diarylheptanoids where the two aryl groups are linked to each other by an ether group conjugated to their 3-position.",
      'parent' => 2652,
    ),
    array(
      'tid' => 3525,
      'name' => "3'-prenylated isoflavanones",
      'description' => "Isoflavanones featuring a C5-isoprenoid unit at the 3'-position.",
      'parent' => 1827,
    ),
    array(
      'tid' => 3526,
      'name' => "6-prenylated isoflavanones",
      'description' => "Isoflavanones featuring a C5-isoprenoid unit at the 6-position.",
      'parent' => 1827,
    ),
    array(
      'tid' => 3527,
      'name' => "8-prenylated isoflavanones",
      'description' => "Isoflavanones featuring a C5-isoprenoid unit at the 8-position.",
      'parent' => 1827,
    ),
    array(
      'tid' => 3528,
      'name' => "Rotenones",
      'description' => "Rotenoids with a structure based on a 6a,12a-dihydrochromeno[3,4-b]chromen-12(6H)-one skeleton.",
      'parent' => 1607,
    ),
    array(
      'tid' => 3529,
      'name' => "Furo[2,3-b]chromones",
      'description' => "Polycyclic aromatic compounds containing a furan ring fused to a 1-benzopyran-4-one ring system to form a furo[2,3-b]chromone skeleton.",
      'parent' => 1735,
    ),
    array(
      'tid' => 3530,
      'name' => "Pyranoisoflavonoids",
      'description' => "Isoflavonoids that contain a pyran ring fused to either of the A, B, or C ring of the isoflavonoid skeleton.",
      'parent' => 2506,
    ),
    array(
      'tid' => 3531,
      'name' => "Flavonoid-3-O-glycosides",
      'description' => "Phenolic compounds containing a flavonoid moiety which is O-glycosidically linked to carbohydrate moiety at the C3-position.",
      'parent' => 1583,
    ),
    array(
      'tid' => 3532,
      'name' => "Flavonoid-3-O-glucuronides",
      'description' => "Phenolic compounds containing a flavonoid moiety which is O-glycosidically linked to glucuronic acid at the C3-position.",
      'parent' => 2934,
    ),
    array(
      'tid' => 3533,
      'name' => "Flavonoid-7-O-glycosides",
      'description' => "Phenolic compounds containing a flavonoid moiety which is O-glycosidically linked to carbohydrate moiety at the C7-position.",
      'parent' => 1583,
    ),
    array(
      'tid' => 3534,
      'name' => "Flavonoid-7-O-glucuronides",
      'description' => "Phenolic compounds containing a flavonoid moiety which is O-glycosidically linked to glucuronic acid at the C7-position.",
      'parent' => 2934,
    ),
    array(
      'tid' => 3535,
      'name' => "Flavonoid 8-C-glycosides",
      'description' => "Compounds containing a carbohydrate moiety which is C-glycosidically linked to 8-position of a 2-phenylchromen-4-one flavonoid backbone.",
      'parent' => 1737,
    ),
    array(
      'tid' => 3536,
      'name' => "Dinaphthofurans",
      'description' => "Organic aromatic compounds that contain two naphthalene moieties fused to each other through a furan ring. Furan is a 5 membered- ring aromatic ring with four carbon and one oxygen atoms. Naphthalene is a polycyclic aromatic hydrocarbon  made up of two fused benzene rings.",
      'parent' => 1634,
    ),
    array(
      'tid' => 3537,
      'name' => "Dinaphtho[2,1-b;2',3'-d]furans",
      'description' => "Organic aromatic compounds that contain two naphthalene moieties fused to each other through a furan ring to form a dinaphtho[2,1-b;2',3'-d]furan skeleton.",
      'parent' => 3536,
    ),
    array(
      'tid' => 3538,
      'name' => "Gallic acids",
      'description' => "Organic compounds that contain a 3,4,5-trihydroxybenzoic acid moiety.",
      'parent' => 1251,
    ),
    array(
      'tid' => 3539,
      'name' => "Galloyl esters",
      'description' => "Organic compounds that contain an ester derivative of 3,4,5-trihydroxybenzoic acid.",
      'parent' => 1251,
    ),
    array(
      'tid' => 3540,
      'name' => "Flavonoid-8-O-glycosides",
      'description' => "Phenolic compounds containing a flavonoid moiety which is O-glycosidically linked to carbohydrate moiety at the C8-position.",
      'parent' => 1583,
    ),
    array(
      'tid' => 3541,
      'name' => "Flavonoid-8-O-glucuronides",
      'description' => "Phenolic compounds containing a flavonoid moiety which is O-glycosidically linked to glucuronic acid at the C8-position.",
      'parent' => 2934,
    ),
    array(
      'tid' => 3542,
      'name' => "Furanochalcones",
      'description' => "Compounds containing a furan ring fused to either ring of a chalcone moiety.",
      'parent' => 1630,
    ),
    array(
      'tid' => 3543,
      'name' => "Pyranochromenes",
      'description' => "Organic heterocyclic compounds containing a pyran ring fused to a chromene (1-benzopyran) moiety.",
      'parent' => 3410,
    ),
    array(
      'tid' => 3544,
      'name' => "Methyl-branched fatty acids",
      'description' => "Fatty acids with an acyl chain that has a methyl branch. Usually, they are saturated and contain only one or more methyl group. However, branches other than methyl may be present.",
      'parent' => 338,
    ),
    array(
      'tid' => 3545,
      'name' => "Himachalane and lippifoliane sesquiterpenoids",
      'description' => "Sesquiterpenoids with a structure based on either the himachalane or the lippifoliane skeleton.",
      'parent' => 1550,
    ),
    array(
      'tid' => 3546,
      'name' => "Jatropholane and crotopholane diterpenoids",
      'description' => "Diterpenoids with a structure based either on the jatropholane or the crotopholane skeleton. Jatropholanes arise by 5,13- and 6,10-cyclisation of a casbane precursor. Subsequent cleavage of the 2,15-cyclopropane bond affords crotofolane.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3547,
      'name' => "Fusicoccane diterpenoids",
      'description' => "Diterpenoids with a structure based on a 20-carbon dicyclopenta[a,d]cyclooctane  skeleton  (5->8->5 ring system) known as fusicoccane.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3548,
      'name' => "Valparane and mulinane diterpenoids",
      'description' => "Diterpenoids with a structure based on either the valparane or mulinane skeleton. Valparane and mulinane are tricyclic compounds containing a tetradecahydrocyclohepta[e]indene skeleton. Valparane carries a 1-methylethyl at the 3-position, as well as three methyl groups at the 5a-, 8-, and 10b-position of the ring system. Mulinane carries a 1-methylethyl at the 3-position, as well as three methyl groups at the 3a-, 5a-, and 8-position of the ring system.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3549,
      'name' => "Bicyclogermacrane and isolepidozane sesquiterpenoids",
      'description' => "Sesquiterpenoids with a structure based either on the bicyclogermacrane (3,7,11,11-tetramethylbicyclo[8.1.0]undecane, 9CI) skeleton or the isolepidozane skeleton.",
      'parent' => 1550,
    ),
    array(
      'tid' => 3550,
      'name' => "Pachydictyane and cneorubin diterpenoids",
      'description' => "Diterpenoids with a structure that is based either on the pachydictyane or the cneorubin skeleton. Pachydictyane is a bicyclic compound consisting of a guaiane skeleton that carries a prenyl group attached to the C12 carbon atom. Cneorubin is a tricyclic compound consisting of a cycloprop[e]azulene where the cyclopropane carries a methyl group and a 4-methylpentyl group.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3551,
      'name' => "Anthocyanin-3'-O-glycosides",
      'description' => "Phenolic compounds containing one anthocyanidin moiety which is O-glycosidically linked to a carbohydrate moiety at the C3'-position.",
      'parent' => 1361,
    ),
    array(
      'tid' => 3552,
      'name' => "Anthocyanin-4'-O-glycosides",
      'description' => "Phenolic compounds containing one anthocyanidin moiety which is O-glycosidically linked to a carbohydrate moiety at the C4'-position.",
      'parent' => 1361,
    ),
    array(
      'tid' => 3553,
      'name' => "Anthocyanidin 7-O-2-p-coumaroyl glycosides",
      'description' => "Anthocyanidin 7-O-glycosides where the carbohydrate moiety is esterified at the C2 position (of the sugar unit) with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 3556,
    ),
    array(
      'tid' => 3554,
      'name' => "Anthocyanidin 7-O-6-p-coumaroyl glycosides",
      'description' => "Anthocyanidin 7-O-glycosides where the carbohydrate moiety is esterified at the C6 position with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 3556,
    ),
    array(
      'tid' => 3555,
      'name' => "Anthocyanidin-7-O-Glycosides",
      'description' => "Phenolic compounds containing one anthocyanidin moiety which is O-glycosidically linked to a carbohydrate moiety at the C7-position.",
      'parent' => 1361,
    ),
    array(
      'tid' => 3556,
      'name' => "Anthocyanidin 7-O-p-coumaroyl glycosides",
      'description' => "Anthocyanidin 7-O-glycosides where the carbohydrate moiety is esterified with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 3680,
    ),
    array(
      'tid' => 3557,
      'name' => "19-oxosteroids",
      'description' => "Steroid derivatives carrying a C=O group at the 19-position of the steroid skeleton.",
      'parent' => 1194,
    ),
    array(
      'tid' => 3558,
      'name' => "17-oxosteroids",
      'description' => "Steroid derivatives carrying a C=O group at the 17-position of the steroid skeleton.",
      'parent' => 1194,
    ),
    array(
      'tid' => 3559,
      'name' => "Elisabethane diterpenoids",
      'description' => "Diterpenoids with a structure based on the elisabethane skeleton, a tricyclic serrulatane derivative that is formed by connecting the C1 and C9 atom of serrulatane. This class of compounds also includes seco-elisabethane derivatives, nor-elisabethanes (resulting from the loss of one carbon atom), and bisnor-elisabethanes (resulting from the loss of two carbon atoms).",
      'parent' => 1551,
    ),
    array(
      'tid' => 3560,
      'name' => "Elisapterane, elisabane, cumbiane or colombiane diterpenoids",
      'description' => "Diterpenoids with a structure based on either the elisapterane, elisabane, cumbiane or colombiane skeleton. They derive from serrulatane. Elisapterane is a tetracyclic compound formed by C10-C15 cyclization of elisabethane. Elisabane (nor-elisapterane) results from the loss of the C17 carbon atom of elisapterane. Cumbiane is formed by C10-C16 cyclization of the elisabethane carbon skeleton. Meanwhile, the cleavage of the C15-C16 bond of cumbiane yields the seco-cumbiane skeleton. Colombiane is also a tetracyclic skeleton arises from the C12-C2 cyclization of the elisabethane skeleton.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3561,
      'name' => "Ileabethane, pseudopterane or nor-sandresane diterpenoids",
      'description' => "Diterpenoids with a structure based on either the ileabethane, the pseudopterane, or the nor-sandresane skeleton. Ileabethane is a tricyclic carbon skeleton arising from the C8-C14 of serrulatane. In the nor-sandresane skeleton, a cyclohexane ring is fused to a seven-membered saturated aliphatic carbocycle, which could stem from the rearrangement of an amphilectane-based precursor involving loss of a carbon atom and a 1,2-alkyl shift with ring expansion.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3562,
      'name' => "5,10-cycloaromadendrane sesquiterpenoids",
      'description' => "Aromadendrane sesquiterpenoids that arise from the C5-C10 cyclization of the aromadendrane skeleton.",
      'parent' => 1781,
    ),
    array(
      'tid' => 3563,
      'name' => "Rotundane sesquiterpenoids",
      'description' => "Sesquiterpenoids with a structure based on the rotundane skeleton, which arise by a C10-C12 cyclization of bicyclic guaiane skeleton.",
      'parent' => 1550,
    ),
    array(
      'tid' => 3564,
      'name' => "Maaliane sesquiterpenoids",
      'description' => "Cycloeudesmane sesquiterpenoids that arise from the C7-C11 cyclization of the eudesmane skeleton.",
      'parent' => 101,
    ),
    array(
      'tid' => 3565,
      'name' => "Aristolane sesquiterpenoids",
      'description' => "Sesquiterpenoids with a structure based on the aristolane skeleton. Aristolanes arise from the C6,C11 cyclization of the bicyclic eremophilane skeleton.",
      'parent' => 1550,
    ),
    array(
      'tid' => 3566,
      'name' => "Cholestane steroids",
      'description' => "Steroids with a structure containing the 27-carbon cholestane skeleton.",
      'parent' => 258,
    ),
    array(
      'tid' => 3567,
      'name' => "Ergostane steroids",
      'description' => "Steroids with a structure based on the ergostane skeleton, which arises from the methylation of cholestane at the 24-position.",
      'parent' => 258,
    ),
    array(
      'tid' => 3568,
      'name' => "Androstane steroids",
      'description' => "Steroids with a structure based on the 19-carbon androstane skeleton.",
      'parent' => 258,
    ),
    array(
      'tid' => 3569,
      'name' => "Pregnane steroids",
      'description' => "Steroids with a structure based on the 21-carbon pregnane skeleton.",
      'parent' => 258,
    ),
    array(
      'tid' => 3570,
      'name' => "Estrogens and derivatives",
      'description' => "Steroids with a structure containing a 3-hydroxylated estrane.",
      'parent' => 1466,
    ),
    array(
      'tid' => 3571,
      'name' => "N-substituted N'-hydroxyguanidines",
      'description' => "Compounds containing a guanidine group in which one of the hydrogens attached to the nitrogen at position 1 is substituted by a hydroxyl group, while the nitrogen at position 2 is substituted.",
      'parent' => 3280,
    ),
    array(
      'tid' => 3572,
      'name' => "Guanidinoglycosides",
      'description' => "Aminoglycoside analogs in which amine groups of natural aminoglycoside antibiotics have been converted into guanidine groups.",
      'parent' => 3305,
    ),
    array(
      'tid' => 3573,
      'name' => "4,5-disubstituted 2-deoxystreptamines",
      'description' => "2-deoxystreptamine aminoglycosides that a glycosidically linked to a pyranose of furanose unit at the C4- and C5-positions.",
      'parent' => 3575,
    ),
    array(
      'tid' => 3574,
      'name' => "4,6-disubstituted 2-deoxystreptamines",
      'description' => "2-deoxystreptamine aminoglycosides that a glycosidically linked to a pyranose of furanose unit at the C4- and C6-positions.",
      'parent' => 3575,
    ),
    array(
      'tid' => 3575,
      'name' => "2-deoxystreptamine aminoglycosides",
      'description' => "Aminoglycosides containing the 2-deoxystreptamine (1,3-diaminocyclohexane-4,5,6-triol) core.",
      'parent' => 1675,
    ),
    array(
      'tid' => 3576,
      'name' => "Streptamine aminoglycosides",
      'description' => "Aminoglycosides containing the aminocyclitol the streptamine (1,3-diaminocyclohexane-2,4,5,6-tetrol) core.",
      'parent' => 1675,
    ),
    array(
      'tid' => 3577,
      'name' => "6-beta-hydroxysteroids",
      'description' => "Steroids carrying a beta-hydroxyl group at the 6-position of the steroid backbone.",
      'parent' => 3578,
    ),
    array(
      'tid' => 3578,
      'name' => "6-hydroxysteroids",
      'description' => "Steroids carrying a hydroxyl group at the 6-position of the steroid backbone.",
      'parent' => 1295,
    ),
    array(
      'tid' => 3579,
      'name' => "2'-prenylated isoflavanones",
      'description' => "Isoflavanones featuring a C5-isoprenoid unit at the 2'-position.",
      'parent' => 1827,
    ),
    array(
      'tid' => 3580,
      'name' => "2'-prenylated isoflavones",
      'description' => "Isoflavones featuring a C5-isoprenoid unit at the 2'-position.",
      'parent' => 494,
    ),
    array(
      'tid' => 3581,
      'name' => "Capnellane and isocapnellane sesquiterpenoids",
      'description' => "Sesquiterpenes with a structure characterized by the presence of a tricyclo[6.3.0.0^2,6]undecane ring system, which is also found in the hirsutane group. However, capnellanes carry two methyl groups at the 3-position.",
      'parent' => 3583,
    ),
    array(
      'tid' => 3582,
      'name' => "Angular triquinanes",
      'description' => "Triquinane with a structure based on a [6.3.0.0^1,5] undecane carbon skeleton.",
      'parent' => 2004,
    ),
    array(
      'tid' => 3583,
      'name' => "Linear triquinanes",
      'description' => "Triquinane with a structure based on a [6.3.0.0^2,6] undecane carbon skeleton.",
      'parent' => 2004,
    ),
    array(
      'tid' => 3584,
      'name' => "Precapnellane sesquiterpenoids",
      'description' => "Sesquiterpenes with a structure characterized by the presence of a precapnellane skeleton. Precapnellane is a bicyclic compound made up of a cyclopentane fused to a cyclooctane and carrying one methyl group at the 1- and 5-position, as well as two methyl groups at the 8-position.",
      'parent' => 1550,
    ),
    array(
      'tid' => 3585,
      'name' => "Propellane triquinanes",
      'description' => "Triquinane with a structure based on a [3.3.3] carbon skeleton.",
      'parent' => 2004,
    ),
    array(
      'tid' => 3586,
      'name' => "Pentalenane and rearranged pentalenane sesquiterpenoids",
      'description' => "Sesquiterpenoids with a structure characterized by a Decahydro-1,4,7,7-tetra-methylcyclopenta[c]-pentalene (pentalenane sesquiterpenoids) or a Decahydro-1,4,6,7-tetra-methylcyclopenta[c]-pentalene skeleton (rearranged pentalenane sesquiterpenoids).",
      'parent' => 3582,
    ),
    array(
      'tid' => 3587,
      'name' => "2'-prenylated flavones",
      'description' => "Flavones that features a C5-isoprenoid substituent at the 2'-position.",
      'parent' => 1615,
    ),
    array(
      'tid' => 3588,
      'name' => "2'-prenylated flavanones",
      'description' => "Flavanones that features a C5-isoprenoid substituent at the 2'-position.",
      'parent' => 3645,
    ),
    array(
      'tid' => 3589,
      'name' => "Imidazopyrazines",
      'description' => "Organic heteropolycyclic compounds containing a pyrazine ring fused to an imidazole ring. These also include hydrogenated derivatives of the imidazopyrazine moiety. Imidazole is 5-membered ring consisting of three carbon atoms, and two nitrogen centers at the 1- and 3-positions. Pyrazine is a 6-membered ring consisting of six carbon atoms and two nitrogen centers at ring positions 1 and 4.",
      'parent' => 2,
    ),
    array(
      'tid' => 3590,
      'name' => "Imidazo-[4,5-c]pyridines",
      'description' => "Organic heterocyclic compounds containing an imidazo-[4,5-c]pyridine ring system. Imidazo-[4,5-c]pyridine consists of an imidazole ring fused to a pyridine, so that the three ring nitrogen atoms are at the 1-, 2-, and 5-position, respectively.",
      'parent' => 328,
    ),
    array(
      'tid' => 3591,
      'name' => "Sulfinyl sulfones",
      'description' => "Organic compounds containing a sulfinyl sulfone group, with the general structure RS(=O)S(R')(=O)=O or RS(=O)(=O)S(R')=O (R=organyl group, R'=H or organyl group).",
      'parent' => 1157,
    ),
    array(
      'tid' => 3592,
      'name' => "Phenanthro-perylenequinones",
      'description' => "Natural compounds or derivatives thereof that contain the phenanthroperylenequinone skeleton. Phenanthroperylenequinone is an octacyclic compound consisting of 2 1-hydroxy-9,10-dihydroanthracen-9-one ring system joined to each other with a naphthalene.",
      'parent' => 2903,
    ),
    array(
      'tid' => 3593,
      'name' => "Naphthalene sulfonamides",
      'description' => "Organic aromatic compounds that contain a naphthalene moiety that carries a sulfonamide (or a derivative thereof) at one or more positions. Naphthalene is a bicyclic compound that is made up of two fused benzene ring.",
      'parent' => 3597,
    ),
    array(
      'tid' => 3594,
      'name' => "Pyridoazepine alkaloids",
      'description' => "Alkaloids are characterized by a pyrido[1,2- a]azepine nucleus usually linked with two carbon chains mostly forming terminal lactone rings. These compounds are believed to be derived from a protostemonine-type precursor have been discovered.",
      'parent' => 3427,
    ),
    array(
      'tid' => 3595,
      'name' => "1-naphthalene sulfonamides",
      'description' => "Organic aromatic compounds that contain a naphthalene moiety that carries a sulfonamide (or a derivative thereof) at the 1-position. Naphthalene is a bicyclic compound that is made up of two fused benzene ring.",
      'parent' => 3593,
    ),
    array(
      'tid' => 3596,
      'name' => "2-naphthalene sulfonamides",
      'description' => "Organic aromatic compounds that contain a naphthalene moiety that carries a sulfonamide (or a derivative thereof) at the 1-position. Naphthalene is a bicyclic compound that is made up of two fused benzene ring.",
      'parent' => 3593,
    ),
    array(
      'tid' => 3597,
      'name' => "Naphthalene sulfonic acids and derivatives",
      'description' => "Organic aromatic compounds that contain a naphthalene moiety that carries a sulfonic acid group (or a derivative thereof) at one or more positions. Naphthalene is a bicyclic compound that is made up of two fused benzene ring.",
      'parent' => 23,
    ),
    array(
      'tid' => 3598,
      'name' => "1-naphthalene sulfonic acids and derivatives",
      'description' => "Organic aromatic compounds that contain a naphthalene moiety that carries a sulfonic acid group (or a derivative thereof) at the 1-position. Naphthalene is a bicyclic compound that is made up of two fused benzene ring.",
      'parent' => 3597,
    ),
    array(
      'tid' => 3599,
      'name' => "2-naphthalene sulfonic acids and derivatives",
      'description' => "Organic aromatic compounds that contain a naphthalene moiety that carries a sulfonic acid group (or a derivative thereof) at the 2-position. Naphthalene is a bicyclic compound that is made up of two fused benzene ring.",
      'parent' => 3597,
    ),
    array(
      'tid' => 3600,
      'name' => "1-naphthalene sulfonates",
      'description' => "Organic aromatic compounds that contain a naphthalene moiety that carries a sulfonic acid group at the 1-position. Naphthalene is a bicyclic compound that is made up of two fused benzene ring.",
      'parent' => 3310,
    ),
    array(
      'tid' => 3601,
      'name' => "2-naphthalene sulfonates",
      'description' => "Organic aromatic compounds that contain a naphthalene moiety that carries a sulfonic acid group at the 2-position. Naphthalene is a bicyclic compound that is made up of two fused benzene ring.",
      'parent' => 3310,
    ),
    array(
      'tid' => 3602,
      'name' => "2-bromoanilines",
      'description' => "Organic compounds that contain an aniline carrying a bromine atom at the C2-position.",
      'parent' => 284,
    ),
    array(
      'tid' => 3603,
      'name' => "1-bromo,2-chlorobenzenes",
      'description' => "Organic aromatic compounds that containing a benzene ring substituted at two adjacent carbon centers with a bromine atom and a chlorine atom, respectively. These atoms are the only halogen substituents of the benzene ring.",
      'parent' => 3664,
    ),
    array(
      'tid' => 3604,
      'name' => "Ceramide 2-N-methylaminoethylphosphonates",
      'description' => "Phosphonosphingolipids consisting of a ceramide skeleton, which conjugated to the phosphonate moiety of a N-methyl linked 2-aminoethylphosphonate group.",
      'parent' => 3391,
    ),
    array(
      'tid' => 3605,
      'name' => "Ceramide aminoethylphosphonates",
      'description' => "Phosphonosphingolipids consisting of a ceramide skeleton, which conjugated to a 2-aminoethylphosphonate group.",
      'parent' => 3391,
    ),
    array(
      'tid' => 3606,
      'name' => "Thio-lactosylceramides",
      'description' => "Glycosphingolipids with a structure containing a ceramide skeleton that is S-glycosidically linked to a lactose moiety.",
      'parent' => 3258,
    ),
    array(
      'tid' => 3607,
      'name' => "1-azafluoranthenes",
      'description' => "Organic compounds of the alkaloid family that contains a indeno[1,2,3-ij]isoquinoline nucleus.",
      'parent' => 279,
    ),
    array(
      'tid' => 3608,
      'name' => "Organic anions",
      'description' => "Organic compounds that have a negative electric charge.",
      'parent' => 0,
    ),
    array(
      'tid' => 3609,
      'name' => "Organic cations",
      'description' => "Organic compounds with a positive electric charge.",
      'parent' => 0,
    ),
    array(
      'tid' => 3610,
      'name' => "Organic zwitterions",
      'description' => "Organic neutral compounds having formal unit electrical charges of opposite sign.",
      'parent' => 0,
    ),
    array(
      'tid' => 3611,
      'name' => "Inorganic anions",
      'description' => "Inorganic compounds that have a negative electric charge.",
      'parent' => 1568,
    ),
    array(
      'tid' => 3612,
      'name' => "Inorganic cations",
      'description' => "Inorganic compounds with a positive electric charge.",
      'parent' => 1568,
    ),
    array(
      'tid' => 3613,
      'name' => "Inorganic zwitterions",
      'description' => "Inorganic neutral compounds having formal unit electrical charges of opposite sign.",
      'parent' => 1568,
    ),
    array(
      'tid' => 3614,
      'name' => "1,2-diacyl-sn-glycerol-3(2'-aminoethyl)phosphonates",
      'description' => "Lipids that contain an aminoethylphosphonate group attached at a C3 carbon of a 1,2-diacylglycerol backbone.",
      'parent' => 3618,
    ),
    array(
      'tid' => 3615,
      'name' => "1,2-diacyl-sn-glycerol-3(2'-aminopropyl)phosphonates",
      'description' => "Lipids that contain an aminopropylphosphonate group attached at a C3 carbon of a 1,2-diacylglycerol backbone.",
      'parent' => 3616,
    ),
    array(
      'tid' => 3616,
      'name' => "Glycerophosphonolipids",
      'description' => "Lipids that contain a phosphonate group attached at a terminal carbon of a glycerol backbone.",
      'parent' => 12,
    ),
    array(
      'tid' => 3617,
      'name' => "Glycerol-3-phosphonocholines",
      'description' => "Lipids that contain a phosphonocholine group linked to the C3 terminal carbon of a glycerol moiety.",
      'parent' => 3620,
    ),
    array(
      'tid' => 3618,
      'name' => "Glycerol-3-phosphonoethanolamines",
      'description' => "Lipids that contain a phosphonoethanolamine group linked to the C3 terminal carbon of a glycerol moiety.",
      'parent' => 3621,
    ),
    array(
      'tid' => 3619,
      'name' => "1,2-diacyl-sn-glycerol-3(2'-trimethylaminoethyl)phosphonates",
      'description' => "Lipids that contain an trimethylaminoethylphosphonate group attached at a C3 carbon of a 1,2-diacylglycerol backbone.",
      'parent' => 3617,
    ),
    array(
      'tid' => 3620,
      'name' => "Glycerophosphonocholines",
      'description' => "Lipids that contain a phosphonocholine group linked to a terminal carbon of a glycerol moiety.",
      'parent' => 3616,
    ),
    array(
      'tid' => 3621,
      'name' => "Glycerophosphonoethanolamines",
      'description' => "Lipids that contain a phosphonoethanolamine group linked to a terminal carbon of a glycerol moiety.",
      'parent' => 3616,
    ),
    array(
      'tid' => 3622,
      'name' => "Carbonyl ylides",
      'description' => "1,3-Dipolar  Compounds having the general structure R1C(R2)=[O+][C-](R3)R4 or R1[C+](R2)O[C-](R3)R4.",
      'parent' => 3701,
    ),
    array(
      'tid' => 3623,
      'name' => "1,2-dithiole-3-ones",
      'description' => "Organic heterocyclic compounds containing a 1,2-dithiole ring that bears a C=O group.",
      'parent' => 3624,
    ),
    array(
      'tid' => 3624,
      'name' => "1,2-dithioles",
      'description' => "Compounds containing a 5-membered unsaturated ring with three carbon atoms and two adjacent sulfur atoms.",
      'parent' => 2090,
    ),
    array(
      'tid' => 3625,
      'name' => "1,3-dithioles",
      'description' => "Compounds containing a 5-membered unsaturated ring with three carbon atoms, and two sulfur atoms at the 1- and 3-positions, respectively.",
      'parent' => 2090,
    ),
    array(
      'tid' => 3626,
      'name' => "Enoate esters",
      'description' => "An alpha,beta-unsaturated carboxylic ester of general formula R1C(R2)=C(R3)C(=O)OR4 (R4= organyl compound) in which the ester C=O function is conjugated to a C=C double bond at the alpha,beta position.",
      'parent' => 3628,
    ),
    array(
      'tid' => 3627,
      'name' => "Ynoate esters",
      'description' => "An alpha,beta-unsaturated carboxylic ester of general formula R1C#CC(=O)OR2 (R2= organyl compound) in which the ester C=O function is conjugated to a C#C double bond at the alpha,beta position.",
      'parent' => 3628,
    ),
    array(
      'tid' => 3628,
      'name' => "Alpha,beta-unsaturated carboxylic esters",
      'description' => "Carboxylic esters of general structure R1C(R2)=C(R3)C(=O)OR4 (R4= organyl compound) or R1C#CC(=O)OR2 (R2= organyl compound), in which the ester group is conjugated to an unsaturated C-C bond.",
      'parent' => 1238,
    ),
    array(
      'tid' => 3629,
      'name' => "Carbenes",
      'description' => "The electrically neutral species H2C and its derivatives, in which the carbon is covalently bonded to two univalent groups of any kind or a divalent group and bears two non-bonding electrons, which may be spin-paired (singlet state) or spin-non-paired (triplet state). Subclasses of carbenes include acyl carbenes, imidoyl carbenes, and vinyl carbenes.",
      'parent' => 0,
    ),
    array(
      'tid' => 3630,
      'name' => "Organic 1,3-dipolar compounds",
      'description' => "Electrically neutral organic molecules carrying a positive and a negative charge in one of their major canonical descriptions. In most dipolar compounds the charges are delocalized; however the term is also applied to species where this is not the case. The term 1,3-dipolar compounds is used for those in which a significant canonical resonance form can be represented by a separation of charge over three atoms (in connection with 1,3-dipolar cycloadditions).",
      'parent' => 0,
    ),
    array(
      'tid' => 3631,
      'name' => "Allyl-type 1,3-dipolar organic compounds",
      'description' => "Organic 1,3-dipolar compounds with the general structure  X=Y+-Z- <-> X--Y+=Z<-> X+-Y-Z-<-> X-=Y-Z+ (X, Z = C, N, or O; Y = N or O).",
      'parent' => 3630,
    ),
    array(
      'tid' => 3632,
      'name' => "Carbene-type 1,3-dipolar compounds",
      'description' => "1,3-dipolar compounds with the general structure X:-C=Z<-> X+=C-Z- (X = C or N; Z = C, N, or O).",
      'parent' => 3630,
    ),
    array(
      'tid' => 3633,
      'name' => "Propargyl-type 1,3-dipolar organic compounds",
      'description' => "Organic 1,3-dipolar compounds with the general structure  X#N+-Z- <-> X-=N+=Z <-> X-=N-Z+ <-> X-N=Z (X = C or O, Z = C, N, or O).",
      'parent' => 3630,
    ),
    array(
      'tid' => 3634,
      'name' => "Acyl carbenes",
      'description' => "Any compound with the general structure acyl-C:-R. In organic chemistry, an unspecified acyl carbene is commonly a carboxylic acyl carbene RC(=O)-C:-R.",
      'parent' => 3632,
    ),
    array(
      'tid' => 3635,
      'name' => "Imidoyl carbenes",
      'description' => "Carbenes having the structure RC(=NR)C:-R.",
      'parent' => 3632,
    ),
    array(
      'tid' => 3636,
      'name' => "Vinyl carbenes",
      'description' => "Carbenes having a vinylic group on a carbenic carbon atom R2C=CRC:R <-> R2C+-CR=C-R.",
      'parent' => 3632,
    ),
    array(
      'tid' => 3637,
      'name' => "Flav-3-enes",
      'description' => "Flavonoids with a structure based on the 2-phenylchromene skeleton, with a double bond between the C3 and C4 carbon atoms of the chromene moiety.",
      'parent' => 334,
    ),
    array(
      'tid' => 3638,
      'name' => "3-prenylated flav-3-enes",
      'description' => "Flav3-enes that features a C5-isoprenoid substituent at the 3-position.",
      'parent' => 3637,
    ),
    array(
      'tid' => 3639,
      'name' => "3-prenylated flavans",
      'description' => "Flavans that features a C5-isoprenoid substituent at the 3-position.",
      'parent' => 337,
    ),
    array(
      'tid' => 3640,
      'name' => "4-prenylated flavans",
      'description' => "Flavans that features a C5-isoprenoid substituent at the 4-position.",
      'parent' => 337,
    ),
    array(
      'tid' => 3641,
      'name' => "7-prenylated flavans",
      'description' => "Flavans that features a C5-isoprenoid substituent at the 7-position.",
      'parent' => 337,
    ),
    array(
      'tid' => 3642,
      'name' => "8-prenylated flavans",
      'description' => "Flavans that features a C5-isoprenoid substituent at the 8-position.",
      'parent' => 337,
    ),
    array(
      'tid' => 3643,
      'name' => "3'-prenylated flavans",
      'description' => "Flavans that features a C5-isoprenoid substituent at the 3'-position.",
      'parent' => 337,
    ),
    array(
      'tid' => 3644,
      'name' => "4'-prenylated flavans",
      'description' => "Flavans that features a C5-isoprenoid substituent at the 4'-position.",
      'parent' => 337,
    ),
    array(
      'tid' => 3645,
      'name' => "2'-prenylated flavans",
      'description' => "Flavans that features a C5-isoprenoid substituent at the 2'-position.",
      'parent' => 337,
    ),
    array(
      'tid' => 3646,
      'name' => "6-prenylated flavans",
      'description' => "Flavans that features a C5-isoprenoid substituent at the 6-position.",
      'parent' => 337,
    ),
    array(
      'tid' => 3647,
      'name' => "7-prenylated flavanones",
      'description' => "Flavanones that features a C5-isoprenoid substituent at the 7-position.",
      'parent' => 3641,
    ),
    array(
      'tid' => 3648,
      'name' => "4-prenylated flavanones",
      'description' => "Flavanones that features a C5-isoprenoid substituent at the 4-position.",
      'parent' => 3644,
    ),
    array(
      'tid' => 3649,
      'name' => "5-prenylated 2-arybenzofurans",
      'description' => "2-arylbenzofuran flavonoids featuring a C5-isoprenoid unit at the 5-position.",
      'parent' => 3405,
    ),
    array(
      'tid' => 3650,
      'name' => "Prenylated neoflavonoids",
      'description' => "Neoflavonoids that features a C5-isoprenoid substituent at any position of the A, B, or C ring. Neoflavonoids are compounds with a structure based on the 4-phenylchromene backbone.",
      'parent' => 1614,
    ),
    array(
      'tid' => 3651,
      'name' => "3'-hydroxy,4'-methoxyisoflavonoids",
      'description' => "Isoflavonoids carrying a methoxy group attached to the C4' atom, as well as a hydroxyl group at the C3'-position of the isoflavonoid backbone.",
      'parent' => 2606,
    ),
    array(
      'tid' => 3652,
      'name' => "Pyranoneoflavonoids",
      'description' => "Compounds containing a pyran ring fused to either ring A, B, or C of the neoflavonoid skeleton. Neoflavonoids are compounds with a structure based on the 4-phenylchromene backbone.",
      'parent' => 1614,
    ),
    array(
      'tid' => 3653,
      'name' => "1,1'-azonaphthalenes",
      'description' => "Organonitrogen aromatic compounds that contain a central azo group, where each nitrogen atom is conjugated to the 1-position of a naphthalene ring system. Naphthalene is a compound made up of two fused benzene rings.",
      'parent' => 23,
    ),
    array(
      'tid' => 3654,
      'name' => "Molybdopterin dinucleotides",
      'description' => "A dinucleotide that is made up of a molybdopterin and a purine or pyrimidine base linked to each other through a phosphate chain.",
      'parent' => 289,
    ),
    array(
      'tid' => 3655,
      'name' => "Eremophilane, 8,9-secoeremophilane and furoeremophilane sesquiterpenoids",
      'description' => "Sesquiterpenoids with a structure based either on the eremophilane skeleton, its 8,9-seco derivative, or the furoeremophilane skeleton. Eremophilanes have been shown to be derived from eudesmanes by migration of the methyl group at C-10 to C-5.",
      'parent' => 1550,
    ),
    array(
      'tid' => 3656,
      'name' => "Alkyl-CoA disulfides",
      'description' => "Compounds containing an S-alkyl group linked to the S-end of the coenzyme A moiety.",
      'parent' => 12,
    ),
    array(
      'tid' => 3657,
      'name' => "3-MCPD diesters",
      'description' => "Compounds containing a 3-monochloropropane-1,2-diol skeleton that is esterified at the C1 and C3 terminal carbon atoms.",
      'parent' => 1725,
    ),
    array(
      'tid' => 3658,
      'name' => "Sn1-3-MCPD monoesters",
      'description' => "Compounds containing a 3-monochloropropane-1,2-diol skeleton that is esterified at the C1 terminal carbon atom only.",
      'parent' => 1726,
    ),
    array(
      'tid' => 3659,
      'name' => "Sn2-3-MCPD monoesters",
      'description' => "Compounds containing a 3-monochloropropane-1,2-diol skeleton that is esterified at the C2 terminal carbon atom only.",
      'parent' => 1726,
    ),
    array(
      'tid' => 3660,
      'name' => "Sn1-2-MCPD monoesters",
      'description' => "Compounds containing a 2-monochloropropane-1,3-diol skeleton that is esterified at the C1 terminal carbon atom only.",
      'parent' => 1725,
    ),
    array(
      'tid' => 3661,
      'name' => "2-MCPD diesters",
      'description' => "Compounds containing a 2-monochloropropane-1,3-diol skeleton that is esterified at the C1 and C3 terminal carbon atoms.",
      'parent' => 1725,
    ),
    array(
      'tid' => 3662,
      'name' => "Organic phosphoric acid diamides",
      'description' => "Organophosphorus compounds with the general formula RNP(R2)(O)=O (R=alkyl, aryl; R2 = amine group).",
      'parent' => 1204,
    ),
    array(
      'tid' => 3663,
      'name' => "Dimethoxybenzyl-N-methylpiperazines",
      'description' => "Organic aromatic compounds containing a piperazine ring that carries a methyl group on one amine group and a dimethoxybenzyl moiety on the other amine group.",
      'parent' => 3358,
    ),
    array(
      'tid' => 3664,
      'name' => "1,2-dihalobenzenes",
      'description' => "Organic compounds that contain a benzene ring that is substituted by halogen atoms at exactly two carbon atoms, which are adjacent.",
      'parent' => 35,
    ),
    array(
      'tid' => 3665,
      'name' => "1,3-dihalobenzenes",
      'description' => "Organic compounds that contain a benzene ring that is substituted by halogen atoms at exactly two carbon atoms, C1 and C3, respectively.",
      'parent' => 35,
    ),
    array(
      'tid' => 3666,
      'name' => "1,4-dihalobenzenes",
      'description' => "Organic compounds that contain a benzene ring that is substituted by halogen atoms at exactly two carbon atoms, C1 and C4, respectively.",
      'parent' => 35,
    ),
    array(
      'tid' => 3667,
      'name' => "Inorganic 1,3-dipolar compounds",
      'description' => "Electrically neutral inorganic molecules carrying a positive and a negative charge in one of their major canonical descriptions. In most dipolar compounds the charges are delocalized; however the term is also applied to species where this is not the case. The term 1,3-dipolar compounds is used for those in which a significant canonical resonance form can be represented by a separation of charge over three atoms (in connection with 1,3-dipolar cycloadditions).",
      'parent' => 1568,
    ),
    array(
      'tid' => 3668,
      'name' => "Allyl-type 1,3-dipolar inorganic compounds",
      'description' => "Inorganic 1,3-dipolar compounds with the general structure  X=Y+-Z- <-> X--Y+=Z<-> X+-Y-Z-<-> X-=Y-Z+ (X, Z = N, or O; Y = N or O).",
      'parent' => 3667,
    ),
    array(
      'tid' => 3669,
      'name' => "Propargyl-type 1,3-dipolar inorganic compounds",
      'description' => "1,3-dipolar compounds with the general structure  X#N+-Z- <-> X-=N+=Z <-> X-=N-Z+ <-> X-N=Z (X =O, Z =N, or O).",
      'parent' => 3667,
    ),
    array(
      'tid' => 3670,
      'name' => "Aryl ketones",
      'description' => "Organic aromatic compounds that contain a ketone group substituted at one C-atom with an aryl group. They have the generic structure RC(=O)R', where R = aryl group and R'=organyl group.",
      'parent' => 118,
    ),
    array(
      'tid' => 3671,
      'name' => "Aryl alkyl ketones",
      'description' => "Ketones have the generic structure RC(=O)R', where R = aryl group and R'=alkyl group.",
      'parent' => 3670,
    ),
    array(
      'tid' => 3672,
      'name' => "Alpha,beta-unsaturated ketones",
      'description' => "Ketones with the general structure R#CC(=O)R' or R=CC(=O)R', where R=organyl and R'= organyl group.",
      'parent' => 3131,
    ),
    array(
      'tid' => 3673,
      'name' => "b'-hydroxy-alpha,beta-unsaturated ketones",
      'description' => "Alpha,beta-unsaturated ketones that carry a hydroxyl group at the beta'-position.",
      'parent' => 3672,
    ),
    array(
      'tid' => 3674,
      'name' => "Alpha-branched alpha,beta-unsaturated ketones",
      'description' => "Alpha,beta-unsaturated ketones that carry a branch on the alpha carbon. They have the generic structure RC(=O)C(R')=C, R = organyl group and R'= any heteroatom.",
      'parent' => 3672,
    ),
    array(
      'tid' => 3675,
      'name' => "Alpha-hydroxyaldehydes",
      'description' => "Organic compounds containing an aldehyde substituted with a hydroxyl group on the adjacent carbon.",
      'parent' => 124,
    ),
    array(
      'tid' => 3676,
      'name' => "Enol ester epoxides",
      'description' => "Epoxide containing derivatives of enol esters. They have an acyloxy substituent on either carbon atom of the epoxide ring and their general structure is CC1OC1OC(R)=O, R = H or organyl chain.",
      'parent' => 159,
    ),
    array(
      'tid' => 3677,
      'name' => "Alpha-acyloxy carbonyl compounds",
      'description' => "Carbonyl compounds that have an acyloxy substituent alpha to the carbonyl group. They have the general structure R4C(=O)OC(R2)(R3)C(R1)=O (R1,R4=H or organyl; R2,R3 = any atom).",
      'parent' => 1831,
    ),
    array(
      'tid' => 3678,
      'name' => "Flavonoid 3-O-p-coumaroyl glycosides",
      'description' => "Flavonoid 3-O-glycosides where the carbohydrate moiety is esterified with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 1583,
    ),
    array(
      'tid' => 3679,
      'name' => "Flavonoid 5-O-p-coumaroyl glycosides",
      'description' => "Flavonoid 5-O-glycosides where the carbohydrate moiety is esterified with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 1583,
    ),
    array(
      'tid' => 3680,
      'name' => "Flavonoid 7-O-p-coumaroyl glycosides",
      'description' => "Flavonoid 7-O-glycosides where the carbohydrate moiety is esterified with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 1583,
    ),
    array(
      'tid' => 3681,
      'name' => "Flavonoid 3p-O-p-coumaroyl glycosides",
      'description' => "Flavonoid 3p-O-glycosides where the carbohydrate moiety is esterified with a p-coumaric acid. P-coumaric acid is an organic derivative of cinnamic acid, that carries a hydroxyl group at the 4-position of the benzene ring.",
      'parent' => 1583,
    ),
    array(
      'tid' => 3682,
      'name' => "Thioflavones",
      'description' => "Organic compounds that contains the 2-phenyl-4H-1-benzothiopyran-4-one skeleton, which consists of a 1-benzothiopyran-4-one substituted at the 2-position by a phenyl group. These compounds are thio analogues of flavones.",
      'parent' => 3413,
    ),
    array(
      'tid' => 3683,
      'name' => "Thioflavans",
      'description' => "Compounds containing a thiochromane skeleton substituted at the 2-position with a phenyl group.",
      'parent' => 2834,
    ),
    array(
      'tid' => 3684,
      'name' => "2,5-dioxopiperazines",
      'description' => "Organic heterocyclic compounds that contain a piperazine with the oxo groups at the 2- and 5-positions. Piperazine is a six-membered heterocyclic compound consisting of two nitrogen atoms and four carbon atoms.",
      'parent' => 1731,
    ),
    array(
      'tid' => 3685,
      'name' => "Alpha-acyloxy aldehydes",
      'description' => "Aldehydes that have an acyloxy substituent alpha to the carbonyl group. They have the general structure R4C(=O)OC(R2)(R3)C(R1)=O (R1=H, R4=H or organyl; R2,R3 = any atom).",
      'parent' => 3677,
    ),
    array(
      'tid' => 3686,
      'name' => "Furanoid lignans",
      'description' => "Lignans with a structure that contains either a tetrahydrofuran ring, a furan ring, or a furofuan ring system, that arises from the joining of the two phenylpropanoid units.",
      'parent' => 1392,
    ),
    array(
      'tid' => 3687,
      'name' => "Nitrile oxides",
      'description' => "Ylides having the structure RC#[N+][O-] or R[C-]=[N+]=O.",
      'parent' => 3633,
    ),
    array(
      'tid' => 3688,
      'name' => "Diazo compounds",
      'description' => "Organic compounds having the divalent diazo group, =N+=N-, attached to a carbon atom.",
      'parent' => 3633,
    ),
    array(
      'tid' => 3689,
      'name' => "Nitrile sulfides",
      'description' => "Sulfur analogues of nitrile oxides with the general structure RC#[N+][S-] or R[C-]=[N+]=S.",
      'parent' => 278,
    ),
    array(
      'tid' => 3690,
      'name' => "Pyrido[3,4-c]pyridazines",
      'description' => "Organic compounds containing a pyrido[3,4-c]pyridazine moiety. Pyrido[3,4-c]pyridazine is a 10-membered bicyclic compound made up of a pyran ring fused to a pyridazine ring so that the three nitrogen atoms are located at the 1-, 2-, and 8-position, respectively.",
      'parent' => 2,
    ),
    array(
      'tid' => 3691,
      'name' => "Diselenins",
      'description' => "Organic heterocyclic compounds containing a diselenin ring. Diselenin is a six-membered heterocyclic with for carbon atoms and two selenium atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 3692,
      'name' => "1,2-diselenins",
      'description' => "Organic heterocyclic compounds containing a 1,2-diselenin ring. Diselenin is a six-membered heterocyclic with for carbon atoms, and two selenium atoms at the 1- and 2-position.",
      'parent' => 3691,
    ),
    array(
      'tid' => 3693,
      'name' => "1,3-diselenins",
      'description' => "Organic heterocyclic compounds containing a 1,3-diselenin ring. Diselenin is a six-membered heterocyclic with for carbon atoms, and two selenium atoms at the 1- and 3-position.",
      'parent' => 3691,
    ),
    array(
      'tid' => 3694,
      'name' => "1,4-diselenins",
      'description' => "Organic heterocyclic compounds containing a 1,4-diselenin ring. Diselenin is a six-membered heterocyclic with for carbon atoms, and two selenium atoms at the 1- and 4-position.",
      'parent' => 3691,
    ),
    array(
      'tid' => 3695,
      'name' => "Nitrile selenides",
      'description' => "Organonitrogen compounds containing a nitrogen-selenium bond. They have the general structure R-C#NSe, where R = any atom.",
      'parent' => 278,
    ),
    array(
      'tid' => 3696,
      'name' => "Selenanthrenes",
      'description' => "Organic compounds containing a selenanthrene moiety. Selenanthrene  is a tricyclic ring system that consists of two benzene rings fused to each other  through a 1,4-selenine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 3697,
      'name' => "Pyrano[3,4-c]pyridazines",
      'description' => "Organic compounds containing a pyrano[3,4-c]pyridazine moiety. Pyrano[3,4-c]pyridazine is a 10-membered bicyclic compound made up of a pyran ring fused to a pyridazine ring so that the two nitrogen atoms and the oxygen atom are located at the 1-, 2-, and 8-position, respectively.",
      'parent' => 2,
    ),
    array(
      'tid' => 3698,
      'name' => "Tyrosols",
      'description' => "Organic aromatic compounds containing a phenethyl alcohol moiety that carries a hydroxyl group at the 4-position of the benzene group.",
      'parent' => 139,
    ),
    array(
      'tid' => 3699,
      'name' => "Organic thionylimides",
      'description' => "Organic compounds that contain the thionylimide group (N=S=O).",
      'parent' => 278,
    ),
    array(
      'tid' => 3700,
      'name' => "Inorganic thionylimides",
      'description' => "Inorganic compounds that contain the thionylimide group (N=S=O).",
      'parent' => 1568,
    ),
    array(
      'tid' => 3701,
      'name' => "Oxonium ylides",
      'description' => "Compounds having the general structure R2[O+]-C-R2. Oxonium ylides also constituted a class of 1,3-dipolar compounds of general structure R2C=[O+]-Y- , comprising carbonyl imides, carbonyl oxides and carbonyl ylides.",
      'parent' => 3631,
    ),
    array(
      'tid' => 3702,
      'name' => "Pyranosyl nitrile oxides",
      'description' => "Nitrile oxides that are C-glycosylated to a pyranose.",
      'parent' => 2204,
    ),
    array(
      'tid' => 3703,
      'name' => "2-pyranosylbenzoxazoles",
      'description' => "Nucleoside and nucleotide analogs with a structure that consists of a benzoxazole base which is N-substituted at the 2-position with a pyranose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the pyranose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3704,
      'name' => "2-pyranosylbenzothiazoles",
      'description' => "Nucleoside and nucleotide analogs with a structure that consists of a benzothiazole base which is N-substituted at the 2-position with a pyranose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the pyranose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3705,
      'name' => "2-ribofuranosylbenzimidazoles",
      'description' => "Nucleoside and nucleotide analogs with a structure that consists of a benzimidazole ring system which is N-substituted at the 2-position with a ribose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the furanose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3706,
      'name' => "2-pyranosylbenzimidazoles",
      'description' => "Nucleoside and nucleotide analogs with a structure that consists of a benzimidazole which is N-substituted at the 2-position with a pyranose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the pyranose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3707,
      'name' => "Furo[3,2-d]pyrimidine glycosides",
      'description' => "Nucleosides or derivatives thereof that consist of a furo[3,2-d]pyrimidine ring system that is N-glycosidically linked to a ribose or deoxyribose. They bear the sugar moiety on the pyrimidine part of the molecule.",
      'parent' => 289,
    ),
    array(
      'tid' => 3708,
      'name' => "1-pyranosylbenzimidazoles",
      'description' => "Nucleoside and nucleotide analogs with a structure that consists of a Benzimidazole which is N-substituted at the 1-position with a pyranose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the pyranose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3709,
      'name' => "2-ribofuranosylbenzotriazoles",
      'description' => "Nucleoside and nucleotide analogs with a structure that consists of a benzotriazole ring system which is N-substituted at the 2-position with a ribose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the furanose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3710,
      'name' => "1-pyranosylbenzotriazoles",
      'description' => "Nucleoside and nucleotide analogs with a structure that consists of a Benzotriazole which is N-substituted at the 1-position with a pyranose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the pyranose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3711,
      'name' => "2-pyranosylbenzotriazoles",
      'description' => "Nucleoside and nucleotide analogs with a structure that consists of a benzotriazole base which is N-substituted at the 2-position with a pyranose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the pyranose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3712,
      'name' => "2-ribofuranosylindazoles",
      'description' => "Nucleoside and nucleotide analogs with a structure that consists of an indazole ring system which is N-substituted at the 2-position with a ribose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the furanose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3713,
      'name' => "1-pyranosylindazoles",
      'description' => "Nucleoside and nucleotide analogs with a structure that consists of an indazole which is N-substituted at the 1-position with a pyranose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the pyranose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3714,
      'name' => "2-pyranosylindazoles",
      'description' => "Nucleoside and nucleotide analogs with a structure that consists of an indazole base which is N-substituted at the 2-position with a pyranose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the pyranose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3715,
      'name' => "1-pyranosylindoles",
      'description' => "Nucleoside and nucleotide analogs with a structure that consists of an indole base which is N-substituted at the 1-position with a pyranose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the pyranose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3716,
      'name' => "3-ribofuranosylpyrazoles",
      'description' => "Nucleoside and nucleotide analogs with a structure that consists of a pyrazole ring system which is N-substituted at the 3-position with a ribose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the furanose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3717,
      'name' => "1,2-substituted cyclopentyl purine nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a hydroxyl group and at the 2-position with either a purine base.",
      'parent' => 3739,
    ),
    array(
      'tid' => 3718,
      'name' => "1,3-substituted cyclopentyl purine nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a hydroxyl group and at the 3-position with either a purine base.",
      'parent' => 3740,
    ),
    array(
      'tid' => 3719,
      'name' => "1,2-substituted cyclopentyl pyrimidine nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a hydroxyl group and at the 2-position with either a pyrimidine base.",
      'parent' => 3739,
    ),
    array(
      'tid' => 3720,
      'name' => "1,3-substituted cyclopentyl pyrimidine nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a hydroxyl group and at the 3-position with either a pyrimidine base.",
      'parent' => 3740,
    ),
    array(
      'tid' => 3721,
      'name' => "Cyclopropyl purine nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclopropane that is substituted a the 1-position with a hydroxyl group and at the 2- position with either a purine base.",
      'parent' => 3741,
    ),
    array(
      'tid' => 3722,
      'name' => "Cyclopropyl pyrimidine nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclopropane that is substituted a the 1-position with a hydroxyl group and at the 2- position with either a pyrimidine base.",
      'parent' => 3741,
    ),
    array(
      'tid' => 3723,
      'name' => "Cyclobutyl nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a hydroxyl group and at the 3- position with either a purine or pyrimidine base.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3724,
      'name' => "Phosphonated cyclopentyl nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a phosphonate group, and at the 2- or the 3- position with either a purine or pyrimidine base.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3725,
      'name' => "Acyclic 2,4-diaminopyrimidine nucleoside phosphonates",
      'description' => "Pyrimidine nucleoside analogues with a structure that is characterized by a phosphonylmethoxyethoxyl group that is linked to the N1 atom of a 2,4-diaminopyrimidine.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3726,
      'name' => "Acyclic purine nucleoside phosphonates",
      'description' => "Purine nucleoside analogues with a structure that is characterized by a phosphonylmethoxyethoxyl group that is linked to the N1 atom of a purine.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3727,
      'name' => "Phosphonated cyclopropyl purine nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a phosphonate group and at the 2-position with either a purine base.",
      'parent' => 3744,
    ),
    array(
      'tid' => 3728,
      'name' => "Phosphonated cyclopropyl pyrimidine nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a phosphonate group and at the 2-position with either a pyrimidine base.",
      'parent' => 3744,
    ),
    array(
      'tid' => 3729,
      'name' => "1,2-substituted phosphonated cyclopentyl purine nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a phosphonate group, and at the 2-position with either a purine base.",
      'parent' => 3742,
    ),
    array(
      'tid' => 3730,
      'name' => "1,2-substituted phosphonated cyclopentyl pyrimidine nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a phosphonate group, and at the 2-position with either a pyrimidine base.",
      'parent' => 3742,
    ),
    array(
      'tid' => 3731,
      'name' => "1,3-substituted phosphonated cyclopentyl purine nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a phosphonate group, and at the 3-position with either a purine base.",
      'parent' => 3743,
    ),
    array(
      'tid' => 3732,
      'name' => "1,3-substituted phosphonated cyclopentyl pyrimidine nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a phosphonate group, and at the 3-position with either a  pyrimidine base.",
      'parent' => 3743,
    ),
    array(
      'tid' => 3733,
      'name' => "Phosphonated 2'-oxa,3'-aza purine nucleosides",
      'description' => "Nucleoside and nucleotide analogues with a structure that consists of a purine base, which N-substituted at the 1-position with a 3'-aza derivative  (1,3-oxazolidine) of the ribose moiety that is characteristic of nucleosides. Moreover, a phosphonate group s attached to the  C4-atom of the resulting 1.3-oxazolidine.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3734,
      'name' => "Phosphonated 2'-oxa,3'-aza pyrimidine nucleosides",
      'description' => "Nucleoside and nucleotide analogues with a structure that consists of a pyrimidine base, which is N-substituted at the 1-position with a 3'-aza derivative  (1,3-oxazolidine) of the ribose moiety that is characteristic of nucleosides. Moreover, a phosphonate group s attached to the  C4-atom of the resulting 1.3-oxazolidine.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3735,
      'name' => "C2-linked imidazole ribonucleosides and ribonucleotides",
      'description' => "Nucleoside and nucleotide analogues with a structure that consists of an imidazole ring system which is substituted at the C2-position with a ribose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the furanose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3736,
      'name' => "C4-linked imidazole ribonucleosides and ribonucleotides",
      'description' => "Nucleoside and nucleotide analogues with a structure that consists of an imidazole ring system which is substituted at the C4-position with a ribose moiety. Nucleotide analogues contain a phosphate group linked to the C5 carbon atom of the furanose.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3737,
      'name' => "Nucleoside and nucleotide analogues",
      'description' => "Analogues of nucleosides and nucleotides. These include phosphonated nucleosides, C-glycosylated nucleoside bases, analogues where the sugar unit is a pyranose, and carbocyclic nucleosides, among others.",
      'parent' => 289,
    ),
    array(
      'tid' => 3738,
      'name' => "Cyclopentyl nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a hydroxyl group and at the 2- or the 3- position with either a purine or pyrimidine base.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3739,
      'name' => "1,2-substituted cyclopentyl nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclopentane that is substituted a the 1-position with a hydroxyl group and at the 2-position with either a purine or pyrimidine base.",
      'parent' => 3738,
    ),
    array(
      'tid' => 3740,
      'name' => "1,3-substituted cyclopentyl nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a hydroxyl group and at the 3-position with either a purine or pyrimidine base.",
      'parent' => 3738,
    ),
    array(
      'tid' => 3741,
      'name' => "Cyclopropyl nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclopropane that is substituted a the 1-position with a hydroxyl group and at the 2- position with either a purine or pyrimidine base.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3742,
      'name' => "1,2-substituted phosphonated cyclopentyl nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a phosphonate group, and at the 2-position with either a purine or pyrimidine base.",
      'parent' => 3724,
    ),
    array(
      'tid' => 3743,
      'name' => "1,3-substituted phosphonated cyclopentyl nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a phosphonate group, and at the 3-position with either a purine or pyrimidine base.",
      'parent' => 3724,
    ),
    array(
      'tid' => 3744,
      'name' => "Phosphonated cyclopropyl nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a cyclobutane that is substituted a the 1-position with a phosphonate group and at the 2-position with either a purine or pyrimidine base.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3745,
      'name' => "Pyrano[3,2-d]pyrimidine glycosides",
      'description' => "Nucleosides or derivatives thereof that consist of a pyrano[3,2-d]pyrimidine ring system that is N-glycosidically linked to a ribose or deoxyribose. They bear the sugar moiety on the pyrimidine part of the molecule.",
      'parent' => 289,
    ),
    array(
      'tid' => 3746,
      'name' => "3'-thia pyrimidine nucleosides",
      'description' => "Nucleoside analogues with a structure that consists of a pyrimidine base, which is N-substituted at the 1-position with a 3'-thia derivative  (1,3-oxazolidine) of the ribose moiety that is characteristic of nucleosides.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3747,
      'name' => "Furo[3,4-d]pyrimidine glycosides",
      'description' => "Nucleosides or derivatives thereof that consist of a furo[3,4-d]pyrimidine ring system that is N-glycosidically linked to a ribose or deoxyribose. They bear the sugar moiety on the pyrimidine part of the molecule.",
      'parent' => 289,
    ),
    array(
      'tid' => 3748,
      'name' => "Thieno[2,3-d]pyrimidine glycosides",
      'description' => "Nucleosides or derivatives thereof that consist of a thieno[2,3-d]pyrimidine ring system that is N-glycosidically linked to a ribose or deoxyribose.",
      'parent' => 289,
    ),
    array(
      'tid' => 3749,
      'name' => "v-triazolo[4,5-d]pyrimidine glycosides",
      'description' => "Nucleosides or derivatives thereof that consist of a v-triazolo[4,5-d]pyrimidine ring system that is N-glycosidically linked to a ribose or deoxyribose. They usually bear the sugar moiety on the pyrimidine part of the molecule.  Nucleotides have a phosphate group linked to the C5 carbon of the ribose (or deoxyribose) moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 3750,
      'name' => "Pyrazolo[3,4-d]pyrimidine glycosides",
      'description' => "Nucleosides or derivatives thereof that consist of a pyazolo[3,2-d]pyrimidine ring system that is N-glycosidically linked to a ribose or deoxyribose. They bear the sugar moiety on the pyrimidine part of the molecule.",
      'parent' => 289,
    ),
    array(
      'tid' => 3751,
      'name' => "Pteridine nucleosides and nucleotides",
      'description' => "Nucleosides and derivatives with a structure that consists of a pteridine that is N-linked to a ribose or deoxyribose moiety. Nucleotides have a phosphate group linked to the C5 carbon of the ribose (or deoxyribose) moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 3752,
      'name' => "Cedrane and isocedrane sesquiterpenoids",
      'description' => "Sesquiternoids with a structure based on the cedrane or the isocedrane skeleton. Cedrane is a tricyclic molecules a 3,6,8,8-tetramethyl-1H-3a,7-methano-azulene moiety. Isocedrane is a rearranged cedrane arising from the migration of methyl group moved from the 6-position to the 4-position.",
      'parent' => 1550,
    ),
    array(
      'tid' => 3753,
      'name' => "12,13-diacylphorbols and derivatives",
      'description' => "Diterpenoids with a structure based on the phorbol skeleton that is acylated at the 12- and 13-position.",
      'parent' => 2906,
    ),
    array(
      'tid' => 3754,
      'name' => "Akageran and related alkaloids",
      'description' => "A small group of alkaloids typified by Akagerine, a tetracyclic compound that consist of a b-carboline fused to an azepine ring, which is substituted by a methyl group and a 2-methyl butane group. Akageran and related alkaloids appears to be formed by bond-breaking of a corynanthe precursor followed by formation of a 7-membered ring.",
      'parent' => 279,
    ),
    array(
      'tid' => 3755,
      'name' => "Aspidofractine alkaloids",
      'description' => "Alkaloids with a structure that is based on the hexacyclic aspidofractine core. These compounds are related to the Aspidosperma group by formation of a C-2 to C-18 bond.",
      'parent' => 279,
    ),
    array(
      'tid' => 3756,
      'name' => "Condylocarpan alkaloids",
      'description' => "Alkaloids with a structure based on the condylocarpan backbone. These alkaloids contain a ring system similar to that of the curan group, but are formed by cyclisation of C-21 on to C-7 in a Corynanthe precursor, rather than the formation of a 3,7 bond.",
      'parent' => 279,
    ),
    array(
      'tid' => 3757,
      'name' => "Ervatamia alkaloids",
      'description' => "Alkaloids with a structure based on the tetracyclic ervatamia skeleton, which arises from the 5,6- bond cleavage and 6,16- bond formation in the vobasine skeleton.",
      'parent' => 279,
    ),
    array(
      'tid' => 3758,
      'name' => "Gelsemium alkaloids",
      'description' => "Alkaloids with a structure that is based on the tetracyclic gelsemium skeleton. These alkaloids contain an oxindole function and a cage-like, hydroaromatic residue which is believed to arise from an intermediate related to anhydrovobasinediol by formation of a 6,20 bond and rearrangement to an oxindole. The major alkaloids in this group are related to Gelsemine; however, a smaller group, characterized by Gelsedine, lack the 6,20 bond, and have also lost C-21.",
      'parent' => 279,
    ),
    array(
      'tid' => 3759,
      'name' => "Macroline alkaloids",
      'description' => "Alkaloids with a structure that is based on the tetracyclic macroline skeleton. The macroline skeleton arises by scission of the C-21 to N-4 bond  of the akuammilan skeleton, and mostly occurs in bisindole alkaloids.",
      'parent' => 279,
    ),
    array(
      'tid' => 3760,
      'name' => "Pandoline alkaloids",
      'description' => "Alkaloids with a structure that is based on the pentacyclic pandoline skeleton. The Pandoline (pseudoaspidospermidine) (type II indole alkaloid) nucleus is believed to be formed by cyclisation of a secodine derivative.",
      'parent' => 279,
    ),
    array(
      'tid' => 3761,
      'name' => "Melodinus alkaloids",
      'description' => "Alkaloids with a structure that is based on the melodinus skeleton. This backbone is a  pentacyclic structure that contains a tetrahydroquinoline and an indolizine joined to each other through a cyclopentane.",
      'parent' => 279,
    ),
    array(
      'tid' => 3762,
      'name' => "Pleiocarpaman alkaloids",
      'description' => "Alkaloids with a structure that is based on the pleiocarpaman skeleton. These alkaloids arise from the cyclization of a corynantheine precursor via C-16 to N-1.",
      'parent' => 279,
    ),
    array(
      'tid' => 3763,
      'name' => "Schizozygine alkaloids",
      'description' => "Alkaloids with a structure based o the hexacyclic schizozygine skeleton, consisting of quinolizidine, indole, and piperidine.",
      'parent' => 279,
    ),
    array(
      'tid' => 3764,
      'name' => "Correantan alkaloids",
      'description' => "Alkaloids with a structure that is based on the correantan skeleton, which is a tetracyclic compound consisting of the seven-membered azepane ring fused to the pyridine moiety of a beta-carboline.",
      'parent' => 279,
    ),
    array(
      'tid' => 3765,
      'name' => "Kopsane alkaloids",
      'description' => "A group of compounds with a structure based on the heptacyclic kopsane skeleton, formed by attachment of C-22 (the methoxycarbonyl carbon) of Venalstonine to C-6.",
      'parent' => 279,
    ),
    array(
      'tid' => 3766,
      'name' => "Pyrichalasins",
      'description' => "Cytochalasans with a structure in which the hydrogenated isoindole bears p-methoxybenzyl group.",
      'parent' => 1821,
    ),
    array(
      'tid' => 3767,
      'name' => "Chaetoglobosins",
      'description' => "Cytochalasans with a structure in which the hydrogenated isoindole bears an (indol-3-yl)methyl group.",
      'parent' => 1821,
    ),
    array(
      'tid' => 3768,
      'name' => "Aspochalasins",
      'description' => "Cytochalasans with a structure in which the hydrogenated isoindole bears a 2-methylpropyl group.",
      'parent' => 1821,
    ),
    array(
      'tid' => 3769,
      'name' => "Alachalasins",
      'description' => "Cytochalasans with a structure in which the hydrogenated isoindole bears a methyl group.",
      'parent' => 1821,
    ),
    array(
      'tid' => 3770,
      'name' => "Pyrrolo[3,4-d]pyridazines",
      'description' => "Organic compounds containing a pyrrolo fused to a pyridazine ring. Pyrrole is 5-membered ring consisting of four carbon atoms and one nitrogen atom. Pyridazine is a six-membered aromatic ring with two adjacent nitrogen atoms, and for carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 3771,
      'name' => "Imidazo[5,1-d]-1,2,3,5-tetrazines",
      'description' => "Organic aromatic compounds consisting of an imidazole fused to a 1,2,3,5-tetrazine. Imidazole is 5-membered ring consisting of three carbon atoms, and two nitrogen centers at the 1- and 3-positions. 1,2,3,5-tetrazine is a six-membered aromatic heterocycle made up of four nitrogen atoms at the 1-, 2-, 3-,and 5-positions, as well as and a two carbon atoms.",
      'parent' => 2001,
    ),
    array(
      'tid' => 3772,
      'name' => "4a-homomorphinans",
      'description' => "Alkaloids with a structure based on the 4a-homomorphinan skeleton. 4a-homomorphinan is a tetracyclic compound similar to morphinan, with the difference that the benzene ring is replaced by a cycloheptatriene ring.",
      'parent' => 279,
    ),
    array(
      'tid' => 3773,
      'name' => "Androcymbine alkaloids",
      'description' => "Alkaloids with a structure that is based on the androcymbine skeleton. This is a tetracyclic compound analogous to dibenzocycloheptane, where one benzene ring carries a ketone.",
      'parent' => 279,
    ),
    array(
      'tid' => 3774,
      'name' => "4,5-epoxy-10-normorphinans",
      'description' => "Alkaloids with a structure based on the 4,5-epoxy-10-normorphinan skeleton. These compounds possess a morphinan skeleton that lacks B-ring.",
      'parent' => 279,
    ),
    array(
      'tid' => 3775,
      'name' => "Phenethylisoquinoline alkaloids",
      'description' => "Alkaloids with a structure based on the phenethylisoquinoline skeleton. Phenethylisoquinoline is a tricyclic compound that consists of a quinoline that is carries a phenethyl group at the 2-position.",
      'parent' => 279,
    ),
    array(
      'tid' => 3776,
      'name' => "Allocolchicine alkaloids",
      'description' => "Alkaloids with a structure based on the tricyclic allocolchicine skeleton, which consists of a dibenzocycloheptane where the cycloheptane moiety carries the N-acetamide group.",
      'parent' => 279,
    ),
    array(
      'tid' => 3777,
      'name' => "Lumicolchicine alkaloids",
      'description' => "Alkaloids with a structure based on the tetracyclic lumicolchicine skeleton. They can derive from a colchicine precursor where the cycloheptatriene ring is replaced with a bicyclo[3.2.0]hepta-2,6-diene ring system.",
      'parent' => 279,
    ),
    array(
      'tid' => 3778,
      'name' => "Cephalotaxus alkaloids",
      'description' => "Alkaloids with a structure based on the cephalotaxine skeleton, a tetracyclic 1,3-benzodioxole-containing compound which arises from the skeletal rearrangement of the hydroaromatic component of the Erythrina group.",
      'parent' => 279,
    ),
    array(
      'tid' => 3779,
      'name' => "Hetidine-type diterpenoid alkaloids",
      'description' => "Alkaloid diterpenoids with a structure based on the hetidine skeleton, which is a hexacyclic compound with an additional C-20-C-14 bond in the atisine-type.",
      'parent' => 2738,
    ),
    array(
      'tid' => 3780,
      'name' => "Hetisine-type diterpenoid alkaloids",
      'description' => "Alkaloid diterpenoids with a structure based on the hetisine skeleton, which is a heptacyclic compound with an additional N-C-6 bond as compared with the hetidine-type, and thus, is one of most complex entries in the atisane-class.",
      'parent' => 2738,
    ),
    array(
      'tid' => 3781,
      'name' => "Danudatine-type diterpenoid alkaloids",
      'description' => "Alkaloid diterpenoids with a structure based on the danudatine skeleton, which is a hexacyclic compound with an additional C-20-C7 bond in the atisine skeleton.",
      'parent' => 2738,
    ),
    array(
      'tid' => 3782,
      'name' => "Kaurane diterpenoids",
      'description' => "Diterpene alkaloids with a structure that is based on the kaurane skeleton. Kaurane is a tetracyclic compound that arises by cyclisation of a pimarane precursor followed by rearrangement. It possesses a [3,2,1]-bicyclic ring system with C15-C16 bridge connected to C13, forming the five-membered ring D.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3783,
      'name' => "Veatchine-type diterpenoid alkaloids",
      'description' => "Alkaloid diterpenoids with a structure based on the veatchine skeleton, a pentacyclic compound, in which the carbon skeleton is the same as kaurane.",
      'parent' => 3782,
    ),
    array(
      'tid' => 3784,
      'name' => "Napelline-type diterpenoid alkaloids",
      'description' => "Alkaloid diterpenoids with a structure based on the napelline skeleton, which is a hexacyclic compound, with an additional C-20-C-7 bond  in the kaurane-type.",
      'parent' => 3782,
    ),
    array(
      'tid' => 3785,
      'name' => "4,6-disubstituted quinolizidines",
      'description' => "Compounds containing a quinolizine ring system that is substituted only at the 4- and 6-positions. Some alkaloids possessing a quinolizidine disubstituted at the 4- and 6-positions with alkyl groups have been isolated.",
      'parent' => 221,
    ),
    array(
      'tid' => 3786,
      'name' => "1,4-disubstituted quinolizidines",
      'description' => "Compounds containing a quinolizine ring system that is substituted only at the 1- and 4-positions. Some alkaloids possessing a quinolizidine disubstituted at the 1- and 4-positions with alkyl groups have been isolated.",
      'parent' => 221,
    ),
    array(
      'tid' => 3787,
      'name' => "Quinolidines",
      'description' => "Organic compounds containing a quinolidine or decahydroquinoline moiety, which is a bicyclic skeleton consisting of a piperidine fused to a cyclohexane ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 3788,
      'name' => "Aconitane-type diterpenoid alkaloids",
      'description' => "Alkaloid diterpenoids with a structure based on the hexacyclic aconitane skeleton. These compounds have no oxygen functionality at the C7 atom.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3789,
      'name' => "Lappaconitine-type diterpenoid alkaloids",
      'description' => "C18-bisnorditerpenoid alkaloids with a structure based on the heptacyclic lappaconitine skeleton. Lappaconitine similar to aconitane, with the difference that the former lacks a carbon atom at the 18-position.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3790,
      'name' => "Ranaconitine-type diterpenoid alkaloids",
      'description' => "C18-bisnorditerpenoid alkaloids with a structure based on the heptacyclic lycoctonine skeleton. Lappaconitine similar to aconitane, with the difference that the former lacks a carbon atom at the 18-position.",
      'parent' => 1551,
    ),
    array(
      'tid' => 3791,
      'name' => "Strictosidine alkaloids",
      'description' => "Alkaloids with a structure that is based on the strictosidine skeleton, which contains the tricyclic beta-carboline moiety.",
      'parent' => 279,
    ),
    array(
      'tid' => 3792,
      'name' => "(3'->5')-cyclic dinucleotides and analogues",
      'description' => "Cyclic compounds consisting of two ribose moieties connected by two 5',3'-phosphodiester bonds to form a cycle. Each ribose unit is N-linked to a nucleic base or an analogue thereof. Some natural (3'->5')-cyclic dinucleotides include c-di-AMP. Synthetic derivatives are generally more elaborated molecules in which one or the two nucleobase moieties, and/or sugar residues, and/or phosphodiester linkers have been modified.",
      'parent' => 3796,
    ),
    array(
      'tid' => 3793,
      'name' => "(3'->5')-cyclic dinucleotide bis(phosphoromonothioate) analogues",
      'description' => "Cyclic compounds consisting of two ribose moieties connected two 5',3'-phosphomonothioic acid O,O'-diester bonds to form a cycle. Each ribose unit is N-linked to a nucleic base or an analogue thereof.",
      'parent' => 3792,
    ),
    array(
      'tid' => 3794,
      'name' => "(3'->5')-cyclic dinucleotide phosphoromonothioate analogues",
      'description' => "Cyclic compounds consisting of two ribose moieties connected one 5',3'-phosphomonothioic acid O,O'-diester bond and one phosphodiester bond, to form a cycle. Each ribose unit is N-linked to a nucleic base or an analogue thereof.",
      'parent' => 3792,
    ),
    array(
      'tid' => 3795,
      'name' => "(3'->5')-cyclic dinucleotide phosphorotrithioate analogues",
      'description' => "Cyclic compounds consisting of two ribose moieties connected one 5',3'-phosphomonothioic acid O,O'-diester bond and one 5',3'-phosphodithioic acid O,O'-diester to form a cycle. Each ribose unit is N-linked to a nucleic base or an analogue thereof.",
      'parent' => 3792,
    ),
    array(
      'tid' => 3796,
      'name' => "(3'->5')-dinucleotides and analogues",
      'description' => "Cyclic compounds consisting of two ribose moieties connected by one 5',3'-phosphodiester bond to form a cycle. Each ribose unit is N-linked to a nucleic base or an analogue thereof. Synthetic derivatives are generally more elaborated molecules in which one or the two nucleobase moieties, and/or sugar residues, and/or phosphodiester linkers have been modified.",
      'parent' => 289,
    ),
    array(
      'tid' => 3797,
      'name' => "(3'->5')-dinucleotide phosphorothioates",
      'description' => "Compounds consisting of two ribose moieties connected one 5',3'-phosphomonothioic acid O,O'-diester bond. Each ribose unit is N-linked to a nucleic base or an analogue thereof.",
      'parent' => 3796,
    ),
    array(
      'tid' => 3798,
      'name' => "(3'->5')-dinucleotide phosphorodithioates",
      'description' => "Compounds consisting of two ribose moieties connected by one 5',3'-phosphodithioate bond. Each ribose unit is N-linked to a nucleic base or an analogue thereof.",
      'parent' => 3796,
    ),
    array(
      'tid' => 3799,
      'name' => "Phosphorothioate polynucleotides",
      'description' => "Polynucleotides in which one of the non-bridging oxygens in each phosphodiester linkage has been replaced by sulfur.",
      'parent' => 3297,
    ),
    array(
      'tid' => 3800,
      'name' => "Phosphorothioate oligonucleotides",
      'description' => "Oligonucleotides in which one of the non-bridging oxygens in each phosphodiester linkage has been replaced by sulfur.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3801,
      'name' => "Purine nucleoside phosphorothioates",
      'description' => "Analogues of purine nucleoside monophosphates where the ribose unit is linked to a phosphorothioate group at the 5'-position, instead of a phosphate group.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3802,
      'name' => "Pyrimidine nucleoside phosphorothioates",
      'description' => "Analogues of pyrimidine nucleoside monophosphates where the ribose unit is linked to a phosphorothioate group at the 5'-position, instead of a phosphate group.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3803,
      'name' => "2',3'-cyclic purine nucleoside phosphorothioates",
      'description' => "2',3'-cyclic purine nucleoside phosphate analogues, where a phosphate oxygen has been exchanged for sulphur generating a chiral phosphorothioate. In 2',3'-cyclic nucleoside phosphorothioate, the oxygen atoms at the 2'- and 3'-positions of the ribose are part of the phosphorothioate group.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3804,
      'name' => "2',3'-cyclic pyrimidine nucleoside phosphorothioates",
      'description' => "2',3'-cyclic pyrimidine nucleoside phosphate analogues, where a phosphate oxygen has been exchanged for sulphur generating a chiral phosphorothioate. In 2',3'-cyclic nucleoside phosphorothioate, the oxygen atoms at the 2'- and 3'-positions of the ribose are part of the phosphorothioate group.",
      'parent' => 3737,
    ),
    array(
      'tid' => 3805,
      'name' => "Indolonaphthyridine alkaloids",
      'description' => "A numerous and relatively straightforward subgroup of the b-carbolines, e.g. Canthin-6-one, in which an additional C3 unit is attached between C-1 and the indole nitrogen to form an additional ring. The group includes a few dimeric examples, such as Haplophytine.",
      'parent' => 279,
    ),
    array(
      'tid' => 3806,
      'name' => "Mono-(1Z-alkenyl)-glycerols",
      'description' => "Monoradylglycerolipids that carry exactly one 1Z-alkyenyl chain attached to the glycerol moiety.",
      'parent' => 3808,
    ),
    array(
      'tid' => 3807,
      'name' => "Glycero-3-pyrophosphates",
      'description' => "Lipids structurally characterized by the presence of a glycerol moiety bonded to one or two chains, and to a pyrophosphate group at the O3-position.",
      'parent' => 256,
    ),
    array(
      'tid' => 3808,
      'name' => "Monoradylglycerols",
      'description' => "Glycerolipids that carry exactly one acyl chain attached to the glycerol moiety.",
      'parent' => 175,
    ),
    array(
      'tid' => 3809,
      'name' => "Diradylglycerols",
      'description' => "Glycerolipids that carry exactly two acyl chains attached to the glycerol moiety.",
      'parent' => 175,
    ),
    array(
      'tid' => 3810,
      'name' => "Dialkylglycerols",
      'description' => "Glycerides consisting of two fatty acid chains covalently bonded to a glycerol molecule through ether linkages.",
      'parent' => 3809,
    ),
    array(
      'tid' => 3811,
      'name' => "1-alkyl,3-acylglycerols",
      'description' => "Glycerides consisting of two fatty acyl chains covalently bonded to a glycerol molecule at the 1- and 3-positions through an ether and an ester linkage, respectively.",
      'parent' => 3809,
    ),
    array(
      'tid' => 3812,
      'name' => "1-acyl,2-alkylglycerols",
      'description' => "Glycerides consisting of two fatty acyl chains covalently bonded to a glycerol molecule at the 2- and 1-positions through an ether and an ester linkage, respectively.",
      'parent' => 3809,
    ),
    array(
      'tid' => 3813,
      'name' => "1-alkyl,2-acylglycerols",
      'description' => "Glycerides consisting of two fatty acyl chains covalently bonded to a glycerol molecule at the 1- and 2-positions through an ether and an ester linkage, respectively.",
      'parent' => 3809,
    ),
    array(
      'tid' => 3814,
      'name' => "Alkyldiacylglycerols",
      'description' => "Triradylglycerols that carry exactly two acyl chains attached to the glycerol moiety through an ester linkage,  and one attached through an ester linkage.",
      'parent' => 3815,
    ),
    array(
      'tid' => 3815,
      'name' => "Triradylcglycerols",
      'description' => "Glycerolipids that carry exactly three acyl chains attached to the glycerol moiety.",
      'parent' => 175,
    ),
    array(
      'tid' => 3816,
      'name' => "1Z-alkenyldiacylglycerols",
      'description' => "Triradylglycerols that carry exactly two acyl chains attached to the glycerol moiety through an ester linkage,  a 1-Z-alkenyl chain and attached through an ether linkage.",
      'parent' => 3815,
    ),
    array(
      'tid' => 3817,
      'name' => "Dialkylmonoacylglycerols",
      'description' => "Triradylglycerols that carry exactly two acyl chains attached to the glycerol moiety through an ether linkage,  and one 1Z-alkenyl chain attached through an ester linkage.",
      'parent' => 3815,
    ),
    array(
      'tid' => 3818,
      'name' => "Glycosylmonoalkylglycerols",
      'description' => "Glycosylglycerols carrying exactly one fatty acyl chain attached to the glycerol moiety through an ether linkage.",
      'parent' => 3819,
    ),
    array(
      'tid' => 3819,
      'name' => "Glycosylmonoradylglycerols",
      'description' => "Glycosylglycerols that carry exactly one acyl chain attached to the glycerol moiety.",
      'parent' => 637,
    ),
    array(
      'tid' => 3820,
      'name' => "Glycosyldialkylglycerols",
      'description' => "Glycosylglycerols carrying exactly two fatty acyl chains attached to the glycerol moiety through an ether linkage.",
      'parent' => 3822,
    ),
    array(
      'tid' => 3821,
      'name' => "Glycosylalkylacylglycerols",
      'description' => "Glycosylglycerols that carry exactly two acyl chains attached to the glycerol moiety through an ether linkage, and an ester linkage.",
      'parent' => 3822,
    ),
    array(
      'tid' => 3822,
      'name' => "Glycosyldiradylglycerols",
      'description' => "Glycosylglycerols that carry exactly two acyl chains attached to the glycerol moiety.",
      'parent' => 637,
    ),
    array(
      'tid' => 3823,
      'name' => "1Z-alkenylglycerophosphocholines",
      'description' => "Glycerophosphocholines that carry exactly one 1Z-alkenyl chain attached to the glycerol moiety through an ether linkage.",
      'parent' => 2213,
    ),
    array(
      'tid' => 3824,
      'name' => "1Z-alkenylacylglycerols",
      'description' => "Diradylglycerols that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage,  and one 1Z-alkenyl chain attached through an ether linkage.",
      'parent' => 3809,
    ),
    array(
      'tid' => 3825,
      'name' => "1-(1Z-alkenyl),2-acyl-glycerols",
      'description' => "Glycerides consisting of one 1Z-alkenyl chain and one acyl chain covalently bonded to a glycerol molecule at the 1- and 2-positions through an ether and an ester linkage, respectively.",
      'parent' => 3824,
    ),
    array(
      'tid' => 3826,
      'name' => "1-acyl,2-(1Z-alkenyl)-glycerophosphocholines",
      'description' => "Glycerophosphocholines that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O1-position,  and one 1Z-alkenyl chain attached through an ether linkage at the O2-position.",
      'parent' => 2213,
    ),
    array(
      'tid' => 3827,
      'name' => "1-(1Z-alkenyl),2-acyl-glycerophosphocholines",
      'description' => "Glycerophosphocholines that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O2-position,  and one 1Z-alkenyl chain attached through an ether linkage at the O1-position.",
      'parent' => 2213,
    ),
    array(
      'tid' => 3828,
      'name' => "1-acyl,2-alkylglycero-3-phosphocholines",
      'description' => "Glycerophosphocholines that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O1-position,  and one acyl chain attached through an ether linkage at the O2-position.",
      'parent' => 2213,
    ),
    array(
      'tid' => 3829,
      'name' => "1-alkyl,2-acylglycero-3-phosphocholines",
      'description' => "Glycerophosphocholines that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O2-position,  and one alkyl chain attached through an ether linkage at the O1-position.",
      'parent' => 2213,
    ),
    array(
      'tid' => 3830,
      'name' => "1-alkyl,2-acylglycerophosphoethanolamines",
      'description' => "Glycerophosphoethanolamines that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O2-position,  and one alkyl chain attached through an ether linkage at the O1-position.",
      'parent' => 2215,
    ),
    array(
      'tid' => 3831,
      'name' => "Dialkylglycerophosphoethanolamines",
      'description' => "Glycerophosphoglycerols that carry exactly two chains attached to the glycerol moiety through ether linkages.",
      'parent' => 2215,
    ),
    array(
      'tid' => 3832,
      'name' => "1-(1Z-alkenyl),2-acylglycerophosphoethanolamines",
      'description' => "Glycerophosphoethanolamines that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O2-position,  and one 1Z-alkenyl chain attached through an ether linkage at the O1-position.",
      'parent' => 2215,
    ),
    array(
      'tid' => 3833,
      'name' => "Monoalkylglycerophosphoethanolamines",
      'description' => "Glycerophosphoethanolamines that carry exactly one alkyl chain attached to the glycerol moiety through a ether linkage.",
      'parent' => 2215,
    ),
    array(
      'tid' => 3834,
      'name' => "1-(1Z-alkenyl)-glycero-3-phosphoethanolamines",
      'description' => "Glycerophosphoglycerophosphates that carry exactly one 1Z-alkenyl chain attached to the glycerol moiety through an ether linkage.",
      'parent' => 2215,
    ),
    array(
      'tid' => 3835,
      'name' => "Alkyldiazohydroxides",
      'description' => "Organonitrogen compounds with the general formula RN=NOH, where R = organyl.",
      'parent' => 278,
    ),
    array(
      'tid' => 3836,
      'name' => "Dialkylglycerophosphoserines",
      'description' => "Glycerophosphoserines that contain exactly two fatty acyl chains attached to the glycerol moiety through ether linkages.",
      'parent' => 2218,
    ),
    array(
      'tid' => 3837,
      'name' => "Monoalkylglycerol-3-phosphoserines",
      'description' => "Lipids containing a glycerol moiety carrying a phosphoserine at the 3-position, as well as an alkyl chain attached to the glycerol moiety through an ether linkage.",
      'parent' => 2218,
    ),
    array(
      'tid' => 3838,
      'name' => "1Z-alkenylglycero-3-phosphoserines",
      'description' => "Glycerophosphocholines that carry exactly one 1Z-alkenyl chain attached to the glycerol moiety through an ether linkage.",
      'parent' => 2218,
    ),
    array(
      'tid' => 3839,
      'name' => "1-alkyl,2-acylglycerophosphoglycerols",
      'description' => "Glycerophosphoglycerols that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O2-position,  and one alkyl chain attached through an ether linkage at the O1-position.",
      'parent' => 2216,
    ),
    array(
      'tid' => 3840,
      'name' => "1-(1Z-alkenyl),2-acylglycerophosphoglycerols",
      'description' => "Glycerophosphoglycerols that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O2-position,  and one 1Z-alkenyl chain attached through an ether linkage at the O1-position.",
      'parent' => 2216,
    ),
    array(
      'tid' => 3841,
      'name' => "Dialkylglycerolphosphoglycerols",
      'description' => "Glycerophosphoglycerols that carry exactly two alkyl chain attached to the glycerol moiety through ether linkages.",
      'parent' => 2216,
    ),
    array(
      'tid' => 3842,
      'name' => "Monoalkylglycerophosphoglycerols",
      'description' => "Glycerophosphoglycerols that carry exactly one alkyl chain attached to the glycerol moiety through an ether linkage.",
      'parent' => 2216,
    ),
    array(
      'tid' => 3843,
      'name' => "1-(1Z-alkenyl)glycerophosphoglycerols",
      'description' => "Glycerophosphoglycerols that carry exactly one 1Z-alkenyl chain attached to the glycerol moiety through an ether linkage.",
      'parent' => 2216,
    ),
    array(
      'tid' => 3844,
      'name' => "Monoacylglycerophosphomonoradylglycerols",
      'description' => "Glycerophosphomonoradylglycerols that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage.",
      'parent' => 2216,
    ),
    array(
      'tid' => 3845,
      'name' => "Diacylglycerophosphomonoradylglycerols",
      'description' => "Glycerophosphomonoradylglycerols that carry exactly two acyl chains attached to the glycerol moiety through ester linkages.",
      'parent' => 2216,
    ),
    array(
      'tid' => 3846,
      'name' => "1-alkyl,2-acylglycerophosphoglycerophosphates",
      'description' => "Glycerophosphoglycerophosphates that contain exactly two fatty acyl chains attached to the glycerol moiety, one through an ester linkage at the O2-position, and the other through an ether linkage at the O1-position.",
      'parent' => 2217,
    ),
    array(
      'tid' => 3847,
      'name' => "1-(1Z-alkenyl),2-acylglycerophosphoglycerophosphates",
      'description' => "Glycerophosphoglycerophosphates that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O2-position,  and one 1Z-alkenyl chain attached through an ether linkage at the O1-position.",
      'parent' => 2217,
    ),
    array(
      'tid' => 3848,
      'name' => "1-alkyl,2-acylglycerophosphoinositols",
      'description' => "Glycerophosphoinositols that contain exactly two fatty acyl chains attached to the glycerol moiety, one through an ester linkage at the O2-position, and the other through an ether linkage at the O1-position.",
      'parent' => 2219,
    ),
    array(
      'tid' => 3849,
      'name' => "1-(1Z-alkenyl),2-acylglycerophosphoinositols",
      'description' => "Glycerophosphoinositols that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O2-position,  and one 1Z-alkenyl chain attached through an ether linkage at the O1-position.",
      'parent' => 2219,
    ),
    array(
      'tid' => 3850,
      'name' => "Dialkylglycerophosphoinositols",
      'description' => "Glycerophosphoinositols that contain exactly two fatty acyl chains attached to the glycerol moiety, one through ether linkages at the O1- and O2-positions.",
      'parent' => 2219,
    ),
    array(
      'tid' => 3851,
      'name' => "Monoalkylglycerophosphoinositols",
      'description' => "Glycerophosphoinositols that contain exactly on fatty acyl chain attached to the glycerol moiety through an ether linkage.",
      'parent' => 2219,
    ),
    array(
      'tid' => 3852,
      'name' => "1-(1Z-alkenyl)glycerophosphoinositols",
      'description' => "Glycerophosphoinositols that carry exactly one 1Z-alkenyl chain attached to the glycerol moiety through an ether linkage.",
      'parent' => 2219,
    ),
    array(
      'tid' => 3853,
      'name' => "Glycero-3-phosphosulfocholines",
      'description' => "Lipids containing a glycerol moiety carrying a phosphosulfocholine at the 3-position.",
      'parent' => 256,
    ),
    array(
      'tid' => 3854,
      'name' => "Dolichols",
      'description' => "A group of long-chain mostly unsaturated organic compounds that are made up of varying numbers of isoprene units terminating in an alpha-saturated isoprenoid group, containing an alcohol functional group. The three isoprene units at the distal end  are trans-linked.",
      'parent' => 1535,
    ),
    array(
      'tid' => 3855,
      'name' => "Dolichyl monophosphates",
      'description' => "Polyprenyl compounds consisting of a monophosphate group substituted by a dolichyl moiety.",
      'parent' => 478,
    ),
    array(
      'tid' => 3856,
      'name' => "Dolichyl diphosphates",
      'description' => "Polyprenyl compounds consisting of a diphosphate group substituted by a dolichyl moiety.",
      'parent' => 478,
    ),
    array(
      'tid' => 3857,
      'name' => "Acyldolichols",
      'description' => "Polyprenyl compounds consisting of a dolichyl moiety carrying an acyl group.",
      'parent' => 3854,
    ),
    array(
      'tid' => 3858,
      'name' => "Bactoprenols",
      'description' => "Compounds consisting of a (un-) substituted bactoprenyl group, which is a C-55 isoprenoid alcohol obtained by condensation of 10 unsaturated isoprene units a one saturated isoprene unit.",
      'parent' => 1535,
    ),
    array(
      'tid' => 3859,
      'name' => "Bactoprenol monophosphates",
      'description' => "Polyprenyl compounds consisting of a monophosphate group substituted by a bactoprenyl moiety.",
      'parent' => 478,
    ),
    array(
      'tid' => 3860,
      'name' => "Bactoprenol diphosphates",
      'description' => "Polyprenyl compounds consisting of a diphosphate group substituted by a bactoprenyl moiety.",
      'parent' => 478,
    ),
    array(
      'tid' => 3861,
      'name' => "Fatty acyl glycosides of mono- and disaccharides",
      'description' => "Compounds composed of a mono- or disaccharide moiety linked to one hydroxyl group of a fatty alcohol or of a phosphorylated alcohol (phosphoprenols), a hydroxy fatty acid or to one carboxyl group of a fatty acid (ester linkage) or to an amino alcohol.",
      'parent' => 1766,
    ),
    array(
      'tid' => 3862,
      'name' => "Dialkylthioethers",
      'description' => "Organosulfur compounds containing a thioether group that is substituted by two alkyl groups.",
      'parent' => 1202,
    ),
    array(
      'tid' => 3863,
      'name' => "Alkylarylthioethers",
      'description' => "Organosulfur compounds containing a thioether group that is substituted by an alkyl and an aryl group.",
      'parent' => 4631,
    ),
    array(
      'tid' => 3864,
      'name' => "Diarylthioethers",
      'description' => "Organosulfur compounds containing a thioether group that is substituted by two aryl groups.",
      'parent' => 4631,
    ),
    array(
      'tid' => 3865,
      'name' => "Organic salts",
      'description' => "Organic compounds consisting of an assembly of cations and anions.",
      'parent' => 0,
    ),
    array(
      'tid' => 3866,
      'name' => "Inorganic salts",
      'description' => "Inorganic compounds consisting of an assembly of cations and anions.",
      'parent' => 1,
    ),
    array(
      'tid' => 3867,
      'name' => "Trialkylsilanes",
      'description' => "Organosilicon compounds containing exactly one alkyl chain attached to the silicon atom.",
      'parent' => 3195,
    ),
    array(
      'tid' => 3868,
      'name' => "Phosphoric monoester monoamides",
      'description' => "Organophosphorus compounds containing a monoamide derivative of a phosphoric acid monoester functional group. They have the general structure R1OP(=O)(OH)N(R3)R4, where R1 = organyl group and R3-R4 = H or organyl.",
      'parent' => 2857,
    ),
    array(
      'tid' => 3869,
      'name' => "Phosphoric diester monoamides",
      'description' => "Organophosphorus compounds containing a monoamide derivative of a phosphoric acid diester functional group. They have the general structure R1OP(=O)(OR2)N(R3)R4, where R1-R2 = organyl group and R3-R4 = H or organyl.",
      'parent' => 408,
    ),
    array(
      'tid' => 3870,
      'name' => "Phosphoric monoester diamides",
      'description' => "Organophosphorus compounds containing a monoamide derivative of a phosphoric acid diester functional group. They have the general structure R1OP(=O)(N(R2)R3)N(R4)R5, where R1 = organyl group and R2-R5 = H or organyl.",
      'parent' => 3662,
    ),
    array(
      'tid' => 3871,
      'name' => "Organic phosphoric acid triamides",
      'description' => "Organophosphorus compounds with the general formula RNP(R2)(R3)=O (R=alkyl, aryl; R2-R3 = amine groups).",
      'parent' => 1204,
    ),
    array(
      'tid' => 3872,
      'name' => "Carbothioic S-esters",
      'description' => "Ester derivatives of carbothioic S-acids, with the general structure RSC(=O)R' where R = organyl group and R' = H or organyl group.",
      'parent' => 264,
    ),
    array(
      'tid' => 3873,
      'name' => "Carbothioic S-lactones",
      'description' => "Cyclic organosulfur compounds with the general structure RC(=O)SR', R-R' = organyl group, where the central atom is part of the ring.",
      'parent' => 264,
    ),
    array(
      'tid' => 3874,
      'name' => "Carbothioic O-esters",
      'description' => "Ester derivatives of carbothioic O-acids, with the general structure ROC(=S)R' where R = organyl group and R' = H or organyl group.",
      'parent' => 264,
    ),
    array(
      'tid' => 3875,
      'name' => "Carbothioic O-lactones",
      'description' => "Cyclic organosulfur compounds with the general structure RC(=S)OR', R-R' = organyl group, where the central atom is part of the ring.",
      'parent' => 264,
    ),
    array(
      'tid' => 3876,
      'name' => "Carbothioic halides",
      'description' => "Organosulfur compounds with the general structure RC(=S)X, where R = organyl group and X = halogen atom.",
      'parent' => 267,
    ),
    array(
      'tid' => 3877,
      'name' => "Carbodithioic acid esters",
      'description' => "Ester derivatives of a carbodithioic acid (RC(=S)SH).",
      'parent' => 264,
    ),
    array(
      'tid' => 3878,
      'name' => "Carbodithiolactones",
      'description' => "Cyclic organosulfur compounds with the general formula RC(=S)SR', where the central carbon atom is part of a ring; R,R' = organyl group.",
      'parent' => 2,
    ),
    array(
      'tid' => 3879,
      'name' => "Oxime esters",
      'description' => "Organic compounds containing an ester derivative of the oxime functional group.",
      'parent' => 411,
    ),
    array(
      'tid' => 3880,
      'name' => "Hydroxamic acid esters",
      'description' => "Hydroxamic acids in which the hydrogen of the hydroxy group has been replaced by an organyl group.",
      'parent' => 1093,
    ),
    array(
      'tid' => 3881,
      'name' => "Cyclic carboximidic acids",
      'description' => "Organic acids with the general formula RC(=N)-OH (R=H, organic group), where the carboximidic acid group is part of a cycle.",
      'parent' => 2484,
    ),
    array(
      'tid' => 3882,
      'name' => "Imidolactones",
      'description' => "Cyclic organooxygen compounds with the general structure R(=N)OR' where the central carbon atom is part of a ring, and R,R' = organyl group.",
      'parent' => 499,
    ),
    array(
      'tid' => 3883,
      'name' => "Imidothioic acids",
      'description' => "Sulfur derivatives of imidic acid containing the functional group -RC(=N)S, obtained by replacing the oxygen atom by a sulfur atom.",
      'parent' => 2462,
    ),
    array(
      'tid' => 3884,
      'name' => "Cyclic imidothioic acids",
      'description' => "Organic compounds containing the imidothioic acid group as part of a cycle.",
      'parent' => 3883,
    ),
    array(
      'tid' => 3885,
      'name' => "Imidothiolactones",
      'description' => "Analogs of imidolactones where the oxygen atom is replaced by a sulfur atom. They have the general structure RC(=N)SR' where the central carbon atom is part of a ring. R,R' =  organyl group.",
      'parent' => 1094,
    ),
    array(
      'tid' => 3886,
      'name' => "Imidolactams",
      'description' => "Cyclic organooxygen compounds containing the structure RC(=N)N where the central carbon atom and one of the linked nitrogen atoms are part of the same ring( R here is an organyl group). They can also be viewed as analogs of lactams where the oxygen atom is replaced by a nitrogen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 3887,
      'name' => "Cyclic imidoyl halides",
      'description' => "Imidoyl halides with the general formula R(X)C=NR' (R, R'=H, alkyl, aryl), where the central carbon atom is part of a ring.",
      'parent' => 2870,
    ),
    array(
      'tid' => 3888,
      'name' => "Vinylogous halides",
      'description' => "Organic compounds containing a halogen atom, which is indirectly attached to a carbonyl via an intervening vinyl (>C=C<) moiety.",
      'parent' => 2868,
    ),
    array(
      'tid' => 3889,
      'name' => "Vinylogous acids",
      'description' => "Organic compounds containing a hydroxyl group, which is indirectly attached to a carbonyl via an intervening vinyl (>C=C<) moiety.",
      'parent' => 264,
    ),
    array(
      'tid' => 3890,
      'name' => "Vinylogous amides",
      'description' => "Organic compounds containing an amine group, which is indirectly attached to a carbonyl via an intervening vinyl (>C=C<) moiety.",
      'parent' => 264,
    ),
    array(
      'tid' => 3891,
      'name' => "Vinylogous esters",
      'description' => "Organic compounds containing an ester group, which is indirectly attached to a carbonyl via an intervening vinyl (>C=C<) moiety.",
      'parent' => 264,
    ),
    array(
      'tid' => 3892,
      'name' => "Organic phosphonic acid diamides",
      'description' => "Organophosphorus compounds containing a diamide derivative of phosphonic acid, with the general structure R1P(=O)(N(R2)R3)N(R4)R5, where R = organyl and R2-R5 = H or organyl group.",
      'parent' => 419,
    ),
    array(
      'tid' => 3893,
      'name' => "Phosphonic acid diesters",
      'description' => "Organophosphorus compounds containing a diester derivative of phosphonic acid, with the general structure ROP(=O)OR' (R,R' = organyl group).",
      'parent' => 419,
    ),
    array(
      'tid' => 3894,
      'name' => "Phosphonic amide esters",
      'description' => "Organophosphorus compounds containing a diester derivative of phosphonic acid amide, with the general structure ROP(=O)N(R')R\" (R = organyl group, R'-R\" = H or organyl group).",
      'parent' => 419,
    ),
    array(
      'tid' => 3895,
      'name' => "Ketene silyl acetals",
      'description' => "Organosilicon compounds with the general structure OC(O[Si])=CR, where R = H or organyl group.",
      'parent' => 3194,
    ),
    array(
      'tid' => 3896,
      'name' => "Silyl monohalides",
      'description' => "Organosilicon compounds with the general formula  RSi(R')(R'')X; R-R'' = organyl group, X = halogen atom.",
      'parent' => 3194,
    ),
    array(
      'tid' => 3897,
      'name' => "Silyl dihalides",
      'description' => "Organosilicon compounds with the general formula  RSi(R')(X)X; R-R' = organyl group, X = halogen atom.",
      'parent' => 3194,
    ),
    array(
      'tid' => 3898,
      'name' => "Silyl trihalides",
      'description' => "Organosilicon compounds with the general formula  RSi(X)(X)X; R = organyl group, X = halogen atom.",
      'parent' => 3194,
    ),
    array(
      'tid' => 3899,
      'name' => "Aralkylamines",
      'description' => "Alkylamines in which the alkyl group is substituted at one carbon atom by an aromatic hydrocarbyl group.",
      'parent' => 2449,
    ),
    array(
      'tid' => 3900,
      'name' => "N-acetoxyarylamines",
      'description' => "Arylamines that contain an acetytoxy group attached to the nitrogen.",
      'parent' => 2449,
    ),
    array(
      'tid' => 3901,
      'name' => "Dialkylarylamines",
      'description' => "Aliphatic aromatic amines in which the amino group is linked to two aliphatic chains and one aromatic group.",
      'parent' => 2454,
    ),
    array(
      'tid' => 3902,
      'name' => "Alkyldiarylamines",
      'description' => "Tertiary alkylarylamines having two aryl and one alkyl groups attached to the amino group.",
      'parent' => 2454,
    ),
    array(
      'tid' => 3903,
      'name' => "Haloalkenes",
      'description' => "Compounds derived from an alkene by replacing a hydrogen atom with a halogen atom.",
      'parent' => 267,
    ),
    array(
      'tid' => 3904,
      'name' => "Bromoalkenes",
      'description' => "Compounds derived from an alkene by replacing a hydrogen atom with a bromine atom.",
      'parent' => 3903,
    ),
    array(
      'tid' => 3905,
      'name' => "Chloroalkenes",
      'description' => "Compounds derived from an alkene by replacing a hydrogen atom with a chlorine atom.",
      'parent' => 3903,
    ),
    array(
      'tid' => 3906,
      'name' => "Fluoroalkenes",
      'description' => "Compounds derived from an alkene by replacing a hydrogen atom with a fluorine atom.",
      'parent' => 3903,
    ),
    array(
      'tid' => 3907,
      'name' => "Iodoalkenes",
      'description' => "Compounds derived from an alkene by replacing a hydrogen atom with an iodine atom.",
      'parent' => 3903,
    ),
    array(
      'tid' => 3908,
      'name' => "Fatty N-acylethanolamines",
      'description' => "Lipids containing an fatty acyl chain attached to a N-acyl ethanolamine group.",
      'parent' => 1096,
    ),
    array(
      'tid' => 3909,
      'name' => "Fatty Acyls",
      'description' => "Organic molecules synthesized by chain elongation of an acetyl-CoA primer with malonyl-CoA (or methylmalonyl-CoA) groups that might contain a cyclic functionality and/or are substituted with heteroatoms.",
      'parent' => 12,
    ),
    array(
      'tid' => 3910,
      'name' => "2-aroylquinolines",
      'description' => "Compounds containing a quinoline which carries an aroyl group at the 2-position. An aroyl group is a univalent radical R-CO- derived from an aromatic carboxylic acid.",
      'parent' => 1253,
    ),
    array(
      'tid' => 3911,
      'name' => "5-amino-2-aroylquinolines",
      'description' => "Compounds containing a quinoline which carries an aroyl group at the 2-position, and an amino group at the 5-position.",
      'parent' => 3910,
    ),
    array(
      'tid' => 3912,
      'name' => "4-aroylquinolines",
      'description' => "Compounds containing a quinoline which carries an aroyl group at the 4-position. An aroyl group is a univalent radical R-CO- derived from an aromatic carboxylic acid.",
      'parent' => 1253,
    ),
    array(
      'tid' => 3913,
      'name' => "Stenine-type alkaloids",
      'description' => "Alkaloids which can be structurally represented by the tetracyclic\nfuro[2,3-h]pyrrolo[3,2,1-jk][1]benzazepin-10(2H)-one nucleus.",
      'parent' => 3427,
    ),
    array(
      'tid' => 3914,
      'name' => "Stemoamide-type alkaloids",
      'description' => "Alkaloids which include a tricyclic 2H-furo[3,2-c]pyrrolo[1,2-a]azepine nucleus.",
      'parent' => 3427,
    ),
    array(
      'tid' => 3915,
      'name' => "Stemonamine-type alkaloids",
      'description' => "Alkaloids with a structure characterized by the tetracyclic 2AH,11H-spiro[1H-cyclopenta-[b]pyrrolo[1,2-a]azepine-11,2A-furan]-5A,10-dione nucleus with a spirolactone ring at C-12.",
      'parent' => 3427,
    ),
    array(
      'tid' => 3916,
      'name' => "Tuberostemospironine-type alkaloids",
      'description' => "Alkaloids with a structure that is characterized by a 2H-spiro[furan-2,9A[9H]pyrrolo[1,2-a]azepin]-\n5-one nucleus which displays a spiro gamma-lactone at C-9 of the basic ring.",
      'parent' => 3427,
    ),
    array(
      'tid' => 3917,
      'name' => "Parvistemoline-type alkaloids",
      'description' => "Alkaloids that feature a conserved pyrrolo[1,2-a]azepine nucleus. They are characterized by a hexahydro-2,6-dimethyl-5-oxofuro[3,2-b]furan-3-yl moiety attached to C-9 in the pyrrolo[1,2-a]azepine nucleus.",
      'parent' => 3427,
    ),
    array(
      'tid' => 3918,
      'name' => "Saccharolipids",
      'description' => "Compounds in which fatty acids are linked directly to a sugar backbone, forming structures that are compatible with membrane bilayers. In the saccharolipids, a sugar substitutes for the glycerol backbone that is present in glycerolipids and glycerophospholipids. The most familiar saccharolipids contain an acylated glucosamine. In contrast to others glycolipids, the fatty acid is not glycosidically linked to the sugar moiety.",
      'parent' => 12,
    ),
    array(
      'tid' => 3919,
      'name' => "Acetate salts",
      'description' => "Organic compounds containing acetic acid as its acid component.",
      'parent' => 1166,
    ),
    array(
      'tid' => 3920,
      'name' => "Hydrobromides",
      'description' => "Organic salts that results from the reaction of hydrobromic acid with an organic base.",
      'parent' => 3865,
    ),
    array(
      'tid' => 3921,
      'name' => "Hydrochlorides",
      'description' => "Organic salts that results from the reaction of hydrochloric acid with an organic base.",
      'parent' => 3865,
    ),
    array(
      'tid' => 3922,
      'name' => "Acetamides",
      'description' => "Organic compounds with the general formula RNHC(=O)CH3, where R= organyl group.",
      'parent' => 475,
    ),
    array(
      'tid' => 3924,
      'name' => "Phenylalkylamines",
      'description' => "Organic amines where the amine group is secondary and linked on one end to a phenyl group and on the other end, to an alkyl group.",
      'parent' => 3899,
    ),
    array(
      'tid' => 3925,
      'name' => "Alkylglucosinolates",
      'description' => "Organic compounds containing a glucosinolate moiety that carries an alkyl chain.",
      'parent' => 373,
    ),
    array(
      'tid' => 3926,
      'name' => "Beta-diketones",
      'description' => "Organic compounds containing two keto groups separated by a single carbon atom.",
      'parent' => 133,
    ),
    array(
      'tid' => 3927,
      'name' => "Organic potassium salts",
      'description' => "Organic compounds containing a potassium ion.",
      'parent' => 4099,
    ),
    array(
      'tid' => 3928,
      'name' => "Organic sodium salts",
      'description' => "Organic compounds containing a sodium ion.",
      'parent' => 4099,
    ),
    array(
      'tid' => 3929,
      'name' => "Organic sulfate salts",
      'description' => "Organic compounds containing a sulfate ion.",
      'parent' => 3865,
    ),
    array(
      'tid' => 3930,
      'name' => "Organic bromide salts",
      'description' => "Organic compounds containing a bromine ion.",
      'parent' => 3865,
    ),
    array(
      'tid' => 3931,
      'name' => "Organic chloride salts",
      'description' => "Organic compounds containing a chlorine ion.",
      'parent' => 3865,
    ),
    array(
      'tid' => 3932,
      'name' => "Organic iodide salts",
      'description' => "Organic compounds containing a iodine ion.",
      'parent' => 3865,
    ),
    array(
      'tid' => 3933,
      'name' => "Organic perchlorate salts",
      'description' => "Organic compounds containing a perchlorate ion.",
      'parent' => 3865,
    ),
    array(
      'tid' => 3934,
      'name' => "Dithiocarbamic acids and derivatives",
      'description' => "Organosulfur compounds with the general formula SC(=S)N(R1)R2; R1-R2 =  H or organyl group.",
      'parent' => 264,
    ),
    array(
      'tid' => 3935,
      'name' => "Dithiocarbamic acids",
      'description' => "Organosulfur compounds with the general formula HSC(=S)N(R1)R2; R1-R2 =  H or organyl group.",
      'parent' => 3934,
    ),
    array(
      'tid' => 3936,
      'name' => "Dithiocarbamic acid esters",
      'description' => "Organosulfur compounds with the general formula R3SC(=S)N(R1)R2; R1-R2 =  H or organyl group, R3 = organyl.",
      'parent' => 3934,
    ),
    array(
      'tid' => 3937,
      'name' => "Cyclic dithiocarbamates",
      'description' => "Organic compounds containing the dithiocarbamic acid group as part of a cycle.",
      'parent' => 3934,
    ),
    array(
      'tid' => 3938,
      'name' => "Phosphine sulfides",
      'description' => "Compounds having the general formula R3P=S <=> R3P+S-.",
      'parent' => 1438,
    ),
    array(
      'tid' => 3939,
      'name' => "Phosphine imides",
      'description' => "Organophosphorus compounds with the general formula R1P(R2)(R3)N=R4; R1 = organyl, R2-R4 = H or organyl.",
      'parent' => 400,
    ),
    array(
      'tid' => 3940,
      'name' => "Organic oxides",
      'description' => "Organic compounds containing an oxide group.",
      'parent' => 4603,
    ),
    array(
      'tid' => 3941,
      'name' => "Inorganic arsenides",
      'description' => "Inorganic compounds containing arsenic with one or more less electronegative elements.",
      'parent' => 4057,
    ),
    array(
      'tid' => 3942,
      'name' => "Inorganic sulfides",
      'description' => "Inorganic compounds of sulfur with a less electronegative element.",
      'parent' => 1568,
    ),
    array(
      'tid' => 3943,
      'name' => "Inorganic phosphides",
      'description' => "Inorganic compounds containing phosphorus with a less electronegative element or elements.",
      'parent' => 1568,
    ),
    array(
      'tid' => 3944,
      'name' => "Inorganic oxides",
      'description' => "Inorganic chemical compounds with one or more oxygen atoms combined with another element.",
      'parent' => 1568,
    ),
    array(
      'tid' => 3945,
      'name' => "Inorganic hydrides",
      'description' => "Inorganic compounds in which hydrogen is bonded to a more electropositive element or group. Usually, they contain one or more hydrogen centers having nucleophilic, reducing, or basic properties.",
      'parent' => 1568,
    ),
    array(
      'tid' => 3946,
      'name' => "Inorganic selenides",
      'description' => "Inorganic chemical compounds in which selenium serves as an anion with oxidation number of -2. The selenium atom here when participating in a chemical bond, is linked to a less electronegative atom.",
      'parent' => 1568,
    ),
    array(
      'tid' => 3947,
      'name' => "Nitrosamides",
      'description' => "Organonitrogen compounds with the general formula O=CN(R)-N=O, where R=H or organyl group.",
      'parent' => 4777,
    ),
    array(
      'tid' => 3948,
      'name' => "Inorganic nitrosamines",
      'description' => "Inorganic compounds containing the nitrosamine functional group, with the structure R2NN=O.",
      'parent' => 1568,
    ),
    array(
      'tid' => 3949,
      'name' => "Inorganic hydroxylamines",
      'description' => "Inorganic compounds containing the hydroxylamine group RN(R')-OH, where R,R' = H or inorganic moiety.",
      'parent' => 1568,
    ),
    array(
      'tid' => 3950,
      'name' => "Isporenylated bicyclo [2.2.2] alkaloids",
      'description' => "Alkaloids characterized by the unique bicyclo [2.2.2] ring system, constituted mainly from tryptophan, proline, or substituted  proline derivatives, where the olefinic unit of the isoprene moiety is usually oxidatively cyclized across the alpha carbon of a cyclic dipeptide (a piperazinedione).",
      'parent' => 279,
    ),
    array(
      'tid' => 3951,
      'name' => "Dialkyl peroxides",
      'description' => "Organic compounds containing a peroxide group substituted by two alkyl groups.",
      'parent' => 414,
    ),
    array(
      'tid' => 3952,
      'name' => "2-aminoanthraquinones",
      'description' => "Organic compounds containing an anthraquinone ring system, which is substituted at the 2-position by an amino group.",
      'parent' => 151,
    ),
    array(
      'tid' => 3953,
      'name' => "8-hydroxyquinolines",
      'description' => "Compounds containing a quinoline moiety, which carries a hydroxy group at the 8-position. Quinoline consists of a benzene ring fused to a pyrimidine ring to form benzo[b]azabenzene.",
      'parent' => 1253,
    ),
    array(
      'tid' => 3954,
      'name' => "Polybrominated biphenyls",
      'description' => "Organic aromatic compounds containing a biphenyl moiety, which is substituted at two or more ring positions by a bromine atom.",
      'parent' => 52,
    ),
    array(
      'tid' => 3955,
      'name' => "Benzidines",
      'description' => "Organic compounds containing the benzidine skeleton, made up of a biphenyl ring system substituted at the 4- and 4'-positions with a unsubstituted amine group.",
      'parent' => 41,
    ),
    array(
      'tid' => 3956,
      'name' => "3,3'-disubstituted benzidines",
      'description' => "Organic compounds containing a benzidine skeleton, which is substituted only at the 3-  and 3'-positions.",
      'parent' => 3955,
    ),
    array(
      'tid' => 3957,
      'name' => "3,3'-dihalogenated benzidines",
      'description' => "Organic compounds containing a benzidine skeleton, which is substituted at different positions, only two of which (3- and 3'-) carry a halogen atom.",
      'parent' => 3956,
    ),
    array(
      'tid' => 3958,
      'name' => "Perfluorooctanoic acid and derivatives",
      'description' => "Organic compounds containing an octyl chain attached to the C-alpha of a carboxylic acid group (or a derivative thereof), where all hydrogens of the octyl chain are replaced by fluorine atoms.",
      'parent' => 3962,
    ),
    array(
      'tid' => 3959,
      'name' => "Perfluorooctane phosphonic acid and derivatives",
      'description' => "Organic compounds containing an octyl chain attached to the phosphorus of a phosphonic acid group (or a derivative thereof), where all hydrogens of the octyl chain are replaced by fluorine atoms.",
      'parent' => 3963,
    ),
    array(
      'tid' => 3960,
      'name' => "Perfluorooctane sulfonic acid and derivatives",
      'description' => "Organic compounds containing an octyl chain attached to the sulfur of a sulfonic acid (or a derivative thereof), where all hydrogens of the octyl chain are replaced by fluorine atoms.",
      'parent' => 3961,
    ),
    array(
      'tid' => 3961,
      'name' => "Perfluoroalkyl sulfonic acid and derivatives",
      'description' => "Organic compounds containing an alkyl chain attached to the sulfur of a sulfonic acid group (or a derivative thereof), where all hydrogens of the alkyl chain are replaced by fluorine atoms.",
      'parent' => 1027,
    ),
    array(
      'tid' => 3962,
      'name' => "Perfluoroalkyl carboxylic acid and derivatives",
      'description' => "Organic compounds containing an alkyl chain attached to the C-alpha of a carboxylic acid group (or a derivative thereof), where all hydrogens of the alkyl chain are replaced by fluorine atoms.",
      'parent' => 1027,
    ),
    array(
      'tid' => 3963,
      'name' => "Perfluoroalkyl phosphonic acid and derivatives",
      'description' => "Organic compounds containing an alkyl chain attached to the phosphorus of a phosphonic acid group (or a derivative thereof), where all hydrogens of the alkyl chain are replaced by fluorine atoms.",
      'parent' => 1027,
    ),
    array(
      'tid' => 3964,
      'name' => "Aminotoluenes",
      'description' => "Organic aromatic compounds containing a benzene that carries a single methyl group and one amino group.",
      'parent' => 1091,
    ),
    array(
      'tid' => 3965,
      'name' => "Diaminotoluenes",
      'description' => "Organic aromatic compounds containing a benzene that carries a single methyl group exactly 2 amino groups.",
      'parent' => 3964,
    ),
    array(
      'tid' => 3966,
      'name' => "Perfluoroalkyl sulfonamides",
      'description' => "Organic compounds containing an alkyl chain attached to the sulfur of a sulfonamide, where all hydrogens of the alkyl chain are replaced by fluorine atoms.",
      'parent' => 3961,
    ),
    array(
      'tid' => 3967,
      'name' => "Fluorotelomer alcohols",
      'description' => "Fluorocarbon-based oligomers linked to an alcohol chain.",
      'parent' => 1027,
    ),
    array(
      'tid' => 3968,
      'name' => "Dinitroanilines",
      'description' => "Organic compounds containing an aniline moiety, which is substituted at 2 positions by a nitro group.",
      'parent' => 284,
    ),
    array(
      'tid' => 3969,
      'name' => "Dinitrotoluenes",
      'description' => "Organic aromatic compounds containing a benzene that carries a single methyl group and exactly two nitro groups.",
      'parent' => 4108,
    ),
    array(
      'tid' => 3970,
      'name' => "Halopyridines",
      'description' => "Organic compounds containing a pyridine ring substituted at one or more positions by a halogen atom.",
      'parent' => 89,
    ),
    array(
      'tid' => 3971,
      'name' => "Polyhalopyridines",
      'description' => "Organic compounds containing a pyridine ring substituted at two or more positions by a halogen atom.",
      'parent' => 3970,
    ),
    array(
      'tid' => 3972,
      'name' => "3-pyridinecarbonitriles",
      'description' => "Organic compounds containing a pyridine ring substituted at the 3-position by a carbonitrile group.",
      'parent' => 89,
    ),
    array(
      'tid' => 3973,
      'name' => "Organic nitrenes",
      'description' => "Compounds containing a bond between a carbon and a nitrogen atom with only 2 pairs of unshared electrons.",
      'parent' => 278,
    ),
    array(
      'tid' => 3974,
      'name' => "Carbonylnitrenes",
      'description' => "Organic compounds containing a nitrene to which a carbonyl group is attached.",
      'parent' => 3973,
    ),
    array(
      'tid' => 3975,
      'name' => "Sulfonylnitrenes",
      'description' => "Organic compounds containing a nitrene to which a sulfonyl group is attached.",
      'parent' => 3973,
    ),
    array(
      'tid' => 3976,
      'name' => "Alkyldimethylbenzylammonium halides",
      'description' => "Organic compounds consisting of a quaternary ammonium group substituted with a benzyl group, two methyl groups as well as an alkyl chain. These compounds also contain a halogen ion and have the general structure R1[N+](CH3)(CH3)R2.[X-], where R1 = benzyl group, R2 = alkyl chain, and X = halogen atom.",
      'parent' => 2279,
    ),
    array(
      'tid' => 3977,
      'name' => "Alkyldimethylbenzylammonium chlorides",
      'description' => "Organic compounds consisting of a quaternary ammonium group substituted with a benzyl group, two methyl groups as well as an alkyl chain. These compounds also contain a chlorine ion and have the general structure R1[N+](CH3)(CH3)R2.[Cl-], where R1 = benzyl group and R2 = alkyl chain.",
      'parent' => 3976,
    ),
    array(
      'tid' => 3978,
      'name' => "Hydroxybenzaldehydes",
      'description' => "Organic aromatic compounds containing a benzene ring carrying an aldehyde group and a hydroxyl group.",
      'parent' => 1345,
    ),
    array(
      'tid' => 3979,
      'name' => "Benzyl bromides",
      'description' => "Organic compounds containing  a benzene skeleton substituted with a bromomethyl group.",
      'parent' => 3981,
    ),
    array(
      'tid' => 3980,
      'name' => "Benzyl chlorides",
      'description' => "Organic compounds containing  a benzene skeleton substituted with a chloromethyl group.",
      'parent' => 3981,
    ),
    array(
      'tid' => 3981,
      'name' => "Benzyl halides",
      'description' => "Organic compounds containing  a benzene skeleton substituted with a halomethyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 3982,
      'name' => "Benzyl fluorides",
      'description' => "Organic compounds containing  a benzene skeleton substituted with a fluoromethyl group.",
      'parent' => 3981,
    ),
    array(
      'tid' => 3983,
      'name' => "Toluene diisocyanates",
      'description' => "Organic compounds containing a benzene ring, which is substituted by a methyl group and two isocyanate groups.",
      'parent' => 1091,
    ),
    array(
      'tid' => 3984,
      'name' => "Arsines",
      'description' => "AsH3 and compounds derived from it by substituting one, two or three hydrogen atoms by hydrocarbyl groups: R3As, RAsH2, R2AsH, R3As (R is not H) are called primary, secondary and tertiary arsines, respectively.",
      'parent' => 405,
    ),
    array(
      'tid' => 3985,
      'name' => "Diarsolanes",
      'description' => "Organic compounds containing a diarsolane ring, which is a saturated five-membered ring made up of three carbon and two arsenic atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 3986,
      'name' => "Arsine oxides",
      'description' => "Hydrocarbyl derivatives of H3As=O.",
      'parent' => 4280,
    ),
    array(
      'tid' => 3987,
      'name' => "Arsine imides",
      'description' => "Hydrocarbyl derivatives of H3As=N.",
      'parent' => 405,
    ),
    array(
      'tid' => 3988,
      'name' => "Arsine sulfides",
      'description' => "Hydrocarbyl derivatives of H3As=S.",
      'parent' => 405,
    ),
    array(
      'tid' => 3989,
      'name' => "Acylals",
      'description' => "Diesters of geminal diols.",
      'parent' => 1238,
    ),
    array(
      'tid' => 3990,
      'name' => "Organosulfonic anhydrides",
      'description' => "Organic compounds having the structure RS(=O)2OS(=O)2R', where R = organyl group and R' = H or organyl group.",
      'parent' => 270,
    ),
    array(
      'tid' => 3991,
      'name' => "Sulfonediimides",
      'description' => "Compounds having the structure, RS(=NR)2R', formally derived from sulfones by replacing (=O)2 by (=NR)2. R = organyl group, R' = H or organyl group.",
      'parent' => 4,
    ),
    array(
      'tid' => 3992,
      'name' => "Organic triazanes",
      'description' => "Organic compounds containing the triazane group (NH2NHNH2) or a hydrocarbyl derivative thereof.",
      'parent' => 278,
    ),
    array(
      'tid' => 3993,
      'name' => "Aminoxides",
      'description' => "Hydrocarbyl derivatives of the aminoxide anion, with the general formula R3N+[O-] or R3N=O.",
      'parent' => 278,
    ),
    array(
      'tid' => 3994,
      'name' => "Phosphonic dihydrazides",
      'description' => "Organic derivatives of phosphonic acid having the general formula RP(=O)(NHNH2)2, where the R is an organyl group and the hydrogen atoms can be replaced by an organyl group.",
      'parent' => 419,
    ),
    array(
      'tid' => 3995,
      'name' => "Organic cobalt salts",
      'description' => "Organic salt compounds containing a cobalt atom in its ionic form.",
      'parent' => 3997,
    ),
    array(
      'tid' => 3996,
      'name' => "Inorganic cobalt salts",
      'description' => "Inorganic salts containing a cobalt ion.",
      'parent' => 3866,
    ),
    array(
      'tid' => 3997,
      'name' => "Organic transition metal salts",
      'description' => "Organic salt compounds containing a transition metal atom in its ionic form.",
      'parent' => 4036,
    ),
    array(
      'tid' => 3998,
      'name' => "Organic metalloid salts",
      'description' => "Organic salt compounds containing a metalloid atom in its ionic form.",
      'parent' => 4036,
    ),
    array(
      'tid' => 3999,
      'name' => "Methoxyanilines",
      'description' => "Organic compound containing an aniline group substituted at one or more positions by a methoxy group.",
      'parent' => 284,
    ),
    array(
      'tid' => 4000,
      'name' => "2-aminobenzamides",
      'description' => "Organic compounds containing a benzamide moiety with an amine group attached to the 2-position of the benzene ring.",
      'parent' => 1917,
    ),
    array(
      'tid' => 4001,
      'name' => "2-amino-1,3,4-thiadiazoles",
      'description' => "Thiadiazoles with an amino group attached to the 2-position of a 1,3,4-thiadiazole ring.",
      'parent' => 2562,
    ),
    array(
      'tid' => 4002,
      'name' => "2-amino-5-substituted-1,3,4-thiadiazoles",
      'description' => "Thiadiazoles with an amino group attached to the 2-position of a 1,3,4-thiadiazole ring, as well as a substituent at the 5-position.",
      'parent' => 4001,
    ),
    array(
      'tid' => 4003,
      'name' => "2-amino-1,3-thiazoles",
      'description' => "Compounds containing a 1,3-thiazole ring substituted by an amine group at the 2-position.",
      'parent' => 2329,
    ),
    array(
      'tid' => 4004,
      'name' => "2-aminothiophenes",
      'description' => "Organic compounds containing an amino group conjugated to a thiophene ring at the 2-position.",
      'parent' => 1936,
    ),
    array(
      'tid' => 4005,
      'name' => "3,4,5-trisubstituted-2-aminothiophenes",
      'description' => "Organic compounds containing a thiophene ring substituted  at the 2-,3-,4-, and 5-position, with an amine group at the 2-position.",
      'parent' => 4004,
    ),
    array(
      'tid' => 4006,
      'name' => "N-arylated-2-aminothiophenes",
      'description' => "Organic compounds containing an arylated amino group conjugated to a thiophene ring at the 2-position.",
      'parent' => 4004,
    ),
    array(
      'tid' => 4007,
      'name' => "Benzazocines",
      'description' => "Organic compounds containing the benzazocine ring system, which consists of a benzene ring bound to an azocine ring.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4008,
      'name' => "Chloroquinolines",
      'description' => "Compounds containing a quinoline moiety, which carries one or more chlorine atoms.",
      'parent' => 4403,
    ),
    array(
      'tid' => 4009,
      'name' => "Phthalate esters",
      'description' => "Ester derivatives of phthalic acids, which are based on a benzene dicarboxylic acid skeleton.",
      'parent' => 1105,
    ),
    array(
      'tid' => 4010,
      'name' => "m-Phthalate esters",
      'description' => "Ester derivatives of m-phthalic acids, which are based on a benzene 1,3-dicarboxylic acid skeleton.",
      'parent' => 4009,
    ),
    array(
      'tid' => 4011,
      'name' => "o-Phthalate esters",
      'description' => "Ester derivatives of o-phthalic acids, which are based on a benzene 1,2-dicarboxylic acid skeleton.",
      'parent' => 4009,
    ),
    array(
      'tid' => 4012,
      'name' => "p-Phthalate esters",
      'description' => "Ester derivatives of p-phthalic acids, which are based on a benzene 1,4-dicarboxylic acid skeleton.",
      'parent' => 4009,
    ),
    array(
      'tid' => 4013,
      'name' => "C19-gibberellin 6-carboxylic acids",
      'description' => "C19-gibberellins with a carboxyl group at the 6-position.",
      'parent' => 2998,
    ),
    array(
      'tid' => 4014,
      'name' => "C20-gibberellin 6-carboxylic acids",
      'description' => "C20-gibberellins with a carboxyl group at the 6-position.",
      'parent' => 2999,
    ),
    array(
      'tid' => 4015,
      'name' => "C20-gibberellin 20-carboxylic acids",
      'description' => "C20-gibberellins with a carboxyl group at the 6-position.",
      'parent' => 2999,
    ),
    array(
      'tid' => 4016,
      'name' => "2-hydroxy,20-norgibberellanes",
      'description' => "Gibberellins where the C20 carbon atom has been eliminated, and which carry a hydroxyl group at the 2-position.",
      'parent' => 2998,
    ),
    array(
      'tid' => 4017,
      'name' => "Organocopper compounds",
      'description' => "Compounds containing a bond between a carbon atom and a copper atom.",
      'parent' => 1371,
    ),
    array(
      'tid' => 4018,
      'name' => "Organic copper salts",
      'description' => "Organic salt compounds containing a copper atom in its ionic form.",
      'parent' => 3997,
    ),
    array(
      'tid' => 4019,
      'name' => "Inorganic copper salts",
      'description' => "Inorganic salts containing a copper ion.",
      'parent' => 3866,
    ),
    array(
      'tid' => 4020,
      'name' => "Vinylogous thioesters",
      'description' => "Organic compounds containing a thioester group, which is indirectly attached to a carbonyl via an intervening vinyl (>C=C<) moiety.",
      'parent' => 264,
    ),
    array(
      'tid' => 4021,
      'name' => "4-hydroxy-3-polyprenylbenzoic acids",
      'description' => "Benzoic acids that are substituted at the 3-position by any polyprenyl group and at the 4-position by a hydroxyl group.",
      'parent' => 2565,
    ),
    array(
      'tid' => 4022,
      'name' => "(5L-glutamyl)-alpha-peptides",
      'description' => "Oligo- and polypeptides consisting of any C-terminal alpha peptide having a L-gamma-glutamyl residue attached at the N alpha-position.",
      'parent' => 3025,
    ),
    array(
      'tid' => 4023,
      'name' => "5L-glutamyl alpha-amino-acids",
      'description' => "Dipeptides consisting of any C-terminal amino acid having a L-gamma-glutamyl residue attached at the N alpha-position.",
      'parent' => 3024,
    ),
    array(
      'tid' => 4024,
      'name' => "Organolead compounds",
      'description' => "Compounds containing bond between a carbon atom and a lead atom.",
      'parent' => 1523,
    ),
    array(
      'tid' => 4025,
      'name' => "Organosilver compounds",
      'description' => "Organic compounds containing a bond between a carbon atom and a silver atom.",
      'parent' => 1371,
    ),
    array(
      'tid' => 4026,
      'name' => "Cyanide salts",
      'description' => "Organic compounds containing the cyanide anion [C-]#N.",
      'parent' => 3865,
    ),
    array(
      'tid' => 4027,
      'name' => "Alkyl lead compounds",
      'description' => "Organolead compounds containing one or more alkyl chains  attached to the lead atom.",
      'parent' => 4024,
    ),
    array(
      'tid' => 4028,
      'name' => "Hydroxymercuribenzoic acids",
      'description' => "Benzoic acids containing a hydroxymercury (-HgOH) group attached to the benzene moiety.",
      'parent' => 4029,
    ),
    array(
      'tid' => 4029,
      'name' => "Mercuribenzoic acids",
      'description' => "Benzoic acids containing a mercury atom attached to the benzene moiety.",
      'parent' => 2565,
    ),
    array(
      'tid' => 4030,
      'name' => "2-Hydroxymercuribenzoic acids",
      'description' => "Benzoic acids containing a hydroxymercury (-HgOH) group attached to the 2-position of the benzene moiety.",
      'parent' => 4028,
    ),
    array(
      'tid' => 4031,
      'name' => "3-Hydroxymercuribenzoic acids",
      'description' => "Benzoic acids containing a hydroxymercury (-HgOH) group attached to the 3-position of the benzene moiety.",
      'parent' => 4028,
    ),
    array(
      'tid' => 4032,
      'name' => "4-Hydroxymercuribenzoic acids",
      'description' => "Benzoic acids containing a hydroxymercury (-HgOH) group attached to the 4-position of the benzene moiety.",
      'parent' => 4028,
    ),
    array(
      'tid' => 4033,
      'name' => "2-Mercuribenzoic acids",
      'description' => "Benzoic acids containing a mercury atom attached to the 2-position of the benzene moiety.",
      'parent' => 4029,
    ),
    array(
      'tid' => 4034,
      'name' => "3-Mercuribenzoic acids",
      'description' => "Benzoic acids containing a mercury atom attached to the 3-position of the benzene moiety.",
      'parent' => 4029,
    ),
    array(
      'tid' => 4035,
      'name' => "4-Mercuribenzoic acids",
      'description' => "Benzoic acids containing a mercury atom attached to the 4-position of the benzene moiety.",
      'parent' => 4029,
    ),
    array(
      'tid' => 4036,
      'name' => "Organic metal salts",
      'description' => "Organic salt compounds containing a metal atom in its ionic form.",
      'parent' => 3865,
    ),
    array(
      'tid' => 4037,
      'name' => "Organic metal bromide salts",
      'description' => "Organic metal salts containing a bromine atom in its ionic form.",
      'parent' => 4036,
    ),
    array(
      'tid' => 4038,
      'name' => "Organic tin salts",
      'description' => "Organic salt compounds containing a tin atom in its ionic form.",
      'parent' => 4040,
    ),
    array(
      'tid' => 4039,
      'name' => "Inorganic tin salts",
      'description' => "Inorganic salt compounds containing a tin atom either in its ionic form or bonded to another atom.",
      'parent' => 3866,
    ),
    array(
      'tid' => 4040,
      'name' => "Organic post-transition metal salts",
      'description' => "Organic salt compounds containing a post-transition metal atom in its ionic form.",
      'parent' => 4036,
    ),
    array(
      'tid' => 4041,
      'name' => "Organic aluminium salts",
      'description' => "Organic salt compounds containing a tin atom in its ionic form.",
      'parent' => 4040,
    ),
    array(
      'tid' => 4042,
      'name' => "Alkyl mercury compounds",
      'description' => "Organometallic compounds containing an alkyl group attached to a mercury atom.",
      'parent' => 407,
    ),
    array(
      'tid' => 4043,
      'name' => "Aryl mercury compounds",
      'description' => "Organometallic compounds containing an aryl group attached to a mercury atom.",
      'parent' => 407,
    ),
    array(
      'tid' => 4044,
      'name' => "Phallotoxins",
      'description' => "Bicyclic heptapeptides containing an indole fused to the cyclic peptide moiety.",
      'parent' => 1995,
    ),
    array(
      'tid' => 4045,
      'name' => "Amatoxins",
      'description' => "Cyclic peptides containing eight amino acid residues arranged in a macrobicyclic motif.",
      'parent' => 1995,
    ),
    array(
      'tid' => 4046,
      'name' => "Perfluoroalkane N-alkylsulfonamides",
      'description' => "Organic compounds containing an alkyl chain, where all hydrogens of the alkyl chain are replaced by fluorine atoms, and which is attached to the sulfur of a N-alkyl sulfonamide group.",
      'parent' => 3961,
    ),
    array(
      'tid' => 4047,
      'name' => "Perfluoroalkane N,N-alkylsulfonamides",
      'description' => "Organic compounds containing an alkyl chain, where all hydrogens of the alkyl chain are replaced by fluorine atoms, and which is attached to the sulfur of a N,N-dialkyl sulfonamide group.",
      'parent' => 3961,
    ),
    array(
      'tid' => 4048,
      'name' => "Perfluoroalkane sulfonamidoethanols",
      'description' => "Organic compounds containing an alkyl chain attached to the sulfur of a sulfonamidoethanol group, where all hydrogens of the alkyl chain are replaced by fluorine atoms.",
      'parent' => 3961,
    ),
    array(
      'tid' => 4049,
      'name' => "Perfluoroalkane sulfonamidoacetals",
      'description' => "Organic compounds containing an alkyl chain attached to the sulfur of a sulfonamidoacetal, where all hydrogens of the alkyl chain are replaced by fluorine atoms.",
      'parent' => 3961,
    ),
    array(
      'tid' => 4050,
      'name' => "Perfluoroalkanesulfonyl fluorides",
      'description' => "Organic compounds containing an alkyl chain attached to the sulfur of an organosulfonyl fluoride group, where all hydrogens of the alkyl chain are replaced by fluorine atoms.",
      'parent' => 1027,
    ),
    array(
      'tid' => 4051,
      'name' => "Organic lead salts",
      'description' => "Organic salts containing a lead ion.",
      'parent' => 4040,
    ),
    array(
      'tid' => 4052,
      'name' => "Inorganic lead salts",
      'description' => "Inorganic salts containing a lead ion.",
      'parent' => 3866,
    ),
    array(
      'tid' => 4053,
      'name' => "Trivalent inorganic arsenic compounds",
      'description' => "Inorganic compounds containing a trivalent arsenic atom.",
      'parent' => 4057,
    ),
    array(
      'tid' => 4054,
      'name' => "Pentavalent inorganic arsenic compounds",
      'description' => "Inorganic compounds containing a pentavalent arsenic atom.",
      'parent' => 4057,
    ),
    array(
      'tid' => 4055,
      'name' => "Trivalent organic arsenic compounds",
      'description' => "Organoarsenic compounds in which a carbon is linked to a trivalent arsenic atom.",
      'parent' => 405,
    ),
    array(
      'tid' => 4056,
      'name' => "Pentavalent organic arsenic compounds",
      'description' => "Organoarsenic compounds in which a carbon is linked to a pentavalent arsenic atom.",
      'parent' => 405,
    ),
    array(
      'tid' => 4057,
      'name' => "Inorganic arsenic compounds",
      'description' => "Inorganic compounds containing the arsenic atom.",
      'parent' => 1568,
    ),
    array(
      'tid' => 4058,
      'name' => "Methylated trivalent arsenic compounds",
      'description' => "Organoarsenic compounds containing a trivalent arsenic atom linked to one or more methyl group.",
      'parent' => 4055,
    ),
    array(
      'tid' => 4059,
      'name' => "Trialkylarsanes",
      'description' => "Organoarsenic compounds containing a trivalent arsenic atom linked to three alkyl groups.",
      'parent' => 4237,
    ),
    array(
      'tid' => 4060,
      'name' => "Inorganic mercury compounds",
      'description' => "Inorganic compounds containing a mercury atom.",
      'parent' => 1568,
    ),
    array(
      'tid' => 4061,
      'name' => "Inorganic nickel compounds",
      'description' => "Inorganic compounds containing a nickel atom.",
      'parent' => 1568,
    ),
    array(
      'tid' => 4062,
      'name' => "Inorganic silver salts",
      'description' => "Inorganic salts containing a silver ion or a bonded silver atom.",
      'parent' => 3866,
    ),
    array(
      'tid' => 4063,
      'name' => "Organic silver salts",
      'description' => "Organic salt compounds containing a copper atom either in its ionic form or bonded to another atom.",
      'parent' => 3997,
    ),
    array(
      'tid' => 4064,
      'name' => "Transition metal cyanide salts",
      'description' => "Organic compounds containing a transition metal and a cyanide ion [C-]#N.",
      'parent' => 3997,
    ),
    array(
      'tid' => 4065,
      'name' => "Triorganolead compounds",
      'description' => "Compounds containing a lead compound bonded to three carbon atoms.",
      'parent' => 4024,
    ),
    array(
      'tid' => 4066,
      'name' => "Triorganotin compounds",
      'description' => "Compounds containing a tin compound bonded to exactly three carbon atoms.",
      'parent' => 1524,
    ),
    array(
      'tid' => 4067,
      'name' => "Triorganotin halide salts",
      'description' => "Organic compounds containing a tin atom bonded to three carbon atoms and a halogen atom.",
      'parent' => 4038,
    ),
    array(
      'tid' => 4068,
      'name' => "Triorganotin metal salts",
      'description' => "Organic compounds containing a tin atom bonded to three carbon atoms and a metal atom.",
      'parent' => 4038,
    ),
    array(
      'tid' => 4069,
      'name' => "Trialkylstibanes",
      'description' => "Organoantimony compounds containing a  trivalent antimony atom linked to exactly three alkyl chains.",
      'parent' => 349,
    ),
    array(
      'tid' => 4070,
      'name' => "Monoalkyltins",
      'description' => "Triorganotin compounds where the tin atom is linked to exactly one alkyl groups.",
      'parent' => 1524,
    ),
    array(
      'tid' => 4071,
      'name' => "Dialkyltins",
      'description' => "Triorganotin compounds where the tin atom is linked to exactly two alkyl groups.",
      'parent' => 1524,
    ),
    array(
      'tid' => 4072,
      'name' => "Trialkyltins",
      'description' => "Triorganotin compounds where the tin atom is linked to exactly three alkyl groups.",
      'parent' => 4066,
    ),
    array(
      'tid' => 4073,
      'name' => "Organochromium compounds",
      'description' => "Compounds containing a bond between a carbon atom and a chromium atom.",
      'parent' => 1371,
    ),
    array(
      'tid' => 4074,
      'name' => "Inorganic chromium (VI) compounds",
      'description' => "Inorganic compounds containing one or more hexavalent chromium atoms.",
      'parent' => 1568,
    ),
    array(
      'tid' => 4075,
      'name' => "Organic cadmium salts",
      'description' => "Organic salts of cadmium. They usually contain cadmium in its ionic form.",
      'parent' => 3997,
    ),
    array(
      'tid' => 4076,
      'name' => "Inorganic cadmium salts",
      'description' => "Inorganic salts of cadmium. They usually contain cadmium in its ionic form.",
      'parent' => 3866,
    ),
    array(
      'tid' => 4077,
      'name' => "Inorganic antimony salts",
      'description' => "Inorganic salts of antimony. They usually contain antimony in its ionic form.",
      'parent' => 3866,
    ),
    array(
      'tid' => 4078,
      'name' => "Organic antimony salts",
      'description' => "Organic salts of antimony. They usually contain antimony in its ionic form.",
      'parent' => 3998,
    ),
    array(
      'tid' => 4079,
      'name' => "Vinylaziridines",
      'description' => "Compounds containing an aziridine ring substituted by one or more vinyl groups.",
      'parent' => 103,
    ),
    array(
      'tid' => 4080,
      'name' => "N-vinylaziridines",
      'description' => "Compounds containing an aziridine ring where the nitrogen atom is substituted by a vinyl group.",
      'parent' => 4079,
    ),
    array(
      'tid' => 4081,
      'name' => "Iridoid O-glycosides",
      'description' => "Iridoid monoterpenes containing a glycosyl (usually a pyranosyl) moiety linked to the iridoid skeleton.",
      'parent' => 2049,
    ),
    array(
      'tid' => 4082,
      'name' => "4-arylsulfanyl-substituted kainoids",
      'description' => "Kainoids carrying an aryl sulfanyl group at the 4-position of the pyrrolidine ring.",
      'parent' => 1801,
    ),
    array(
      'tid' => 4083,
      'name' => "1-benzylquinolines",
      'description' => "Organic aromatic compounds containing a quinoline that is substituted at the 1-position by a benzyl group.",
      'parent' => 1253,
    ),
    array(
      'tid' => 4084,
      'name' => "Cyanogens",
      'description' => "Organonitrogen compounds of the form NC-CN or X-CN, where X is a halogen.",
      'parent' => 362,
    ),
    array(
      'tid' => 4085,
      'name' => "Dialkyltin dicarboxylates",
      'description' => "Organotin compounds containing  a tin atom linked to 2 alkyl chain and to acyl groups.",
      'parent' => 4071,
    ),
    array(
      'tid' => 4086,
      'name' => "Thiodisulfinates",
      'description' => "Organosulfur compounds with the general formula RS(=O)S, where R = organyl group.",
      'parent' => 4,
    ),
    array(
      'tid' => 4087,
      'name' => "Acyl nitrates",
      'description' => "Organic compounds containing a nitrate that is O-linked to an acyl group.",
      'parent' => 395,
    ),
    array(
      'tid' => 4088,
      'name' => "Peroxyacyl nitrates",
      'description' => "Organic compounds containing a peroxide group linked to an acyl group and a nitrate group.",
      'parent' => 395,
    ),
    array(
      'tid' => 4089,
      'name' => "Dialkyldisulfides",
      'description' => "Organic compounds containing a disulfide group R-SS-R' where R and R' are both alkyl groups.",
      'parent' => 2800,
    ),
    array(
      'tid' => 4090,
      'name' => "Dialkyltin salts",
      'description' => "Salts of dialkyltin compounds.",
      'parent' => 4071,
    ),
    array(
      'tid' => 4091,
      'name' => "Alkyl nitrates",
      'description' => "Organic compounds containing a nitrate that is O-linked to an alkyl group.",
      'parent' => 395,
    ),
    array(
      'tid' => 4092,
      'name' => "Acyl nitrites",
      'description' => "Organic compounds containing an acyl group linked to a nitrite group.",
      'parent' => 396,
    ),
    array(
      'tid' => 4093,
      'name' => "Alkyl nitrites",
      'description' => "Organic compounds containing an alkyl group linked to a nitrite group.",
      'parent' => 396,
    ),
    array(
      'tid' => 4094,
      'name' => "Alkyl perchlorates",
      'description' => "Organic compounds containing perchlorate group attached to an alkyl group.",
      'parent' => 2067,
    ),
    array(
      'tid' => 4095,
      'name' => "1-phenethylisoquinolines",
      'description' => "Organic aromatic compounds containing a quinoline ring system substituted at the 1-position by a phenethyl group.",
      'parent' => 2566,
    ),
    array(
      'tid' => 4096,
      'name' => "Mitomycins, mitosane and mitosene derivatives",
      'description' => "A group of pyrroloindolediones, which carry a methyl group at the 6-position of their quinone moiety. The mitosane (containing an aziridine) and mitosene server as backbone for mitomycins and their derivatives.",
      'parent' => 390,
    ),
    array(
      'tid' => 4097,
      'name' => "1,4-benzodiazepines",
      'description' => "Organic compounds containing a benzene ring fused to a 1,4-azepine.",
      'parent' => 295,
    ),
    array(
      'tid' => 4098,
      'name' => "Imidazo[1,5-a][1,4]benzodiazepines",
      'description' => "Compounds containing an imidazole ring and a 1,4-benzodiazepine ring system, both sharing one nitrogen atom.",
      'parent' => 4097,
    ),
    array(
      'tid' => 4099,
      'name' => "Organic alkali metal salts",
      'description' => "Organic salts of an alkali metal. The alkali metal atom is usually in its ionic form.",
      'parent' => 4036,
    ),
    array(
      'tid' => 4100,
      'name' => "Thio-linked disaccharides",
      'description' => "Compounds containing two carbohydrate moieties linked to each to each other through a thioglycosidic bond.",
      'parent' => 1542,
    ),
    array(
      'tid' => 4101,
      'name' => "N-linked disaccharides",
      'description' => "Compounds containing two carbohydrate moieties linked to each to each other through a N-glycosidic bond.",
      'parent' => 1542,
    ),
    array(
      'tid' => 4102,
      'name' => "Inorganic sodium salts",
      'description' => "Inorganic salt compounds containing a sodium atom either in its ionic form or bonded to another atom (metal or halogen).",
      'parent' => 3866,
    ),
    array(
      'tid' => 4103,
      'name' => "Inorganic chloride salts",
      'description' => "Inorganic salt compounds containing a chlorine atom either in its ionic form or bonded to another atom (metal or halogen).",
      'parent' => 3866,
    ),
    array(
      'tid' => 4104,
      'name' => "1,3,5-triazine ribonucleosides and ribonucleotides",
      'description' => "Nucleosides or nucleotides with a structure that consists of a 1,3,5-triazine ring, which is N-linked to a ribose (or deoxyribose). Nucleotides have a phosphate group linked to the C5 carbon of the ribose (or deoxyribose) moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 4105,
      'name' => "1,3,5-triazines",
      'description' => "Compounds containing a triazine ring, which is a heterocyclic ring, similar to the six-member benzene ring but with three carbons replaced by nitrogen atoms, at ring positions 1, 3, and 5.",
      'parent' => 98,
    ),
    array(
      'tid' => 4106,
      'name' => "1,2,3-triazines",
      'description' => "Compounds containing a triazine ring, which is a heterocyclic ring, similar to the six-member benzene ring but with three carbons replaced by nitrogen atoms, at ring positions 1, 2, and 3.",
      'parent' => 98,
    ),
    array(
      'tid' => 4107,
      'name' => "1,2,4-triazines",
      'description' => "Compounds containing a triazine ring, which is a heterocyclic ring, similar to the six-member benzene ring but with three carbons replaced by nitrogen atoms, at ring positions 1, 2, and 4.",
      'parent' => 98,
    ),
    array(
      'tid' => 4108,
      'name' => "Nitrotoluenes",
      'description' => "Organic aromatic compounds containing a benzene that carries a single methyl group and at least 1 nitro group.",
      'parent' => 1091,
    ),
    array(
      'tid' => 4109,
      'name' => "Menaquinones",
      'description' => "Vitamin K2 compounds consisting of a naphtho-1,4-quinone ring system, which is substituted at the 2-position by an isoprenyl side-chain, and usually, at the 3-position by a methyl group.",
      'parent' => 1547,
    ),
    array(
      'tid' => 4110,
      'name' => "1-benzoylpiperidines",
      'description' => "Compounds containing a piperidine ring substituted at the 1-position with a benzoyl group.",
      'parent' => 321,
    ),
    array(
      'tid' => 4111,
      'name' => "Dimethoxybenzenes",
      'description' => "Organic aromatic compounds containing a monocyclic benzene moiety carrying exactly two methoxy groups.",
      'parent' => 4113,
    ),
    array(
      'tid' => 4112,
      'name' => "Benzoyl peroxides",
      'description' => "Organic compounds containing two benzoyl groups O-linked to each other via a peroxide group. Their skeleton has the general formula [C6H5C(O)]2O2.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4113,
      'name' => "Methoxybenzenes",
      'description' => "Organic aromatic compounds containing a monocyclic benzene moiety carrying exactly or one more methoxy groups.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4114,
      'name' => "Alpha-imino acids",
      'description' => "Organic acids containing an imino group attached to a carbon, which in turn is immediately linked to a carboxyl group. They have the generic structure RN=CC(=O)OH or RN=CC(=O)[O-] (salt form), where R is any atom.",
      'parent' => 4132,
    ),
    array(
      'tid' => 4115,
      'name' => "N-substituted alpha-imino acids",
      'description' => "Alpha imino acids in which the N-atom of the imino group is substituted. They have the generic structure RN=CC(=O)OH or RN=CC(=O)[O-] (salt form), where R is a non-hydrogen atom.",
      'parent' => 4114,
    ),
    array(
      'tid' => 4116,
      'name' => "N,S-acetals",
      'description' => "Organosulfur compounds with the generic structure RC(SR')N([H])C=O, where R,R'= H or organyl group.",
      'parent' => 1666,
    ),
    array(
      'tid' => 4117,
      'name' => "C-nitro compounds",
      'description' => "Compounds having the nitro group, -NO2 (free valence on nitrogen), which is attached to carbon.",
      'parent' => 1152,
    ),
    array(
      'tid' => 4118,
      'name' => "Oxoisoaporphines",
      'description' => "Alkaloids with a structure that contains the isoaporphine skeleton with an oxo group at the 7-position.",
      'parent' => 3018,
    ),
    array(
      'tid' => 4119,
      'name' => "Isoatisine-type diterpenoid alkaloids",
      'description' => "Alkaloid diterpenoids with a structure based on the pentacyclic isoatisine skeleton.",
      'parent' => 2738,
    ),
    array(
      'tid' => 4120,
      'name' => "Lycorine-type amaryllidaceae alkaloids",
      'description' => "Amaryllidaceae alkaloids compounds containing the lycorine skeleton, made up of a pyrrolo[d,e]phenanthridine ring system.",
      'parent' => 1775,
    ),
    array(
      'tid' => 4121,
      'name' => "Norbelladine-type amaryllidaceae alkaloids",
      'description' => "Amaryllidaceae alkaloids compounds containing the norbelladine skeleton.  They are derived initially from the condensation of tyramine and protocatechuic aldehyde or its derivatives in plants.",
      'parent' => 1775,
    ),
    array(
      'tid' => 4122,
      'name' => "Homolycorine-type amaryllidaceae alkaloids",
      'description' => "Amaryllidaceae alkaloids compounds containing the homolycorine skeleton, made up of a [3,4-g]benzopyranone ring due to the oxidation of the hydroxyl group at the C6. They are biogenetically formed through a restructuring of lycorine-type alkaloids.",
      'parent' => 1775,
    ),
    array(
      'tid' => 4123,
      'name' => "Crinine- and Haemanthamine-type amaryllidaceae alkaloids",
      'description' => "Amaryllidaceae alkaloids compounds with a structure based on the crinine or haemanthamine backbone. Both backbones have a common 5,10b-ethano bridge moiety in their frameworks, which is a very significant taxonomic feature, and the configurations of the 5,10b-ethano bridge are opposite to each other.",
      'parent' => 1775,
    ),
    array(
      'tid' => 4124,
      'name' => "Tazettine-type amaryllidaceae alkaloids",
      'description' => "Amaryllidaceae alkaloids derived from the haemanthamine-type alkaloids, which are characterized as a linkage between C6 and C11 by an oxygen atom to form a [3,4-g]benzopyran framework.",
      'parent' => 1775,
    ),
    array(
      'tid' => 4125,
      'name' => "Montanine-type amaryllidaceae alkaloids",
      'description' => "Amaryllidaceae alkaloids based on the montanine skeleton, which is made up of a characteristic 5,11-methanomorphanthridine framework.",
      'parent' => 1775,
    ),
    array(
      'tid' => 4126,
      'name' => "Plicamine-type amaryllidaceae alkaloids",
      'description' => "Dinitrogenous Amaryllidaceae alkaloids derived from tazettine-type alkaloids, by replacement of the oxygen atom at the C6 by a nitrogen atom, which is in turn substituted with a 4-hydroxyphenethyl unit.  In addition, all alkaloids of this minor subgroup have an amide group on the C12.",
      'parent' => 1775,
    ),
    array(
      'tid' => 4127,
      'name' => "Galanthindole-type amaryllidaceae alkaloids",
      'description' => "Amaryllidaceae alkaloids based on a 7-arylindole or 7-aryl-2,3-dihydroindole skeleton.",
      'parent' => 1775,
    ),
    array(
      'tid' => 4128,
      'name' => "Galanthamine-type amaryllidaceae alkaloids",
      'description' => "Amaryllidaceae alkaloids with a structure characterized a tetracyclic skeleton with two ortho aromatic protons in ring A.",
      'parent' => 1775,
    ),
    array(
      'tid' => 4129,
      'name' => "Phenanthridine- and phenanthridone-type amaryllidaceae alkaloids",
      'description' => "Amaryllidaceae alkaloids compounds based on the phenanthridine or the phenanthridone skeleton. Phenanthridone-type alkaloids have the highest oxygenated C ring in all Amaryllidaceae alkaloids, and they always show an amide group in ring B. On the contrary, alkaloids of the phenanthridine type often show completely aromatic ring system, occasionally with a methylation quaternary nitrogen atom.",
      'parent' => 1775,
    ),
    array(
      'tid' => 4130,
      'name' => "Gracilline-type amaryllidaceae alkaloids",
      'description' => "Amaryllidaceae alkaloids compounds containing a 10b,4a-ethanoiminodibenzo[b,d]pyrane skeleton.",
      'parent' => 1775,
    ),
    array(
      'tid' => 4131,
      'name' => "6,7-benzomorphans",
      'description' => "Opioid alkaloids based on the tricyclic 6,7-benzomorphan skeleton. Benzomorphans are derived from morpholine, but lack its C ring.",
      'parent' => 279,
    ),
    array(
      'tid' => 4132,
      'name' => "Alpha-imino acid and derivatives",
      'description' => "Organic acids containing an imino group attached to a carbon, which in turn is immediately linked to a carboxyl group (or a derivative thereof).",
      'parent' => 265,
    ),
    array(
      'tid' => 4133,
      'name' => "Alpha-imino acid esters",
      'description' => "Ester derivatives of alpha-imino acids. They have the general structure RN=CC(=O)OR', where R = H, organyl group and R' = organyl group.",
      'parent' => 4132,
    ),
    array(
      'tid' => 4134,
      'name' => "Epithionitriles",
      'description' => "Organoheterocyclic compounds made up of a carbon atom linked to a thiirane ring and a carbonitrile group.",
      'parent' => 377,
    ),
    array(
      'tid' => 4135,
      'name' => "Desulfoglucosinolates",
      'description' => "Derivatives of glucosinolates which arise by removal of the sulfonate moiety.",
      'parent' => 1498,
    ),
    array(
      'tid' => 4136,
      'name' => "Thiohydroximic acids and derivatives",
      'description' => "Organosulfur compounds containing the thiohydroximic acid group (RC(S)=NOH, where R = H or organyl group) or a derivative thereof.",
      'parent' => 264,
    ),
    array(
      'tid' => 4137,
      'name' => "Thiohydroximic acids",
      'description' => "Organosulfur compounds with the general structure RC(S)=NOH, where R = H or organyl group.",
      'parent' => 4136,
    ),
    array(
      'tid' => 4138,
      'name' => "S-alkyl-thiohydroximates",
      'description' => "Organosulfur compounds with the general structure RC(S)=NOH, where R =alkyl group.",
      'parent' => 4137,
    ),
    array(
      'tid' => 4139,
      'name' => "Azacyclic compounds",
      'description' => "Organic compounds containing an heterocycle with at least one nitrogen atom and one carbon atom linked to each other.",
      'parent' => 2,
    ),
    array(
      'tid' => 4140,
      'name' => "Oxacyclic compounds",
      'description' => "Organic compounds containing an heterocycle with at least one oxygen atom linked to a ring carbon.",
      'parent' => 2,
    ),
    array(
      'tid' => 4141,
      'name' => "Phosphacyclic compounds",
      'description' => "Organic compounds containing an heterocycle with at least one phosphorus atom and one carbon atom linked to each other.",
      'parent' => 2,
    ),
    array(
      'tid' => 4142,
      'name' => "Kalmanes and 1,5-seco-kalmanes",
      'description' => "Grayanoids containing a B-homo-C-nor grayanane skeleton or a 1,5-derivative thereof.",
      'parent' => 2871,
    ),
    array(
      'tid' => 4143,
      'name' => "Methionine and derivatives",
      'description' => "Compounds containing methionine or a derivative thereof resulting from reaction of methionine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4144,
      'name' => "Heteroaromatic compounds",
      'description' => "Compounds containing an aromatic ring where a carbon atom is linked to an hetero atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 4145,
      'name' => "D-alpha-amino acids",
      'description' => "Alpha amino acids which have the D-configuration of the alpha-carbon atom.",
      'parent' => 2404,
    ),
    array(
      'tid' => 4146,
      'name' => "L-alpha-amino acids",
      'description' => "Alpha amino acids which have the L-configuration of the alpha-carbon atom.",
      'parent' => 2404,
    ),
    array(
      'tid' => 4147,
      'name' => "Phenylpyridazines",
      'description' => "Organic compounds containing a pyridazine ring substituted by a phenyl group.",
      'parent' => 74,
    ),
    array(
      'tid' => 4148,
      'name' => "N-acyl-L-alpha-amino acids",
      'description' => "N-acylated alpha amino acids which have the L-configuration of the alpha-carbon atom.",
      'parent' => 2402,
    ),
    array(
      'tid' => 4149,
      'name' => "Polycyclic hydrocarbons",
      'description' => "Polycyclic organic compounds made up only of carbon and hydrogen atoms.",
      'parent' => 2837,
    ),
    array(
      'tid' => 4150,
      'name' => "Hydrocarbon derivatives",
      'description' => "Derivatives of hydrocarbons obtained by substituting one or more carbon atoms by an heteroatom. They contain at least one carbon atom and heteroatom.",
      'parent' => 0,
    ),
    array(
      'tid' => 4151,
      'name' => "Hydroxypyridines",
      'description' => "Organic compounds containing a pyridine ring substituted at one or more positions by a hydroxyl group.",
      'parent' => 89,
    ),
    array(
      'tid' => 4152,
      'name' => "Methylpyridines",
      'description' => "Organic compounds containing a pyridine ring substituted at one or more positions by a methyl group.",
      'parent' => 89,
    ),
    array(
      'tid' => 4153,
      'name' => "Cladiellane diterpenoids",
      'description' => "Diterpenoids containing a cladiellane skeleton. Cladiellane is a tricyclic ring system derived from eunicellane.",
      'parent' => 1551,
    ),
    array(
      'tid' => 4154,
      'name' => "Hydroxyisoflavonoids",
      'description' => "Organic compounds containing an isoflavonoid skeleton carrying one or more hydroxyl groups.",
      'parent' => 2506,
    ),
    array(
      'tid' => 4155,
      'name' => "Diphenylethers",
      'description' => "Aromatic compounds containing two benzene rings linked to each other through an ether group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4156,
      'name' => "Steroidal alkaloid glycosides",
      'description' => "Compounds made up of a steroidal alkaloid moiety which is glycosylated, usually at the C-3 or C-28 position.",
      'parent' => 2724,
    ),
    array(
      'tid' => 4157,
      'name' => "Halomethanes",
      'description' => "Organic compounds in which at least one of the four hydrogen atoms of methane (CH4) are replaced by halogen atoms.",
      'parent' => 2867,
    ),
    array(
      'tid' => 4158,
      'name' => "1-hydroxysteroids",
      'description' => "Steroids carrying a hydroxyl group at the 1-position of the steroid backbone.",
      'parent' => 1295,
    ),
    array(
      'tid' => 4159,
      'name' => "18-hydroxysteroids",
      'description' => "Steroids carrying a hydroxyl group at the 18-position of the steroid backbone.",
      'parent' => 1295,
    ),
    array(
      'tid' => 4160,
      'name' => "Trihalomethanes",
      'description' => "Organic compounds in which exactly three of the four hydrogen atoms of methane (CH4) are replaced by halogen atoms.",
      'parent' => 4157,
    ),
    array(
      'tid' => 4161,
      'name' => "Hydroxypyrimidines",
      'description' => "Organic compounds containing a hydroxyl group attached to a pyrimidine ring. Pyrimidine is a 6-membered ring consisting of four carbon atoms and two nitrogen centers at the 1- and 3- ring positions.",
      'parent' => 75,
    ),
    array(
      'tid' => 4162,
      'name' => "Hydroxyindoles",
      'description' => "Organic compounds containing an indole moiety that carries a hydroxyl group.",
      'parent' => 211,
    ),
    array(
      'tid' => 4163,
      'name' => "Thioselenides",
      'description' => "Organic compounds containing a sulfur-selenium bond. This class is restricted to compounds where at least one of the sulfur or selenium atoms is linked to a carbon atom.",
      'parent' => 4,
    ),
    array(
      'tid' => 4164,
      'name' => "Dithiophosphate O-esters",
      'description' => "O-ester derivatives of dithiophosphates, with the general structure RSP(O)(O)=S (R = organyl group).",
      'parent' => 3385,
    ),
    array(
      'tid' => 4165,
      'name' => "Phenolic glycosides",
      'description' => "Organic compounds containing a phenolic structure attached to a glycosyl moiety. Some examples of phenolic structures include lignans, and flavonoids. Among the sugar units found in natural glycosides are D-glucose, L-Fructose, and L rhamnose.",
      'parent' => 2105,
    ),
    array(
      'tid' => 4166,
      'name' => "Phenoselenazines",
      'description' => "Organic compounds containing two benzene rings joined together by a selenomorpholine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4167,
      'name' => "Perimidines",
      'description' => "Organic compounds containing a benzene ring fused to a quinazoline ring system. They are analogues of phenalenes where two carbon atoms in exactly one ring are replaced by nitrogen atoms to form a pyrimidine.",
      'parent' => 485,
    ),
    array(
      'tid' => 4168,
      'name' => "Quindolines",
      'description' => "Organic compounds containing an indole and a quinoline, where the pyrrole moiety of the indole is fused to the pyridine moiety of the quinoline.",
      'parent' => 1253,
    ),
    array(
      'tid' => 4169,
      'name' => "Selenophenes",
      'description' => "Organic compounds containing selenophene, a five-membered monocyclic aromatic ring composed of four C atoms and one selenium atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 4170,
      'name' => "Oxirenes",
      'description' => "Organic compounds containing oxirene, an unsaturated three-membered ring with two carbon atoms and one oxygen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 4171,
      'name' => "2-Thiopyrimidines",
      'description' => "Aromatic heterocyclic compounds containing a pyrimidine ring where the carbon at the 2-position involved in a C=S bond.",
      'parent' => 4173,
    ),
    array(
      'tid' => 4172,
      'name' => "4-Thiopyrimidines",
      'description' => "Aromatic heterocyclic compounds containing a pyrimidine ring where the carbon at the 4-position involved in a C=S bond.",
      'parent' => 4173,
    ),
    array(
      'tid' => 4173,
      'name' => "Thiopyrimidines",
      'description' => "Aromatic heterocyclic compounds containing a pyrimidine ring that has one or more carbon atoms involved in a C=S bond.",
      'parent' => 75,
    ),
    array(
      'tid' => 4174,
      'name' => "Pyridine nucleosides",
      'description' => "Compounds comprising a pyridine base attached to a ribosyl or deoxyribosyl moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 4175,
      'name' => "S-alkylsulfenates",
      'description' => "Organosulfur compounds containing a sulfenic acid, where the sulfur atom is linked to an alkyl group. They have the general formula RSOH, where R is an alkyl group.",
      'parent' => 1235,
    ),
    array(
      'tid' => 4176,
      'name' => "Amino acids",
      'description' => "Organic compounds that contain at least one carboxyl group and one amino group.",
      'parent' => 347,
    ),
    array(
      'tid' => 4177,
      'name' => "Ethylene bisdithiocarbamates",
      'description' => "Dithiocarbamic acids (or derivatives) resulting from the formal addition of  a molecule of carbon disulfide to each amino group of ethylenediamine. In addition, compounds containing a 1,2-ethanediyl carbamodithioate moiety are also members of this class.",
      'parent' => 3936,
    ),
    array(
      'tid' => 4178,
      'name' => "1-(1Z-alkenyl),3-acylglycerophosphoethanolamines",
      'description' => "Glycerophosphoethanolamines that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O3-position,  and one 1Z-alkenyl chain attached through an ether linkage at the O1-position.",
      'parent' => 2215,
    ),
    array(
      'tid' => 4179,
      'name' => "Long-chain (3R)-3-hydroxyacyl CoAs",
      'description' => "Organic compounds containing a (R)-3-hydroxyl acylated coenzyme A derivative, to which the acyl chain carries between 13 and 21 carbon atoms.",
      'parent' => 3224,
    ),
    array(
      'tid' => 4180,
      'name' => "Very-long-chain (3R)-3-hydroxyacyl CoAs",
      'description' => "Organic compounds containing a (R)-3-hydroxyl acylated coenzyme A derivative, to which the acyl chain carries at least 22 carbon atoms.",
      'parent' => 3224,
    ),
    array(
      'tid' => 4181,
      'name' => "3-sulfated flavonoids",
      'description' => "Flavonoids that are sulfated at the 3-ring position of the flavonoid skeleton.",
      'parent' => 3005,
    ),
    array(
      'tid' => 4182,
      'name' => "Flavonoid 3-phosphates",
      'description' => "Flavonoids that carry a phosphate group at the3-ring position of the flavonoid skeleton.",
      'parent' => 334,
    ),
    array(
      'tid' => 4183,
      'name' => "Long-chain alkyl amine oxides",
      'description' => "Aminoxides that carry an alkyl chain ranging from C10 to C24.",
      'parent' => 3993,
    ),
    array(
      'tid' => 4184,
      'name' => "Trialkyl amine oxides",
      'description' => "Hydrocarbyl derivatives of the aminoxide anion, with the general formula R3N+[O-] or R3N=O, where R is an alkyl group.",
      'parent' => 3993,
    ),
    array(
      'tid' => 4185,
      'name' => "Trialkylarsane oxides",
      'description' => "Organoarsenic compounds with the general formula R3As=O.",
      'parent' => 4055,
    ),
    array(
      'tid' => 4186,
      'name' => "Trialkylphosphanes",
      'description' => "Organophosphorus compounds with the general formula R3P=O.",
      'parent' => 400,
    ),
    array(
      'tid' => 4187,
      'name' => "Phorbines",
      'description' => "Cyclic tetrapyrrole that consists of porphyrin that has a cyclopentane ring fused to one of the pyrrole rings and the adjacent methine group.",
      'parent' => 1455,
    ),
    array(
      'tid' => 4188,
      'name' => "Phthalocyanines",
      'description' => "Cyclic tetrapyrroles that contain a phthalocyanine skeleton, which consists of four isoindole-type units, with the connecting carbon atoms in the macrocycle replaced by nitrogen.",
      'parent' => 1455,
    ),
    array(
      'tid' => 4189,
      'name' => "Coumarans",
      'description' => "Compounds containing the coumaran skeleton, which consists of a benzene ring fused to a 2,3-dihydrofuran ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4190,
      'name' => "1-phenylcoumarans",
      'description' => "Compounds containing a coumaran ring system substituted at the 1-position with phenyl group.",
      'parent' => 4189,
    ),
    array(
      'tid' => 4191,
      'name' => "Isocoumarans",
      'description' => "Compounds containing the coumaran skeleton, which consists of a benzene ring fused to a 1,3-dihydrofuran ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4192,
      'name' => "14-alpha-methylsteroids",
      'description' => "Steroids substituted at the 14-position with a methyl group in the alpha-configuration.",
      'parent' => 258,
    ),
    array(
      'tid' => 4193,
      'name' => "Thienothiophenes",
      'description' => "Organic compounds containing two thiophene rings fused to each other.",
      'parent' => 2,
    ),
    array(
      'tid' => 4194,
      'name' => "Pyrrolo[1,2-a]benzimidazoles",
      'description' => "Compounds containing a pyrrole or a dehydrogenated derivative fused to the imidazole moiety of a benzimidazole.",
      'parent' => 294,
    ),
    array(
      'tid' => 4195,
      'name' => "Allyl sulfur compounds",
      'description' => "Compounds containing an allylsulfur group, with the general structure H2C(=CH2)CS.",
      'parent' => 4,
    ),
    array(
      'tid' => 4196,
      'name' => "3-alkylindoles",
      'description' => "Compounds containing an indole moiety that carries an alkyl chain at the 3-position.",
      'parent' => 2497,
    ),
    array(
      'tid' => 4197,
      'name' => "N-alkylindoles",
      'description' => "Compounds containing an indole moiety that carries an alkyl chain at the 1-position.",
      'parent' => 211,
    ),
    array(
      'tid' => 4198,
      'name' => "Dithiazinanes",
      'description' => "Cyclic compounds that contain a dithiazinane ring, which is a saturated heterocycle that consisting of one nitrogen atom, two sulfur atoms, and 2 carbon atoms.",
      'parent' => 4139,
    ),
    array(
      'tid' => 4199,
      'name' => "1,3,5-dithiazinanes",
      'description' => "Cyclic compounds that contain a dithiazinane ring, which is a saturated heterocycle that consisting of one nitrogen atom, two sulfur atoms at the 1-,3-, and 5- position, respectively.",
      'parent' => 4198,
    ),
    array(
      'tid' => 4200,
      'name' => "Hydroxyanilides",
      'description' => "Compounds that contain an anilide moiety, where the benzene ring carries a hydroxyl group.",
      'parent' => 285,
    ),
    array(
      'tid' => 4201,
      'name' => "Triazolobenzothiazoles",
      'description' => "Compound containing a triazole ring fused to the benzene or the thiazole moiety of the benzothiazole ring system.",
      'parent' => 315,
    ),
    array(
      'tid' => 4202,
      'name' => "1-sulfamoyl-1,2,3-triazoles",
      'description' => "Compounds containing a 1,2,3-triazole that carries a sulfamoyl group at the 1-position.",
      'parent' => 99,
    ),
    array(
      'tid' => 4203,
      'name' => "Phenyl-beta-methoxyacrylates",
      'description' => "Aromatic compounds containing a methyl-3-methoxyacrylate moiety that carries a benzyl group at the C-alpha carbon.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4204,
      'name' => "Phenylbenzamines",
      'description' => "Aromatic compounds consisting of a benzyl group that is N-linked to a benzamine.",
      'parent' => 185,
    ),
    array(
      'tid' => 4205,
      'name' => "Furancarboxamides",
      'description' => "Compounds containing a furan ring that carries a carboxamide group.",
      'parent' => 4758,
    ),
    array(
      'tid' => 4206,
      'name' => "Pyrazole-4-carboxamides",
      'description' => "Compounds containing a pyrazole ring that carries a carboxamide group at the 4-position.",
      'parent' => 2350,
    ),
    array(
      'tid' => 4207,
      'name' => "Pyrazole-5-carboxamides",
      'description' => "Compounds containing a pyrazole ring that carries a carboxamide group at the 4-position.",
      'parent' => 2350,
    ),
    array(
      'tid' => 4208,
      'name' => "Xylenes",
      'description' => "Aromatic compounds that contain a xylene moiety, which is a monocyclic benzene carrying exactly two methyl groups.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4209,
      'name' => "m-Xylenes",
      'description' => "Aromatic compounds that contain a m-xylene moiety, which is a monocyclic benzene carrying exactly two methyl groups at the 1- and 3-positions.",
      'parent' => 4208,
    ),
    array(
      'tid' => 4210,
      'name' => "o-Xylenes",
      'description' => "Aromatic compounds that contain a o-xylene moiety, which is a monocyclic benzene carrying exactly two methyl groups at the 1- and 2-positions.",
      'parent' => 4208,
    ),
    array(
      'tid' => 4211,
      'name' => "p-Xylenes",
      'description' => "Aromatic compounds that contain a p-xylene moiety, which is a monocyclic benzene carrying exactly two methyl groups at the 1- and 4-positions.",
      'parent' => 4208,
    ),
    array(
      'tid' => 4212,
      'name' => "Xylenols",
      'description' => "Aromatic compounds that contain a xylene moiety, which is a monocyclic benzene carrying exactly two methyl groups, and at least one hydroxyl group.",
      'parent' => 4208,
    ),
    array(
      'tid' => 4213,
      'name' => "m-Xylenols",
      'description' => "Aromatic compounds that contain a m-xylenol moiety, which is a monocyclic benzene carrying exactly two methyl groups at the 1- and 3-positions, and at least one hydroxyl group.",
      'parent' => 4212,
    ),
    array(
      'tid' => 4214,
      'name' => "o-Xylenols",
      'description' => "Aromatic compounds that contain a o-xylenol moiety, which is a monocyclic benzene carrying exactly two methyl groups at the 1- and 2-positions, and at least one hydroxyl group.",
      'parent' => 4212,
    ),
    array(
      'tid' => 4215,
      'name' => "p-Xylenols",
      'description' => "Aromatic compounds that contain a p-xylenol moiety, which is a monocyclic benzene carrying exactly two methyl groups at the 1- and 4-positions, and at least one hydroxyl group.",
      'parent' => 4212,
    ),
    array(
      'tid' => 4216,
      'name' => "Anilinopyrimidines",
      'description' => "Aromatic heterocyclic compounds containing an anilinopyrimidine skeleton, which consists of an aniline that is N-substituted by a pyrimidine.",
      'parent' => 75,
    ),
    array(
      'tid' => 4217,
      'name' => "1,4-oxathiin carboxamides",
      'description' => "Heterocyclic compounds containing a 1,4-oxathiin ring that carries a carboxamide group. 1,4-oxathiin is an unsaturated heterocycle where the carbon atoms at the 1-, and 4-positions are replaced by containing a sulfur atom  and an oxygen atom, respectively.",
      'parent' => 2058,
    ),
    array(
      'tid' => 4218,
      'name' => "Allylamines",
      'description' => "Organic compound containing an allyl group and an amine group, with the general structure R2C=C(H)N(R'2), where R-R'=H or organyl.",
      'parent' => 2449,
    ),
    array(
      'tid' => 4219,
      'name' => "Toluamides",
      'description' => "Aromatic compounds containing a toluene, which carries a carboxamide group.",
      'parent' => 1091,
    ),
    array(
      'tid' => 4220,
      'name' => "m-Toluamides",
      'description' => "Aromatic compounds containing a toluene, which carries a carboxamide group a the 3-position.",
      'parent' => 4219,
    ),
    array(
      'tid' => 4221,
      'name' => "o-Toluamides",
      'description' => "Aromatic compounds containing a toluene, which carries a carboxamide group a the 2-position.",
      'parent' => 4219,
    ),
    array(
      'tid' => 4222,
      'name' => "p-Toluamides",
      'description' => "Aromatic compounds containing a toluene, which carries a carboxamide group a the 4-position.",
      'parent' => 4219,
    ),
    array(
      'tid' => 4223,
      'name' => "N,N-dialkyl-m-toluamides",
      'description' => "Aromatic that contain a m-toluamide, where the carboxamide group is N- substituted with two alkyl chains.",
      'parent' => 4220,
    ),
    array(
      'tid' => 4224,
      'name' => "N,N-dialkyl-p-toluamides",
      'description' => "Aromatic that contain a m-toluamide, where the carboxamide group is N- substituted with two alkyl chains.",
      'parent' => 4222,
    ),
    array(
      'tid' => 4225,
      'name' => "Tetraalkylammonium salts",
      'description' => "Organonitrogen compounds containing a quaternary ammonium substituted with four alkyl chains.",
      'parent' => 503,
    ),
    array(
      'tid' => 4226,
      'name' => "1,2,4-triazolo[4,3-a][1,4]benzodiazepines",
      'description' => "Aromatic compounds containing a 1,4-benzodiazepine fused to and sharing a nitrogen atom with a 1,2,4-triazole ring.",
      'parent' => 4097,
    ),
    array(
      'tid' => 4227,
      'name' => "1-(1Z-alkenyl),3-acyl-glycerophosphates",
      'description' => "Glycerophosphates that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O3-position,  and one 1Z-alkenyl chain attached through an ether linkage at the O1-position.",
      'parent' => 2214,
    ),
    array(
      'tid' => 4228,
      'name' => "1-(1Z-alkenyl),3-acyl-glycerol-2-phosphocholines",
      'description' => "Glycerophosphocholines that carry exactly one acyl chain attached to the glycerol moiety through an ester linkage at the O3-position,  and one 1Z-alkenyl chain attached through an ether linkage at the O1-position.",
      'parent' => 2213,
    ),
    array(
      'tid' => 4229,
      'name' => "Pyrrolo[1,2-c][1,3]benzodiazepines",
      'description' => "Heterocyclic aromatic compounds containing a 1,3-benzodiazepine ring system that is fused to, and shared a nitrogen atom with a pyrrole ring.",
      'parent' => 295,
    ),
    array(
      'tid' => 4230,
      'name' => "Pyrrolo[2,1-c][1,4]benzodiazepines",
      'description' => "Heterocyclic aromatic compounds containing a 1,4-benzodiazepine ring system that is fused to, and shared a nitrogen atom with a pyrrole ring.",
      'parent' => 4097,
    ),
    array(
      'tid' => 4231,
      'name' => "C2-aryl pyrrolo[2,1-c][1,4]benzodiazepines",
      'description' => "Heterocyclic aromatic compounds containing a 2-aryl substituted 1,4-benzodiazepine ring system that is fused to, and shared a nitrogen atom with a pyrrole ring.",
      'parent' => 4230,
    ),
    array(
      'tid' => 4232,
      'name' => "5'-O-tritylated nucleosides and derivatives",
      'description' => "Ribonucleosides or derivatives, in which the ribose moiety carries a trityl group at the 5' position, and is N-linked at the to either a purine or a pyrimidine base.",
      'parent' => 289,
    ),
    array(
      'tid' => 4233,
      'name' => "Benzenesulfonyl compounds",
      'description' => "Aromatic compounds containing a benzenesulfonyl group, which consists of a monocyclic benzene moiety that carries a sulfonyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4234,
      'name' => "Benzenesulfonyl chlorides",
      'description' => "Aromatic compounds containing a benzenesulfonyl group, where the sulfonyl moiety is singly boned to a chloride atom.",
      'parent' => 4308,
    ),
    array(
      'tid' => 4235,
      'name' => "Azetidino[1,2-d][1,4]benzodiazepines",
      'description' => "Aromatic heterocyclic compounds containing a 1,4-benzodiazepine ring system fused to and sharing a nitrogen atom with an azetidine.",
      'parent' => 4097,
    ),
    array(
      'tid' => 4236,
      'name' => "6-Thiathiophenes",
      'description' => "Aromatic heterocyclic compounds containing a 6-thiathiophene ring system, an analog of thieno[2,3-b]thiophene, with three adjacent sulfur atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 4237,
      'name' => "Tertiary arsines",
      'description' => "Organoarsenic compounds with a trisubstituted arsenic atom. They have the general formula R[As](R')R\", R,R',R\"=organyl group.",
      'parent' => 4055,
    ),
    array(
      'tid' => 4238,
      'name' => "Tetraorganoarsonium salts",
      'description' => "Organoarsenic compounds, where the arsenic atom is tetrasubstituted by organic groups. They have the general structure R4[As+]X-, X=any atom but H.",
      'parent' => 405,
    ),
    array(
      'tid' => 4239,
      'name' => "Pentaorganoarsanes",
      'description' => "Organoarsenic compounds containing an arsenic compound that is pentasubstituted by only organic groups.",
      'parent' => 4056,
    ),
    array(
      'tid' => 4240,
      'name' => "Sulfur-containing organoarsenic compounds",
      'description' => "Organoarsenic compounds that containing a sulfur atom.",
      'parent' => 405,
    ),
    array(
      'tid' => 4241,
      'name' => "Organoarsenic sulfides",
      'description' => "Organoarsenic compounds with the general formula R[As]S, where R = organyl group.",
      'parent' => 4240,
    ),
    array(
      'tid' => 4242,
      'name' => "Thiodiarsines",
      'description' => "Organoarsenic compounds with the general formula R[As]S[As]R', where R = organyl group, R'=H or organyl group.",
      'parent' => 4240,
    ),
    array(
      'tid' => 4243,
      'name' => "Organotetrahaloarsoranes",
      'description' => "Organoarsenic compounds, having a pentavalent arsenic atom linked to four halogen atoms and a organic group.",
      'parent' => 405,
    ),
    array(
      'tid' => 4244,
      'name' => "Diorganotrihaloarsoranes",
      'description' => "Organoarsenic compounds containing a pentavalent arsenic compound that is by two organic groups and three halogen atoms.",
      'parent' => 4056,
    ),
    array(
      'tid' => 4245,
      'name' => "Triorganodihaloarsoranes",
      'description' => "Organoarsenic compounds containing a pentavalent arsenic compound that is by three organic groups and two halogen atoms.",
      'parent' => 4056,
    ),
    array(
      'tid' => 4246,
      'name' => "Arsonous acid esters",
      'description' => "Organoarsonous acid derivatives, where the two oxygen atoms are esterified.",
      'parent' => 264,
    ),
    array(
      'tid' => 4247,
      'name' => "Organoarsinous acid esters",
      'description' => "Organoarsonous acid derivatives, where the hydrogen atom of the hydroxyl group is replaced by an organyl group.",
      'parent' => 264,
    ),
    array(
      'tid' => 4248,
      'name' => "Organoarsinous acids",
      'description' => "As-hydrocarbyl compounds with the general formula R2As(OH), where R is an organic group.",
      'parent' => 264,
    ),
    array(
      'tid' => 4249,
      'name' => "Tetraorganostibonium salts",
      'description' => "Organoantimony compounds containing an antimony cation that is tetrasubstituted with four organic groups, and which interacts with an anion.",
      'parent' => 349,
    ),
    array(
      'tid' => 4250,
      'name' => "1-phosphatidyl-1D-myo-inositol-4,5-bisphosphates",
      'description' => "Lipids containing a myo-inositol-4,5-bisphosphate attached to the phosphate group of a glycerol-3-phosphate moiety, and two acyl chains linked to the glycerol at the O1- and O2- positions, through ester linkages.",
      'parent' => 1676,
    ),
    array(
      'tid' => 4251,
      'name' => "1-phosphatidyl-1D-myo-inositols",
      'description' => "Lipids containing a myo-inositol attached to the phosphate group of a glycerol-3-phosphate moiety, and two acyl chains linked to the glycerol at the O1- and O2- positions, through ester linkages.",
      'parent' => 1344,
    ),
    array(
      'tid' => 4252,
      'name' => "N-acetyl-2-arylethylamines",
      'description' => "Compounds containing an acetamide group that is N-linked to an arylethylamine.",
      'parent' => 3922,
    ),
    array(
      'tid' => 4253,
      'name' => "2-arylethylamines",
      'description' => "Primary amines that have the general formula RCCNH2, where R is an organic group.",
      'parent' => 2450,
    ),
    array(
      'tid' => 4254,
      'name' => "Phosphatidylinositol-3,4,5-trisphosphates",
      'description' => "Phosphatidylinositol bisphosphates in which the inositol moiety is substituted by a phosphate group at the  C-3, C-4, and C-5 positions.",
      'parent' => 1139,
    ),
    array(
      'tid' => 4255,
      'name' => "Pyrroline 2-carboxylic acids",
      'description' => "Heterocyclic compounds containing a pyrroline ring substituted by one carboxyl group at the 2-position.",
      'parent' => 2417,
    ),
    array(
      'tid' => 4256,
      'name' => "Very long-chain 2-enoyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to a long-chain 2-enoyl chain of at least 22 carbon atoms.",
      'parent' => 3180,
    ),
    array(
      'tid' => 4257,
      'name' => "Very long-chain 3-enoyl CoAs",
      'description' => "Organic compounds containing a coenzyme A substructure linked to a long-chain 3-enoyl chain of at least 22 carbon atoms.",
      'parent' => 3180,
    ),
    array(
      'tid' => 4258,
      'name' => "Arylsulfates",
      'description' => "Organic compounds containing a sulfate group that carries an aryl group through an ether group.",
      'parent' => 403,
    ),
    array(
      'tid' => 4259,
      'name' => "Pyridoxamine 5'-phosphates",
      'description' => "Heterocyclic aromatic compounds containing a pyridoxamine that carries a phosphate group at the 5'-position.",
      'parent' => 1966,
    ),
    array(
      'tid' => 4260,
      'name' => "S-prenyl-L-cysteines",
      'description' => "Cysteine derivatives that carry a prenyl chain attached to the sulfanyl group.",
      'parent' => 3441,
    ),
    array(
      'tid' => 4261,
      'name' => "N-acylneuraminate-9-phosphates",
      'description' => "Neuraminic acids carrying an N-acyl substituent, as well as a phosphate group at the O9-position.",
      'parent' => 3048,
    ),
    array(
      'tid' => 4262,
      'name' => "1-alkyl,2-acetylglycero-3-phosphocholines",
      'description' => "Glycerophosphocholines that carry exactly one acetyl chain attached to the glycerol moiety through an ester linkage at the O2-position,  and one alkyl chain attached through an ether linkage at the O1-position.",
      'parent' => 3829,
    ),
    array(
      'tid' => 4263,
      'name' => "1-phosphatidyl-1D-myo-inositol-3-phosphates",
      'description' => "Lipids containing a myo-inositol-3-phosphate attached to the phosphate group of a glycerol-3-phosphate moiety, and two acyl chains linked to the glycerol at the O1- and O2- positions, through ester linkages.",
      'parent' => 1324,
    ),
    array(
      'tid' => 4264,
      'name' => "1-phosphatidyl-1D-myo-inositol-3,4,5-trisphosphates",
      'description' => "Lipids containing a myo-inositol-3,4,5-bisphosphate attached to the phosphate group of a glycerol-3-phosphate moiety, and two acyl chains linked to the glycerol at the O1- and O2- positions, through ester linkages.",
      'parent' => 4254,
    ),
    array(
      'tid' => 4265,
      'name' => "1-phosphatidyl-1D-myo-inositol-3,4-bisphosphates",
      'description' => "Lipids containing a myo-inositol-3,4-bisphosphate attached to the phosphate group of a glycerol-3-phosphate moiety, and two acyl chains linked to the glycerol at the O1- and O2- positions, through ester linkages.",
      'parent' => 1139,
    ),
    array(
      'tid' => 4266,
      'name' => "1-phosphatidyl-1D-myo-inositol-3,5-bisphosphates",
      'description' => "Lipids containing a myo-inositol-3,5-bisphosphate attached to the phosphate group of a glycerol-3-phosphate moiety, and two acyl chains linked to the glycerol at the O1- and O2- positions, through ester linkages.",
      'parent' => 1139,
    ),
    array(
      'tid' => 4267,
      'name' => "N-acyl-L-glutamines",
      'description' => "N-acylated glutamine which has the L-configuration of the alpha-carbon atom.",
      'parent' => 4148,
    ),
    array(
      'tid' => 4268,
      'name' => "3-Acylpyruvic acids",
      'description' => "Compounds containing a pyruvic acid substituted at the 3-position by an acyl group.",
      'parent' => 1115,
    ),
    array(
      'tid' => 4269,
      'name' => "6,7-dihydropteridines",
      'description' => "Aromatic heterocyclic compounds containing 6,7-dihydropteridine, a bicyclic compound that results from the dehydrogenation of pteridine at the 6-, and 7-positions.",
      'parent' => 109,
    ),
    array(
      'tid' => 4270,
      'name' => "5,6,7,8-tetrahydropteridines",
      'description' => "Aromatic heterocyclic compounds containing 5,6,7,8-tetrahydropteridine, a bicyclic compound that results from the dehydrogenation of pteridine at the 5-, 6-,  7-and 8-positions.",
      'parent' => 109,
    ),
    array(
      'tid' => 4271,
      'name' => "N-acylserotonins",
      'description' => "Aromatic heterocyclic compounds containing a serotonin, in which the amine group is acylated.",
      'parent' => 1637,
    ),
    array(
      'tid' => 4272,
      'name' => "N-acyldopamines",
      'description' => "Aromatic heterocyclic compounds containing a dopamine, in which the amine group is acylated.",
      'parent' => 182,
    ),
    array(
      'tid' => 4273,
      'name' => "Long-chain N-acylserotonins",
      'description' => "Aromatic heterocyclic compounds containing a serotonin, in which the amine group is acylated to a long fatty acyl chain.",
      'parent' => 4271,
    ),
    array(
      'tid' => 4274,
      'name' => "1-O-alkylglycerols",
      'description' => "Glycerolipids containing a glycerol moiety that carries an alkyl group at the 1-position.",
      'parent' => 3263,
    ),
    array(
      'tid' => 4275,
      'name' => "1-O-alkyl-sn-glycerols",
      'description' => "Glycerolipids containing a chiral glycerol moiety that carries an alkyl group at the 1-position.",
      'parent' => 4274,
    ),
    array(
      'tid' => 4276,
      'name' => "Polyprenyl monophosphates",
      'description' => "Prenol lipids in which the monophosphate group is linked to one end of the polyprenol moiety.",
      'parent' => 478,
    ),
    array(
      'tid' => 4277,
      'name' => "Polyprenyl diphosphates",
      'description' => "Prenol lipids in which the diphosphate group is linked to one end of the polyprenol moiety.",
      'parent' => 478,
    ),
    array(
      'tid' => 4278,
      'name' => "N-acyl-aliphatic L-alpha-amino-acids",
      'description' => "L-alpha amino acids carrying a N-acylated aliphatic chain.",
      'parent' => 3211,
    ),
    array(
      'tid' => 4279,
      'name' => "N-acyl-aromatic L-alpha-amino-acids",
      'description' => "L-alpha amino acids carrying a N-acylated aromatic chain.",
      'parent' => 3212,
    ),
    array(
      'tid' => 4280,
      'name' => "Oxygen-containing organoarsenic compounds",
      'description' => "Organoarsenic compounds that containing an oxygen atom.",
      'parent' => 405,
    ),
    array(
      'tid' => 4281,
      'name' => "Monohaloarsines",
      'description' => "Organoarsenic compounds with the general formula R[As](R')X, where R = Organyl group, R'=H atom or Organyl group, and X = halogen atom.",
      'parent' => 405,
    ),
    array(
      'tid' => 4282,
      'name' => "Dihaloarsines",
      'description' => "Organoarsenic compounds with the general formula R[As](X)X, where R = Organyl group, and X = halogen atom.",
      'parent' => 405,
    ),
    array(
      'tid' => 4283,
      'name' => "Triorganodialkoxyarsoranes",
      'description' => "Organoarsenic compounds containing a pentavalent arsenic compound that is by three organic groups, alkoxy groups.",
      'parent' => 4056,
    ),
    array(
      'tid' => 4284,
      'name' => "Tetraorganoalkoxyarsoranes",
      'description' => "Organoarsenic compounds containing a pentavalent arsenic compound that is by three organic groups, alkoxy groups.",
      'parent' => 4056,
    ),
    array(
      'tid' => 4285,
      'name' => "Organotin selenides",
      'description' => "Organotin compounds containing a divalent selenium atom linked to two tin atoms, each linked to at least one organyl group.",
      'parent' => 1524,
    ),
    array(
      'tid' => 4286,
      'name' => "Organotin sulfides",
      'description' => "Organotin compounds containing a divalent sulfur atom linked to two tin atoms, each linked to at least one organyl group.",
      'parent' => 1524,
    ),
    array(
      'tid' => 4287,
      'name' => "Organotin tellurides",
      'description' => "Organotin compounds containing a divalent tellurium atom linked to two tin atoms, each linked to at least one organyl group.",
      'parent' => 1524,
    ),
    array(
      'tid' => 4288,
      'name' => "Organolead sulfides",
      'description' => "Organolead compounds containing a divalent selenium atom linked to two lead atoms, each linked to at least one organyl group.",
      'parent' => 4024,
    ),
    array(
      'tid' => 4289,
      'name' => "Tetraorganolead compounds",
      'description' => "Compounds containing a lead compound bonded to four carbon atoms.",
      'parent' => 4024,
    ),
    array(
      'tid' => 4290,
      'name' => "Primary stibines",
      'description' => "Organoantimony hydrides in which the antimony tom is bond to one carbon atom and two hydrogen atoms. They have the generic structure RAsH2.",
      'parent' => 349,
    ),
    array(
      'tid' => 4291,
      'name' => "Secondary stibines",
      'description' => "Organoantimony hydrides in which the antimony tom is bond to two carbon atoms and an hydrogen atom. They have the generic structure R2AsH.",
      'parent' => 349,
    ),
    array(
      'tid' => 4292,
      'name' => "1,2,4-benzothiadiazine-1,1-dioxides",
      'description' => "Aromatic heterocyclic compounds containing a 1,2,4-benzothiadiazine ring system with two S=O bonds at the 1-position.",
      'parent' => 308,
    ),
    array(
      'tid' => 4293,
      'name' => "1-benzothiophenes",
      'description' => "Aromatic heterocyclic compound containing the Benzo[b]thiophene ring system.",
      'parent' => 312,
    ),
    array(
      'tid' => 4294,
      'name' => "2-benzothiophenes",
      'description' => "Aromatic heterocyclic compound containing the 2-benzothiophene ring system, in which the benzene ring is fused to the thiophene ring across positions 3 and 4.",
      'parent' => 312,
    ),
    array(
      'tid' => 4295,
      'name' => "2-azidobenzoic acids",
      'description' => "Compounds containing an azide group at the 2-position of a benzoic acid.",
      'parent' => 2565,
    ),
    array(
      'tid' => 4296,
      'name' => "Phenylketones",
      'description' => "Aromatic compounds containing a ketone substituted by one aryl group.",
      'parent' => 3670,
    ),
    array(
      'tid' => 4297,
      'name' => "Aryl-phenylketones",
      'description' => "Aromatic compounds containing a ketone substituted by one aryl group, and a phenyl group.",
      'parent' => 4296,
    ),
    array(
      'tid' => 4298,
      'name' => "Alkyl-phenylketones",
      'description' => "Aromatic compounds containing a ketone substituted by one alkyl group, and a phenyl group.",
      'parent' => 4296,
    ),
    array(
      'tid' => 4299,
      'name' => "Glucosylceramides",
      'description' => "Compounds containing a ceramide linked to a simple glucosyl moiety.",
      'parent' => 1428,
    ),
    array(
      'tid' => 4300,
      'name' => "D-glucosyl-N-acylsphingosines",
      'description' => "Sphingolipids containing a sphingosine substituted at the 1-hydroxy group by a D-glucosyl group and at the 2-amino group by an acyl group.",
      'parent' => 4299,
    ),
    array(
      'tid' => 4301,
      'name' => "3-hydroxy-3-alkylglutaryl CoAs",
      'description' => "Alpha, omega dicarboxyacyl-CoA that result from the formal condensation of the thiol group of coenzyme A with one of the carboxy groups of 3-hydroxy-3-alkylglutaric acid.",
      'parent' => 2960,
    ),
    array(
      'tid' => 4302,
      'name' => "(S)-3-hydroxy-3-alkylglutaryl CoAs",
      'description' => "3-hydroxy-3-alkylglutaryl-CoAs where the 3-hydroxy-3-alkylglutaryl component has (S)-configuration.",
      'parent' => 4301,
    ),
    array(
      'tid' => 4303,
      'name' => "4-Hydrocarbylideneazlactones",
      'description' => "Heterocyclic compounds containing a substituted 1,3-oxazoline ring, and with the general structure RC(R')=C1N=C(R'')OC1=O. They are often referred to as 'unsaturated azlactones'.",
      'parent' => 84,
    ),
    array(
      'tid' => 4304,
      'name' => "D-glucosyl-N-acylsphinganines",
      'description' => "Sphingolipids containing a sphinganine substituted at the 1-hydroxy group by a D-glucosyl group and at the 2-amino group by an acyl group.",
      'parent' => 4299,
    ),
    array(
      'tid' => 4305,
      'name' => "Glycosyl-N-acylsphingosines",
      'description' => "Compounds containing a sphingosine linked to a simple glucosyl moiety.",
      'parent' => 1428,
    ),
    array(
      'tid' => 4306,
      'name' => "Metallobisdithiocarbamates",
      'description' => "Organosulfur compounds containing a metal atom (usually in ionic form), which is linked to two dithiocarbamate.",
      'parent' => 3934,
    ),
    array(
      'tid' => 4307,
      'name' => "1-phosphatidyl-1d-myo-inositol-4-phosphates",
      'description' => "Lipids containing a myo-inositol-3-phosphate attached to the phosphate group of a glycerol-3-phosphate moiety, and two acyl chains linked to the glycerol at the O1- and O2- positions, through ester linkages.",
      'parent' => 1324,
    ),
    array(
      'tid' => 4308,
      'name' => "Benzenesulfonyl halides",
      'description' => "Aromatic compounds containing a benzenesulfonyl group, where the sulfonyl moiety is singly boned to an halogen atom.",
      'parent' => 4233,
    ),
    array(
      'tid' => 4309,
      'name' => "Benzenesulfonate esters",
      'description' => "Arenesulfonate esters that result from the formal condensation of the hydroxy group of an alcohol, enol, phenol or heteroarenol with benzenesulfonic acid.",
      'parent' => 32,
    ),
    array(
      'tid' => 4310,
      'name' => "Valine and derivatives",
      'description' => "Compounds containing valine or a derivative thereof resulting from reaction of valine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4311,
      'name' => "Histidine and derivatives",
      'description' => "Compounds containing cysteine or a derivative thereof resulting from reaction of cysteine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4312,
      'name' => "Asparagine and derivatives",
      'description' => "Compounds containing asparagine or a derivative thereof resulting from reaction of asparagine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4313,
      'name' => "Cysteine and derivatives",
      'description' => "Compounds containing cysteine or a derivative thereof resulting from reaction of cysteine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4314,
      'name' => "Alanine and derivatives",
      'description' => "Compounds containing alanine or a derivative thereof resulting from reaction of alanine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4315,
      'name' => "Glutamine and derivatives",
      'description' => "Compounds containing glutamine or a derivative thereof resulting from reaction of glutamine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4316,
      'name' => "Serine and derivatives",
      'description' => "Compounds containing serine or a derivative thereof resulting from reaction of serine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4317,
      'name' => "Aspartic acid and derivatives",
      'description' => "Compounds containing an aspartic acid or a derivative thereof resulting from reaction of aspartic acid at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4318,
      'name' => "Glycine and derivatives",
      'description' => "Compounds containing glycine or a derivative thereof resulting from reaction of glycine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4319,
      'name' => "Tyrosine and derivatives",
      'description' => "Compounds containing tyrosine or a derivative thereof resulting from reaction of tyrosine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4320,
      'name' => "Arginine and derivatives",
      'description' => "Compounds containing arginine or a derivative thereof resulting from reaction of arginine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4321,
      'name' => "Phenylalanine and derivatives",
      'description' => "Compounds containing phenylalanine or a derivative thereof resulting from reaction of phenylalanine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4322,
      'name' => "Proline and derivatives",
      'description' => "Compounds containing proline or a derivative thereof resulting from reaction of proline at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4323,
      'name' => "Glutamic acid and derivatives",
      'description' => "Compounds containing glutamic acid or a derivative thereof resulting from reaction of glutamic acid at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4324,
      'name' => "Daphniphylline-type alkaloids",
      'description' => "Alkaloids (or derivatives thereof) from the genus Daphniphyllum, possessing 22 carbon polycyclic fused ring systems with or without the C8 side chain. The C8 unit consists of 6-oxabicyclo[3.2.1]octane or 2,8-dioxabicyclo[3.2.1]octane.",
      'parent' => 279,
    ),
    array(
      'tid' => 4325,
      'name' => "Cyclohexenones",
      'description' => "Compounds containing a cylohexenone moiety, which is a six-membered aliphatic ring that carries a ketone and has one endocyclic double bond.",
      'parent' => 3487,
    ),
    array(
      'tid' => 4326,
      'name' => "Yuzurimine-type alkaloids",
      'description' => "Alkaloids (or derivatives thereof) from the genus Daphniphyllum that contain a 22 carbon core, commonly with a C9-C10 double bond, and C-22 is mostly a methyl ester of a carboxyl group.",
      'parent' => 279,
    ),
    array(
      'tid' => 4327,
      'name' => "Tetraalkylphosphonium compounds",
      'description' => "Organophosphorus compounds that contain a tetravalent phosphorus atom substituted to four alkyl chains.",
      'parent' => 400,
    ),
    array(
      'tid' => 4328,
      'name' => "Tetraalkylphosphonium halides",
      'description' => "Organophosphorus compounds that contain an halogen atom, and a tetravalent phosphorus atom substituted to four alkyl chains.",
      'parent' => 400,
    ),
    array(
      'tid' => 4329,
      'name' => "Leucine and derivatives",
      'description' => "Compounds containing leucine or a derivative thereof resulting from reaction of leucine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4330,
      'name' => "Isoleucine and derivatives",
      'description' => "Compounds containing isoleucine or a derivative thereof resulting from reaction of isoleucine at the amino group or the carboxy group, or from the replacement of any hydrogen of glycine by a heteroatom.",
      'parent' => 60,
    ),
    array(
      'tid' => 4331,
      'name' => "Imidazoquinolines",
      'description' => "Aromatic heterocyclic compounds containing an imidazole ring fused to a quinoline ring system. In some configurations, the imidazole ring shares a nitrogen atom with the quinoline moiety.",
      'parent' => 1253,
    ),
    array(
      'tid' => 4332,
      'name' => "Imidazo[2,1-b]benzothiazoles",
      'description' => "Aromatic heterocyclic compounds containing an imidazole ring fused to and sharing a nitrogen atom with a benzo-1,3-thiazole ring system.",
      'parent' => 311,
    ),
    array(
      'tid' => 4333,
      'name' => "Quinolo[1,2-a]quinazolines",
      'description' => "Aromatic heterocyclic compounds containing a quinazoline and a quinoline fused to each other in a configuration so that they share a nitrogen atom.",
      'parent' => 485,
    ),
    array(
      'tid' => 4334,
      'name' => "Pyrido[2,3-b]quinoxalines",
      'description' => "Aromatic heterocyclic compounds containing  a pyridine fused to the benzene moiety of a quinoxaline ring system.",
      'parent' => 486,
    ),
    array(
      'tid' => 4335,
      'name' => "Pyrido[2,3-g]quinoxalines",
      'description' => "Aromatic heterocyclic compounds containing  a pyridine fused to the benzene moiety of a quinoxaline ring system.",
      'parent' => 486,
    ),
    array(
      'tid' => 4336,
      'name' => "Nitrothiophenes",
      'description' => "Aromatic heterocyclic compound containing a nitro group attached to a thiophene ring.",
      'parent' => 97,
    ),
    array(
      'tid' => 4337,
      'name' => "2-nitrothiophenes",
      'description' => "Aromatic heterocyclic compound containing a nitro group attached to a thiophene ring a the 2-position.",
      'parent' => 4336,
    ),
    array(
      'tid' => 4338,
      'name' => "3-nitrothiophenes",
      'description' => "Aromatic heterocyclic compound containing a nitro group attached to a thiophene ring a the 3-position.",
      'parent' => 4336,
    ),
    array(
      'tid' => 4339,
      'name' => "Nitrohalothiophenes",
      'description' => "Aromatic heterocyclic compound containing a thiophene ring that carries a nitro group, as well as an halogen atom.",
      'parent' => 4336,
    ),
    array(
      'tid' => 4340,
      'name' => "2-nitrohalothiophenes",
      'description' => "Aromatic heterocyclic compound containing a thiophene ring that carries a nitro group attached at the 2-position, as well as an halogen atom.",
      'parent' => 4339,
    ),
    array(
      'tid' => 4341,
      'name' => "3-nitrohalothiophenes",
      'description' => "Aromatic heterocyclic compound containing a thiophene ring that carries a nitro group attached at the 3-position, as well as an halogen atom.",
      'parent' => 4339,
    ),
    array(
      'tid' => 4342,
      'name' => "Phenyl-1,3-oxazoles",
      'description' => "Aromatic heterocyclic compounds containing a 1,3-oxazole substituted at one or more positions by a phenyl group.",
      'parent' => 83,
    ),
    array(
      'tid' => 4343,
      'name' => "Aminocyclitols",
      'description' => "Cyclitols with at least one hydroxyl group replace by an amino group.",
      'parent' => 2510,
    ),
    array(
      'tid' => 4344,
      'name' => "Cyclitols",
      'description' => "Compounds containing a cycloalkane moiety with one hydroxyl group on each of three or more ring atoms.",
      'parent' => 2509,
    ),
    array(
      'tid' => 4345,
      'name' => "Indeno[1,2-c]pyrazoles",
      'description' => "Aromatic heterocyclic compounds that contain indeno[1,2-c]pyrazole,  which consists of a pyrazole ring fused to an indene ring system.",
      'parent' => 2,
    ),
    array(
      'tid' => 4346,
      'name' => "Dipyrido[1,4]diazepines",
      'description' => "Aromatic heteropolycyclic compounds containing two pyridines rings bound to a 1,4-diazepine ring.",
      'parent' => 2782,
    ),
    array(
      'tid' => 4347,
      'name' => "Tetraalkyltins",
      'description' => "Tetraorganotin compounds where the tin atom is linked to exactly four alkyl groups.",
      'parent' => 4348,
    ),
    array(
      'tid' => 4348,
      'name' => "Tetraorganotin compounds",
      'description' => "Compounds containing a tin compound bonded to exactly four carbon atoms.",
      'parent' => 1524,
    ),
    array(
      'tid' => 4349,
      'name' => "Acyclic pyrimidine nucleoside phosphonates",
      'description' => "Purine nucleoside analogues with a structure that is characterized by a phosphonylmethoxyethoxyl group that is linked to the N1 atom of a purine.",
      'parent' => 3737,
    ),
    array(
      'tid' => 4350,
      'name' => "Deoxyribo- and ribonucleoside phosphonates",
      'description' => "N-glycosyl compound that possess both a nucleobase, usually a purine or a pyrimidine, linked to either a ribose or deoxyribose, which in turn carries a phosphonate group at the 5'-position.",
      'parent' => 289,
    ),
    array(
      'tid' => 4351,
      'name' => "Oligonucleotides",
      'description' => "Organic polymers made up of a sequence of 3 to 12 purine or pyrimidine nucleotide residues linked to one another from the 5' -end to the 3'-end through a phosphate group.",
      'parent' => 3737,
    ),
    array(
      'tid' => 4352,
      'name' => "(3'->5')-cyclic dinucleotide bis(carbamate) analogues",
      'description' => "(3'->5')-cyclic dinucleotides in which the two phosphodiester bonds are replaced by two isosteric carbamate linkages.",
      'parent' => 3792,
    ),
    array(
      'tid' => 4353,
      'name' => "Imidazole[4,5-c]pyridine ribonucleosides and ribonucleotides",
      'description' => "Organic compounds in which the C-1 of a ribosyl moiety is N-linked to an imidazole[4,5-c]pyridine ring system. Nucleotides have a phosphate group linked to the C5 carbon of the ribose (or deoxyribose) moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 4354,
      'name' => "Phenyloxadiazoles",
      'description' => "Polycyclic aromatic compounds containing a benzene ring linked to a 1,2,4-oxadiazole ring through a CC or CN bond.",
      'parent' => 2924,
    ),
    array(
      'tid' => 4355,
      'name' => "Benzenecarbothioic S-acids",
      'description' => "Aromatic compounds containing a benzene ring that carries a carbothioic S-acid group.",
      'parent' => 176,
    ),
    array(
      'tid' => 4356,
      'name' => "Sulfono(thioperoxoic) SO-acids",
      'description' => "Organosulfur compounds with the general formula RSO2-SOH, where R is an organic substituent.",
      'parent' => 1157,
    ),
    array(
      'tid' => 4357,
      'name' => "Sulfonothioic O-acids",
      'description' => "Organosulfur compounds with the general formula RS(O)(S)-OH.",
      'parent' => 4,
    ),
    array(
      'tid' => 4358,
      'name' => "Sulfonothioic S-acids",
      'description' => "Organosulfur compounds with the general formula RS(O)(O)-SH, where R is an organic substituent.",
      'parent' => 1157,
    ),
    array(
      'tid' => 4359,
      'name' => "Sulfonoperoxoic acids",
      'description' => "Organosulfur compounds with the general formula RSO2-OOH, where R is an organic substituent.",
      'parent' => 1157,
    ),
    array(
      'tid' => 4360,
      'name' => "Sulfonoselenoic Se-acids",
      'description' => "Organosulfur compounds containing a selenium atom, and with the general formula RSI2-SeH, where R is an organic substituent.",
      'parent' => 1157,
    ),
    array(
      'tid' => 4361,
      'name' => "Acylaminobenzoic acid and derivatives",
      'description' => "Derivatives of amino benzoic acid derivatives where the amine group is N-acylated.",
      'parent' => 176,
    ),
    array(
      'tid' => 4362,
      'name' => "Purine ribonucleoside phosphonates",
      'description' => "N-glycosyl compound that possess both a purine nucleobase linked to either a ribose or deoxyribose, which in turn carries a phosphonate group at the 5'-position.",
      'parent' => 4350,
    ),
    array(
      'tid' => 4363,
      'name' => "Pyrimidine ribonucleoside phosphonates",
      'description' => "N-glycosyl compound that possess both a pyrimidine nucleobase linked to either a ribose or deoxyribose, which in turn carries a phosphonate group at the 5'-position.",
      'parent' => 4350,
    ),
    array(
      'tid' => 4364,
      'name' => "Ribonucleoside phosphoramidites",
      'description' => "Ribonucleoside analogues that consist of a nucleobase (usually purine or pyrimidine), linked to a ribose or deoxyribose, which is protected at the 2',3', or 5'-position by a phosphoramidite group.",
      'parent' => 3737,
    ),
    array(
      'tid' => 4365,
      'name' => "Indolo[2,3-b]quinoxalines",
      'description' => "Aromatic heterocyclic compounds containing an indole fused to a quinoxaline ring system, where the imidazole moiety and the pyrazine moiety of the indole and the quinoxaline, respectively, are fused to each other.",
      'parent' => 486,
    ),
    array(
      'tid' => 4366,
      'name' => "2-Anilinoquinolines",
      'description' => "Aromatic heteropolycyclic compounds containing a quinoline ring that is N-linked at the 2-position to an aniline.",
      'parent' => 1253,
    ),
    array(
      'tid' => 4367,
      'name' => "3-Anilinoquinolines",
      'description' => "Compounds containing a quinoline ring system that is N-linked to an aniline group at the 3-position.",
      'parent' => 1253,
    ),
    array(
      'tid' => 4368,
      'name' => "4-Anilinoquinolines",
      'description' => "Compounds containing a quinoline ring system that is N-linked to an aniline group at the 4-position.",
      'parent' => 1253,
    ),
    array(
      'tid' => 4369,
      'name' => "Organic chromium salts",
      'description' => "Organic salt compounds containing a chromium atom in its ionic form.",
      'parent' => 3997,
    ),
    array(
      'tid' => 4370,
      'name' => "Pyrazolo[3,4-b]pyrazines",
      'description' => "Aromatic heterocyclic compounds containing a pyrazole ring and a pyrazine ring fused to one another without sharing a nitrogen atom.",
      'parent' => 2,
    ),
    array(
      'tid' => 4371,
      'name' => "Pyrazolo[1,5-b]pyridazines",
      'description' => "Aromatic heterocyclic compounds containing a pyrazole ring fused to and sharing a nitrogen atom with a pyridazine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4372,
      'name' => "Pyrazolo[1,5-a][1,3,5]triazines",
      'description' => "Aromatic heterocyclic compounds containing a pyrazole ring fused to and sharing a nitrogen atom with a 1,3,5-triazine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4373,
      'name' => "Pyrazolo[1,5-d][1,2,4]triazines",
      'description' => "Aromatic heterocyclic compounds containing a pyrazole ring fused to and sharing a nitrogen atom with a 1,2,4-triazine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4374,
      'name' => "Substituted imidazole-4-acetic acid and analogues",
      'description' => "Aromatic heterocyclic compounds containing an imidazole ring, which is substituted at the 4-position by acetic acid (or a derivative thereof), and at the 2- or 5-position by any group.",
      'parent' => 2310,
    ),
    array(
      'tid' => 4375,
      'name' => "Pyrazolo[4,3-e]pyrrolo[1,2-a]pyrazines",
      'description' => "Aromatic heterocyclic compounds containing pyrrole fused and shares one nitrogen atom with the pyrazine moiety of a pyrazolo[3,4-a]pyrazine ring system.",
      'parent' => 2,
    ),
    array(
      'tid' => 4376,
      'name' => "Imidazo[1,2-a]pyrazin-8-ones",
      'description' => "Aromatic heteropolycyclic compounds containing an imidazole ring fused to and sharing one nitrogen with a pyrazine ring. The bicyclic moiety carries an oxo group at the 8-position.",
      'parent' => 2,
    ),
    array(
      'tid' => 4377,
      'name' => "Imidazo[1,2-a]pyrimidines",
      'description' => "Aromatic heteropolycyclic compounds containing an imidazole ring fused to and sharing one nitrogen with a pyrimidine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4378,
      'name' => "Imidazo[1,2-a][1,2,4]triazines",
      'description' => "Aromatic heteropolycyclic compounds containing an imidazole ring fused to and sharing one nitrogen with a 1,2,4-triazine ring. In imidazo[1,2-a][1,2,4]triazines the 1,2,4-triazine ring shares the atom at the 2-position with the imidazole ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4379,
      'name' => "Imidazo[1,2-d][1,2,4]triazines",
      'description' => "Aromatic heteropolycyclic compounds containing an imidazole ring fused to and sharing one nitrogen with a 1,2,4-triazine ring. In imidazo[1,2-d][1,2,4]triazines the 1,2,4-triazine ring shares the atom at the 4-position with the imidazole ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4380,
      'name' => "Imidazo[2,1-c][1,2,4]triazines",
      'description' => "Aromatic heteropolycyclic compounds containing an imidazole ring fused to and sharing one nitrogen with a 1,2,4-triazine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4381,
      'name' => "Imidazo[4,3-c][1,2,4]triazines",
      'description' => "Aromatic heteropolycyclic compounds containing an imidazole ring fused to and sharing one nitrogen with a 1,2,4-triazine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4382,
      'name' => "Pyrazolo[1',5':1,6]pyrimido[4,5-d]pyridazines",
      'description' => "Aromatic heterocyclic compounds containing a pyrimidine fused to both a pyrazole and a pyridazine rings. In this ring system, pyrimidine shares one atom with the pyrazole ring, and no nitrogen atom with the pyrazole ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4383,
      'name' => "Pyrazolo[1',5':1,6]pyrimido[4,5-d]pyridazin-4-ones",
      'description' => "Aromatic heterocyclic compounds containing a pyrimidine fused to both a pyrazole and a pyridazine rings. The resulting ring system carries an oxo group at the 4-position. Here, the pyrimidine ring shares one atom with the pyrazole ring, and no nitrogen atom with the pyrazole ring.",
      'parent' => 4382,
    ),
    array(
      'tid' => 4384,
      'name' => "2,4-Diaminoquinazolines",
      'description' => "Aromatic heterocyclic compounds containing a quinazoline ring, which is substituted at the 2- and 4-positions with an amine group.",
      'parent' => 485,
    ),
    array(
      'tid' => 4385,
      'name' => "2,4-Diaminothieno[2,3-d]pyrimidines",
      'description' => "Aromatic heterocyclic compounds containing a thieno[2,3-d]pyrimidine ring system substituted at the 2- and 4-positions with an amine group.",
      'parent' => 2020,
    ),
    array(
      'tid' => 4386,
      'name' => "5-Benzylpyrimidine-2,4-diamines",
      'description' => "Aromatic heterocyclic compounds containing a 2,4-diaminopyrimidine moiety that is substituted at the 5-position by a benzyl group.",
      'parent' => 75,
    ),
    array(
      'tid' => 4387,
      'name' => "Pyrazolo[3,4-d]pyrimidines",
      'description' => "Aromatic heterocyclic compounds containing a pyrazolo[3,4-d]pyrimidine ring system, which consists of a pyrazole ring fused to but and not sharing a nitrogen atom with a pyrimidine ring.",
      'parent' => 305,
    ),
    array(
      'tid' => 4388,
      'name' => "Imidazo[1,5-a]pyrazines",
      'description' => "Aromatic heteropolycyclic compounds containing an imidazole ring fused to and sharing one nitrogen with a pyrazine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4389,
      'name' => "2'-Aminoanilides",
      'description' => "Organic compounds containing an anilide moieties that carries an amino group at the 2-position of the benzene ring.",
      'parent' => 285,
    ),
    array(
      'tid' => 4390,
      'name' => "Pyrazolo[1,5-a]pyrimidines",
      'description' => "Aromatic heterocyclic compounds containing a pyrazolo[3,4-d]pyrimidine ring system, which consists of a pyrazole ring fused to and sharing exactly one nitrogen atom with a pyrimidine ring.",
      'parent' => 305,
    ),
    array(
      'tid' => 4391,
      'name' => "4-Anilinoquinazolines",
      'description' => "Organic heterocyclic compounds containing a quinazoline that is N-linked to an aniline.",
      'parent' => 284,
    ),
    array(
      'tid' => 4392,
      'name' => "Pyrrolo[2,3-a]carbazoles",
      'description' => "A subclass of pyrrolocarbazoles, where the pyrrole ring fused to the carbazole contains a nitrogen atom adjacent to the C2-atom of the carbazole ring.",
      'parent' => 1865,
    ),
    array(
      'tid' => 4393,
      'name' => "6-Amino-4-phenyltetrahydroquinolines",
      'description' => "Aromatic heterocyclic compounds containing a tetrahydroquinoline ring system substituted at the 4- and the 6- positions with a phenyl group and an amine group, respectively.",
      'parent' => 1715,
    ),
    array(
      'tid' => 4394,
      'name' => "Phenylpiperazinyl-cyclohexylureas",
      'description' => "Aromatic heterocyclic compounds containing a phenyl-4-piperazine, where the piperazine ring is N-linked to a cyclohexylurea at the 4-position.",
      'parent' => 1984,
    ),
    array(
      'tid' => 4395,
      'name' => "Phenylpiperazinyl-cyclohexylsulfonamides",
      'description' => "Aromatic heterocyclic compounds containing a phenyl-4-piperazine, where the piperazine ring is N-linked to a cyclohexylsulfonamide at the 4-position.",
      'parent' => 1984,
    ),
    array(
      'tid' => 4396,
      'name' => "Imidazo[1,2-a]pyridines",
      'description' => "Aromatic heteropolycyclic compounds containing an imidazole ring fused to and sharing one nitrogen with a pyridine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4397,
      'name' => "5-piperazinylimidazo[1,2-a]pyridines",
      'description' => "Aromatic heteropolycyclic compounds containing a piperidine ring that is N-linked to the 5-position of an imidazo[1,2-a]pyridine ring system.",
      'parent' => 1976,
    ),
    array(
      'tid' => 4398,
      'name' => "6-piperazinylimidazo[1,2-a]pyridines",
      'description' => "Aromatic heteropolycyclic compounds containing a piperidine ring that is N-linked to the 5-position of an imidazo[1,2-a]pyridine ring system.",
      'parent' => 1976,
    ),
    array(
      'tid' => 4399,
      'name' => "7-piperazinylimidazo[1,2-a]pyridines",
      'description' => "Aromatic heteropolycyclic compounds containing a piperidine ring that is N-linked to the 7-position of an imidazo[1,2-a]pyridine ring system.",
      'parent' => 1976,
    ),
    array(
      'tid' => 4400,
      'name' => "8-piperazinylimidazo[1,2-a]pyridines",
      'description' => "Aromatic heteropolycyclic compounds containing a piperidine ring that is N-linked to the 8-position of an imidazo[1,2-a]pyridine ring system.",
      'parent' => 1976,
    ),
    array(
      'tid' => 4401,
      'name' => "1,3-thiazolo[5,4-d]pyrimidines",
      'description' => "Aromatic heteropolycyclic compounds containing a 1,3-thiazolo[5,4-d]pyrimidine ring system, which consists of a 1,3-thiazole ring fused to but not sharing a nitrogen atom with a pyrimidine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4402,
      'name' => "7-oxo-1,3-thiazolo[5,4-d]pyrimidines",
      'description' => "Aromatic heteropolycyclic compounds containing a 1,3-thiazolo[5,4-d]pyrimidine ring system that carries an oxo group at the 7-position. 1,3-thiazolo[5,4-d]pyrimidine consists of a 1,3-thiazole ring fused to but not sharing a nitrogen atom with a pyrimidine ring.",
      'parent' => 4401,
    ),
    array(
      'tid' => 4403,
      'name' => "Haloquinolines",
      'description' => "Compounds containing a quinoline moiety, which is substituted at one or more ring positions by n halogen atom.",
      'parent' => 1253,
    ),
    array(
      'tid' => 4404,
      'name' => "Ribonucleoside 3'-phosphates",
      'description' => "Ribonucleosides that contain a phosphate group attached to the C-3 carbon of the ribose or deoxyribose moiety. The nucleobases here are limited to purine, pyrimidine, and pyridine derivatives.",
      'parent' => 289,
    ),
    array(
      'tid' => 4405,
      'name' => "Pyridopyrazines",
      'description' => "Aromatic heteropolycyclic compounds containing a pyridine ring fused to a pyrazine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4406,
      'name' => "3-arylsulfonyl-pyrazolo[1,5-a]pyrimidines",
      'description' => "Aromatic heteropolycyclic compounds that contain a pyrazolo[1,5-a]pyrimidine ring system, which is substituted at the 3-position by an arylsulfonyl group.",
      'parent' => 4390,
    ),
    array(
      'tid' => 4407,
      'name' => "Furopyridines",
      'description' => "Aromatic heterocyclic compounds containing a furopyridine ring system, which consists of a furan ring fused to a pyridine ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4408,
      'name' => "Furo[2,3-c]pyridines",
      'description' => "Aromatic compounds containing a furopyridine ring system, where the O- and the N-atom are at the 1- and 6- position, respectively.",
      'parent' => 4407,
    ),
    array(
      'tid' => 4409,
      'name' => "Furo[3,2-c]pyridines",
      'description' => "Aromatic compounds containing a furopyridine ring system, where the O- and the N-atom are at the 1- and 5- position, respectively.",
      'parent' => 4407,
    ),
    array(
      'tid' => 4410,
      'name' => "Cephalosporin 3'-carbamates",
      'description' => "Cephalosporins that are substituted at the 3'-position by a carbamate group.",
      'parent' => 173,
    ),
    array(
      'tid' => 4411,
      'name' => "Cephalosporin 3'-esters",
      'description' => "Cephalosporins that are esterified at the 3'-position.",
      'parent' => 173,
    ),
    array(
      'tid' => 4412,
      'name' => "3'-quaternary ammonium cephalosporins",
      'description' => "Cephalosporins that are substituted at the 3'-position by a quaternary ammonium group.",
      'parent' => 173,
    ),
    array(
      'tid' => 4413,
      'name' => "Anthranilamides",
      'description' => "Aromatic compound containing a benzene carboxamide moiety that carries an amine group at the 2-position of the benzene ring.",
      'parent' => 178,
    ),
    array(
      'tid' => 4414,
      'name' => "N-benzoylpyrazoles",
      'description' => "Aromatic heterocyclic compounds containing a pyrazole ring that is N-substituted at the 1-position by a benzoyl group.",
      'parent' => 4704,
    ),
    array(
      'tid' => 4415,
      'name' => "Pyrrolo[2,3-d]pyrimidines",
      'description' => "Aromatic heteropolycyclic compounds containing a pyrrolo[2,3-d]pyrimidine ring system, which is an pyrrolopyrimidine isomers having the 3 ring nitrogen atoms at the 1-, 5-, and 7-positions.",
      'parent' => 1799,
    ),
    array(
      'tid' => 4416,
      'name' => "Furo[2,3-d]pyrimidines",
      'description' => "Aromatic heteropolycyclic compounds containing a furo[2,3-d]pyrimidine ring system, which is a furopyrimidine isomer having the on ring oxygen atom, and 2 nitrogen atoms at the 1-, 5-, and 7-positions, respectively.",
      'parent' => 2,
    ),
    array(
      'tid' => 4417,
      'name' => "Pyrido[2,3-d]pyrimidines",
      'description' => "Compounds containing the pyrido[2,3-d]pyrimidine ring system, which is a pyridopyrimidine isomer with three ring nitrogen atoms at the 1-, 3-, and 8- position.",
      'parent' => 1859,
    ),
    array(
      'tid' => 4418,
      'name' => "Pyrrolo[2,1-f][1,2,4]triazines",
      'description' => "Aromatic heterocyclic compounds containing a pyrrolo[2,1-f][1,2,4]triazine ring system. Pyrrolo[2,1-f][1,2,4]triazine consists of a 1,2,4-triazine ring fused to and sharing the N2-atom with a pyrrole ring.",
      'parent' => 1798,
    ),
    array(
      'tid' => 4419,
      'name' => "Pyrido[3,4-d]pyrimidines",
      'description' => "Compounds containing the pyrido[3,4-d]pyrimidine ring system, which is a pyridopyrimidine isomer with three ring nitrogen atoms at the 1-, 3-, and 7- position.",
      'parent' => 1859,
    ),
    array(
      'tid' => 4420,
      'name' => "2-amino-pyrido[2,3-d]pyrimidines",
      'description' => "Compounds containing the pyrido[2,3-d]pyrimidine ring system, which carries an amine at the 2-position. Pyrido[2,3-d]pyrimidine is a pyridopyrimidine isomer with three ring nitrogen atoms at the 1-, 3-, and 8- position.",
      'parent' => 4417,
    ),
    array(
      'tid' => 4421,
      'name' => "Isoindolo[2,1-a]quinoxalines",
      'description' => "Aromatic heterocyclic compounds containing an isoindole moiety fused to and sharing a nitrogen atom with a quinoxaline ring system.",
      'parent' => 486,
    ),
    array(
      'tid' => 4422,
      'name' => "Benzo[c]quinolizin-3-ones",
      'description' => "Aromatic organonitrogen heterocyclic compounds containing a benzo[c]quinolizine ring system, which carries an oxo group at the 3-position.",
      'parent' => 222,
    ),
    array(
      'tid' => 4423,
      'name' => "Benzo[f]quinolin-3-ones",
      'description' => "Aromatic organonitrogen heterocyclic compounds that contain a benzo[f]quinoline ring system  carrying an oxo group at the 3-position.",
      'parent' => 1908,
    ),
    array(
      'tid' => 4424,
      'name' => "Pyrrolo[3,2-c]quinolines",
      'description' => "Aromatic organonitrogen heterocyclic compounds containing a pyrrolo[3,2-c]quinoline, a pyrroloquinoline isomer that possesses two ring nitrogen atoms at the 1- and 5-positions.",
      'parent' => 1734,
    ),
    array(
      'tid' => 4425,
      'name' => "O-thiocarbamates",
      'description' => "O-ester derivatives of thiocarbamic acid, with the general formula ROC(=S)NR2.",
      'parent' => 1190,
    ),
    array(
      'tid' => 4426,
      'name' => "S-thiocarbamates",
      'description' => "S-ester derivatives of thiocarbamic acid, with the general formula RSC(=O)NR2.",
      'parent' => 1190,
    ),
    array(
      'tid' => 4427,
      'name' => "S-Alkyl-thiocarbamates",
      'description' => "S-ester derivatives of thiocarbamic acid, with the general formula RSC(=O)NR2, where R is an alkyl group.",
      'parent' => 4426,
    ),
    array(
      'tid' => 4428,
      'name' => "Thiocarbamate salts",
      'description' => "Salts of thiocarbamic acids.",
      'parent' => 1368,
    ),
    array(
      'tid' => 4429,
      'name' => "Dithiocarbamate salts",
      'description' => "Salts of dithiocarbamic acids.",
      'parent' => 3934,
    ),
    array(
      'tid' => 4430,
      'name' => "Chloroformic acid esters",
      'description' => "Organochlorine compounds which are esters of chloroformic acid.",
      'parent' => 364,
    ),
    array(
      'tid' => 4431,
      'name' => "Alkylchloroformates",
      'description' => "Compounds containing a chloroformic acid group that is esterified with an alkyl group.",
      'parent' => 4430,
    ),
    array(
      'tid' => 4432,
      'name' => "Inorganic silicides",
      'description' => "Inorganic compounds containing silicon with a less electronegative element or elements (according to the Pauling scale).",
      'parent' => 1568,
    ),
    array(
      'tid' => 4433,
      'name' => "Borate esters",
      'description' => "Ester derivatives of boric acid, with the generic formula ROB(OR')OR\", where R is an organic group.",
      'parent' => 264,
    ),
    array(
      'tid' => 4434,
      'name' => "Organic sulfonic acids and derivatives",
      'description' => "Compounds containing a sulfonic acid or derivative, with the general structure RS(=O)2X (R= H or organyl group, X=any heteroatom).",
      'parent' => 264,
    ),
    array(
      'tid' => 4435,
      'name' => "Sulfonic acid esters",
      'description' => "Esters of sulfonic acid, which have the general structure RS(=O)2OR' (R,R' = organyl group or H).",
      'parent' => 4434,
    ),
    array(
      'tid' => 4436,
      'name' => "Metal alkyls",
      'description' => "Organometallic compounds hat containing a metal atom substituted by on or more alkyl groups.",
      'parent' => 462,
    ),
    array(
      'tid' => 4437,
      'name' => "Organic sulfonic anhydrides",
      'description' => "Organic compounds having the structure RS(=O)2OS(=O)2R', where R , R' = H or organyl group.",
      'parent' => 4434,
    ),
    array(
      'tid' => 4438,
      'name' => "Organic sulfonic acids",
      'description' => "Organic compounds containing a sulfonic acid or derivative, with the general structure RS(=O)2OH (R= H or organyl group).",
      'parent' => 4434,
    ),
    array(
      'tid' => 4439,
      'name' => "Organic sulfonamides",
      'description' => "Organic compounds containing the sulfonamide functional group, an amide of sulfonic acid with the general structure R1S(=O)2N(R2)R3 (R1=H or organyl; R2,R3=H, alkyl, aryl).",
      'parent' => 4434,
    ),
    array(
      'tid' => 4440,
      'name' => "Metal aryls",
      'description' => "Organometallic compounds hat containing a metal atom substituted by on or more aryl groups.",
      'parent' => 462,
    ),
    array(
      'tid' => 4441,
      'name' => "Metal allyls",
      'description' => "Organometallic compounds containing an allylic group attached to the metal atom.",
      'parent' => 462,
    ),
    array(
      'tid' => 4442,
      'name' => "Metal alkyl halides",
      'description' => "Organometallic compounds with the generic formula R-M-X, where R is an alkyl group, and X is a metal atom.",
      'parent' => 462,
    ),
    array(
      'tid' => 4443,
      'name' => "Transition metal alkyls",
      'description' => "Metal alkyls, where the alkyl group is attached to a transition metal atom.",
      'parent' => 4436,
    ),
    array(
      'tid' => 4444,
      'name' => "Organochlorosilanes",
      'description' => "Organosilicon compounds where the tetravalent silicon atom is linked to one or more chlorine atoms.",
      'parent' => 4445,
    ),
    array(
      'tid' => 4445,
      'name' => "Organoheterosilanes",
      'description' => "Organosilicon compounds where the tetravalent silicon atom is linked to one or more heteroatoms.",
      'parent' => 3194,
    ),
    array(
      'tid' => 4446,
      'name' => "Siloxanes",
      'description' => "Saturated silicon-oxygen hydrides with unbranched or branched chains of alternating silicon and oxygen atoms (each silicon atom is separated from its nearest silicon neighbours by single oxygen atoms). The general structure of unbranched siloxanes is H3Si[OSiH2]nOSiH3. H3Si[OSiH2]nOSiH[OSiH2OSiH3]2 is an example of a branched siloxane. By extension hydrocarbyl derivatives are commonly included.",
      'parent' => 3194,
    ),
    array(
      'tid' => 4447,
      'name' => "Carbonate salts",
      'description' => "Compounds that results from the interaction between a positive ion and the negatively charge oxygen atom of the carbonate ion.",
      'parent' => 364,
    ),
    array(
      'tid' => 4448,
      'name' => "Alkali metal carbonate salts",
      'description' => "Organic salts that results from the interaction of an alkali metal ion with a negatively charged oxygen atom of the carbonate ion.",
      'parent' => 4449,
    ),
    array(
      'tid' => 4449,
      'name' => "Metal carbonate salts",
      'description' => "Organic salts that results from the interaction of a metal ion with a negatively charged oxygen atom of the carbonate ion.",
      'parent' => 4447,
    ),
    array(
      'tid' => 4450,
      'name' => "Acrylic acids and derivatives",
      'description' => "Organic compounds containing acrylic acid CH2=CHCO2H or a derivative thereof.",
      'parent' => 265,
    ),
    array(
      'tid' => 4451,
      'name' => "Acrylic acids",
      'description' => "Organic compounds containing acrylic acid CH2=CHCO2H.",
      'parent' => 4450,
    ),
    array(
      'tid' => 4452,
      'name' => "Acrylic acid esters",
      'description' => "Organic compounds containing and ester acrylic acid (CH2=CHC(=O)OH).",
      'parent' => 4450,
    ),
    array(
      'tid' => 4453,
      'name' => "Alpha-aminonitriles",
      'description' => "Organonitrogen compounds that contain an amino group located on the carbon at the position alpha to a carbonitrile group.  They have the general formula RC(NH2)C#N, where the amine group can be substituted.",
      'parent' => 362,
    ),
    array(
      'tid' => 4454,
      'name' => "Alpha-hydroxynitriles",
      'description' => "Organonitrogen compounds that contain a hydroxyl group located on the carbon at the position alpha to a carbonitrile group. They have the general formula RC(OH)C#N.",
      'parent' => 362,
    ),
    array(
      'tid' => 4455,
      'name' => "Organic sulfite salts",
      'description' => "Organic salts of the sulfite ion.",
      'parent' => 3865,
    ),
    array(
      'tid' => 4456,
      'name' => "Organic sulfites",
      'description' => "Organic compounds containing the selenite oxoanion, with the formula  [SO3]2-, or its conjugated base.",
      'parent' => 463,
    ),
    array(
      'tid' => 4457,
      'name' => "Organic thiosulfate salts",
      'description' => "Organic salts of the thiosulfate ion.",
      'parent' => 3865,
    ),
    array(
      'tid' => 4458,
      'name' => "Organic bromate salts",
      'description' => "Organic salts of bromate. They contain bromate in its ionic form or conjugated to a metal atom.",
      'parent' => 3865,
    ),
    array(
      'tid' => 4459,
      'name' => "Organic selenite salts",
      'description' => "Organic salts containing a selenite group, in its ionic form or bound to a metal atom.",
      'parent' => 3865,
    ),
    array(
      'tid' => 4460,
      'name' => "Organic iodate salts",
      'description' => "Organic salts containing the iodate group, in its ionic form or bound to a metal atom.",
      'parent' => 3865,
    ),
    array(
      'tid' => 4461,
      'name' => "Triazolines",
      'description' => "Compounds that contain the triazoline ring, which is a five-membered unsaturated ring having two carbon atoms, three nitrogen atoms and one double bond.",
      'parent' => 2490,
    ),
    array(
      'tid' => 4462,
      'name' => "Organic chlorite salts",
      'description' => "Organic salts containing the chlorite group, in its ionic form or bound to a metal atom.",
      'parent' => 3865,
    ),
    array(
      'tid' => 4463,
      'name' => "Organic phosphite salts",
      'description' => "Organic salts containing a phosphite group, in its ionic form or bound to a metal atom.",
      'parent' => 3865,
    ),
    array(
      'tid' => 4464,
      'name' => "Inorganic azides",
      'description' => "Inorganic compounds bearing the group N3, viz. -N=N+=N-.",
      'parent' => 1568,
    ),
    array(
      'tid' => 4465,
      'name' => "Alkyl azides",
      'description' => "Compounds bearing the group N3, viz. -N=N+=N- attached to an alkyl group.",
      'parent' => 4467,
    ),
    array(
      'tid' => 4466,
      'name' => "Aryl azides",
      'description' => "Compounds bearing the group N3, viz. -N=N+=N- attached to an aryl group.",
      'parent' => 4467,
    ),
    array(
      'tid' => 4467,
      'name' => "Organoazides",
      'description' => "Compounds bearing the group N3, viz. -N=N+=N- attached to an organic group.",
      'parent' => 3633,
    ),
    array(
      'tid' => 4468,
      'name' => "Salt-like carbides",
      'description' => "Inorganic salts containing a carbon atom combined with one or more elements of similar or lower electronegativity.",
      'parent' => 4469,
    ),
    array(
      'tid' => 4469,
      'name' => "Carbides",
      'description' => "Inorganic compounds containing a carbon atom combined with one or more elements of similar or lower electronegativity.",
      'parent' => 1568,
    ),
    array(
      'tid' => 4470,
      'name' => "Inorganic nitrides",
      'description' => "Inorganic compounds of nitrogen where nitrogen has a formal oxidation state of -3.",
      'parent' => 1568,
    ),
    array(
      'tid' => 4471,
      'name' => "Inorganic nitrites",
      'description' => "Inorganic compounds containing the nitrite ion NO2-.",
      'parent' => 1568,
    ),
    array(
      'tid' => 4472,
      'name' => "Ketals",
      'description' => "Acetals derived from ketones by replacement of the oxo group by two hydrocarbyloxy groups R2C(OR)2 ( R not Hydrogen ). This term, once abandoned, has been reinstated as a subclass of acetals.",
      'parent' => 1656,
    ),
    array(
      'tid' => 4473,
      'name' => "Alkenyl azides",
      'description' => "Compounds bearing the group N3, viz. -N=N+=N- attached to an alkenyl group.",
      'parent' => 4467,
    ),
    array(
      'tid' => 4474,
      'name' => "Saturated hydrocarbons",
      'description' => "Hydrocarbons that contains only saturated carbon atoms, which are linked to one another through single bonds. These includes alkanes and cycloalkanes.",
      'parent' => 2837,
    ),
    array(
      'tid' => 4475,
      'name' => "Unsaturated hydrocarbons",
      'description' => "Hydrocarbons that contains one or more unsaturated carbon atoms. These compounds contain one or more double, triple, or aromatic bonds.",
      'parent' => 2837,
    ),
    array(
      'tid' => 4476,
      'name' => "Unsaturated aliphatic hydrocarbons",
      'description' => "Aliphatic Hydrocarbons that contains one or more unsaturated carbon atoms. These compounds contain one or more double or triple bonds.",
      'parent' => 4475,
    ),
    array(
      'tid' => 4477,
      'name' => "Aromatic hydrocarbons",
      'description' => "Aromatic compounds that are made up of carbon and hydrogen atoms only.",
      'parent' => 2837,
    ),
    array(
      'tid' => 4478,
      'name' => "Acetylides",
      'description' => "Compounds arising by replacement of one or both hydrogen atoms of acetylene (ethyne) by a metal or other cationic group. E.g. NaC#CH monosodium acetylide. By extension, analogous compounds derived from terminal acetylenes, RC#CH. The class is limited here to derivatives of acetylene where the hydrogen atom is replaced with an element with similar or lower electronegativity that carbon.",
      'parent' => 0,
    ),
    array(
      'tid' => 4479,
      'name' => "Trialkylheterosilanes",
      'description' => "Organoheterosilanes, bearing a silicon atom linked to three alkyl groups and one heteroatom.",
      'parent' => 4445,
    ),
    array(
      'tid' => 4480,
      'name' => "Trialkylchlorosilanes",
      'description' => "Organoheterosilanes, bearing a silicon atom linked to three alkyl groups and one chlorine atom.",
      'parent' => 4479,
    ),
    array(
      'tid' => 4481,
      'name' => "Trimethylsilyl esters",
      'description' => "Organoheterosilanes, bearing a silicon atom that is  linked to three methyl groups and is O-esterified.",
      'parent' => 3194,
    ),
    array(
      'tid' => 4482,
      'name' => "Dialkyl alkylphosphonates",
      'description' => "Compounds containing a phosphonic acid that is diesterified with alkyl groups, and the phosphorus atom is also directly attached to an alkyl group.",
      'parent' => 3893,
    ),
    array(
      'tid' => 4483,
      'name' => "Alkylphosphonofluoridic acids and esters",
      'description' => "Organophosphorus compounds containing a phosphonic acid or an ester derivative thereof, where the phosphorus atom is directly attached to an alkyl group.",
      'parent' => 400,
    ),
    array(
      'tid' => 4484,
      'name' => "Trialkylphosphites",
      'description' => "Organic compounds containing a phosphorous acid, which is tri-esterified with alkyl groups.",
      'parent' => 400,
    ),
    array(
      'tid' => 4485,
      'name' => "Cyclohexyl halides",
      'description' => "Organohalogen compounds containing a monocyclic cyclohexane moiety that is substituted at one or more positions by an halogen atom.",
      'parent' => 2867,
    ),
    array(
      'tid' => 4486,
      'name' => "O-alkylpyrimidines",
      'description' => "Compounds containing a pyrimidine , which is O-alkylated at one or more ring positions.",
      'parent' => 75,
    ),
    array(
      'tid' => 4487,
      'name' => "Inorganic lithium salts",
      'description' => "Inorganic salts containing a lithium ion.",
      'parent' => 3866,
    ),
    array(
      'tid' => 4488,
      'name' => "Organic lithium salts",
      'description' => "Organic compounds containing a lithium ion.",
      'parent' => 4099,
    ),
    array(
      'tid' => 4489,
      'name' => "Organic beryllium salts",
      'description' => "Organic compounds containing a beryllium ion.",
      'parent' => 4036,
    ),
    array(
      'tid' => 4490,
      'name' => "Inorganic beryllium salts",
      'description' => "Inorganic salts of cadmium. They usually contain beryllium in its ionic form.",
      'parent' => 3866,
    ),
    array(
      'tid' => 4491,
      'name' => "Organic metal halides",
      'description' => "Organic compounds containing metals and halogens. Some are ionic while others are covalently bonded.",
      'parent' => 4036,
    ),
    array(
      'tid' => 4492,
      'name' => "Organonickel compounds",
      'description' => "Organic compounds containing a bond between a carbon atom and a nickel atom.",
      'parent' => 1371,
    ),
    array(
      'tid' => 4493,
      'name' => "Organic calcium salts",
      'description' => "Organic salts containing a calcium ion.",
      'parent' => 4036,
    ),
    array(
      'tid' => 4494,
      'name' => "Inorganic calcium salts",
      'description' => "Inorganic salts containing a calcium ion.",
      'parent' => 3866,
    ),
    array(
      'tid' => 4495,
      'name' => "14-hydroxysteroids",
      'description' => "Steroids carrying a hydroxyl group at the 14-position of the steroid backbone.",
      'parent' => 1295,
    ),
    array(
      'tid' => 4496,
      'name' => "3',5'-cyclic purine nucleoside phosphorothioates",
      'description' => "3',5'-cyclic purine nucleoside phosphate analogues, where a phosphate oxygen has been exchanged for sulphur generating a chiral phosphorothioate. In 3',5'-cyclic nucleoside phosphorothioate, the oxygen atoms at the 3'- and 5'-positions of the ribose are part of the phosphorothioate group.",
      'parent' => 3737,
    ),
    array(
      'tid' => 4497,
      'name' => "3',5'-cyclic pyrimidine nucleoside phosphorothioates",
      'description' => "3',5'-cyclic pyrimidine nucleoside phosphate analogues, where a phosphate oxygen has been exchanged for sulphur generating a chiral phosphorothioate. In 3',5'-cyclic nucleoside phosphorothioate, the oxygen atoms at the 3'- and 5'-positions of the ribose are part of the phosphorothioate group.",
      'parent' => 3737,
    ),
    array(
      'tid' => 4498,
      'name' => "2',3'-dideoxy-3'-thionucleosides",
      'description' => "2',3'-deoxyribonucleosides, where the ribose unit is thio-substituted at the 3'-position. The nucleobases here are limited to purine, pyrimidine, and pyridine derivatives.",
      'parent' => 289,
    ),
    array(
      'tid' => 4499,
      'name' => "2',3'-dideoxy-3'-thionucleoside triphosphates",
      'description' => "2',3'-deoxyribonucleoside derivatives, where the ribose unit is thio-substituted at the 3'-position, and at the 5'-position by a triphosphate group. The nucleobases here are limited to purine, pyrimidine, and pyridine derivatives.",
      'parent' => 289,
    ),
    array(
      'tid' => 4500,
      'name' => "2',3'-dideoxy-3'-thionucleoside diphosphates",
      'description' => "2',3'-deoxyribonucleoside derivatives, where the ribose unit is thio-substituted at the 3'-position, and at the 5'-position by a diphosphate group. The nucleobases here are limited to purine, pyrimidine, and pyridine derivatives.",
      'parent' => 289,
    ),
    array(
      'tid' => 4501,
      'name' => "2',3'-dideoxy-3'-thionucleoside monophosphates",
      'description' => "2',3'-deoxyribonucleoside derivatives, where the ribose unit is thio-substituted at the 3'-position, and at the 5'-position by a monophosphate group. The nucleobases here are limited to purine, pyrimidine, and pyridine derivatives.",
      'parent' => 289,
    ),
    array(
      'tid' => 4502,
      'name' => "5'-deoxyribonucleosides",
      'description' => "Nucleosides in which the oxygen atom at the 5'position of the ribose moiety has been replaced by another atom. The nucleobases here are limited to purine, pyrimidine, and pyridine derivatives.",
      'parent' => 289,
    ),
    array(
      'tid' => 4503,
      'name' => "5'-deoxy-5'-thionucleosides",
      'description' => "5'-deoxyribonucleosides  in which the ribose is thio-substituted at the 5'position by a S-alkyl group.",
      'parent' => 4502,
    ),
    array(
      'tid' => 4504,
      'name' => "Organic cyanides",
      'description' => "Organic nitrogen compounds that contain the cyano (C#N) group. The group can be present either in the anionic or covalently bond form.",
      'parent' => 278,
    ),
    array(
      'tid' => 4505,
      'name' => "Dinitrophenols",
      'description' => "Organic aromatic compounds containing a benzene that carries a single phenol group and exactly two nitro groups.",
      'parent' => 141,
    ),
    array(
      'tid' => 4506,
      'name' => "N-acetylarylamines",
      'description' => "Acetamides where one or more amide hydrogens is substituted by an aryl group.",
      'parent' => 3282,
    ),
    array(
      'tid' => 4507,
      'name' => "Phosphiranes",
      'description' => "Heterocyclic compounds containing a phosphirane, which is a three-membered saturated ring made up of two carbon atoms and phosphorus atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 4508,
      'name' => "Chloroethylnitrosoureas",
      'description' => "Nitrosoureas derivatives where the central nitrogen atom carrying the nitroso group is also linked to a chloroethyl group.",
      'parent' => 1229,
    ),
    array(
      'tid' => 4509,
      'name' => "1,2,3-thiadiazolopyridines",
      'description' => "Aromatic heterocyclic compounds containing a pyridine fused to a 1,2,3-thiadiazole ring.",
      'parent' => 93,
    ),
    array(
      'tid' => 4510,
      'name' => "7-alkoxylcoumarins",
      'description' => "Aromatic heterocyclic compounds that contain a coumarin ring substituted at the 7-position by an alkoxy group.",
      'parent' => 145,
    ),
    array(
      'tid' => 4511,
      'name' => "Alkylhydrazines",
      'description' => "Organonitrogen compounds that containing a hydrazine group to which an alkyl group is attached.",
      'parent' => 112,
    ),
    array(
      'tid' => 4512,
      'name' => "1,2-diacyl-1-alkylhydrazines",
      'description' => "Hydrazine derivatives where the hydrazine group is N-acylated at both nitrogen atoms, one of which also carries an alkyl group.",
      'parent' => 4816,
    ),
    array(
      'tid' => 4513,
      'name' => "N-benzoyl-N'-phenylureas",
      'description' => "N-acyl-phenylureas that have the acyl group substituted by a phenyl group.",
      'parent' => 2982,
    ),
    array(
      'tid' => 4514,
      'name' => "N-sulfenyl-N'-sulfonyl-ureas",
      'description' => "Urea derivatives that carry a sulfonyl group at one nitrogen atom of the urea backbone, and a sulfenyl group at the other nitrogen atom.",
      'parent' => 490,
    ),
    array(
      'tid' => 4515,
      'name' => "Sulfonyl isocyanates",
      'description' => "Organosulfur compounds that contain a sulfonyl group connected to an isocyanate group.",
      'parent' => 1157,
    ),
    array(
      'tid' => 4516,
      'name' => "Sulfonyl isothiocyanates",
      'description' => "Organosulfur compounds that contain a sulfonyl group connected to an isothiocyanate group.",
      'parent' => 1157,
    ),
    array(
      'tid' => 4517,
      'name' => "P-toluenesulfonamides",
      'description' => "Aromatic heterocyclic compounds containing a toluene that is p-substituted with a sulfonamide group.",
      'parent' => 3276,
    ),
    array(
      'tid' => 4518,
      'name' => "N,N-disubstituted p-toluenesulfonamides",
      'description' => "P-toluenesulfonamide derivatives in which the sulfonamide moiety is N,N-disubstituted.",
      'parent' => 4517,
    ),
    array(
      'tid' => 4519,
      'name' => "Polybrominated dibenzofurans",
      'description' => "Organic compounds containing two or more bromine atoms attached to a dibenzofuran moiety.",
      'parent' => 4520,
    ),
    array(
      'tid' => 4520,
      'name' => "Brominated dibenzofurans",
      'description' => "Organic compounds containing a bromine atom attached to a dibenzofuran moiety.",
      'parent' => 15,
    ),
    array(
      'tid' => 4521,
      'name' => "Chlorofluorocarbons",
      'description' => "Alkyhalide compounds that are composed only of chlorine, fluorine, and carbon atoms.",
      'parent' => 1026,
    ),
    array(
      'tid' => 4522,
      'name' => "Hydrofluorocarbons",
      'description' => "Alkyhalide compounds that are composed only of hydrogen, fluorine, and carbon atoms.",
      'parent' => 1026,
    ),
    array(
      'tid' => 4523,
      'name' => "Aziridinylquinones",
      'description' => "Heterocyclic molecules that contain an aziridine ring linked to a quinone moiety .",
      'parent' => 2495,
    ),
    array(
      'tid' => 4524,
      'name' => "Triphenyl compounds",
      'description' => "Aromatic compounds containing a triphenyl moiety.",
      'parent' => 2448,
    ),
    array(
      'tid' => 4525,
      'name' => "Chlorophenoxyacetates",
      'description' => "Compounds containing a phenoxyacetate that carries one or more chlorine atoms on the benzene ring.",
      'parent' => 417,
    ),
    array(
      'tid' => 4526,
      'name' => "Chloroanilines",
      'description' => "Aromatic compounds containing an aniline moiety substituted at one or more positions with a chlorine atom.",
      'parent' => 284,
    ),
    array(
      'tid' => 4527,
      'name' => "Chloroacetamides",
      'description' => "Organic compounds with the general formula RNHC(=O)CH2Cl, where R= organyl group.",
      'parent' => 475,
    ),
    array(
      'tid' => 4528,
      'name' => "Halotoluenes",
      'description' => "Aromatic compounds containing a toluene that is substituted at one or more ring positions with a halogen atom.",
      'parent' => 1091,
    ),
    array(
      'tid' => 4529,
      'name' => "3-methylindoles",
      'description' => "Aromatic heterocyclic compounds that contain an indole moiety substituted at the 3-position with a methyl group.",
      'parent' => 4196,
    ),
    array(
      'tid' => 4530,
      'name' => "Formamides",
      'description' => "Organonitrogen compounds containing the formamide functional group.",
      'parent' => 475,
    ),
    array(
      'tid' => 4531,
      'name' => "2-halopyrimidines",
      'description' => "Aromatic compounds containing a pyrimidine ring substituted at the 2-position with a halogen atom.",
      'parent' => 1893,
    ),
    array(
      'tid' => 4532,
      'name' => "2-halopyridines",
      'description' => "Organic compounds containing a pyridine ring substituted at the 2-position by a halogen atom.",
      'parent' => 3970,
    ),
    array(
      'tid' => 4533,
      'name' => "1,2,3,6-Tetrahydropyridines",
      'description' => "Organoheterocyclic compounds that contain 1,2,3,6-tetrahydropyridine ring.",
      'parent' => 1934,
    ),
    array(
      'tid' => 4534,
      'name' => "Arylbiguanides",
      'description' => "Organonitrogen compounds containing a biguanide that is N-substituted at one or more position with an aryl moiety.",
      'parent' => 474,
    ),
    array(
      'tid' => 4535,
      'name' => "1,5-diarylbiguanides",
      'description' => "Organonitrogen compounds containing a biguanide that is N-substituted at the 1- and 5- positions with an aryl moiety.",
      'parent' => 4534,
    ),
    array(
      'tid' => 4536,
      'name' => "1-arylbiguanides",
      'description' => "Organonitrogen compounds containing a biguanide that is N-arylsubstituted at only the 1-position.",
      'parent' => 4534,
    ),
    array(
      'tid' => 4537,
      'name' => "4-aminoquinolines",
      'description' => "Organic compounds containing an amino group attached to the 4-position of a quinoline ring system.",
      'parent' => 53,
    ),
    array(
      'tid' => 4538,
      'name' => "4-quinolinemethanols",
      'description' => "Organoheterocyclic compounds containing a quinoline moiety substituted at the 4-position with a methanol.",
      'parent' => 1253,
    ),
    array(
      'tid' => 4539,
      'name' => "Organothalium compounds",
      'description' => "Compounds containing a bond between a carbon atom and a thalium atom.",
      'parent' => 1523,
    ),
    array(
      'tid' => 4540,
      'name' => "Inorganic thalium compounds",
      'description' => "Inorganic molecular entities containing one or more thalium atoms.",
      'parent' => 1568,
    ),
    array(
      'tid' => 4541,
      'name' => "Halonitrobenzenes",
      'description' => "Compounds containing a nitrobenzene moiety, where the benzene ring carries an halogen atom.",
      'parent' => 36,
    ),
    array(
      'tid' => 4542,
      'name' => "Thiopurine S-methylethers",
      'description' => "Aromatic compounds containing a purine that bears a S-methylether group at the 6-position.",
      'parent' => 3453,
    ),
    array(
      'tid' => 4543,
      'name' => "N-methylpyridinium compounds",
      'description' => "Methylpyridines that carry a methyl group at the 1-position.",
      'parent' => 4152,
    ),
    array(
      'tid' => 4544,
      'name' => "Aryl dialkyl phosphates",
      'description' => "Organic compounds containing a phosphate group that is linked to exactly two alkyl chain and one aromatic ring.",
      'parent' => 3457,
    ),
    array(
      'tid' => 4545,
      'name' => "Arylhydroxamates",
      'description' => "Aromatic compounds containing an hydroxamate group attached to an aromatic moiety.",
      'parent' => 278,
    ),
    array(
      'tid' => 4546,
      'name' => "S-(2-hydroxyacyl)glutathiones",
      'description' => "Any glutathione derivative with a S-2-hydroxyacyl substituent.",
      'parent' => 3052,
    ),
    array(
      'tid' => 4547,
      'name' => "5'-acylphosphoadenosines",
      'description' => "Ribonucleoside derivatives containing an adenoside moiety, where the phosphate group is acylated.",
      'parent' => 1617,
    ),
    array(
      'tid' => 4548,
      'name' => "Benzyl isothiocyanates",
      'description' => "Aromatic compounds containing an isothiocyanate group that is N-substituted to a benzyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4549,
      'name' => "Benzyl thiocyanates",
      'description' => "Aromatic compounds containing an thiocyanate group that is S-substituted to a benzyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4550,
      'name' => "13,28-epoxyoleananes",
      'description' => "Triterpenoids that contain an oleanane skeleton substituted by an oxolane  bridge at positions13 and 28.",
      'parent' => 180,
    ),
    array(
      'tid' => 4551,
      'name' => "Trifluoromethylbenzenes",
      'description' => "Organofluorine compounds that contain a benzene ring substituted with one or more trifluoromethyl groups.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4552,
      'name' => "Indazole-3-carboxamides",
      'description' => "Aromatic compounds containing an indazole ring system that is substituted at the 3-position with a carboxamide group.",
      'parent' => 80,
    ),
    array(
      'tid' => 4553,
      'name' => "Cumulenes",
      'description' => "Hydrocarbons that contain at least three consecutive double bonds.",
      'parent' => 4475,
    ),
    array(
      'tid' => 4554,
      'name' => "Nitrimines",
      'description' => "Compounds having the structure O2NN=CR2 (also called N-nitroimines).",
      'parent' => 1152,
    ),
    array(
      'tid' => 4555,
      'name' => "L-cysteine-S-conjugates",
      'description' => "Compounds containing L-cysteine where the thio-group is conjugated.",
      'parent' => 4313,
    ),
    array(
      'tid' => 4556,
      'name' => "S-sulfo-L-cysteines",
      'description' => "S-conjugated L-cysteine where the S-substituent is specified as a sulfo group.",
      'parent' => 4555,
    ),
    array(
      'tid' => 4557,
      'name' => "Organopnictogen compounds",
      'description' => "Compounds containing a bond between carbon a pnictogen atom. Pnictogens are p-block element atoms that are in the group 15 of the periodic table.",
      'parent' => 0,
    ),
    array(
      'tid' => 4558,
      'name' => "Inorganic pnictogen compounds",
      'description' => "Compounds containing one or more pnictogen atoms. Pnictogens are p-block element atoms that are in the group 15 of the periodic table.",
      'parent' => 1568,
    ),
    array(
      'tid' => 4559,
      'name' => "Avenanthramides",
      'description' => "A group of phenolic alkaloids consisting of conjugate of three phenylpropanoids (ferulic, caffeic, or p-coumaric acid) and anthranilic acid.",
      'parent' => 2503,
    ),
    array(
      'tid' => 4560,
      'name' => "Cyanate esters",
      'description' => "Esters of cyanic acid, with the general formula R-OC#N (R = organyl group).",
      'parent' => 363,
    ),
    array(
      'tid' => 4561,
      'name' => "N-cinnamoylanthranilic acids",
      'description' => "Aromatic compounds containing a cinnamic acid conjugated to an anthranilic acid.",
      'parent' => 2810,
    ),
    array(
      'tid' => 4562,
      'name' => "Metal cyanates",
      'description' => "Compounds containing a metal atom and a cyanate. The metal cyanate group can be in neutral or ionic form (involving a cationic metal and the anionic cyanate).",
      'parent' => 363,
    ),
    array(
      'tid' => 4563,
      'name' => "Inorganic 3-nitrosotriazenes",
      'description' => "Inorganic compounds containing a 3-nitrosotriazene moiety, with the formula N=N-N-N=O.",
      'parent' => 1568,
    ),
    array(
      'tid' => 4564,
      'name' => "Ethoxyethynyl alcohols",
      'description' => "Organic compounds containing an ethoxyethynyl group substituted with an alcohol group.",
      'parent' => 129,
    ),
    array(
      'tid' => 4565,
      'name' => "Haloacetylenes and derivatives",
      'description' => "Organohalogen compounds containing an acetylene group substituted with one or more halogen atoms.",
      'parent' => 267,
    ),
    array(
      'tid' => 4566,
      'name' => "Metal acetylides",
      'description' => "Organic compounds containing an acetylide group substituted with a metal atom.",
      'parent' => 4478,
    ),
    array(
      'tid' => 4567,
      'name' => "Acetylenic peroxides",
      'description' => "Organooxygen compounds with the general formula RC#CCOOH or RC#CCOO-.",
      'parent' => 1308,
    ),
    array(
      'tid' => 4568,
      'name' => "Alkylaluminium and derivatives",
      'description' => "Organoaluminium compounds where the aluminium atom is linked to an alkyl group.",
      'parent' => 1529,
    ),
    array(
      'tid' => 4569,
      'name' => "Alkylaluminium halides",
      'description' => "Organoaluminium compounds containing an aluminium atom linked to an halide and an alkyl group. The three main structural sub-categories include the alkylaluminium dihalides, dialkylaluminium halides, and trialkyldialuminium trihalides.",
      'parent' => 4568,
    ),
    array(
      'tid' => 4570,
      'name' => "Alkylboranes",
      'description' => "Organoboron compounds where the boron atom is substituted by one or more alkyl groups.",
      'parent' => 2795,
    ),
    array(
      'tid' => 4571,
      'name' => "Alkylhaloboranes",
      'description' => "Organoboron compounds with the general formula RBX2 or R2BX (R=alkyl, X=halogen).",
      'parent' => 4570,
    ),
    array(
      'tid' => 4572,
      'name' => "Alkylhalophosphines",
      'description' => "Organophosphorus compounds with the general formula RPX2 or R2PX (R=alkyl, X=halogen).",
      'parent' => 400,
    ),
    array(
      'tid' => 4573,
      'name' => "Monoalkylboranes",
      'description' => "Organoboron compounds where the boron atom is substituted by only one alkyl group.",
      'parent' => 4570,
    ),
    array(
      'tid' => 4574,
      'name' => "Dialkylboranes",
      'description' => "Organoboron compounds where the boron atom is substituted by only two alkyl groups.",
      'parent' => 4570,
    ),
    array(
      'tid' => 4575,
      'name' => "Trialkylboranes",
      'description' => "Organoboron compounds where the boron atom is substituted by only three alkyl groups.",
      'parent' => 4570,
    ),
    array(
      'tid' => 4576,
      'name' => "Acylsalicylic acids and derivatives",
      'description' => "Salicylic acids or derivatives, that are O-acylated.",
      'parent' => 487,
    ),
    array(
      'tid' => 4577,
      'name' => "Acylsalicylic acids",
      'description' => "O-acylated derivatives of salicylic acid.",
      'parent' => 4576,
    ),
    array(
      'tid' => 4578,
      'name' => "Acylsalicylamides",
      'description' => "O-acylated derivatives of salicylamide.",
      'parent' => 4576,
    ),
    array(
      'tid' => 4579,
      'name' => "Diacyl peroxides",
      'description' => "Organooxygen compounds containing a peroxide disubstituted with acyl groups.",
      'parent' => 346,
    ),
    array(
      'tid' => 4580,
      'name' => "3-beta-hydroxysteroid-4-alpha-carboxylates",
      'description' => "Steroids that carry a beta-hydroxyl group and a carboxyl group at the 3- and 4-positions, respectively.",
      'parent' => 3492,
    ),
    array(
      'tid' => 4581,
      'name' => "Trifluoromethanesulfonates",
      'description' => "Alkanesulfonic acids, that contain a sulfonate group that is substituted with a trifluoromethyl group.",
      'parent' => 3311,
    ),
    array(
      'tid' => 4582,
      'name' => "Alkyl hydroperoxides",
      'description' => "Organooxygen compounds containing a hydroperoxide group substituted with an alkyl group. They have the general formula ROOH, where R is the alkyl group.",
      'parent' => 1308,
    ),
    array(
      'tid' => 4583,
      'name' => "Trialkylantimony halides",
      'description' => "Organoantimony compounds where the tetravalent or pentavalent antimony atom is substituted by an halogen atom and exactly three alkyl groups.",
      'parent' => 349,
    ),
    array(
      'tid' => 4584,
      'name' => "Allyl trifluoromethanesulfonates",
      'description' => "Trifluoromethanesulfonates that are O-substituted with an allyl group. They have the general formula RCH=CR'CH2OSO2CF3.",
      'parent' => 4581,
    ),
    array(
      'tid' => 4585,
      'name' => "Allylic hydroperoxides",
      'description' => "Organooxygen compounds containing a hydroperoxide group substituted with an allyl group. They have the general formula RCH=CR'CH2OSO2CF3.",
      'parent' => 1308,
    ),
    array(
      'tid' => 4586,
      'name' => "Diazoethers",
      'description' => "Organooxygen compounds with the general formula RN=NOR' (R=H or organyl, R'=organyl).",
      'parent' => 323,
    ),
    array(
      'tid' => 4587,
      'name' => "Arenediazoates",
      'description' => "Diazoethers which are N-substituted with an aryl group through a CN bond.",
      'parent' => 4586,
    ),
    array(
      'tid' => 4588,
      'name' => "Bis-arenediazo oxides",
      'description' => "Organonitrogen compounds with the general formula RN=NON=NR', where R and R' are aryl groups.",
      'parent' => 3633,
    ),
    array(
      'tid' => 4589,
      'name' => "Bis-arenediazo sulfides",
      'description' => "Organonitrogen compounds with the general formula RN=NON=NR', where R and R' are aryl groups.",
      'parent' => 3633,
    ),
    array(
      'tid' => 4590,
      'name' => "Arenediazo aryl sulfides",
      'description' => "Organonitrogen compounds  with the general formula RN=NSR', where R,R' are aryl groups.",
      'parent' => 3633,
    ),
    array(
      'tid' => 4591,
      'name' => "Trialkylaluminiums",
      'description' => "Organoaluminium compounds where the aluminium atom is substituted with three alkyl groups.",
      'parent' => 4568,
    ),
    array(
      'tid' => 4592,
      'name' => "Organozinc compounds",
      'description' => "Organometallic compounds that contain a chemical bond between a carbon atom and a zinc atom.",
      'parent' => 1371,
    ),
    array(
      'tid' => 4593,
      'name' => "Dialkylzincs",
      'description' => "Organozinc compounds containing a zinc atom that is disubstituted with alkyl groups. They have the general formula RZnR', where R and R' are alkyl groups.",
      'parent' => 4592,
    ),
    array(
      'tid' => 4594,
      'name' => "Organomagnesium halides",
      'description' => "Organomagnesium compounds with the formula RMgX, where R=organyl group, and X = halogen atom.",
      'parent' => 287,
    ),
    array(
      'tid' => 4595,
      'name' => "Alkylmagnesium halides",
      'description' => "Organomagnesium halides where the organyl group is an alkyl group.",
      'parent' => 4594,
    ),
    array(
      'tid' => 4596,
      'name' => "Arylmagnesium halides",
      'description' => "Organomagnesium halides where the organyl group is an aryl group.",
      'parent' => 4594,
    ),
    array(
      'tid' => 4597,
      'name' => "Dialkylmagnesiums",
      'description' => "Organomagnesium compounds where the magnesium atom is substituted with two alkyl groups. They have the general formula RMgR', where R and R' are alkyl groups.",
      'parent' => 287,
    ),
    array(
      'tid' => 4598,
      'name' => "Alkyl trialkyllead peroxides",
      'description' => "Alkylead compounds where the lead atom is substituted with three alkyl groups, and O-substituted with an alkyl peroxide. They have the general formula ROOPbR'3.",
      'parent' => 4065,
    ),
    array(
      'tid' => 4599,
      'name' => "3-cyanotriazenes",
      'description' => "Organonitrogen compounds with the general formula NN=NC#N.",
      'parent' => 3633,
    ),
    array(
      'tid' => 4600,
      'name' => "Aromatic 3-cyanotriazenes",
      'description' => "Organonitrogen compounds containing a 3-cyanotriazene moiety which is substituted at the terminal amine with an aromatic group.",
      'parent' => 4599,
    ),
    array(
      'tid' => 4601,
      'name' => "Dialkyl hyponitrites",
      'description' => "Organooxygen compounds with the general structure is RON=NOR', where R and R' are alkyl groups.",
      'parent' => 323,
    ),
    array(
      'tid' => 4602,
      'name' => "Diazonium perchlorates",
      'description' => "Organic perchlorate compounds with the general structure RN+2 ClO4-, where R is an organyl group.",
      'parent' => 2067,
    ),
    array(
      'tid' => 4603,
      'name' => "Organic oxygen compounds",
      'description' => "Organic compounds that contain one or more oxygen atoms.",
      'parent' => 0,
    ),
    array(
      'tid' => 4604,
      'name' => "Diazonium sulfates",
      'description' => "Organic mixtures of diazonium salts and sulfate salts. They have the general structure (RN+2 )2(SO4)2- , R'N+2 H(SO4)-, where R and R' are organyl groups.",
      'parent' => 3929,
    ),
    array(
      'tid' => 4605,
      'name' => "Diazonium tetrahaloborates",
      'description' => "Organic compounds containing a tetrahaloborate ion and a diazonium ion.",
      'parent' => 1668,
    ),
    array(
      'tid' => 4606,
      'name' => "Difluoroamino compounds",
      'description' => "Organonitrogen compounds containing an amine group substituted with two fluorine atoms, and an organyl group.",
      'parent' => 278,
    ),
    array(
      'tid' => 4607,
      'name' => "Fluorodinitromethyl compounds",
      'description' => "C-nitro compounds with the general structure F(O2N)2C-R.",
      'parent' => 4117,
    ),
    array(
      'tid' => 4608,
      'name' => "1,1-dinitrodifluoramines",
      'description' => "Difluoroamino compounds contaning two nitro groups and with the general structure RC(NO2)2NF2.",
      'parent' => 4606,
    ),
    array(
      'tid' => 4609,
      'name' => "Tris(ketoximino)silanes",
      'description' => "Organoheterosilanes with the general structure RSi(ON=CMeEt)3, where R is an organyl group.",
      'parent' => 4445,
    ),
    array(
      'tid' => 4610,
      'name' => "Metal p-nitrophenoxides",
      'description' => "Para-nitrophenoxide derivatives that are linked to a metal atom.",
      'parent' => 141,
    ),
    array(
      'tid' => 4611,
      'name' => "Metal thiocyanates",
      'description' => "Metal salts of thiocyanic acid.",
      'parent' => 1201,
    ),
    array(
      'tid' => 4612,
      'name' => "Nitroaromatic compounds",
      'description' => "C-nitro compounds where the nitro group is C-substituted with an aromatic group.",
      'parent' => 4117,
    ),
    array(
      'tid' => 4613,
      'name' => "Nitrobenzaldehydes",
      'description' => "Nitrobenzenes that carry an aldehyde group at any position of the benzene ring.",
      'parent' => 36,
    ),
    array(
      'tid' => 4614,
      'name' => "Organometallic peroxides",
      'description' => "Organic compounds that contain a peroxide group substituted with a an organometallic group.",
      'parent' => 462,
    ),
    array(
      'tid' => 4615,
      'name' => "Phenylboronic acids",
      'description' => "Aromatic compounds containing a monocyclic benzene ring that carries a boronic acid.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4616,
      'name' => "Aryl phosphates",
      'description' => "Organophosphorus compounds having a phosphate group substituted by one or more aryl groups.",
      'parent' => 408,
    ),
    array(
      'tid' => 4617,
      'name' => "Aryl phosphomonoesters",
      'description' => "Aryl phosphates in which the phosphate is monosubstituted.",
      'parent' => 4616,
    ),
    array(
      'tid' => 4618,
      'name' => "Aryl phosphodiesters",
      'description' => "Aryl phosphates in which the phosphate is esterified at exactly two positions.",
      'parent' => 4616,
    ),
    array(
      'tid' => 4619,
      'name' => "Aryl phosphotriesters",
      'description' => "Aryl phosphates in which the phosphate is esterified at exactly three positions.",
      'parent' => 4616,
    ),
    array(
      'tid' => 4620,
      'name' => "Branched alkanes",
      'description' => "Acyclic branched hydrocarbons having the general formula CnH2n+2.",
      'parent' => 2500,
    ),
    array(
      'tid' => 4621,
      'name' => "Branched cycloalkanes",
      'description' => "Acyclic unbranched hydrocarbons having the general formula CnH2n+2.",
      'parent' => 1016,
    ),
    array(
      'tid' => 4622,
      'name' => "Branched unsaturated hydrocarbons",
      'description' => "Hydrocarbons that contains one or more unsaturated carbon atoms, and an aliphatic branch.",
      'parent' => 4475,
    ),
    array(
      'tid' => 4623,
      'name' => "Aryl thiophosphates",
      'description' => "Organic compounds containing the thiophosphoric acid functional group or a derivative thereof, with the general structure ROP(OR')(OR'')=S, where at least one R-group is an aryl group.",
      'parent' => 1572,
    ),
    array(
      'tid' => 4624,
      'name' => "Pyridine-2-carboxylic acids",
      'description' => "Compounds containing a pyridine ring bearing a carboxylic acid group at the 2-position.",
      'parent' => 2414,
    ),
    array(
      'tid' => 4625,
      'name' => "Pyridine-3-carboxylic acids",
      'description' => "Compounds containing a pyridine ring bearing a carboxylic acid group at the 3-position.",
      'parent' => 2414,
    ),
    array(
      'tid' => 4626,
      'name' => "5-alkoxy-2-carboxypyrimidines",
      'description' => "Pyrimidine-2-carboxylic acids that carry an alkoxy substituent at the 5-position of the  pyridine ring.",
      'parent' => 4624,
    ),
    array(
      'tid' => 4627,
      'name' => "5-alkyl-2-carboxypyrimidines",
      'description' => "Pyrimidine-2-carboxylic acids that carry an alkyl group at the 5-position of the  pyridine ring.",
      'parent' => 4624,
    ),
    array(
      'tid' => 4628,
      'name' => "4-alkoxyphenols",
      'description' => "Phenols that carry an alkoxy group at the 4-position of the benzene ring.",
      'parent' => 134,
    ),
    array(
      'tid' => 4629,
      'name' => "Benzyl sulfoxides",
      'description' => "Organosulfur compounds that contain a sulfoxide group substituted by a benzyl group. They have the general structure RS(=O)R' ( R=benzyl, R'=organyl).",
      'parent' => 2279,
    ),
    array(
      'tid' => 4630,
      'name' => "Benzyl alkyl sulfoxides",
      'description' => "Organosulfur compounds that contain a sulfoxide group substituted by a benzyl group, and an alkyl group. They have the general structure RS(=O)R' ( R=benzyl, R'=alkyl).",
      'parent' => 4629,
    ),
    array(
      'tid' => 4631,
      'name' => "Aryl thioethers",
      'description' => "Organosulfur compounds containing a thioether group that is substituted by an aryl group.",
      'parent' => 1202,
    ),
    array(
      'tid' => 4632,
      'name' => "Phenyl sulfoxides",
      'description' => "Organosulfur compounds containing a sulfoxide group substituted with a phenyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4633,
      'name' => "1,2-allenyl phenyl sulfoxides",
      'description' => "Organosulfur compounds containing a sulfoxide group substituted with a phenyl group and a 1,2-allenyl group.",
      'parent' => 4632,
    ),
    array(
      'tid' => 4634,
      'name' => "Phenyl sulfides",
      'description' => "Organosulfur compounds containing a thioether group that is substituted by a phenyl group.",
      'parent' => 4631,
    ),
    array(
      'tid' => 4635,
      'name' => "Dibenzothiophene-5-oxides",
      'description' => "Organic aromatic compounds containing a dibenzothiophene disubstituted at the 5-position with a dioxide group.",
      'parent' => 2818,
    ),
    array(
      'tid' => 4636,
      'name' => "Dibenzothiophene-5,5-dioxides",
      'description' => "Organic aromatic compounds containing a dibenzothiophene disubstituted at the 5-position with two dioxide groups.",
      'parent' => 2818,
    ),
    array(
      'tid' => 4637,
      'name' => "Alkyl-2-thio-S-triazines",
      'description' => "Aromatic compounds containing a 1,3,5-triazine ring that is substituted at the 2-position with a S-alkyl group.",
      'parent' => 4105,
    ),
    array(
      'tid' => 4638,
      'name' => "Alkoxy-S-triazines",
      'description' => "Aromatic compounds containing a 1,3,5-triazine ring that is substituted at the 2-position with an alkoxy group.",
      'parent' => 4105,
    ),
    array(
      'tid' => 4639,
      'name' => "Halo-S-triazines",
      'description' => "Aromatic compounds containing a 1,3,5-triazine ring that is substituted at the 2-position with a halogen atom.",
      'parent' => 4105,
    ),
    array(
      'tid' => 4640,
      'name' => "Phenyl methylcarbamates",
      'description' => "Aromatic compounds containing a methylcarbamic acid esterified with a phenyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4641,
      'name' => "Alkylarsine oxides",
      'description' => "Hydrocarbyl derivatives of H3As=O, where the Arsenic atom is linked to one or more alkyl groups.",
      'parent' => 3986,
    ),
    array(
      'tid' => 4642,
      'name' => "Trialkylarsine oxides",
      'description' => "Hydrocarbyl derivatives of H3As=O, where the Arsenic atom is linked to three alkyl groups.",
      'parent' => 4641,
    ),
    array(
      'tid' => 4643,
      'name' => "Phenylacetic acid esters",
      'description' => "Ester derivatives o phenylacetic acids.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4644,
      'name' => "2(hydroxyphenyl)acetic acids",
      'description' => "Phenylacetic acids that carry a hydroxyl group at the 2-position.",
      'parent' => 418,
    ),
    array(
      'tid' => 4645,
      'name' => "3(hydroxyphenyl)acetic acids",
      'description' => "Phenylacetic acids that carry a hydroxyl group at the 3-position.",
      'parent' => 418,
    ),
    array(
      'tid' => 4646,
      'name' => "1-hydroxy-2-unsubstituted benzenoids",
      'description' => "Phenols that a unsubstituted at the 2-position.",
      'parent' => 134,
    ),
    array(
      'tid' => 4647,
      'name' => "1-hydroxy-4-unsubstituted benzenoids",
      'description' => "Phenols that are unsubstituted at the 4-position.",
      'parent' => 134,
    ),
    array(
      'tid' => 4648,
      'name' => "1-hydroxylamino, 2-unsubstituted benzenoids",
      'description' => "Benzenoids in which the benzene moiety is N-linked to an hydroxylamine at the 1-position, and unsubstituted at the 2-position.",
      'parent' => 2448,
    ),
    array(
      'tid' => 4649,
      'name' => "1-hydroxylamino, 4-unsubstituted benzenoids",
      'description' => "Benzenoids in which the benzene moiety is N-linked to an hydroxylamine at the 1-position, and unsubstituted at the 4-position.",
      'parent' => 2448,
    ),
    array(
      'tid' => 4650,
      'name' => "N-phenylhydroxylamines",
      'description' => "Hydroxylamines that are N-substituted with a phenyl group.",
      'parent' => 2448,
    ),
    array(
      'tid' => 4651,
      'name' => "O-phenylhydroxylamines",
      'description' => "Hydroxylamines that are O-substituted with a phenyl group.",
      'parent' => 2448,
    ),
    array(
      'tid' => 4652,
      'name' => "N-alkyl-O-phenylhydroxylamines",
      'description' => "Hydroxylamines that are O-substituted with a phenyl group, and N-substituted by an alkyl group.",
      'parent' => 4651,
    ),
    array(
      'tid' => 4653,
      'name' => "N-aryl-N-phenylhydroxylamines",
      'description' => "Hydroxylamines that are N,N-disubstituted by a phenyl and another aryl group.",
      'parent' => 4650,
    ),
    array(
      'tid' => 4654,
      'name' => "o-Aminophenols",
      'description' => "Phenols that are substituted with an amine group at the 2-position of the benzene ring.",
      'parent' => 140,
    ),
    array(
      'tid' => 4655,
      'name' => "m-Aminophenols",
      'description' => "Phenols that are substituted with an amine group at the 3-position of the benzene ring.",
      'parent' => 140,
    ),
    array(
      'tid' => 4656,
      'name' => "p-Aminophenols",
      'description' => "Phenols that are substituted with an amine group at the 4-position of the benzene ring.",
      'parent' => 140,
    ),
    array(
      'tid' => 4657,
      'name' => "5-unsubstituted pyrrogallols",
      'description' => "Pyrrogallols that are unsubstituted at th5-position of the benzene ring.",
      'parent' => 397,
    ),
    array(
      'tid' => 4658,
      'name' => "Isoindole organothiophosphates",
      'description' => "Aromatic compounds containing an isoindole, which is N-substituted by an organothiophosphate group. Their general structure is R-CSP(=S)(OR')OR'', where R=isoindole, R',R\" = any atom.",
      'parent' => 127,
    ),
    array(
      'tid' => 4659,
      'name' => "Benzo-1,2,3-triazines",
      'description' => "Organic compounds containing a 1,2,3-triazine ring fused to a benzene ring.",
      'parent' => 2,
    ),
    array(
      'tid' => 4660,
      'name' => "Benzotriazine organothiophosphates",
      'description' => "Aromatic compounds containing a benzo-1,2,3-triazine, which is substituted by an organothiophosphate group at the 3-position. Their general structure is R-CSP(=S)(OR')OR'', where R=benzo-1,2,3-triazine, R',R\" = any atom.",
      'parent' => 4659,
    ),
    array(
      'tid' => 4661,
      'name' => "Phosphorodithioic acid O-monoesters",
      'description' => "Organooxygen compounds that contain a phosphorodithioic acid, which is O-monosubstituted by an organyl group.",
      'parent' => 4164,
    ),
    array(
      'tid' => 4662,
      'name' => "Phosphorodithioic acid O,O-diesters",
      'description' => "Organooxygen compounds that contain a phosphorodithioic acid, which is O,O-disubstituted by an organyl group.",
      'parent' => 4164,
    ),
    array(
      'tid' => 4663,
      'name' => "Phosphoramidothioic acid S-esters",
      'description' => "Organooxygen compounds containing a S-ester derivative of phosphoroamidothioic acid. They have the general structure RSP(=O)(O)(NH2), where R is an organyl group.",
      'parent' => 1438,
    ),
    array(
      'tid' => 4664,
      'name' => "Phosphoramidothioic acid O-esters",
      'description' => "Organooxygen compounds containing a O-ester derivative of phosphoroamidothioic acid. They have the general structure ROP(=O)(S)(NH2), where R is an organyl group.",
      'parent' => 1438,
    ),
    array(
      'tid' => 4665,
      'name' => "Phosphoramidothioic-acid-O,S-diesters",
      'description' => "Organooxygen compounds containing a O,S-diester derivative of phosphoroamidothioic acid. They have the general structure RSP(=O)(OR')(NH2), where R,R' are organyl groups.",
      'parent' => 1438,
    ),
    array(
      'tid' => 4666,
      'name' => "N-acylphosphoramidothioic acid and derivatives",
      'description' => "Compounds containing phosphoramidothioic acid or a derivative thereof, which is N-acylated.",
      'parent' => 475,
    ),
    array(
      'tid' => 4667,
      'name' => "Nitroguanidines",
      'description' => "Organonitrogen compounds containing a nitro group, which is N-linked to a guanidine.",
      'parent' => 375,
    ),
    array(
      'tid' => 4668,
      'name' => "1,3,4-thiadiazol-2-ylureas",
      'description' => "Aromatic compounds containing a 1,3,4-thiadiazole ring, which is substituted at the 2-position with urea.",
      'parent' => 4001,
    ),
    array(
      'tid' => 4669,
      'name' => "Pyrimidinyloxybenzylamines",
      'description' => "Aromatic compounds containing a diarylether group substituted with a 3-phenylmethanamine and a pyrimidine.",
      'parent' => 2463,
    ),
    array(
      'tid' => 4670,
      'name' => "Aminophenyl ethers",
      'description' => "Aromatic compounds that contain a phenol ether, which carries an amine group on the benzene ring.",
      'parent' => 2341,
    ),
    array(
      'tid' => 4671,
      'name' => "Nitrophenyl ethers",
      'description' => "Aromatic compounds containing a nitrobenzene moiety that carries an ether group on the benzene ring.",
      'parent' => 36,
    ),
    array(
      'tid' => 4672,
      'name' => "Benzofuranyl 5-alkylsulfonates",
      'description' => "Polycyclic aromatic compounds that contain a benzofuran ring system, which is O-substituted at the 5-position with an alkylsulfonate group.",
      'parent' => 301,
    ),
    array(
      'tid' => 4673,
      'name' => "Benzoylcyclohexane-1,3-diones",
      'description' => "Alkyl-phenylketones where the alkyl group is a cyclohexane 1,3-dione.",
      'parent' => 4298,
    ),
    array(
      'tid' => 4674,
      'name' => "Aryloxyphenoxypropionic acids",
      'description' => "Aromatic compounds containing a phenoxypropionic acid that is para-substituted with an aryl group.",
      'parent' => 4676,
    ),
    array(
      'tid' => 4675,
      'name' => "Aryloxyphenoxypropionic acid esters",
      'description' => "Aromatic compounds containing a phenoxypropionic acid ester that is para-substituted with an aryl group.",
      'parent' => 4677,
    ),
    array(
      'tid' => 4676,
      'name' => "2-phenoxypropionic acids",
      'description' => "Aromatic compounds hat contain a phenol ether attached to the C2-atom of a phenylpropionic acid.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4677,
      'name' => "2-phenoxypropionic acid esters",
      'description' => "Aromatic compounds hat contain a phenol ether attached to the C2-atom of a phenylpropionic acid ester.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4678,
      'name' => "Alkyloxyphenoxypropionic acids",
      'description' => "Aromatic compounds containing a phenoxypropionic acid that is para-substituted with an alkyl group.",
      'parent' => 4676,
    ),
    array(
      'tid' => 4679,
      'name' => "Alkyloxyphenoxypropionic acid esters",
      'description' => "Aromatic compounds containing a phenoxypropionic acid ester that is para-substituted with an alkyl group.",
      'parent' => 4677,
    ),
    array(
      'tid' => 4680,
      'name' => "Hydroxybenzonitriles",
      'description' => "Aromatic containing a benzonitrile group moiety that carries an hydroxyl group on the benzene ring.",
      'parent' => 1530,
    ),
    array(
      'tid' => 4681,
      'name' => "1,2,4-triazolopyrimidine-2-sulfonamides",
      'description' => "Polycyclic aromatic compounds containing a 1,2,4-triazolo[1,5-a]pyrimidine ring system, which is substituted with a sulfonamide at the 2-position.",
      'parent' => 1443,
    ),
    array(
      'tid' => 4682,
      'name' => "1,2,4-triazolopyrimidine-2-sulfonanilides",
      'description' => "Polycyclic aromatic compounds containing a 1,2,4-triazolo[1,5-a]pyrimidine ring system, which is substituted with a sulfonanilide at the 2-position.",
      'parent' => 4681,
    ),
    array(
      'tid' => 4683,
      'name' => "Aryl 1,2,4-triazolones",
      'description' => "Aromatic heterocyclic compounds containing a 1,2,4-triazolone moiety that is substituted at the 5-position with an aryl group.",
      'parent' => 234,
    ),
    array(
      'tid' => 4684,
      'name' => "Diacylhydrazines",
      'description' => "Carboxylic acid hydrazides with the formula RC(=O)NNC(R')=O ( R,R'=H or organyl group).",
      'parent' => 1165,
    ),
    array(
      'tid' => 4685,
      'name' => "1,3-thiazole carboxanilides",
      'description' => "Aromatic heterocyclic compounds containing a 1,3-thiazolecarboxamide group, which is N-substituted with a phenyl group.",
      'parent' => 2008,
    ),
    array(
      'tid' => 4686,
      'name' => "Naphthalene-1-carboxanilides",
      'description' => "Naphthalene-1-carboxamides, where the carboxamide group is substituted with an aniline.",
      'parent' => 2349,
    ),
    array(
      'tid' => 4687,
      'name' => "Naphthalene-2-carboxanilides",
      'description' => "Naphthalene-2-carboxamides, where the carboxamide group is substituted with an aniline.",
      'parent' => 2349,
    ),
    array(
      'tid' => 4688,
      'name' => "1-hydroxynaphthalene-2-carboxanilides",
      'description' => "Naphthalene-2-carboxamides, where the carboxamide group is substituted with an aniline, and the naphthalene ring system is hydroxylated at the ring 1-position.",
      'parent' => 4687,
    ),
    array(
      'tid' => 4689,
      'name' => "8-hydroxynaphthalene-2-carboxanilides",
      'description' => "Naphthalene-2-carboxamides, where the carboxamide group is substituted with an aniline, and the naphthalene ring system is hydroxylated at the ring 8-position.",
      'parent' => 4687,
    ),
    array(
      'tid' => 4690,
      'name' => "6-hydroxynaphthalene-2-carboxanilides",
      'description' => "Naphthalene-2-carboxamides, where the carboxamide group is substituted with an aniline, and the naphthalene ring system is hydroxylated at the ring 6-position.",
      'parent' => 4687,
    ),
    array(
      'tid' => 4691,
      'name' => "Dioxoisoquinoline-4-carboxanilides",
      'description' => "1,3-isoquinolinediones that are substituted at the ring 4-position with a carboxanilide.",
      'parent' => 2932,
    ),
    array(
      'tid' => 4692,
      'name' => "1-benzothiophene-2-carboxanilides",
      'description' => "Aromatic heteropolycyclic compounds that contain a 1-benzothiophene ring system, which is substituted with an anilide at the 2-position.",
      'parent' => 4293,
    ),
    array(
      'tid' => 4693,
      'name' => "Isothiosemicarbazones",
      'description' => "Organosulfur compounds NC(SR)=NN=C(R')R\", where R,R',R\" = H or organyl group.",
      'parent' => 278,
    ),
    array(
      'tid' => 4694,
      'name' => "S-alkylisothiosemicarbazones",
      'description' => "S-alkylated derivatives of isothiosemicarbazones.",
      'parent' => 4693,
    ),
    array(
      'tid' => 4695,
      'name' => "1,4-dihydroxy-2-halobenzenoids",
      'description' => "Aromatic compounds containing a 1,-2-dihydroxybenzene moiety, which carries an halogen atom at the ring 2-position.",
      'parent' => 134,
    ),
    array(
      'tid' => 4696,
      'name' => "Phenyl phosphates",
      'description' => "Aromatic organooxygen compounds containing a phosphate group, which is O-esterified with a phenyl group.",
      'parent' => 4617,
    ),
    array(
      'tid' => 4697,
      'name' => "4-halophenylacetic acids",
      'description' => "Aromatic compounds containing a phenylacetic acid, which is para-substituted with a halogen atom.",
      'parent' => 418,
    ),
    array(
      'tid' => 4698,
      'name' => "N-silyl compounds",
      'description' => "Organosilicon compounds containing at least one silicon-nitrogen bond.",
      'parent' => 3194,
    ),
    array(
      'tid' => 4699,
      'name' => "m-Hydroxybenzoic acid esters",
      'description' => "Benzoic acid esters where the benzene ring is meta-substituted with a hydroxy group.",
      'parent' => 1350,
    ),
    array(
      'tid' => 4700,
      'name' => "o-Hydroxybenzoic acid esters",
      'description' => "Benzoic acid esters where the benzene ring is ortho-substituted with a hydroxy group.",
      'parent' => 1350,
    ),
    array(
      'tid' => 4701,
      'name' => "p-Hydroxybenzoic acid esters",
      'description' => "Benzoic acid esters where the benzene ring is para-substituted with a hydroxy group.",
      'parent' => 1350,
    ),
    array(
      'tid' => 4702,
      'name' => "p-Hydroxybenzoic acid alkyl esters",
      'description' => "Aromatic compounds containing a benzoic acid, which is esterified with an alkyl group and para-substituted with a hydroxyl group.",
      'parent' => 4701,
    ),
    array(
      'tid' => 4703,
      'name' => "Organic thiosulfinic acids",
      'description' => "Organic compounds containing a thiosulfinyl group (HS(S)OH). They have the general structure RS(=S)OH, where R = H or organyl.",
      'parent' => 264,
    ),
    array(
      'tid' => 4704,
      'name' => "Benzoylpyrazoles",
      'description' => "Aromatic compounds containing a benzoyl group substituted with a pyrazole ring.",
      'parent' => 321,
    ),
    array(
      'tid' => 4705,
      'name' => "Pyrimidinyl-2-sulfonylureas",
      'description' => "Aromatic heterocyclic compounds containing a pyrimidine ring which is substituted with a sulfonylurea at the ring 2-position.",
      'parent' => 490,
    ),
    array(
      'tid' => 4706,
      'name' => "S-triazinyl-2-sulfonylureas",
      'description' => "Aromatic heterocyclic compounds containing a s-triazine ring which is substituted with a urea at the ring 2-position.",
      'parent' => 490,
    ),
    array(
      'tid' => 4707,
      'name' => "Organic nitrogen compounds",
      'description' => "Organic compounds containing a nitrogen atom.",
      'parent' => 0,
    ),
    array(
      'tid' => 4708,
      'name' => "2-pyridylmethylamines",
      'description' => "Aromatic heterocyclic compounds contaning a pyridine ring which is substituted at the 2-position with a methylamine.",
      'parent' => 89,
    ),
    array(
      'tid' => 4709,
      'name' => "6-substituted-2-pyridinylmethylamines",
      'description' => "Aromatic heterocyclic compounds contaning a pyridine ring which is substituted at the 2-position with a methylamine, and at the 6-position with any non-hydrogen atom.",
      'parent' => 4708,
    ),
    array(
      'tid' => 4710,
      'name' => "2-benzimidazolylcarbamic acids",
      'description' => "Aromatic heteropolycyclic compounds that contain a carbamyl group N-linked to the C2-atom of a benzimidazole moiety.",
      'parent' => 294,
    ),
    array(
      'tid' => 4711,
      'name' => "2-benzimidazolylcarbamic acid esters",
      'description' => "Aromatic heteropolycyclic compounds that contain a carbamic acid ester group, which is N-linked to the C2-atom of a benzimidazole moiety.",
      'parent' => 294,
    ),
    array(
      'tid' => 4712,
      'name' => "Aromatic anilides",
      'description' => "Aromatic compounds containing an anilide group in which the carboxamide group is substituted with an aromatic group. They have the general structure RNC(=O)R', where R= benzene, and R = aryl group.",
      'parent' => 285,
    ),
    array(
      'tid' => 4713,
      'name' => "Benzanilides",
      'description' => "Aromatic compounds containing an anilide group in which the carboxamide group is substituted with a benzene ring. They have the general structure RNC(=O)R', where R,R'= benzene.",
      'parent' => 4712,
    ),
    array(
      'tid' => 4714,
      'name' => "Phenylcarbamic acid esters",
      'description' => "Ester derivatives of phenylcarbamic acids.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4715,
      'name' => "Hydrazinecarboxylic acid esters",
      'description' => "Ester derivatives of hydrazinecarboxylic acids.",
      'parent' => 3132,
    ),
    array(
      'tid' => 4716,
      'name' => "Haloacetanilides",
      'description' => "Organic compounds containing an acetamide group conjugated to a phenyl group, which is in turn substituted with one or more halogen atoms.",
      'parent' => 1846,
    ),
    array(
      'tid' => 4717,
      'name' => "M-haloacetanilides",
      'description' => "Organic compounds containing an acetamide group conjugated to a phenyl group, which is in turn meta-substituted with a halogen atom.",
      'parent' => 4716,
    ),
    array(
      'tid' => 4718,
      'name' => "O-haloacetanilides",
      'description' => "Organic compounds containing an acetamide group conjugated to a phenyl group, which is in turn ortho-substituted with a halogen atom.",
      'parent' => 4716,
    ),
    array(
      'tid' => 4719,
      'name' => "P-haloacetanilides",
      'description' => "Organic compounds containing an acetamide group conjugated to a phenyl group, which is in turn para-substituted with a halogen atom.",
      'parent' => 4716,
    ),
    array(
      'tid' => 4720,
      'name' => "N-acylcarbazoles",
      'description' => "Aromatic heteropolycyclic compounds containing a carbazole moiety, which is N-acylated.",
      'parent' => 210,
    ),
    array(
      'tid' => 4721,
      'name' => "Chloro-s-triazines",
      'description' => "Aromatic compounds containing a 1,3,5-triazine ring that is substituted at the 2-position with a chlorine atom.",
      'parent' => 4639,
    ),
    array(
      'tid' => 4722,
      'name' => "Cyclic dithiocarbamic acid esters",
      'description' => "Organosulfur cyclic compounds with the general formula R3SC(=S)N(R1)R2; R1-R2 =  H or organyl group, R3 = organyl. Here, the dithiocarbamyl group is part of a ring.",
      'parent' => 3936,
    ),
    array(
      'tid' => 4723,
      'name' => "Cyclohexene oximes",
      'description' => "Cyclic compounds containing a oxime group which is substituted with a cyclohexene ring.",
      'parent' => 411,
    ),
    array(
      'tid' => 4724,
      'name' => "Cyclopropylisoxazoles",
      'description' => "Aromatic heterocyclic compounds containing an isoxazole ring substituted at one or more positions with a cyclopropyl group.",
      'parent' => 81,
    ),
    array(
      'tid' => 4725,
      'name' => "3-cyclopropylisoxazoles",
      'description' => "Aromatic heterocyclic compounds containing an isoxazole ring substituted at the ring 3-position with a cyclopropyl group.",
      'parent' => 4724,
    ),
    array(
      'tid' => 4726,
      'name' => "4-cyclopropylisoxazoles",
      'description' => "Aromatic heterocyclic compounds containing an isoxazole ring substituted at the ring 4-position with a cyclopropyl group.",
      'parent' => 4724,
    ),
    array(
      'tid' => 4727,
      'name' => "5-cyclopropylisoxazoles",
      'description' => "Aromatic heterocyclic compounds containing an isoxazole ring substituted at the ring 5-position with a cyclopropyl group.",
      'parent' => 4724,
    ),
    array(
      'tid' => 4728,
      'name' => "Dichlorophenyl dicarboximides",
      'description' => "Aromatic compounds containing a dichlorobenzene group, which is N-linked to a dicarboximide group.",
      'parent' => 2564,
    ),
    array(
      'tid' => 4729,
      'name' => "Formamidines",
      'description' => "Amidines with the general structure Amidines with the general structure RN=CHN(R')R\", where R, R',and R\" are any atoms not part of an amide or a thioamide group.",
      'parent' => 7,
    ),
    array(
      'tid' => 4730,
      'name' => "Formamidine disulfides",
      'description' => "Organonitrogen compounds containing the compound H2NC(=NH)SSC(=NH)NH2 and its derivatives formed by substitution at nitrogen.",
      'parent' => 2800,
    ),
    array(
      'tid' => 4731,
      'name' => "2-methoxy-1,3,5-triazines",
      'description' => "Aromatic heterocyclic compounds containing a 1,3,5-triazine ring, which is substituted at the 2-position with a methoxy group.",
      'parent' => 4638,
    ),
    array(
      'tid' => 4732,
      'name' => "4-methoxy-1,2,3-triazines",
      'description' => "Aromatic heterocyclic compounds containing a 1,2,3-triazine ring, which is substituted at the 4-position with a methoxy group.",
      'parent' => 4106,
    ),
    array(
      'tid' => 4733,
      'name' => "2-benzylamino-s-triazines",
      'description' => "Aromatic heterocyclic compounds containing a S-triazine ring, which is N-substituted at the 2-position with a benzylamine.",
      'parent' => 3080,
    ),
    array(
      'tid' => 4734,
      'name' => "1,3,5-triazine-2,4-diamines",
      'description' => "Aromatic compounds containing a 1,3,5-triazine ring which is 2,4-disusbtituted wit amine groups.",
      'parent' => 1693,
    ),
    array(
      'tid' => 4735,
      'name' => "Methylthio-s-triazines",
      'description' => "Aromatic compounds containing a 1,3,5-triazine ring that is substituted at the 2-position with a methylthio group.",
      'parent' => 4105,
    ),
    array(
      'tid' => 4736,
      'name' => "Oxadiazines",
      'description' => "Heterocyclic compounds containing an oxadiazine ring, which is an unsaturated six-membered heterocycle that consists of one oxygen 2 nitrogen, and 3 carbon atoms.",
      'parent' => 2,
    ),
    array(
      'tid' => 4737,
      'name' => "1,2,3-oxadiazines",
      'description' => "Heterocyclic compounds containig an oxadiazine ring with one oxygen atom at the 1-position, and two nitrogen atoms at the 2-, and 3-position, respectively.",
      'parent' => 4736,
    ),
    array(
      'tid' => 4738,
      'name' => "1,2,4-oxadiazines",
      'description' => "Heterocyclic compounds containig an oxadiazine ring with one oxygen atom at the 1-position, and two nitrogen atoms at the 2-, and 4-position, respectively.",
      'parent' => 4736,
    ),
    array(
      'tid' => 4739,
      'name' => "1,2,5-oxadiazines",
      'description' => "Heterocyclic compounds containig an oxadiazine ring with one oxygen atom at the 1-position, and two nitrogen atoms at the 2-, and 5-position, respectively.",
      'parent' => 4736,
    ),
    array(
      'tid' => 4740,
      'name' => "1,3,4-oxadiazines",
      'description' => "Heterocyclic compounds containig an oxadiazine ring with one oxygen atom at the 1-position, and two nitrogen atoms at the 3-, and 4-position, respectively.",
      'parent' => 4736,
    ),
    array(
      'tid' => 4741,
      'name' => "1,3,5-oxadiazines",
      'description' => "Heterocyclic compounds containig an oxadiazine ring with one oxygen atom at the 1-position, and two nitrogen atoms at the 3-, and 5-position, respectively.",
      'parent' => 4736,
    ),
    array(
      'tid' => 4742,
      'name' => "Phenoxy compounds",
      'description' => "Aromatic compounds contaning a phenoxy group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4743,
      'name' => "3-phenoxypropionic acids",
      'description' => "Aromatic compounds containing a 3-phenoxypropionic acid.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4744,
      'name' => "Phenylenediamines",
      'description' => "Aromatic compound containing a benzene ring which carries 2 amino groups.",
      'parent' => 284,
    ),
    array(
      'tid' => 4745,
      'name' => "M-phenylenediamines",
      'description' => "Aromatic compound containing a benzene ring which carries 2 amino groups, at the 1- and 3-positions.",
      'parent' => 4744,
    ),
    array(
      'tid' => 4746,
      'name' => "O-phenylenediamines",
      'description' => "Aromatic compound containing a benzene ring which carries 2 amino groups, at the 1- and 2-positions.",
      'parent' => 4744,
    ),
    array(
      'tid' => 4747,
      'name' => "P-phenylenediamines",
      'description' => "Aromatic compound containing a benzene ring which carries 2 amino groups, at the 1- and 4-positions.",
      'parent' => 4744,
    ),
    array(
      'tid' => 4748,
      'name' => "Phenyl thiophosphates",
      'description' => "Organothiophosphorus compounds that contain a thiophosphoric acid O-esterified with a phenyl group.",
      'parent' => 4623,
    ),
    array(
      'tid' => 4749,
      'name' => "Phthalimides",
      'description' => "Aromatic heterocyclic compounds containing a 1,3-dioxoisoindoline moiety. They are imide derivatives of phthalic anhydrides.",
      'parent' => 1820,
    ),
    array(
      'tid' => 4750,
      'name' => "2-pyrimidinylthiobenzoic acids",
      'description' => "Benzoic acids that carry a 2-thiopyrimidine at the 2-position of the benzene ring.",
      'parent' => 2565,
    ),
    array(
      'tid' => 4751,
      'name' => "Cyclic sulfite esters",
      'description' => "Organic compounds containing a sulfite ester group as part of a ring.",
      'parent' => 2074,
    ),
    array(
      'tid' => 4752,
      'name' => "Oxime carbamates",
      'description' => "Oxime ether derivatives with the general formula CC(R)=NOC(=O)N(R')R\", where R-R\" = H or organyl.",
      'parent' => 278,
    ),
    array(
      'tid' => 4753,
      'name' => "Aldoxime carbamates",
      'description' => "Oxime ether derivatives with the general formula CC(R)=NOC(=O)N(R')R\", where R=H, and R',R\" = H or organyl.",
      'parent' => 4752,
    ),
    array(
      'tid' => 4754,
      'name' => "Ketoxime carbamates",
      'description' => "Oxime ether derivatives with the general formula CC(R)=NOC(=O)N(R')R\", where R=organyl, and R',R\" = H or organyl.",
      'parent' => 4752,
    ),
    array(
      'tid' => 4755,
      'name' => "Furanilides",
      'description' => "Aromatic anilides with the general structure RC(=O)N(R')R\", where R=furan, and R\"=benzene.",
      'parent' => 4712,
    ),
    array(
      'tid' => 4756,
      'name' => "2-furanilides",
      'description' => "Aromatic heterocyclic compounds contaning a furan ring that is substituted at the 2-position with an anilide.",
      'parent' => 4755,
    ),
    array(
      'tid' => 4757,
      'name' => "3-furanilides",
      'description' => "Aromatic heterocyclic compounds contaning a furan ring that is substituted at the 3-position with an anilide.",
      'parent' => 4755,
    ),
    array(
      'tid' => 4758,
      'name' => "Furoic acid and derivatives",
      'description' => "Aromatic heterocyclic compounds containing a furan ring, which carries a carboxyl group or a derivative thereof.",
      'parent' => 76,
    ),
    array(
      'tid' => 4759,
      'name' => "Furan-3-carboxylic acid and derivatives",
      'description' => "Aromatic heterocyclic compounds containing a furan ring, which carries a carboxyl group or a derivative thereof at the ring 3-position.",
      'parent' => 4758,
    ),
    array(
      'tid' => 4760,
      'name' => "Furan-3-carboxylic acids",
      'description' => "Aromatic heterocyclic compounds containing a furan ring, which carries a carboxyl group at the ring 3-position.",
      'parent' => 4759,
    ),
    array(
      'tid' => 4761,
      'name' => "Furan-3-carboxylic acid amides",
      'description' => "Aromatic heterocyclic compounds containing a furan ring, which carries a carboxamide at the ring 3-position.",
      'parent' => 4759,
    ),
    array(
      'tid' => 4762,
      'name' => "Furan-3-carboxylic acid esters",
      'description' => "Aromatic heterocyclic compounds containing a furan ring, which carries a carboxylic ester at the ring 3-position.",
      'parent' => 4759,
    ),
    array(
      'tid' => 4763,
      'name' => "Precocenes",
      'description' => "Aromatic heteropolycyclic compounds that contain a 2,2-dimethyl-1-benzopyran moiety, which carries a methoxy group at the ring 7-position.",
      'parent' => 3522,
    ),
    array(
      'tid' => 4764,
      'name' => "7-benzofuranyl methylcarbamates",
      'description' => "Aromatic heteropolycyclic compounds containing a 1-benzofuran moiety, that is O-substituted with a N-methylcarbamate at the 7-position.",
      'parent' => 301,
    ),
    array(
      'tid' => 4765,
      'name' => "Oxime organothiophosphates",
      'description' => "Organic compounds containing an oxime group, which is O-substituted with a thiophosphoric acid ester.",
      'parent' => 278,
    ),
    array(
      'tid' => 4766,
      'name' => "Phenylphosphonothioates",
      'description' => "Aromatic compound contaning a phosphonothioate, which is C-substituted with a phenyl group.",
      'parent' => 2279,
    ),
    array(
      'tid' => 4767,
      'name' => "Phenyl phenylphosphonothioates",
      'description' => "Aromatic compounds containing a phenylphosphonothioate group, which is O-esterified with another phenyl group. They have the general structure OP(R)(=S)OR', where R,R'=phenyl groups.",
      'parent' => 4766,
    ),
    array(
      'tid' => 4768,
      'name' => "Cyanoacrylates",
      'description' => "Organonitrogen compounds containing an acrylic acid ester, which carries a nitrile group. They have the general structure ROC(=O)C(=C)C#N, where R is an organic group.",
      'parent' => 3626,
    ),
    array(
      'tid' => 4769,
      'name' => "Phenyl ethylphosphonothioates",
      'description' => "Aromatic compounds containing a phenylphosphonothioate group, which is O-esterified with an ethyl group. They have the general structure OP(R)(=S)OR', where R=phenyl group, R' = ethyl group.",
      'parent' => 4766,
    ),
    array(
      'tid' => 4770,
      'name' => "1,3,4-thiadiazol-3-yl-organothiophosphates",
      'description' => "Aromatic heterocyclic compounds containing a 1,3,4-thiadiazole ring, which is substituted at the 2-position with an organothiophosphate group.",
      'parent' => 93,
    ),
    array(
      'tid' => 4771,
      'name' => "Pyrimidinyl phosphorothioates",
      'description' => "Organic compounds containing the thiophosphoric acid functional group or a derivative thereof, with the general structure ROP(OR')(OR'')=S, where R= pyrimidine, R' = organyl group , and R\" = any atom.",
      'parent' => 4623,
    ),
    array(
      'tid' => 4772,
      'name' => "2-methoxychromones",
      'description' => "Aromatic heteropolycyclic compounds containing a chromone ring system, which carries a methoxy group at the 2-position.",
      'parent' => 144,
    ),
    array(
      'tid' => 4773,
      'name' => "3-methoxychromones",
      'description' => "Aromatic heteropolycyclic compounds containing a chromone ring system, which carries a methoxy group at the 3-position.",
      'parent' => 144,
    ),
    array(
      'tid' => 4774,
      'name' => "Chromeno[2,3-b]pyridines",
      'description' => "Aromatic heteropolycyclic compounds containing pyridine linearly fused to the pyran moiety of a benzofuran ring system.",
      'parent' => 2339,
    ),
    array(
      'tid' => 4775,
      'name' => "Chromeno[2,3-b]pyridine-5-ones",
      'description' => "Compounds containing a Chromeno[2,3-b]pyridine moiety that carries an oxo group at the 5-position.",
      'parent' => 144,
    ),
    array(
      'tid' => 4776,
      'name' => "Organic nitroso compounds",
      'description' => "Organic compounds having the nitroso group, -NO, attached to carbon, or to another element, most commonly nitrogen or oxygen.",
      'parent' => 278,
    ),
    array(
      'tid' => 4777,
      'name' => "Organic N-nitroso compounds",
      'description' => "Organic compounds containing a n-nitroso group -NN=O.",
      'parent' => 4776,
    ),
    array(
      'tid' => 4778,
      'name' => "Organic O-nitroso compounds",
      'description' => "Organic compounds containing a n-nitroso group -ON=O.",
      'parent' => 4776,
    ),
    array(
      'tid' => 4779,
      'name' => "Organic S-nitroso compounds",
      'description' => "Organic compounds containing a n-nitroso group -SN=O.",
      'parent' => 4776,
    ),
    array(
      'tid' => 4780,
      'name' => "Organic thionitrous acids",
      'description' => "Organic compounds containing a thionitrous acid, -HSN=O.",
      'parent' => 4779,
    ),
    array(
      'tid' => 4781,
      'name' => "Acyl phosphates",
      'description' => "Organic compounds containing a phosphate linked to an acyl group. They have the general structure  R-CO-P(O)(O)O, R=H or organyl.",
      'parent' => 408,
    ),
    array(
      'tid' => 4782,
      'name' => "Trialkylglycerols",
      'description' => "Triradylglycerols that carry three chains attached to the glycerol moiety through ether linkages.",
      'parent' => 3815,
    ),
    array(
      'tid' => 4783,
      'name' => "Episulfones",
      'description' => "Sulfone derivatives containing the thiirane-1, 1-dione moiety.",
      'parent' => 505,
    ),
    array(
      'tid' => 4784,
      'name' => "Methoxylated amphetamines",
      'description' => "Compounds containing an amphetamine moiety, where the benzene ring is O-methylated.",
      'parent' => 188,
    ),
    array(
      'tid' => 4785,
      'name' => "Sulfonated stilbenes",
      'description' => "Stilbenes that carry a sulfone group at one or more positions of either benzene rings.",
      'parent' => 253,
    ),
    array(
      'tid' => 4786,
      'name' => "N-acylimidazoles",
      'description' => "Compounds containing an imidazole ring, which is N-substituted by an acyl group.",
      'parent' => 2311,
    ),
    array(
      'tid' => 4787,
      'name' => "Methylcarbamates",
      'description' => "Methyl esters of carbamic acid.",
      'parent' => 1162,
    ),
    array(
      'tid' => 4788,
      'name' => "Diazanaphthalenes",
      'description' => "Aromatic heterocyclic chemical compounds containing a naphthalene derivative, where two carbon atoms are replaced by nitrogen atoms. They are subdivided in benzodiazines and naphthyridines.",
      'parent' => 2,
    ),
    array(
      'tid' => 4789,
      'name' => "Benzodiazines",
      'description' => "Aromatic heterocyclic compounds containing a benzene ring fused to a diazine ring. The diazine ring is an analogue of benzene, where two carbon atoms are replaced by nitrogen atoms.",
      'parent' => 4788,
    ),
    array(
      'tid' => 4790,
      'name' => "Thiuram monosulfides",
      'description' => "Organic disulfides that have the general structural formula RN(R')C(=S)SCC(=S)N(R\")R\"', where R-R\"'=alkyl groups.",
      'parent' => 3936,
    ),
    array(
      'tid' => 4791,
      'name' => "Thiuram disulfides",
      'description' => "Organic disulfides that have the general structural formula RN(R')C(=S)SSC(=S)N(R\")R\"', where R-R\"'=alkyl groups.",
      'parent' => 2452,
    ),
    array(
      'tid' => 4792,
      'name' => "Furanonaphthodioxoles",
      'description' => "Aromatic heterocyclic compounds containing a 1,3-dioxole ring linearly fused to the a naphthofuran.",
      'parent' => 1634,
    ),
    array(
      'tid' => 4793,
      'name' => "Dithiophosphate S,S-diesters",
      'description' => "Organic compound containing a S,S-diester derivative of dithiophosphoric acid.",
      'parent' => 3385,
    ),
    array(
      'tid' => 4794,
      'name' => "Chloronaphthalenes",
      'description' => "Aromatic heterocyclic compounds containing a naphthalene moiety substituted at one or more positions by a chlorine atom.",
      'parent' => 23,
    ),
    array(
      'tid' => 4795,
      'name' => "CDP-ethanolamines",
      'description' => "Phosphoethanolamines that consist of an ethanolamine having a cytidine 5'-diphosphate moiety attached to the oxygen.",
      'parent' => 1621,
    ),
    array(
      'tid' => 4796,
      'name' => "Phenylisopropylamines",
      'description' => "Organic aromatic compounds containing a 1-phenylpropan-2-amine moiety.",
      'parent' => 3924,
    ),
    array(
      'tid' => 4797,
      'name' => "Methoxyphenylisopropylamines",
      'description' => "Organic aromatic compounds containing a 1-phenylpropan-2-amine substituted at one or more ring position with a methoxy group.",
      'parent' => 4796,
    ),
    array(
      'tid' => 4798,
      'name' => "1,3-oxazolobenzo-1,4-diazepines",
      'description' => "Aromatic heteropolycyclic compounds containing a 1,3-oxazole ring fused to the 1,-4-diazepine moiety of a 1,4-benzodiazepine ring system.",
      'parent' => 4097,
    ),
    array(
      'tid' => 4799,
      'name' => "2',5'-dideoxyribonucleosides",
      'description' => "Nucleosides characterized by a purine or pyrimidine base, which is N-linked to a 2',5'-dideoxyribose moiety.",
      'parent' => 289,
    ),
    array(
      'tid' => 4800,
      'name' => "5'-S-alkylthio-5'-deoxyribonucleosides",
      'description' => "A 5'-deoxyribonucleoside where  the 5'-hydroxy group of the sugar moiety is substituted by a methylsulfanyl group.",
      'parent' => 4503,
    ),
    array(
      'tid' => 4801,
      'name' => "5'-azido-5'-deoxyribonucleosides",
      'description' => "A 5'-deoxyribonucleoside where the 5'-hydroxy group of the sugar moiety is substituted by a methylsulfanyl group.",
      'parent' => 4502,
    ),
    array(
      'tid' => 4802,
      'name' => "2-benzylaminopyridines",
      'description' => "Aromatic compounds containing pyridine ring substituted at the 2-position by a benzylamine group.",
      'parent' => 2673,
    ),
    array(
      'tid' => 4803,
      'name' => "Organic dichromates",
      'description' => "Organic compounds containing a dichromate moiety.",
      'parent' => 463,
    ),
    array(
      'tid' => 4804,
      'name' => "Benzotropolones",
      'description' => "Organic aromatic polycyclic compounds containing a benzene ring fused to a tropolone.",
      'parent' => 1674,
    ),
    array(
      'tid' => 4805,
      'name' => "Furoic acid esters",
      'description' => "Ester derivatives of furoic acid.",
      'parent' => 4758,
    ),
    array(
      'tid' => 4806,
      'name' => "Alkoxides",
      'description' => "Organooxygen compounds with the general structure RO-, where R is an alkyl group.",
      'parent' => 323,
    ),
    array(
      'tid' => 4807,
      'name' => "Methoxides",
      'description' => "Compounds containing a methoxide group with the formula H3CO-.",
      'parent' => 4806,
    ),
    array(
      'tid' => 4808,
      'name' => "Alpha-haloketones",
      'description' => "Organic compounds contaning a halogen atom attached to the alpha carbon atom relative to C=O group.",
      'parent' => 118,
    ),
    array(
      'tid' => 4809,
      'name' => "Alpha-chloroketones",
      'description' => "Organic compounds contaning a chlorine atom attached to the alpha carbon atom relative to C=O group.",
      'parent' => 4808,
    ),
    array(
      'tid' => 4810,
      'name' => "Indole-3-carbinol and derivatives",
      'description' => "Compounds containing an indole ring system, which is substituted at the 3-position with a methanol.",
      'parent' => 4196,
    ),
    array(
      'tid' => 4811,
      'name' => "2,5-disubstituted morpholines",
      'description' => "Organic compounds containing a morpholine ring, which is substituted at the 2- and 5-positions.",
      'parent' => 392,
    ),
    array(
      'tid' => 4812,
      'name' => "Acenaphthylenes",
      'description' => "Aromatic polycyclic compounds containing an acenaphthylene moiety. Acenaphthylene is a carbotricyclic compound, consisting of a naphthalene with positions C1 and C8 connected by an ethylene bridge.",
      'parent' => 2448,
    ),
    array(
      'tid' => 4813,
      'name' => "Ecdysteroids",
      'description' => "Polyhydroxylated oxosteroids possessing a cyclopentano-perhydro-phenantrene with beta side-chain at C-17, which is the product of terpene biosynthesis through mevalonic acid, cholesterol and related sterols. Ecdysteroids are found in certain plants and animals.",
      'parent' => 258,
    ),
    array(
      'tid' => 4814,
      'name' => "Punaglandins and related compounds",
      'description' => "Cyclopentadienone and cyclopentenone prostaglandins, which are chlorinated at the endocyclic R-carbon position.",
      'parent' => 514,
    ),
    array(
      'tid' => 4815,
      'name' => "Fluoromethoxy benzamides",
      'description' => "Organic compounds containing a benzamide, which is substituted by a fluoromethoxy group.",
      'parent' => 178,
    ),
    array(
      'tid' => 4816,
      'name' => "N'-substituted-N,N'-diacylhydrazines",
      'description' => "Hydrazine derivatives where the hydrazine group is N-acylated at both nitrogen atoms, only one of which is substituted.",
      'parent' => 4684,
    ),
    array(
      'tid' => 4817,
      'name' => "2-heteroaryl carboxamides",
      'description' => "Compounds containing a heteroaromatic ring that carries a carboxamide group.",
      'parent' => 475,
    ),
    array(
      'tid' => 4818,
      'name' => "B-type proanthocyanidins",
      'description' => "Proanthocyanidins, which are characterized by the presence of two or more flavonoid units linked to each other only by either one 4->6, one 4->8, or one 8->8 CC-bond.",
      'parent' => 379,
    ),
    array(
      'tid' => 4819,
      'name' => "Inorganic chromium trioxides",
      'description' => "Inorganic compounds containing a chromium trioxide moiety.",
      'parent' => 1568,
    ),
    array(
      'tid' => 4820,
      'name' => "Organic chromium trioxides",
      'description' => "Organic compounds containing a chromium trioxide moiety.",
      'parent' => 463,
    ),
    array(
      'tid' => 4821,
      'name' => "C8-prenylated coumarins",
      'description' => "Aromatic compounds containing a coumarin skeleton, which is substituted by a prenyl group at the C8-position.",
      'parent' => 145,
    ),
    array(
      'tid' => 4822,
      'name' => "4-hydroxy-6,7-benzomorphans",
      'description' => "Aromatic heteropolycyclic compounds containing a 6,7-benzomorphan skeleton, which is hydroxylated at the ring 4-position.",
      'parent' => 4131,
    ),
    array(
      'tid' => 4823,
      'name' => "2,6-dimethyl-3-benzazocines",
      'description' => "Aromatic compounds containing a 6,7-benzomorphan skeleton, which is substituted by methyl group at the 2- and 6-positions.",
      'parent' => 4131,
    ),
    array(
      'tid' => 4824,
      'name' => "4-azaandrostanes",
      'description' => "Azasteroids that are characterized by an androstane skeleton, where the carbon atom at the 4-position has been replaced by a nitrogen atom.",
      'parent' => 3056,
    ),
    array(
      'tid' => 4825,
      'name' => "Pyridinolates",
      'description' => "Aromatic compounds similar to phenoxide, with the difference that one carbo atom of the benzene ring is replaced by a nitrogen compound.",
      'parent' => 89,
    ),
    array(
      'tid' => 4826,
      'name' => "Selenenic acids",
      'description' => "Aromatic compounds containing a moiety of the generic structure RSeOH, where R is an organic group.",
      'parent' => 264,
    ),
    array(
      'tid' => 4827,
      'name' => "1,2,4-triazolo[3,4-a]phthalazines",
      'description' => "Aromatic heteropolycyclic compounds containing a 1,2,4-triazole fused to and sharing a nitrogen atom with the diazine ring of a phthalazine moiety.",
      'parent' => 207,
    ),
    array(
      'tid' => 4828,
      'name' => "A-type proanthocyanidins",
      'description' => "Proanthocyanidins, which are characterized by the presence of two or more flavonoid units linked to each other by both a 2->7 and a 4->b (or 4->8) interflavonoid CC-bonds.",
      'parent' => 379,
    ),
    array(
      'tid' => 4829,
      'name' => "C-type proanthocyanidins",
      'description' => "Proanthocyanidins, which are characterized by the presence of three or more flavonoid units linked to each other by exactly 4->8 interflavonoid CC-bonds.",
      'parent' => 379,
    ),
    array(
      'tid' => 4830,
      'name' => "Dipeptides",
      'description' => "Organic compounds containing a sequence of exactly two alpha-amino acids joined by a peptide bond.",
      'parent' => 348,
    ),
    array(
      'tid' => 4831,
      'name' => "Oligopeptides",
      'description' => "Organic compounds containing a sequence of between three and ten alpha-amino acids joined by peptide bonds.",
      'parent' => 348,
    ),
  );
  return $chemical_list;
}
